(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1004894,      32450]
NotebookOptionsPosition[    919749,      29868]
NotebookOutlinePosition[    941997,      30608]
CellTagsIndexPosition[    936403,      30424]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["TARCER 1.995", "Title",
 TextAlignment->Center,
 CellTags->"T1.1"],

Cell[TextData[{
 "A ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " program for the reduction of two-loop propagator integrals "
}], "Text",
 TextAlignment->Center],

Cell[TextData[{
 "Rolf Mertig\n",
 ButtonBox["Mertig Research & Consulting\n",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mertig.com"], None}],
 "and\nRainer Scharf\n",
 ButtonBox["Universit\[ADoubleDot]t Leipzig",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.physik.uni-leipzig.de/~scharf/"], None}]
}], "Text",
 Editable->False,
 TextAlignment->Center,
 CellTags->"T1.2"],

Cell["14th March, 2004", "Text",
 TextAlignment->Center],

Cell[TextData[{
 "COMMENTS (RM 9.12.2010) evaluated this notebook with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 8 under Linux 64bit."
}], "Text",
 CellChangeTimes->{{3.500884683171582*^9, 3.500884724165517*^9}}],

Cell["\<\
COMMENTS (RM 14.3..2004) uncommented a global variable assignement.changed \
default setting of $RankLimit to {2,5}.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 31.10.2003) Change default settings of TarcerExpand, modify \
$BasisIntegras for massless integrals,
changed default setting of $RankLimit to {1,6}.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 28.10.2003) Fixed a bug in TarcerExpand (only introduced \
recently),
changed default setting of $RankLimit to {1,5}.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 24.9.2003) Relaxed a condition in equation (61) and (6153)\
\>", "Text"],

Cell["\<\
COMMENTS (RM 18.9.2003): Fixed things for 5.0, eliminated a TVI symmetry \
(causing infinite recursion) and added
TFI decomposition into products of TAI's (was somehow missing but shows up \
in, e.g., the 2-loop Higss selfenergy).
Putting TFI back into the Tarcer context, because the fcloops context created \
trouble ...
Changed default of $Comment to False.\
\>", "Text"],

Cell["\<\
COMMENTS (FO 8.9.2002.): Changed context of TFI to \
HighEnergyPhysics`fcloops`TFI` and updated other HighEnergyPhysics`* contexts.\
\>", "Text"],

Cell["\<\
COMMENTS (FO 15.3.2001.): Changed PreFactor into Prefactor1 to avoid conflict \
with FeynArts and FeynCalc.\
\>", "Text"],

Cell["\<\
COMMENTS (FO 15.3.2001.): Changed context of Zeta2 and made definition \
dependent on not having loaded FeynCalc.\
\>", "Text"],

Cell[TextData[{
 "COMMENTS (RM 25.4.): ",
 ButtonBox["TFISimplify",
  BaseStyle->"Hyperlink",
  ButtonData:>"T1.7.1.1"],
 " (like TFIRecurse, but without trule[9])."
}], "Text"],

Cell[TextData[{
 "COMMENTS (RM 23.4.): bug fixed in ",
 ButtonBox["tlrule[17]",
  BaseStyle->"Hyperlink",
  ButtonData:>"tlrule17"],
 "."
}], "Text"],

Cell[TextData[{
 "COMMENTS (RM 6.4.):  ",
 ButtonBox["special TVR relations",
  BaseStyle->"Hyperlink",
  ButtonData:>"specialTVR"],
 " added to TVR."
}], "Text"],

Cell[TextData[{
 "COMMENTS (RM 22.3.):  ",
 ButtonBox["TVI Symmetry",
  BaseStyle->"Hyperlink",
  ButtonData:>"Tsymmetry"],
 " added to TVR."
}], "Text"],

Cell[TextData[{
 "COMMENTS (RM 18.3.): More rules added to ",
 ButtonBox["$TTable",
  BaseStyle->"Hyperlink",
  ButtonData:>"$TTable"],
 ". "
}], "Text"],

Cell[TextData[{
 "COMMENTS (RM 18.2.): More rules added to ",
 ButtonBox["$TTable",
  BaseStyle->"Hyperlink",
  ButtonData:>"$TTable"],
 ". "
}], "Text"],

Cell[TextData[{
 "COMMENTS (RM 21.2.): Included ",
 ButtonBox["$TTable",
  BaseStyle->"Hyperlink",
  ButtonData:>"$TTable"],
 ". added tlrule[25]"
}], "Text"],

Cell["\<\
COMMENTS (RM 20.2.): $RankLimit = {0,6} ;  Changed TarcerRecurse such that \
special TJR and TVR (reducing D -> D-2) are used first.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 15.2.): $RankLimit = {0,8} ;  
                                              The following test now works:
                                              
                                                 Print[\"test 1 :  TFI[D, pp, \
{0, 0, 0, 1, 3}, {{1, MW}, {1, MZ}, {0, 0}, {1, MZ}, {1,MW}}] = \",
                                                            Timing[t1 \
=TarcerRecurse[TFI[D, pp, {0, 0, 0, 1, 3}, {{1, MW}, {1, MZ}, {0, 0}, {1, \
MZ}, {1,MW}}]]
                                                                       ] // \
InputForm
                                                         ]

                                                  Print[\"test 2 :  TFI[d, \
pp, 0, {0, 0, 0, 0, 4},{{1, m1}, {1, m2}, 0, 0, 0}] = \",
                                                           Timing[t2 \
=TarcerRecurse[TFI[D, pp,  0, {0, 0, 0, 0, 4},{{1, m1}, {1, m2}, 0, 0, 0}]];
                                                                       ] // \
InputForm
                                                          ]
\
\>", "Text"],

Cell["\<\
COMMENTS (RM 13.2.): tlrule[11] and trule[12] made more restrictive: \
inhibiting thus a recursion if {n5,m5} equals {0,0}.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 12.2.): tlrule[15] made safer (in order to not get   0 :> 0 );
                                             TFIRecurse made safer (to not \
get into a recursion);
                                                  There is still something \
wrong with the tlrule's ; since 
                                         TFIRecurse[TFI[D, pp, {0, 0, 0, 1, \
3}, {{1, MW}, {1, MZ}, {0, 0}, {1, MZ}, {1,   MW}}]]
                                         doesn't work ..\
\>", "Text"],

Cell["\<\
COMMENTS (RM 5.2.): tlrule[10] slightly changed to cover more cases.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 2.2.):  FunctionExpand added in tlrule[9]. Option TimeConstraint \
added to TarcerRecurse (because TimeConstrained is buggy under Linux).\
\>", "Text"],

Cell[TextData[{
 "COMMENTS (RM 1.2.):  Changed TarcerRecurse. New TLR ",
 ButtonBox["definition",
  BaseStyle->"Hyperlink",
  ButtonData:>"TLRdef"],
 ". \n                          default $RankLimit={0,6};"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Remember", "=", "True"}], ";"}]], "Input"],

Cell["\<\
COMMENTS (RM 19.1.):   changes are:  tlrule[22] and tlrule[23], minor \
efficiency changes (Expand3 = Identity) and other small programming \
optimizations.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 22.1.):   changes are: bug in tlrule[23] fixed, new tlrule[24], \
new option Factor to TarcerReduce (doesn't change anything by default, but \
allows for improved Factor-ing).\
\>", "Text"],

Cell[TextData[{
 "See also: ",
 ButtonBox["hep-ph/9801383",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://xxx.lanl.gov/abs/hep-ph/9801383"], None}],
 ", published in Comput. Phys. Commun. 111 (1998) 265-273"
}], "Text",
 Editable->False],

Cell[CellGroupData[{

Cell["Table of contents", "Section",
 CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[ButtonBox["Preliminaries",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.1.1"]], "Text"],

Cell[TextData[ButtonBox["Usages",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.2.1"]], "Text"],

Cell[TextData[ButtonBox["Creating the tarcerij.mx file",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.2.1.1"]], "Text"],

Cell[TextData[ButtonBox["Prologue (setting of $RankLimit)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.1"]], "Text"],

Cell[TextData[ButtonBox["Typesetting rules",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.1.1"]], "Text"],

Cell[TextData[ButtonBox["The Palettes",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.2.1"]], "Text"],

Cell[TextData[ButtonBox["OperatorApply",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.3.1"]], "Text"],

Cell[TextData[ButtonBox["MassDerivative",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.4.1"]], "Text"],

Cell[TextData[ButtonBox["TarasovT",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.5.1"]], "Text"],

Cell[TextData[ButtonBox["ApplyTarasovT",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.6.1"]], "Text"],

Cell[TextData[ButtonBox["Misc",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.1"]], "Text"],

Cell[TextData[ButtonBox["Colors",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.1.1"]], "SmallText"],

Cell[TextData[ButtonBox["PQ",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.2.1"]], "SmallText"],

Cell[TextData[ButtonBox["PNQ",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.3.1"]], "SmallText"],

Cell[TextData[ButtonBox["FactorC",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.4.1"]], "SmallText"],

Cell[TextData[ButtonBox["TFI",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.5.1"]], "SmallText"],

Cell[TextData[ButtonBox["TJI",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.6.1"]], "SmallText"],

Cell[TextData[ButtonBox["TBI",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.7.1"]], "SmallText"],

Cell[TextData[ButtonBox["TAI",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.3.7.8.1"]], "SmallText"],

Cell[TextData[ButtonBox["Definitions and notation",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.4.1"]], "Text"],

Cell[TextData[StyleBox[ButtonBox["ToArgs",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.4.1.1"],
 FontColor->RGBColor[0.2, 0.6, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Cayley",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.4.2.1"],
 FontColor->RGBColor[1, 0, 0.4]]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     RowBox[{
      StyleBox["Cayley",
       FontColor->RGBColor[1, 0, 0.4]], "[", "i", "]"}], "=", 
     SubscriptBox["\[CapitalDelta]", "i"]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.4.3.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TextForm]]]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     RowBox[{
      StyleBox["CayleyD",
       FontColor->RGBColor[1, 0.2, 1]], "[", "i", "]"}], "=", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "i"], "/", "\[CapitalDelta]"}]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.4.4.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TextForm]]]], "Text"],

Cell[TextData[ButtonBox["Utility Functions",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun and friends",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.1.1"]], "Text"],

Cell[TextData[ButtonBox["Interchange",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.1.1.1"]], "SmallText"],

Cell[TextData[{
 ButtonBox["\[Nu]",
  BaseStyle->"Hyperlink",
  ButtonData:>"T1.5.2.1"],
 ButtonBox["explicit",
  BaseStyle->"Hyperlink",
  ButtonData:>"T1.5.2.1"]
}], "Text"],

Cell[TextData[ButtonBox["TA",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.2.1.1"]], "SmallText"],

Cell[TextData[ButtonBox["CheckRecursion",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.3.1"]], "Text"],

Cell[TextData[ButtonBox["CheckTVIRecursion",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.3.1.1"]], "SmallText"],

Cell[TextData[ButtonBox["CheckTJIRecursion",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.5.3.2.1"]], "SmallText"],

Cell[TextData[ButtonBox["Recurrence Relations Input and Recursion Function \
Generation",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.1"]], "Text"],

Cell[TextData[ButtonBox["Input (35)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.1.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (35)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.2.1"]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     FormBox[
      SuperscriptBox["1", 
       RowBox[{"+", " "}]],
      TraditionalForm], 
     RowBox[{" ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"35", "_"}], "1"}], ")"}]}]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.2.1.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     FormBox[
      SuperscriptBox["2", 
       RowBox[{"+", " "}]],
      TraditionalForm], 
     RowBox[{" ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"35", "_"}], "2"}], ")"}]}]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.2.2.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     FormBox[
      SuperscriptBox["3", 
       RowBox[{"+", " "}]],
      TraditionalForm], 
     RowBox[{" ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"35", "_"}], "3"}], ")"}]}]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.2.3.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     FormBox[
      SuperscriptBox["4", 
       RowBox[{"+", " "}]],
      TraditionalForm], 
     RowBox[{" ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"35", "_"}], "4"}], ")"}]}]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.2.4.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[ButtonBox["Input (3501)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.3.1"]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"MakeFun", " ", 
       RowBox[{"(", "3501", ")"}], " ", "\[CapitalDelta]"}], "=", "0", " "}], 
     
     FormBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p", "2"], "=", 
        SuperscriptBox["m", "2"]}], ")"}],
      TraditionalForm]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.4.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[ButtonBox["Input (3502)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.5.1"]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"MakeFun", " ", 
       RowBox[{"(", "3502", ")"}], " ", "\[CapitalDelta]"}], "=", "0", " "}], 
     
     FormBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p", "2"], "=", 
        SuperscriptBox["m", "2"]}], ")"}],
      TraditionalForm]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.6.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"MakeFun", " ", 
       RowBox[{"(", "3503", ")"}], " ", "\[CapitalDelta]"}], "=", "0", " "}], 
     
     FormBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p", "2"], "=", 
        SuperscriptBox["m", "2"]}], ")"}],
      TraditionalForm]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.7.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  ButtonBox[
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"MakeFun", " ", 
       RowBox[{"(", "3504", ")"}], " ", "\[CapitalDelta]"}], "=", "0", " "}], 
     
     FormBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["p", "2"], "=", 
        SuperscriptBox["m", "2"]}], ")"}],
      TraditionalForm]}],
    SingleLetterItalics->False],
   Active->True,
   Background->GrayLevel[1],
   ButtonData:>"T1.6.8.1",
   ButtonFunction:>(FrontEndExecute[{
      FrontEnd`NotebookLocate[#2]}]& ),
   ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[ButtonBox["Input (41)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.9.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (41)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.10.1"]], "Text"],

Cell[TextData[ButtonBox["Input (43)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.11.1"]], "Text"],

Cell[TextData[ButtonBox["Input (44)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.12.1"]], "Text"],

Cell[TextData[ButtonBox["Input (45)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.13.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (43) and (44)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.14.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (50)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.15.1"]], "Text"],

Cell[TextData[ButtonBox["Input (51)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.16.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (51)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.17.1"]], "Text"],

Cell[TextData[ButtonBox["Input (52)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.18.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (52)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.19.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (53)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.20.1"]], "Text"],

Cell[TextData[ButtonBox["Input (54)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.21.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (54)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.22.1"]], "Text"],

Cell[TextData[ButtonBox["Input (55)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.23.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (55)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.24.1"]], "Text"],

Cell[TextData[ButtonBox["Input (56)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.25.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (56)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.26.1"]], "Text"],

Cell[TextData[ButtonBox["Input (59)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.27.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (59)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.28.1"]], "Text"],

Cell[TextData[ButtonBox["Input (60)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.29.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (60)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.30.1"]], "Text"],

Cell[TextData[ButtonBox["Input (61)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.31.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (61)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.32.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6153)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.33.1"]], "Text"],

Cell[TextData[ButtonBox["Input (62)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.34.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (62)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.35.1"]], "Text"],

Cell[TextData[ButtonBox["Input (63)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.36.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (63)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.37.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6552)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.38.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6552)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.39.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6553)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.40.1"]], "Text"],

Cell[TextData[ButtonBox["Input (66)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.41.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (66)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.42.1"]], "Text"],

Cell[TextData[ButtonBox["Input (alternative67)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.43.1"]], "Text"],

Cell[TextData[ButtonBox["Input (67)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.44.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (67)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.45.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6713)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.46.1"]], "Text"],

Cell[TextData[ButtonBox["Input (68)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.47.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (68)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.48.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6813)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.49.1"]], "Text"],

Cell[TextData[ButtonBox["Input (70)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.50.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (70)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.51.1"]], "Text"],

Cell[TextData[ButtonBox["Input (71)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.52.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (71)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.53.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (7123)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.54.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (7113)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.55.1"]], "Text"],

Cell[TextData[ButtonBox["Input (78)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.56.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (78)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.57.1"]], "Text"],

Cell[TextData[ButtonBox["Input (80)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.58.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (80)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.59.1"]], "Text"],

Cell[TextData[ButtonBox["Input (81)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.60.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (81)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.61.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8123)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.62.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8113)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.63.1"]], "Text"],

Cell[TextData[ButtonBox["Input (82)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.64.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (82)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.65.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8213)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.66.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8212)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.67.1"]], "Text"],

Cell[TextData[ButtonBox["Input (83)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.68.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (83)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.69.1"]], "Text"],

Cell[TextData[ButtonBox["Input (87)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.70.1"]], "Text"],

Cell[TextData[ButtonBox["(88)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.70.1.1"]], "SmallText"],

Cell[TextData[ButtonBox["(89)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.70.2.1"]], "SmallText"],

Cell[TextData[ButtonBox["MakeFun (87)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.71.1"]], "Text"],

Cell[TextData[ButtonBox["Input (90)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.72.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (90)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.73.1"]], "Text"],

Cell[TextData[ButtonBox["Input (91)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.74.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (911)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.75.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (912)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.76.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (913)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.77.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (914)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.78.1"]], "Text"],

Cell[TextData[ButtonBox["Input (92)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.79.1"]], "Text"],

Cell[TextData[ButtonBox["Input (93)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.80.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (93)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.81.1"]], "Text"],

Cell[TextData[ButtonBox["Input (94)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.82.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (94)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.83.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9401)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.84.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9402)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.85.1"]], "Text"],

Cell[TextData[ButtonBox["Input (95)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.86.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (95)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.87.1"]], "Text"],

Cell[TextData[ButtonBox["Input (96)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.88.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (96)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.89.1"]], "Text"],

Cell[TextData[ButtonBox["Input (97)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.90.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (97)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.91.1"]], "Text"],

Cell[TextData[ButtonBox["Input (98)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.92.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (98)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.93.1"]], "Text"],

Cell[TextData[ButtonBox["Input (99)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.94.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (99)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.95.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9912)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.96.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9913)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.97.1"]], "Text"],

Cell[TextData[ButtonBox["Input (100)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.98.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (100)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.99.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1002)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.100.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1003)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.101.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1004)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.102.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1005)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.103.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1006)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.104.1"]], "Text"],

Cell[TextData[ButtonBox["Input (150)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.105.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (150)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.106.1"]], "Text"],

Cell[TextData[ButtonBox["Input (151)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.107.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (151)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.108.1"]], "Text"],

Cell[TextData[ButtonBox["Input (152)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.109.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (152)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.110.1"]], "Text"],

Cell[TextData[ButtonBox["Input (153)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.111.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (153)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.112.1"]], "Text"],

Cell[TextData[ButtonBox["Input (200)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.113.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (200)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.114.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (201)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.115.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (202)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.116.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (203)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.117.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (204)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.118.1"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (205)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.119.1"]], "Text"],

Cell[TextData[ButtonBox["Input (1xxxx)",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.120.1"]], "Text"],

Cell[TextData[ButtonBox["five -> four",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.121.1"]], "Text"],

Cell[TextData[ButtonBox["four -> three",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.122.1"]], "Text"],

Cell[TextData[ButtonBox["three -> two",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.123.1"]], "Text"],

Cell[TextData[ButtonBox["two -> one",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.6.124.1"]], "Text"],

Cell[TextData[ButtonBox["TarcerRecurse and TFIRecurse",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.7.1"]], "Text"],

Cell[TextData[ButtonBox["TFIRecurse",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.7.1.1"]], "Text"],

Cell[TextData[ButtonBox["T*IS",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.7.2.1"]], "Text"],

Cell[TextData[ButtonBox["TComment",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.7.3.1"]], "Text"],

Cell[TextData[ButtonBox["TarcerRecurse",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.7.4.1"]], "Text"],

Cell[TextData[ButtonBox["TarcerExpand",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.8.1"]], "Text"],

Cell[TextData[ButtonBox["Construct T's",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.9.1"]], "Text"],

Cell[TextData[ButtonBox["$BasisIntegrals",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.10.1"]], "Text"],

Cell[TextData[ButtonBox["Save",
 BaseStyle->"Hyperlink",
 ButtonData:>"T1.9.1"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.1.1"],

Cell[TextData[{
 "This is free software.\nYou may use it, distribute it, change it, improve \
it, etc..\nIf you have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " questions, ask them to support@wolfram.com or to your local ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " reseller."
}], "SmallText",
 Editable->False],

Cell["\<\
 We consider the following type of integrals, where a,b,u,v,r,s,t are \
non-negative integers.\
\>", "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"TFI", "[", 
    RowBox[{"d", ",", 
     SuperscriptBox["p", "2"], ",", "\[CapitalDelta]p", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "v", ",", "r", ",", "s", ",", "t"}], "}"}]}]}], 
   TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          FormBox[
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["\[Nu]", "1"], ",", 
               SubscriptBox["m", "1"]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["\[Nu]", "2"], ","}]}]}]}],
           TraditionalForm], 
          SubscriptBox["m", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\[Nu]", "3"], ",", 
          SubscriptBox["m", "3"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\[Nu]", "4"], ",", 
          SubscriptBox["m", "4"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\[Nu]", "5"], ",", 
          SubscriptBox["m", "5"]}], "}"}]}], "}"}], "]"}], " ", "="}], " "}], 
   TraditionalForm]]],
 "\n\n",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    SuperscriptBox["\[Pi]", "d"]], TraditionalForm]]],
 "\[Integral] \[Integral] ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     FormBox[
      RowBox[{
       SuperscriptBox["d", "d"], 
       SubscriptBox["k", "1"], " ", 
       SuperscriptBox["d", "d"], 
       SubscriptBox["k", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[CapitalDelta]", "\[CenterDot]", 
          SubscriptBox["k", "1"]}], ")"}], "a"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[CapitalDelta]", "\[CenterDot]", 
          SubscriptBox["k", "1"]}], ")"}], "b"]}],
      TraditionalForm], 
     SuperscriptBox[
      RowBox[{"(", 
       SubsuperscriptBox["k", "1", "2"], ")"}], "u"], 
     SuperscriptBox[
      RowBox[{"(", 
       SubsuperscriptBox["k", "2", "2"], ")"}], "v"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"p", "\[CenterDot]", 
        SubscriptBox["k", "1"]}], ")"}], "r"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"p", "\[CenterDot]", 
        SubscriptBox["k", "2"]}], ")"}], "s"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "1"], "\[CenterDot]", 
        SubscriptBox["k", "2"]}], ")"}], "t"]}], 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"[", 
              RowBox[{
               SubsuperscriptBox["k", "1", "2"], "-", 
               SubsuperscriptBox["m", "1", "2"]}], "]"}], 
             SubscriptBox["\[Nu]", "1"]], "[", 
            RowBox[{
             SubsuperscriptBox["k", "2", "2"], "-", 
             SubsuperscriptBox["m", "2", "2"]}], "]"}], 
           SubscriptBox["\[Nu]", "2"]], "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "1"], "-", "p"}], ")"}], "2"], "-", 
           SubsuperscriptBox["m", "3", "2"]}], "]"}], 
         SubscriptBox["\[Nu]", "3"]], "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["k", "2"], "-", "p"}], ")"}], "2"], "-", 
         SubsuperscriptBox["m", "4", "2"]}], "]"}], 
       SubscriptBox["\[Nu]", "4"]], "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "1"], "-", 
          SubscriptBox["k", "2"]}], ")"}], "2"], "-", 
       SubsuperscriptBox["m", "5", "2"]}], "]"}], 
     SubscriptBox["\[Nu]", "5"]]], TraditionalForm]]]
}], "Text"],

Cell["\<\
Putting the        $Post = (#;)&;       instruction after   
Unset[$Post]   suppresses all output cells.
Putting Unset[$Post] behind  $Post=(#:)&;
will produce a lot of typsetted reduction formulae.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unset", "[", "$Post", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Post", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"#", ";"}], ")"}], "&"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"$Notebooks", "=!=", "True"}], ",", 
    RowBox[{"$Post", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"#", ";"}], ")"}], "&"}]}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$HistoryLength", "=", "0"}], ";"}]], "Input"],

Cell["\<\
This determines the directory into which the resulting file tarcer.mx is \
written.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"$Notebooks", ",", 
   RowBox[{"SetDirectory", "[", 
    RowBox[{"ToFileName", "[", 
     RowBox[{"First", "[", 
      RowBox[{"\"\<FileName\>\"", "/.", 
       RowBox[{"NotebookInformation", "[", 
        RowBox[{"InputNotebook", "[", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
  "]"}]], "Input"],

Cell[TextData[{
 "Somehow ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " crashes on my (R.M.) good old NeXTStation if I don't open all cells first \
...; this opens all cells automatically:"
}], "SmallText"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"$System", "===", "\"\<NeXT\>\""}], ",", 
   RowBox[{
    RowBox[{"SelectionMove", "[", 
     RowBox[{
      RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", "Notebook"}],
      "]"}], ";", 
    RowBox[{"FrontEndExecute", "[", 
     RowBox[{"{", 
      RowBox[{"FrontEnd`FrontEndToken", "[", 
       RowBox[{
        RowBox[{"EvaluationNotebook", "[", "]"}], ",", 
        "\"\<SelectionOpenAllGroups\>\""}], "]"}], "}"}], "]"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Creating the tarcerij.mx file", "Subsubsection",
 CellTags->"T1.2.1.1"],

Cell[TextData[{
 "Running this notebook will produce a tarcerij.mx file where ij will be \
replaced by \nthe two number set by the variable $RankLimit (default 33). \n\
In the same directory as this notebook which can be loaded  into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by    <<tarcer33.mx,\nor, when running in Terminal mode, on Unix systems, \
already when starting ",
 StyleBox["Mathematica, ",
  FontSlant->"Italic"],
 "as \nmyshellprompt>  math -initfile tarcer33.mx"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Usages", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.2.1"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BeginPackage", "[", "\"\<HighEnergyPhysics`Tarcer`\>\"", "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TarcerRecurse", "::", "usage"}], "=", 
   "\"\<TarcerRecurse[expr] applies recurrence relations for all TFI's (and \
TVI, TJI, TBI, TAI) in expr. For evaluation and Laurent expansion of the \
resulting basis integrals use TarcerExpand.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TarcerExpand", "::", "usage"}], "=", 
   "\"\<TarcerExpand[expr, d -> (4+e), order] or TarcerExpand[epxr, d -> \
(4-e), order] or TarcerExpand[expr, d -> (4 - 2 om)substitutes integrals as \
specified by the option TarcerRules, and does a Laurent expansion in the \
variable around 0 at the right hand side of the second argument (i.e., you \
can use whatever convention you like ...). The same effect as \
TarcerExpand[TarcerRecurse[expr], ...] can be achieved by setting the option \
TarcerRecurse of TarcerExpand to True. TarcerExpand[expr, d -> (4+e)] is \
equivalent to TarcerExpand[expr, d -> (4+e), 0].\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TarcerReduce", "::", "usage"}], "=", 
   "\"\<TarcerReduce is an option to TarcerExpand. It should be set to a list \
of basic integrals.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cayley", "::", "usage"}], "=", 
   "\"\<Cayley[m1,m2,m3,m4,m5,Sqrt[pp]] is the Cayley determinant.\>\""}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cayleyu", "::", "usage"}], "=", 
   "\"\<Cayleyu are the sub-Cayley-determinants as described in Tarasov's \
paper.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CayleyD", "::", "usage"}], "=", 
   "\"\<CayleyD are the sub-Cayley-determinants as described in Tarasov's \
paper.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Prefactor1", "::", "usage"}], "=", 
   "\"\<Prefactor1[expr] may be used to prohibit TarcerExpand from \
Taylor-expanding expr.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SEpsilon", "::", "usage"}], "=", 
   "\"\<Sepsilon[d] is an abbreviation for Exp[(d-4)/2 EulerGamma].\>\""}], 
  ";"}]], "Input"],

Cell["\<\
TFI::\"usage\" =
\"TFI[d, pp, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] is
the 2-loop d-dimensional integral
1/( (q1^2 - m1^2)^n1  (q2^2 - m2^2)^n2 ((q1-p)^2 - m3^2)^n3 *
    ((q2-p)^2 - m4^2)^n4  ((q1-q2)^2 - m5^2)^n5 ) .

 TFI[d, pp, {x,y,z,v,w}, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}]
has as additional factors in the numerator (q1^2)^x*(q2^2)^y*(q1.p)^z*
(q2.p)^v*(q1.q2)^w .

 TFI[d, pp, dp, {a,b}, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}]
has as additional factors in the numerator  (OPEDelta.q1)^a * \
(OPEDelta.q2)^b;
dp is (OPEDelta.p).\";\
\>", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TFIRecurse", "::", "usage"}], "=", 
   "\"\<TFIRecurse[expr] applies the recursion algorithm implemented in \
TARCER.nb (following Tarasov) to TFI's (and TVI's, TJI's, TBI's, TAI's in \
expr.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TFISimplify", "::", "usage"}], "=", 
   "\"\<TFISimplify[expr] applies the recursion algorithm implemented in \
TARCER.nb (following Tarasov) to TFI's (and TVI's, TJI's, TBI's, TAI's in \
expr, except k1.k2.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TVI", "::", "usage"}], "=", 
   "\"\<TVI[d,pp,{ {n1,m1},{n2,m2},{n3,m3},{n4,m4}}] is the massive 2-loop \
integral with four propagators in d dimensions. \>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TJI", "::", "usage"}], "=", 
   "\"\<TJI[d, pp, { {n1,m1},{n2,m2},{n3,m3} }] is the massive 2-loop \
integral with three propagators in d dimensions. \>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TKI", "::", "usage"}], "=", 
   "\"\<TKI[d, 0, { {n1,m1},{n2,m2},{n3,m3} }] is the bubble massive 2-loop \
selfenergy type integral with three propagators in d dimensions. \>\""}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TBI", "::", "usage"}], "=", 
   "\"\<TBI[d, pp, { {n1,m1},{n2,m2} }] is the massive 1-loop selfenergy type \
integral with two propagators in d dimensions.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TAI", "::", "usage"}], "=", 
   "\"\<TAI[d, pp, { {n1,m1} }] is the massive 1-loop selfenergy type \
integral with one propagator in d dimensions.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TFR", "::", "usage"}], "=", 
   "\"\<TFR is similar in syntax to TFI but applies once the recurrence \
relations derived for TFI.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TVR", "::", "usage"}], "=", 
   "\"\<TVR is similar in syntax to TVI but applies once the recurrence \
relations derived for TVI.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TJR", "::", "usage"}], "=", 
   "\"\<TJR is similar in syntax to TJI but applies once the recurrence \
relations derived for TJI.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TBR", "::", "usage"}], "=", 
   "\"\<TBR is similar in syntax to TBI but applies once the recurrence \
relations derived for TBI.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TAR", "::", "usage"}], "=", 
   "\"\<TAR is similar in syntax to TAI but applies once the recurrence \
relations derived for TAI.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$RankLimit", "::", "usage"}], "=", 
   "\"\<$RankLimit is the list of integers specifying the highest possible \
sums of exponents of scalar products; i.e., {a+b, r+s} means that at most \
(Delta.k1)^a * (Delta.k2)^2 * (p.k1)^r * (p.k2)^s in the numerator will be \
calculated (a,b,r,s have to be non-negative integares). $RankLimit has to be \
set in the TARCER.nb notebook. In the tarcer.mx file this is not possible \
anymore.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$TarcerRecursed", "::", "usage"}], "=", 
   "\"\<If $Comment is set to True all integrals\\n\\t\\twhich are reduced \
are collected in the global variable $TarcerRecured.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$BasisIntegrals", "::", "usage"}], "=", 
   "\"\<$BasisIntegrals is a list of some basis integrals. It is the default \
setting of TarcerReduce of TarcerExpand.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$Comment", "::", "usage"}], "=", 
   "\"\<$Comment can be set to True or False. If set to False no comments are \
generated.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$CommentNotebook", "::", "usage"}], "=", 
   "\"\<$Comment can be set to True or False. Setting it to True will \
generate a separate notebook (if and only if $Comment is True) where the used \
recursion relations are displayed.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$RecursionStop", "::", "usage"}], "=", 
   "\"\<$RecursionStop sets an upper limit on the total number of recursion \
levels. Its purpose is to inhibit erroneous infinite recursions.\>\""}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$TTable", "::", "usage"}], "=", 
   "\"\<$TTable is a list of precomputed reductions. $TTable is the default \
setting of the option Table of TarcerRecurse. \>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Expand3", "=", "Identity"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prologue (setting of $RankLimit)", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.3.1"],

Cell[TextData[{
 "This sets the limit up to which the ",
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 "-operators are constructed automatically, i.e., $RankLimit = {a+b, r+s} , \
concerning: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[CapitalDelta]", "\[CenterDot]", 
       SubscriptBox["k", "1"]}], ")"}], "a"], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[CapitalDelta]", "\[CenterDot]", 
      SubscriptBox["k", "2"]}], ")"}], "b"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RowBox[{"p", "\[CenterDot]", 
       SubscriptBox["k", "1"]}],
      TraditionalForm], ")"}], "r"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RowBox[{"p", "\[CenterDot]", 
       SubscriptBox["k", "2"]}],
      TraditionalForm], ")"}], "s"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$RankLimit", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "6"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$RankLimit", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$RankLimit", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5"}], "}"}]}], ";"}]}], "Input"],

Cell["Check recursion relations by changing False to True here:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$CheckRecursion", "=", "False"}], ";"}]], "Input"],

Cell["\<\
Change False to True for getting the input palettes for entering new \
recursion relations.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PutPalettes", "=", "False"}], ";"}]], "Input"],

Cell[TextData[{
 "Notice:  Instead of using shift operators",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{"  ", 
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"]}],
     TraditionalForm], ",", 
    StyleBox[
     SuperscriptBox["2", "+"],
     FontWeight->"Bold"]}], TraditionalForm]]],
 " etc. the \[Nu]-indices are colored blue; instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{"  ", 
      StyleBox[
       SuperscriptBox["1", "-"],
       FontWeight->"Bold"]}],
     TraditionalForm], ",", 
    StyleBox[
     SuperscriptBox["2", "-"],
     FontWeight->"Bold"]}], TraditionalForm]]],
 " etc. the \[Nu]-indices are colored red."
}], "Text"],

Cell[CellGroupData[{

Cell["Typesetting rules", "Subsection",
 CellTags->"T1.3.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"atime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"SEpsilon", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"SEpsilon", "[", "d_", "]"}], ",", "fmt_"}], "]"}], ":=", 
  RowBox[{"InterpretationBox", "@@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"StyleBox", "[", 
      RowBox[{
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<S\>\"", ",", 
         RowBox[{"First", "[", 
          RowBox[{"Variables", "[", "d", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}]}], "]"}], ",", 
     RowBox[{"SEpsilon", "[", "d", "]"}], ",", 
     RowBox[{"Editable", "\[Rule]", "False"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"SEpsilon", "[", "d_", "]"}], "n_"], ",", "fmt_"}], "]"}], ":=", 
  
  RowBox[{"InterpretationBox", "@@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"StyleBox", "[", 
      RowBox[{
       RowBox[{"SubsuperscriptBox", "[", 
        RowBox[{"\"\<S\>\"", ",", 
         RowBox[{"First", "[", 
          RowBox[{"Variables", "[", "d", "]"}], "]"}], ",", "n"}], "]"}], ",", 
       RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}]}], "]"}], ",", 
     RowBox[{"SEpsilon", "[", "d", "]"}], ",", 
     RowBox[{"Editable", "\[Rule]", "False"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Prefactor1", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"Prefactor1", "[", "d_", "]"}], ",", "fmt_"}], "]"}], ":=", 
  RowBox[{"InterpretationBox", "@@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"MakeBoxes", "[", 
      RowBox[{"d", ",", "fmt"}], "]"}], ",", 
     RowBox[{"Prefactor1", "[", "d", "]"}], ",", 
     RowBox[{"Editable", "->", "False"}]}], "}"}]}]}]], "Input"],

Cell["\<\
Don't mess with the InterpretationBox's !! (important for the palette and \
OperatorApply).\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"Schiebe", "[", 
     RowBox[{"i_", ",", "pm_String"}], "]"}], " ", ",", "fmt_"}], "]"}], ":=", 
  RowBox[{"InterpretationBox", "[", 
   RowBox[{
    RowBox[{"StyleBox", "[", 
     RowBox[{
      RowBox[{"SuperscriptBox", "[", 
       RowBox[{"i", ",", "pm"}], "]"}], ",", 
      RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
    RowBox[{"Schiebe", "[", 
     RowBox[{"i", ",", "pm"}], "]"}], ",", 
    RowBox[{"Editable", "->", "True"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CayleyD", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CayleyD", "[", "i_Integer", "]"}], "[", "args_", "]"}], ",", 
     "fmt_"}], "]"}], ":=", 
   RowBox[{"FractionBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<\[CapitalDelta]\>\"", ",", " ", "i"}], "]"}], ",", 
     "\"\<\[CapitalDelta]\>\""}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CayleyD", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CayleyD", "[", 
       RowBox[{"i_Integer", ",", "j_Integer"}], "]"}], "[", "args_", "]"}], 
     ",", "fmt_"}], "]"}], ":=", 
   RowBox[{"FractionBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<\[CapitalDelta]\>\"", ",", 
       RowBox[{
        RowBox[{"10", " ", "i"}], "+", "j"}]}], "]"}], ",", 
     "\"\<\[CapitalDelta]\>\""}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CayleyD", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CayleyD", "[", 
       RowBox[{"i_Integer", ",", "j_Integer", ",", "k_Integer"}], "]"}], "[", 
      "args_", "]"}], ",", "fmt_"}], "]"}], ":=", 
   RowBox[{"FractionBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<\[CapitalDelta]\>\"", ",", 
       RowBox[{
        RowBox[{"100", "  ", "i"}], "+", 
        RowBox[{"10", "j"}], "+", "k"}]}], "]"}], ",", 
     "\"\<\[CapitalDelta]\>\""}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayley", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Cayley", "[", "i_Integer", "]"}], "[", "args_", "]"}], ",", 
     "fmt_"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[CapitalDelta]\>\"", ",", " ", "i"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayley", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Cayley", "[", 
       RowBox[{"i_Integer", ",", "j_Integer"}], "]"}], "[", "args_", "]"}], 
     ",", "fmt_"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[CapitalDelta]\>\"", ",", 
     RowBox[{
      RowBox[{"10", " ", "i"}], "+", "j"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayley", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Cayley", "[", 
       RowBox[{"i_Integer", ",", "j_Integer", ",", "k_Integer"}], "]"}], "[", 
      "args_", "]"}], ",", "fmt_"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[CapitalDelta]\>\"", ",", 
     RowBox[{
      RowBox[{"100", "  ", "i"}], "+", 
      RowBox[{"10", "j"}], "+", "k"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayleyu", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Cayleyu", "[", 
       RowBox[{"i_Integer", ",", "j_Integer", ",", "k_Integer"}], "]"}], "[", 
      "args_", "]"}], ",", "fmt_"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<u\>\"", ",", 
     RowBox[{
      RowBox[{"100", "  ", "i"}], "+", 
      RowBox[{"10", "j"}], "+", "k"}]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
MakeBoxes[PP, fm_] := InterpretationBox[SuperscriptBox[p, 2], PP]; 
MakeBoxes[m1^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 1, p], m1^p]; \

MakeBoxes[m2^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 2, p], m2^p]; \

MakeBoxes[m3^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 3, p], m3^p]; \

MakeBoxes[m4^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 4, p], m4^p]; \

MakeBoxes[m5^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 5, p], m5^p]; \

m6 = Sqrt[PP]; \
\>", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"m1", ",", "_"}], "]"}], ":=", 
   RowBox[{"InterpretationBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"m", ",", "1"}], "]"}], ",", "m1"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"m2", ",", "_"}], "]"}], ":=", 
   RowBox[{"InterpretationBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"m", ",", "2"}], "]"}], ",", "m2"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"m3", ",", "_"}], "]"}], ":=", 
   RowBox[{"InterpretationBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"m", ",", "3"}], "]"}], ",", "m3"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"m4", ",", "_"}], "]"}], ":=", 
   RowBox[{"InterpretationBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"m", ",", "4"}], "]"}], ",", "m4"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"m5", ",", "_"}], "]"}], ":=", 
   RowBox[{"InterpretationBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"m", ",", "5"}], "]"}], ",", "m5"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"mbt", "[", "z_", "]"}], ":=", 
   RowBox[{"ToBoxes", "[", 
    RowBox[{"z", ",", "TraditionalForm"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_", "/;", 
     RowBox[{
      RowBox[{"Head", "[", "z", "]"}], "=!=", "Plus"}]}], "]"}], ":=", 
   RowBox[{"mbt", "[", "z", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_", "-", "1"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"mbt", "[", "z", "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_Subscript", "-", "2"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{
       RowBox[{"OverscriptBox", "[", 
        RowBox[{
         RowBox[{"z", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", "\"\<_\>\""}], "]"}], ",", 
       RowBox[{"z", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
      "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_", "-", "2"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"OverscriptBox", "[", 
      RowBox[{
       RowBox[{"mbt", "[", "z", "]"}], ",", "\"\<_\>\""}], "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_", "-", "3"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"UnderscriptBox", "[", 
      RowBox[{
       RowBox[{"OverscriptBox", "[", 
        RowBox[{
         RowBox[{"mbt", "[", "z", "]"}], ",", "\"\<_\>\""}], "]"}], ",", 
       "\"\<_\>\""}], "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_", "+", "1"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"mbt", "[", "z", "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "0", ",", "1"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_", "+", "2"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"OverscriptBox", "[", 
      RowBox[{
       RowBox[{"mbt", "[", "z", "]"}], ",", "\"\<_\>\""}], "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "0", ",", "1"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redblue", "[", 
    RowBox[{"z_Subscript", "+", "2"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{
       RowBox[{"OverscriptBox", "[", 
        RowBox[{
         RowBox[{"z", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", "\"\<_\>\""}], "]"}], ",", 
       RowBox[{"z", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
      "]"}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "0", ",", "1"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFI", "[", 
      RowBox[{"d_", ",", "pp_", ",", 
       RowBox[{"{", "ur__", "}"}], ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\"", 
             ",", "\"\< \>\"", ",", "ur"}], "}"}], "]"}]}], "]"}], ",", "\n", 
        "\t\t", 
        RowBox[{"TFI", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", "ur", "}"}], ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFI", "[", 
      RowBox[{"d_", ",", "pp_", ",", "dp_", ",", "any__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"InterpretationBox", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{
           RowBox[{"StyleBox", "[", 
            RowBox[{"\"\<F\>\"", ",", 
             RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
             RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
           RowBox[{"RowBox", "@@", 
            RowBox[{"{", 
             RowBox[{"(", 
              RowBox[{"redblue", "/@", 
               RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"ToBoxes", "[", 
               RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\"",
               ",", "\"\< \>\"", ",", 
              RowBox[{"Apply", "[", 
               RowBox[{"Sequence", ",", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"{", "any", "}"}], "]"}]}], "]"}]}], "}"}], "]"}]}], 
          "]"}], ",", "\n", "\t\t", 
         RowBox[{"TFI", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", "any", ",", 
           RowBox[{"{", "den", "}"}]}], "]"}], ",", 
         RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}]}], "/;", 
    RowBox[{
     RowBox[{"Head", "[", "dp", "]"}], "=!=", "List"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFI", "[", 
      RowBox[{"dpp__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{
               RowBox[{"First", "[", 
                RowBox[{"{", "dpp", "}"}], "]"}], ",", "TraditionalForm"}], 
              "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
        "\t\t", 
        RowBox[{"TFI", "[", 
         RowBox[{"dpp", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}], "&&", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "dpp", "}"}], "]"}], "]"}], "=!=", "List"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TVI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TVI", "[", 
      RowBox[{"dpp__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n", 
   RowBox[{
    RowBox[{"(", "\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"InterpretationBox", "@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubsuperscriptBox", "[", 
           RowBox[{
            RowBox[{"StyleBox", "[", 
             RowBox[{"\"\<V\>\"", ",", 
              RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
              RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
            RowBox[{"RowBox", "@@", 
             RowBox[{"{", 
              RowBox[{"(", 
               RowBox[{"redblue", "/@", 
                RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<(\>\"", ",", 
               RowBox[{"ToBoxes", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", "dpp", "}"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
                "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
          "\t", 
          RowBox[{
           RowBox[{"Hold", "[", "TVI", "]"}], "[", 
           RowBox[{"dpp", ",", 
            RowBox[{"{", "den", "}"}]}], "]"}], ",", 
          RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
      RowBox[{
       RowBox[{"Hold", "[", "TVI", "]"}], "->", "TVI"}]}], ")"}], "/;", 
    RowBox[{
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}], "&&", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "dpp", "}"}], "]"}], "]"}], "=!=", "List"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", "1"}], ",", "\[Beta]", ",", "\[Gamma]", ",", 
       "\[Delta]"}], "}"}]}], "]"}], ",", 
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "-", "1"}], ",", "\[Beta]", ",", "\[Gamma]", ",", 
       "\[Delta]"}], "}"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"TJI", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TJI", "[", 
     RowBox[{"d_", ",", "0", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", "\n", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"InterpretationBox", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"SubsuperscriptBox", "[", 
            RowBox[{
             RowBox[{"StyleBox", "[", 
              RowBox[{"\"\<K\>\"", ",", 
               RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
               RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
             RowBox[{"RowBox", "@@", 
              RowBox[{"{", 
               RowBox[{"(", 
                RowBox[{"redblue", "/@", 
                 RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", 
                RowBox[{"ToBoxes", "[", 
                 RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
                "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
           RowBox[{
            RowBox[{"Hold", "[", "TJI", "]"}], "[", 
            RowBox[{"d", ",", "0", ",", 
             RowBox[{"{", "den", "}"}]}], "]"}], ",", 
           RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
       RowBox[{
        RowBox[{"Hold", "[", "TJI", "]"}], "->", "TJI"}]}], ")"}], "/;", 
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}]}], "\n", "\t", ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"TJI", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TJI", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"InterpretationBox", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{
           RowBox[{"StyleBox", "[", 
            RowBox[{"\"\<J\>\"", ",", 
             RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
             RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
           RowBox[{"RowBox", "@@", 
            RowBox[{"{", 
             RowBox[{"(", 
              RowBox[{"redblue", "/@", 
               RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"ToBoxes", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "dpp", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{
          RowBox[{"Hold", "[", "TJI", "]"}], "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", "den", "}"}]}], "]"}], ",", 
         RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"Hold", "[", "TJI", "]"}], "->", "TJI"}]}], ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TKI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TKI", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<K\>\"", ",", 
         RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
       RowBox[{"RowBox", "@@", 
        RowBox[{"{", 
         RowBox[{"(", 
          RowBox[{"redblue", "/@", 
           RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"ToBoxes", "[", 
           RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\""}], 
         "}"}], "]"}]}], "]"}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"TKI", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TKI", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"InterpretationBox", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{
           RowBox[{"StyleBox", "[", 
            RowBox[{"\"\<K\>\"", ",", 
             RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
             RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
           RowBox[{"RowBox", "@@", 
            RowBox[{"{", 
             RowBox[{"(", 
              RowBox[{"redblue", "/@", 
               RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"ToBoxes", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "dpp", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{
          RowBox[{"Hold", "[", "TKI", "]"}], "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", "den", "}"}]}], "]"}], ",", 
         RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"Hold", "[", "TKI", "]"}], "->", "TKI"}]}], ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TKI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}]}], "]"}], 
   ",", 
   RowBox[{"TKI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", "1"}], ",", "\[Beta]", ",", "\[Gamma]"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"TKI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "-", "1"}], ",", "\[Beta]", ",", "\[Gamma]"}], 
      "}"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TBI", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<B\>\"", ",", 
         RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
       RowBox[{"RowBox", "@@", 
        RowBox[{"{", 
         RowBox[{"(", 
          RowBox[{"redblue", "/@", 
           RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"ToBoxes", "[", 
           RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\""}], 
         "}"}], "]"}]}], "]"}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TBI", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<B\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"TBI", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TBI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "}"}]}], "]"}], ",", 
   RowBox[{"TBI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", "1"}], ",", "\[Beta]"}], "}"}]}], "]"}], ",", 
   
   RowBox[{"TBI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "-", "1"}], ",", "\[Beta]"}], "}"}]}], "]"}]}], 
  "}"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TAI", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TAI", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<A\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"TAI", "[", 
         RowBox[{"d", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", "\[Alpha]", "}"}]}], "]"}], ",", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", "+", "1"}], "}"}]}], "]"}], ",", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", "-", "1"}], "}"}]}], "]"}]}], "}"}]], "Input"],

Cell["\<\
T*IC are just like T*I , but used only for commentary in the 
recursion (TComment).\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFIC", "[", 
      RowBox[{"d_", ",", "pp_", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "i_", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\"", 
             ",", "\"\< \>\"", ",", "i", ",", "\"\<0\>\""}], "}"}], "]"}]}], 
         "]"}], ",", "\n", "\t\t", 
        RowBox[{"TFIC", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "i", ",", "0", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFIC", "[", 
      RowBox[{"d_", ",", "pp_", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "i_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\"", 
             ",", "\"\< \>\"", ",", "\"\<0\>\"", ",", "i"}], "}"}], "]"}]}], 
         "]"}], ",", "\n", "\t\t", 
        RowBox[{"TFIC", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "i", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFIC", "[", 
      RowBox[{"dpp__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{
               RowBox[{"First", "[", 
                RowBox[{"{", "dpp", "}"}], "]"}], ",", "TraditionalForm"}], 
              "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
        "\t\t", 
        RowBox[{"TFIC", "[", 
         RowBox[{"dpp", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}], "&&", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "dpp", "}"}], "]"}], "]"}], "=!=", "List"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TVIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TVIC", "[", 
      RowBox[{"dpp__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n", 
   RowBox[{
    RowBox[{"(", "\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"InterpretationBox", "@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubsuperscriptBox", "[", 
           RowBox[{
            RowBox[{"StyleBox", "[", 
             RowBox[{"\"\<V\>\"", ",", 
              RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
              RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
            RowBox[{"RowBox", "@@", 
             RowBox[{"{", 
              RowBox[{"(", 
               RowBox[{"redblue", "/@", 
                RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<(\>\"", ",", 
               RowBox[{"ToBoxes", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", "dpp", "}"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
                "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
          "\t", 
          RowBox[{
           RowBox[{"Hold", "[", "TVIC", "]"}], "[", 
           RowBox[{"dpp", ",", 
            RowBox[{"{", "den", "}"}]}], "]"}], ",", 
          RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
      RowBox[{
       RowBox[{"Hold", "[", "TVIC", "]"}], "->", "TVIC"}]}], ")"}], "/;", 
    RowBox[{
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}], "&&", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "dpp", "}"}], "]"}], "]"}], "=!=", "List"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"TJIC", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TJIC", "[", 
     RowBox[{"d_", ",", "0", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", "\n", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"InterpretationBox", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"SubsuperscriptBox", "[", 
            RowBox[{
             RowBox[{"StyleBox", "[", 
              RowBox[{"\"\<K\>\"", ",", 
               RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
               RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
             RowBox[{"RowBox", "@@", 
              RowBox[{"{", 
               RowBox[{"(", 
                RowBox[{"redblue", "/@", 
                 RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", 
                RowBox[{"ToBoxes", "[", 
                 RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
                "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
           RowBox[{
            RowBox[{"Hold", "[", "TJIC", "]"}], "[", 
            RowBox[{"d", ",", "0", ",", 
             RowBox[{"{", "den", "}"}]}], "]"}], ",", 
           RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
       RowBox[{
        RowBox[{"Hold", "[", "TJIC", "]"}], "->", "TJIC"}]}], ")"}], "/;", 
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}]}], "\n", "\t", ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"TJIC", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TJIC", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"InterpretationBox", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{
           RowBox[{"StyleBox", "[", 
            RowBox[{"\"\<J\>\"", ",", 
             RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
             RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
           RowBox[{"RowBox", "@@", 
            RowBox[{"{", 
             RowBox[{"(", 
              RowBox[{"redblue", "/@", 
               RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"ToBoxes", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "dpp", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{
          RowBox[{"Hold", "[", "TJIC", "]"}], "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", "den", "}"}]}], "]"}], ",", 
         RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"Hold", "[", "TJIC", "]"}], "->", "TJIC"}]}], ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TBIC", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<B\>\"", ",", 
         RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
       RowBox[{"RowBox", "@@", 
        RowBox[{"{", 
         RowBox[{"(", 
          RowBox[{"redblue", "/@", 
           RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"ToBoxes", "[", 
           RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\""}], 
         "}"}], "]"}]}], "]"}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TBIC", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<B\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"TBIC", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TAIC", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TAIC", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<A\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"TAIC", "[", 
         RowBox[{"d", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFR", "[", 
      RowBox[{"d_", ",", "pp_", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "i_", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\"", 
             ",", "\"\< \>\"", ",", "i", ",", "\"\<0\>\""}], "}"}], "]"}]}], 
         "]"}], ",", "\n", "\t\t", 
        RowBox[{"TFR", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "i", ",", "0", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFR", "[", 
      RowBox[{"d_", ",", "pp_", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "i_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\"", 
             ",", "\"\< \>\"", ",", "\"\<0\>\"", ",", "i"}], "}"}], "]"}]}], 
         "]"}], ",", "\n", "\t\t", 
        RowBox[{"TFR", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "i", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TFR", "[", 
      RowBox[{"dpp__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<F\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{
               RowBox[{"First", "[", 
                RowBox[{"{", "dpp", "}"}], "]"}], ",", "TraditionalForm"}], 
              "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
        "\t\t", 
        RowBox[{"TFR", "[", 
         RowBox[{"dpp", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}], "&&", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "dpp", "}"}], "]"}], "]"}], "=!=", "List"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TVR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TVR", "[", 
      RowBox[{"dpp__", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n", 
   RowBox[{
    RowBox[{"(", "\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"InterpretationBox", "@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubsuperscriptBox", "[", 
           RowBox[{
            RowBox[{"StyleBox", "[", 
             RowBox[{"\"\<V\>\"", ",", 
              RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
              RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
            RowBox[{"RowBox", "@@", 
             RowBox[{"{", 
              RowBox[{"(", 
               RowBox[{"redblue", "/@", 
                RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<(\>\"", ",", 
               RowBox[{"ToBoxes", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", "dpp", "}"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
                "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
          "\t", 
          RowBox[{
           RowBox[{"Hold", "[", "TVR", "]"}], "[", 
           RowBox[{"dpp", ",", 
            RowBox[{"{", "den", "}"}]}], "]"}], ",", 
          RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
      RowBox[{
       RowBox[{"Hold", "[", "TVR", "]"}], "->", "TVR"}]}], ")"}], "/;", 
    RowBox[{
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}], "&&", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "dpp", "}"}], "]"}], "]"}], "=!=", "List"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"TJR", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TJR", "[", 
     RowBox[{"d_", ",", "0", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", "\n", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"InterpretationBox", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"SubsuperscriptBox", "[", 
            RowBox[{
             RowBox[{"StyleBox", "[", 
              RowBox[{"\"\<K\>\"", ",", 
               RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
               RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
             RowBox[{"RowBox", "@@", 
              RowBox[{"{", 
               RowBox[{"(", 
                RowBox[{"redblue", "/@", 
                 RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", 
                RowBox[{"ToBoxes", "[", 
                 RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
                "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
           RowBox[{
            RowBox[{"Hold", "[", "TJR", "]"}], "[", 
            RowBox[{"d", ",", "0", ",", 
             RowBox[{"{", "den", "}"}]}], "]"}], ",", 
           RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
       RowBox[{
        RowBox[{"Hold", "[", "TJR", "]"}], "->", "TJR"}]}], ")"}], "/;", 
     RowBox[{"MemberQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}],
       "]"}]}], "\n", "\t", ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"TJR", "/:", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TJR", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\t", 
  
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"InterpretationBox", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{
           RowBox[{"StyleBox", "[", 
            RowBox[{"\"\<J\>\"", ",", 
             RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
             RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
           RowBox[{"RowBox", "@@", 
            RowBox[{"{", 
             RowBox[{"(", 
              RowBox[{"redblue", "/@", 
               RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"ToBoxes", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "dpp", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "TraditionalForm"}], 
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{
          RowBox[{"Hold", "[", "TJR", "]"}], "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", "den", "}"}]}], "]"}], ",", 
         RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"Hold", "[", "TJR", "]"}], "->", "TJR"}]}], ")"}], "/;", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TBR", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{
       RowBox[{"StyleBox", "[", 
        RowBox[{"\"\<B\>\"", ",", 
         RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
       RowBox[{"RowBox", "@@", 
        RowBox[{"{", 
         RowBox[{"(", 
          RowBox[{"redblue", "/@", 
           RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"ToBoxes", "[", 
           RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", "\"\<)\>\""}], 
         "}"}], "]"}]}], "]"}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TBR", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<B\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"TBR", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TAR", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"TAR", "[", 
      RowBox[{"d_", ",", "pp___", ",", 
       RowBox[{"{", "den__", "}"}]}], "]"}], ",", "fmt_"}], "]"}], ":=", "\n",
    "\t", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"InterpretationBox", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{
          RowBox[{"StyleBox", "[", 
           RowBox[{"\"\<A\>\"", ",", 
            RowBox[{"SingleLetterItalics", "->", "False"}], ",", 
            RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "]"}], ",", 
          RowBox[{"RowBox", "@@", 
           RowBox[{"{", 
            RowBox[{"(", 
             RowBox[{"redblue", "/@", 
              RowBox[{"{", "den", "}"}]}], ")"}], "}"}]}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"ToBoxes", "[", 
              RowBox[{"d", ",", "TraditionalForm"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"TAR", "[", 
         RowBox[{"d", ",", 
          RowBox[{"{", "den", "}"}]}], "]"}], ",", 
        RowBox[{"Editable", "->", "True"}]}], "}"}]}], ")"}], "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"StandardForm", ",", "TraditionalForm"}], "}"}], ",", "fmt"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n1", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"n1", ",", "TraditionalForm"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[Nu]\>\"", ",", "1"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n2", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"n2", ",", "TraditionalForm"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[Nu]\>\"", ",", "2"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n3", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"n3", ",", "TraditionalForm"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[Nu]\>\"", ",", "3"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n4", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"n4", ",", "TraditionalForm"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[Nu]\>\"", ",", "4"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n5", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"n5", ",", "TraditionalForm"}], "]"}], ":=", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[Nu]\>\"", ",", "5"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"ParD", "[", "i_", "]"}], "j_"], ",", "TraditionalForm"}], 
    "]"}], ":=", 
   RowBox[{"SubsuperscriptBox", "[", 
    RowBox[{"\"\<\[PartialD]\>\"", ",", "i", ",", "j"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"ParD", "[", "i_", "]"}], ",", "TraditionalForm"}], "]"}], "^=", 
   
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<\[PartialD]\>\"", ",", "i"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"DPlus", ",", "TraditionalForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{
     RowBox[{"SuperscriptBox", "[", 
      RowBox[{"\"\<d\>\"", ",", "\"\<+\>\""}], "]"}], ",", 
     RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
     RowBox[{"SingleLetterItalics", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"TpD", "[", 
     RowBox[{"_", ",", "b_"}], "]"}], ",", "TraditionalForm"}], "]"}], ":=", 
  RowBox[{"MakeBoxes", "[", 
   RowBox[{"b", ",", "TraditionalForm"}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Palettes", "Subsection",
 CellTags->"T1.3.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"$PutPalettes", "===", "True"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tobut", "[", "a_", "]"}], " ", ":=", " ", 
       RowBox[{"ButtonBox", "[", 
        RowBox[{
         RowBox[{"ToBoxes", "[", 
          RowBox[{"a", ",", "StandardForm"}], "]"}], ",", " ", 
         RowBox[{"ButtonStyle", "->", "\"\<Paste\>\""}]}], "]"}]}], ";"}], 
     "\n", " ", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "pal1", "]"}], "===", "NotebookObject"}], ",", 
        "\n", "\t", 
        RowBox[{"NotebookClose", "[", "pal1", "]"}]}], "]"}], ";"}], "\n", 
     "\t", 
     RowBox[{
      RowBox[{"pal1", "=", 
       RowBox[{"NotebookPut", "[", 
        RowBox[{"Notebook", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cell", "[", 
            RowBox[{
             RowBox[{"BoxData", "[", 
              RowBox[{"GridBox", "[", "\n", "\t\t\t\t\t\t\t", 
               RowBox[{
                RowBox[{"Join", "[", 
                 RowBox[{
                  RowBox[{"Transpose", "@", 
                   RowBox[{"{", "\n", "\t\t\t\t\t\t\t\t\t", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"tobut", "@", 
                    SuperscriptBox[
                    SubscriptBox["m", "j"], "2"]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "5"}], "}"}]}], "]"}], ",", "\n", 
                    "\t\t\t\t\t\t\t\t\t", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"tobut", "@", 
                    SubscriptBox["\[Nu]", "j"]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "5"}], "}"}]}], "]"}], ",", "\n", 
                    "\t\t\t\t\t\t\t\t\t", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"tobut", "@", 
                    RowBox[{"Schiebe", "[", 
                    RowBox[{"i", ",", "\"\<+\>\""}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "5"}], "}"}]}], "]"}], ",", "\n", 
                    "\t                ", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"tobut", "@", 
                    RowBox[{"Schiebe", "[", 
                    RowBox[{"i", ",", "\"\<-\>\""}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "5"}], "}"}]}], "]"}]}], "}"}]}], ",", 
                  "\n", "\t\t\t\t\t\t\t", 
                  RowBox[{
                   RowBox[{"{", "\t", 
                    RowBox[{"tobut", "/@", 
                    RowBox[{"{", 
                    RowBox[{"PP", ",", 
                    SubscriptBox["\[CapitalDelta]", "\[Placeholder]"], ",", 
                    SubscriptBox["u", "\[Placeholder]"], ",", 
                    "\[ScriptCapitalC]"}], " ", "}"}]}], "}"}], "\n"}]}], 
                 "\t\t\t\t\t\t\t", "]"}], ",", 
                RowBox[{"RowSpacings", "->", "0"}], ",", "\n", "      ", 
                RowBox[{"ColumnSpacings", "->", "0"}]}], "]"}], "]"}], ",", 
             "NotebookDefault"}], "]"}], "}"}], ",", "\n", "\t", 
          RowBox[{"Editable", "->", "True"}], ",", "\n", 
          RowBox[{"WindowToolbars", "->", 
           RowBox[{"{", "}"}]}], ",", "\n", 
          RowBox[{"WindowSize", "->", 
           RowBox[{"{", 
            RowBox[{"Fit", ",", " ", "Fit"}], "}"}]}], ",", "\n", 
          RowBox[{"WindowMargins", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "Automatic"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], ",", "\n", 
          RowBox[{"WindowFrame", "->", "\"\<Palette\>\""}], ",", "\n", 
          RowBox[{"WindowElements", "->", 
           RowBox[{"{", "}"}]}], ",", "\n", 
          RowBox[{"WindowFrameElements", "->", "\"\<CloseBox\>\""}], ",", 
          "\n", 
          RowBox[{"WindowClickSelect", "->", "False"}], ",", "\n", 
          RowBox[{"ScrollingOptions", "->", 
           RowBox[{"{", 
            RowBox[{"\"\<PagewiseScrolling\>\"", "->", "True"}], "}"}]}], ",",
           "\n", 
          RowBox[{"ShowCellBracket", "->", "False"}], ",", "\n", 
          RowBox[{"CellMargins", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}], ",", "\n", 
          RowBox[{"Active", "->", "True"}], ",", "\n", 
          RowBox[{"CellOpen", "->", "True"}], ",", "\n", 
          RowBox[{"ShowCellLabel", "->", "False"}], ",", "\n", 
          RowBox[{"ShowCellTags", "->", "False"}], ",", "\n", 
          RowBox[{"ImageMargins", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}], ",", "\n", 
          RowBox[{"Magnification", "->", "2"}], ",", 
          RowBox[{"Visible", "->", "True"}]}], "]"}], "]"}]}], ";"}], "\n", 
     RowBox[{
      RowBox[{"SetOptions", "[", 
       RowBox[{"pal1", ",", 
        RowBox[{"WindowMargins", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "Automatic"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "0"}], "}"}]}], "}"}]}]}], "]"}], ";"}],
      "\n", 
     RowBox[{
      RowBox[{"SetOptions", "[", 
       RowBox[{"pal1", ",", 
        RowBox[{"Visible", "->", "True"}], ",", 
        RowBox[{"WindowSize", "->", 
         RowBox[{"{", 
          RowBox[{"Fit", ",", "Fit"}], "}"}]}]}], "]"}], ";"}], "\n", " ", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "pal2", "]"}], "===", "NotebookObject"}], ",", 
        "\n", "\t", 
        RowBox[{"NotebookClose", "[", "pal2", "]"}]}], "]"}], ";"}], "\n", 
     "\t", 
     RowBox[{
      RowBox[{"pal2", "=", 
       RowBox[{"NotebookPut", "[", 
        RowBox[{"Notebook", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Cell", "[", 
            RowBox[{
             RowBox[{"BoxData", "[", 
              RowBox[{"GridBox", "[", "\n", "\t\t\t\t\t\t\t", 
               RowBox[{
                RowBox[{"JJJ", "=", 
                 RowBox[{"Join", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"tobut", "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"TFI", "[", 
                    RowBox[{
                    RowBox[{"d", "+", "2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"], ",", 
                    SubscriptBox["\[Nu]", "4"], ",", 
                    SubscriptBox["\[Nu]", "5"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TVI", "[", 
                    RowBox[{
                    RowBox[{"d", "+", "2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"], ",", 
                    SubscriptBox["\[Nu]", "4"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TJI", "[", 
                    RowBox[{
                    RowBox[{"d", "+", "2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TKI", "[", 
                    RowBox[{"d", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TBI", "[", 
                    RowBox[{"d", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TAI", "[", 
                    RowBox[{"d", ",", 
                    RowBox[{"{", 
                    SubscriptBox["\[Nu]", "1"], "}"}]}], "]"}]}], "}"}]}], 
                    "}"}], ",", "\n", "\t\t\t\t\t\t\t\t", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"tobut", "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"TFI", "[", 
                    RowBox[{"d", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"], ",", 
                    SubscriptBox["\[Nu]", "4"], ",", 
                    SubscriptBox["\[Nu]", "5"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TVI", "[", 
                    RowBox[{"d", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"], ",", 
                    SubscriptBox["\[Nu]", "4"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TJI", "[", 
                    RowBox[{"d", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TKI", "[", 
                    RowBox[{
                    RowBox[{"d", "-", "2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"], ",", 
                    SubscriptBox["\[Nu]", "3"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TBI", "[", 
                    RowBox[{
                    RowBox[{"d", "-", "2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Nu]", "1"], ",", 
                    SubscriptBox["\[Nu]", "2"]}], "}"}]}], "]"}], ",", 
                    RowBox[{"TAI", "[", 
                    RowBox[{
                    RowBox[{"d", "-", "2"}], ",", 
                    RowBox[{"{", 
                    SubscriptBox["\[Nu]", "1"], "}"}]}], "]"}]}], "}"}]}], 
                    "}"}], "\n"}]}], "\t\t\t\t\t\t\t", "]"}]}], ",", 
                RowBox[{"RowSpacings", "->", "0"}], ",", "\n", "      ", 
                RowBox[{"ColumnSpacings", "->", "0"}]}], "]"}], "]"}], ",", 
             "NotebookDefault"}], "]"}], "}"}], ",", "\n", "\t", 
          RowBox[{"Editable", "->", "True"}], ",", "\n", 
          RowBox[{"WindowToolbars", "->", 
           RowBox[{"{", "}"}]}], ",", "\n", 
          RowBox[{"WindowSize", "->", 
           RowBox[{"{", 
            RowBox[{"FitAll", ",", " ", "FitAll"}], "}"}]}], ",", "\n", 
          RowBox[{"WindowMargins", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "Automatic"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], ",", "\n", 
          RowBox[{"WindowFrame", "->", "\"\<Palette\>\""}], ",", "\n", 
          RowBox[{"WindowElements", "->", 
           RowBox[{"{", "}"}]}], ",", "\n", 
          RowBox[{"WindowFrameElements", "->", "\"\<CloseBox\>\""}], ",", 
          "\n", 
          RowBox[{"WindowClickSelect", "->", "False"}], ",", "\n", 
          RowBox[{"ScrollingOptions", "->", 
           RowBox[{"{", 
            RowBox[{"\"\<PagewiseScrolling\>\"", "->", "True"}], "}"}]}], ",",
           "\n", 
          RowBox[{"ShowCellBracket", "->", "False"}], ",", "\n", 
          RowBox[{"CellMargins", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", "\n", 
          RowBox[{"Active", "->", "True"}], ",", "\n", 
          RowBox[{"CellOpen", "->", "True"}], ",", "\n", 
          RowBox[{"ShowCellLabel", "->", "False"}], ",", "\n", 
          RowBox[{"ShowCellTags", "->", "False"}], ",", "\n", 
          RowBox[{"ImageMargins", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}], ",", "\n", 
          RowBox[{"Magnification", "->", "2"}], ",", 
          RowBox[{"Visible", "->", "True"}]}], "]"}], "]"}]}], ";"}], "\n", 
     RowBox[{
      RowBox[{"SetOptions", "[", 
       RowBox[{"pal2", ",", 
        RowBox[{"WindowMargins", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "15"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "4"}], "}"}]}], "}"}]}]}], "]"}], ";"}],
      "\n", 
     RowBox[{
      RowBox[{"SetOptions", "[", 
       RowBox[{"pal2", ",", 
        RowBox[{"Visible", "->", "True"}], ",", 
        RowBox[{"WindowSize", "->", 
         RowBox[{"{", 
          RowBox[{"Fit", ",", "Fit"}], "}"}]}]}], "]"}], ";"}], "\n", "\t", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"pal2", ",", 
       RowBox[{"WindowSize", "->", 
        RowBox[{"{", 
         RowBox[{"Fit", ",", "Fit"}], "}"}]}]}], "]"}], "\n"}]}], "\t", "]"}],
   ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OperatorApply", "Subsection",
 CellTags->"T1.3.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyF", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TFI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TFI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TFI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TFI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TFI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyV", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TVI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TVI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TVI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TVI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TVI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyJ", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TJI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TJI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TJI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TJI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TJI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyK", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TKI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TKI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TKI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TKI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TKI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyK", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TKI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TKI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TKI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TKI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TKI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyB", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TBI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TBI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TBI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TBI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TBI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OperatorApplyA", "[", 
    RowBox[{"x_", "==", "y_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sch", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"sch", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Schiebe", "[", 
             RowBox[{"i_", ",", "\"\<+\>\""}], "]"}], "ni_."], " ", 
           RowBox[{"TAI", "[", 
            RowBox[{"d_", ",", 
             RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", "\t\t\t\t\t", 
          RowBox[{"TAI", "[", 
           RowBox[{"d", ",", 
            RowBox[{"ReplacePart", "[", 
             RowBox[{
              RowBox[{"{", "n15", "}"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "n15", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "+", "ni"}], ",", "i"}], 
             "]"}]}], "]"}]}], ",", "\n", "\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"Schiebe", "[", 
              RowBox[{"i_", ",", "\"\<-\>\""}], "]"}], "ni_."], " ", 
            RowBox[{"TAI", "[", 
             RowBox[{"d_", ",", 
              RowBox[{"{", "n15__", "}"}]}], "]"}]}], ":>", "\n", 
           "\t\t\t\t\t", 
           RowBox[{"TAI", "[", 
            RowBox[{"d", ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{
               RowBox[{"{", "n15", "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "n15", "}"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "ni"}], ",", "i"}], 
              "]"}]}], "]"}]}], "\n"}]}], "\t\t\t", "}"}]}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "#", "]"}], "//.", "sch"}], ",", 
           RowBox[{"TAI", "[", "__", "]"}], ",", "Factor"}], "]"}], "&"}], 
        ",", "\n", "\t\t\t", 
        RowBox[{"x", "==", "y"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MassDerivative", "Subsection",
 CellTags->"T1.3.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MassDerivative", "[", 
    RowBox[{
     RowBox[{"STLI", "[", 
      RowBox[{"any__", ",", 
       RowBox[{"{", "\n", "       ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"al_", ",", "m1_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"be_", ",", "m2_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ga_", ",", "m3_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"de_", ",", "m4_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ep_", ",", "m5_"}], "}"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "d1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "d2_"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "d3_"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "d4_"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "d5_"}], "}"}]}], "}"}]}], "]"}], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox[":=",
    FontWeight->"Plain"], "\n", 
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Pochhammer", "[", 
        RowBox[{"al", ",", "d1"}], "]"}], " ", 
       RowBox[{"Pochhammer", "[", 
        RowBox[{"be", ",", "d2"}], "]"}], " ", 
       RowBox[{"Pochhammer", "[", 
        RowBox[{"ga", ",", "d3"}], "]"}]}], "*", "\n", "  ", 
      RowBox[{"Pochhammer", "[", 
       RowBox[{"de", ",", "d4"}], "]"}], " ", 
      RowBox[{"Pochhammer", "[", 
       RowBox[{"ep", ",", "d5"}], "]"}]}], " ", ")"}], " ", "*", "\n", " ", 
    RowBox[{"STLI", "[", 
     RowBox[{"any", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"al", "+", "d1"}], ",", "m1"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"be", "+", "d2"}], ",", "m2"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ga", "+", "d3"}], ",", "m3"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"de", "+", "d4"}], ",", "m4"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ep", "+", "d5"}], ",", "m5"}], "}"}]}], "}"}]}], "]"}]}]}],
   ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarasovT", "Subsection",
 CellTags->"T1.3.5.1"],

Cell["\<\
TarasovT[abrs__, qq_ /; Head[qq] =!= List] := 
  TarasovT[abrs, qq, {\"g\", \"g\", \"g\", \"g\", \"g\"}]\
\>", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TarasovT", "[", 
    RowBox[{"r_", ",", " ", "s_", ",", " ", "qq_", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "alp1_", ",", "alp2_", ",", " ", "alp3_", ",", "alp4_", ",", "alp5_"}], 
      "}"}]}], "]"}], " ", ":=", "\n", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
      "al1", ",", "al2", ",", "al3", ",", "al4", ",", "al5", ",", "alrul", 
       ",", "new", ",", "Q1", ",", "Q11", ",", "Q12", ",", "Q2", ",", "Q22", 
       ",", "dum1", ",", "dum2"}], "}"}], ",", "\n", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp1", " ", "===", " ", "0"}], ",", " ", 
         RowBox[{"al1", " ", "=", " ", "0"}]}], "]"}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp2", " ", "===", " ", "0"}], ",", " ", 
         RowBox[{"al2", " ", "=", " ", "0"}]}], "]"}], ";"}], "\n", " ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp3", " ", "===", " ", "0"}], ",", " ", 
         RowBox[{"al3", " ", "=", " ", "0"}]}], "]"}], ";"}], "\n", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp4", " ", "===", " ", "0"}], ",", " ", 
         RowBox[{"al4", " ", "=", " ", "0"}]}], "]"}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp5", " ", "===", " ", "0"}], ",", " ", 
         RowBox[{"al5", " ", "=", " ", "0"}]}], "]"}], ";"}], "\n", " ", 
      RowBox[{
       RowBox[{"alrul", " ", "=", " ", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"al1", ":>", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "1", "]"}]}]}], ",", " ", 
            RowBox[{"al2", ":>", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "2", "]"}]}]}], ",", " ", 
            RowBox[{"al3", ":>", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "3", "]"}]}]}], ",", "\n", 
            "                 ", 
            RowBox[{"al4", ":>", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "4", "]"}]}]}], ",", " ", 
            RowBox[{"al5", ":>", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "5", "]"}]}]}]}], "}"}], ",", " ", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"MatchQ", "[", 
             RowBox[{"#", ",", " ", 
              RowBox[{"0", ":>", "_"}]}], "]"}]}], "&"}]}], "]"}]}], ";"}], 
      "\n", " ", 
      RowBox[{
       RowBox[{"Q1", " ", "=", " ", 
        RowBox[{
         RowBox[{"al3", " ", "al5"}], " ", "+", " ", 
         RowBox[{"al4", " ", "al5"}], " ", "+", " ", 
         RowBox[{"al2", " ", "al3"}], " ", "+", " ", 
         RowBox[{"al3", " ", "al4"}]}]}], ";"}], "\n", " ", 
      RowBox[{
       RowBox[{"Q2", " ", "=", " ", 
        RowBox[{
         RowBox[{"al4", " ", "al5"}], " ", "+", " ", 
         RowBox[{"al3", " ", "al5"}], " ", "+", " ", 
         RowBox[{"al1", " ", "al4"}], " ", "+", " ", 
         RowBox[{"al3", " ", "al4"}]}]}], ";"}], "\n", " ", 
      RowBox[{
       RowBox[{"Q11", " ", "=", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"-", "4"}], ")"}]}], " ", 
         RowBox[{"(", " ", 
          RowBox[{"al2", " ", "+", " ", "al4", " ", "+", " ", "al5"}], " ", 
          ")"}]}]}], ";"}], "\n", " ", 
      RowBox[{
       RowBox[{"Q22", " ", "=", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"-", "4"}], ")"}]}], " ", 
         RowBox[{"(", " ", 
          RowBox[{"al1", " ", "+", " ", "al3", " ", "+", " ", "al5"}], " ", 
          ")"}]}]}], ";"}], "\n", " ", 
      RowBox[{
       RowBox[{"Q12", " ", "=", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"-", "2"}], ")"}]}], " ", "al5"}]}], ";"}], "\n", "\t\t", 
      RowBox[{
       RowBox[{"new", "=", "\n", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"I", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "r"}], "-", "s"}], ")"}]}], 
          RowBox[{"(", " ", 
           RowBox[{"D", "[", " ", 
            RowBox[{
             RowBox[{"Exp", "[", " ", 
              RowBox[{"I", " ", "qq", " ", 
               RowBox[{"(", "\n", "    ", 
                RowBox[{
                 RowBox[{"be1", " ", "Q1"}], " ", "+", " ", 
                 RowBox[{"be2", " ", "Q2"}], " ", "+", 
                 RowBox[{
                  RowBox[{"be1", "^", "2"}], " ", "Q11"}], " ", "+", 
                 RowBox[{
                  RowBox[{"be2", "^", "2"}], " ", "Q22"}], " ", "+", " ", 
                 RowBox[{"be1", " ", "be2", " ", "Q12"}]}], "\n", 
                "                                 ", ")"}], " ", "rho"}], " ",
               "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"be1", ",", "r"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"be2", ",", "s"}], "}"}]}], "\n", "\t\t\t\t", "]"}], 
           " ", ")"}]}], "/.", "\n", " ", 
         RowBox[{"(", " ", 
          RowBox[{"Join", "[", 
           RowBox[{"alrul", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"be1", " ", ":>", " ", "0"}], ",", 
              RowBox[{"be2", " ", ":>", " ", "0"}], ",", " ", 
              RowBox[{"rho", " ", ":>", " ", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"Pi", "^", "2"}]}], "/", 
                 RowBox[{"Pi", "^", "2"}]}], " ", "DPlus"}]}]}], " ", "}"}]}],
            "]"}], ")"}]}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Select", "[", 
               RowBox[{"#", ",", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"FreeQ", "[", 
                    RowBox[{"#", ",", "ParD"}], "]"}], "&&", 
                   RowBox[{"FreeQ", "[", 
                    RowBox[{"#", ",", "DPlus"}], "]"}]}], ")"}], "&"}]}], 
               "]"}], " ", 
              RowBox[{"TpD", "[", 
               RowBox[{"qq", ",", 
                RowBox[{"Select", "[", 
                 RowBox[{"#", ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"!", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"FreeQ", "[", 
                    RowBox[{"#", ",", "ParD"}], "]"}], "&&", 
                    RowBox[{"FreeQ", "[", 
                    RowBox[{"#", ",", "DPlus"}], "]"}]}], ")"}]}], ")"}], 
                   "&"}]}], "]"}]}], "]"}]}], ")"}], "&"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Expand", "[", 
               RowBox[{"new", ",", "ParD"}], "]"}], "+", " ", 
              RowBox[{"dum1", " ", "dum2"}]}], ")"}], "\n"}]}], "\t\t", "]"}],
          "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"dum1", ":>", "0"}], ",", 
           RowBox[{"dum2", ":>", "0"}]}], "}"}]}], "\n"}]}]}]}], "\t\t", 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"TarasovT", "[", 
    RowBox[{"r_", ",", " ", "s_", ",", " ", "pp_", ",", " ", 
     RowBox[{"dp_", "/;", 
      RowBox[{
       RowBox[{"Head", "[", "dp", "]"}], "=!=", "List"}]}]}], "]"}], " ", ":=",
    " ", 
   RowBox[{"TarasovT", "[", 
    RowBox[{"r", ",", "s", ",", "pp", ",", "dp", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<g\>\"", ",", "\"\<g\>\"", ",", "\"\<g\>\"", ",", "\"\<g\>\"", ",", 
       "\"\<g\>\""}], "}"}]}], "]"}]}]}]], "Input"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[CapitalDelta]", " ", 
      SubscriptBox["q", "1"]}], ")"}], "a"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[CapitalDelta]", " ", 
      SubscriptBox["q", "2"]}], ")"}], "b"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"p", " ", 
      SubscriptBox["q", "1"]}], ")"}], "r"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"p", " ", 
      SubscriptBox["q", "2"]}], ")"}], "s"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"TarasovT", "[", 
     RowBox[{
     "a_", ",", "b_", ",", "r_", ",", "s_", ",", "pp_", ",", "dp_", ",", 
      RowBox[{"{", 
       RowBox[{
       "alp1_", ",", "alp2_", ",", "alp3_", ",", "alp4_", ",", "alp5_"}], 
       "}"}]}], "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "al1", ",", "al2", ",", "al3", ",", "al4", ",", "al5", ",", "alrul", 
        ",", "new", ",", "Q1", ",", "Q11", ",", "Q12", ",", "Q2", ",", "Q22", 
        ",", "dum1", ",", "dum2"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp1", "===", "0"}], ",", 
         RowBox[{"al1", "=", "0"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp2", "===", "0"}], ",", 
         RowBox[{"al2", "=", "0"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp3", "===", "0"}], ",", 
         RowBox[{"al3", "=", "0"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp4", "===", "0"}], ",", 
         RowBox[{"al4", "=", "0"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"alp5", "===", "0"}], ",", 
         RowBox[{"al5", "=", "0"}]}], "]"}], ";", 
       RowBox[{"alrul", "=", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"al1", "\[RuleDelayed]", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "1", "]"}]}]}], ",", 
            RowBox[{"al2", "\[RuleDelayed]", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "2", "]"}]}]}], ",", 
            RowBox[{"al3", "\[RuleDelayed]", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "3", "]"}]}]}], ",", 
            RowBox[{"al4", "\[RuleDelayed]", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "4", "]"}]}]}], ",", 
            RowBox[{"al5", "\[RuleDelayed]", 
             RowBox[{"I", " ", 
              RowBox[{"ParD", "[", "5", "]"}]}]}]}], "}"}], ",", 
          RowBox[{
           RowBox[{"\[InvisibleSpace]", 
            RowBox[{"!", 
             RowBox[{"(", 
              RowBox[{"MatchQ", "[", 
               RowBox[{"#1", ",", 
                RowBox[{"0", "\[RuleDelayed]", "_"}]}], "]"}], ")"}]}]}], 
           "&"}]}], "]"}]}], ";", 
       RowBox[{"Q1", "=", 
        RowBox[{
         RowBox[{"al3", " ", "al5"}], "+", 
         RowBox[{"al4", " ", "al5"}], "+", 
         RowBox[{"al2", " ", "al3"}], "+", 
         RowBox[{"al3", " ", "al4"}]}]}], ";", 
       RowBox[{"Q2", "=", 
        RowBox[{
         RowBox[{"al4", " ", "al5"}], "+", 
         RowBox[{"al3", " ", "al5"}], "+", 
         RowBox[{"al1", " ", "al4"}], "+", 
         RowBox[{"al3", " ", "al4"}]}]}], ";", 
       RowBox[{"Q11", "=", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "4"]}], " ", 
         RowBox[{"(", 
          RowBox[{"al2", "+", "al4", "+", "al5"}], ")"}]}]}], ";", 
       RowBox[{"Q22", "=", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "4"]}], " ", 
         RowBox[{"(", 
          RowBox[{"al1", "+", "al3", "+", "al5"}], ")"}]}]}], ";", 
       RowBox[{"Q12", "=", 
        RowBox[{"-", 
         FractionBox["al5", "2"]}]}], ";", 
       RowBox[{"new", "=", 
        RowBox[{
         RowBox[{
          SuperscriptBox["I", 
           RowBox[{
            RowBox[{"-", "r"}], "-", "s", "-", "a", "-", "b"}]], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"be1", ",", "r"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"be2", ",", "s"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"ga1", ",", "a"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"ga2", ",", "b"}], "}"}]}]], 
           RowBox[{"Exp", "[", 
            RowBox[{"I", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"be1", " ", "pp"}], "+", 
                  RowBox[{"ga1", " ", "dp"}]}], ")"}], " ", "Q1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"be2", " ", "pp"}], "+", 
                  RowBox[{"ga2", " ", "dp"}]}], ")"}], " ", "Q2"}], "+", 
               RowBox[{"be1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"be1", " ", "pp"}], "+", 
                  RowBox[{"2", " ", "ga1", " ", "dp"}]}], ")"}], " ", "Q11"}],
                "+", 
               RowBox[{"be2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"be2", " ", "pp"}], "+", 
                  RowBox[{"2", " ", "ga2", " ", "dp"}]}], ")"}], " ", "Q22"}],
                "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"be1", " ", "be2", " ", "pp"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"be1", " ", "ga2"}], "+", 
                    RowBox[{"be2", " ", "ga1"}]}], ")"}], " ", "dp"}]}], 
                 ")"}], " ", "Q12"}]}], ")"}], " ", "rho"}], "]"}]}]}], "/.", 
         
         RowBox[{"Join", "[", 
          RowBox[{"alrul", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"be1", "\[RuleDelayed]", "0"}], ",", 
             RowBox[{"be2", "\[RuleDelayed]", "0"}], ",", 
             RowBox[{"ga1", ":>", "0"}], ",", 
             RowBox[{"ga2", ":>", "0"}], ",", 
             RowBox[{"rho", "\[RuleDelayed]", 
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["\[Pi]", "2"], " ", "DPlus"}], 
                SuperscriptBox["\[Pi]", "2"]]}]}]}], "}"}]}], "]"}]}]}], ";", 
       
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{"#1", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"FreeQ", "[", 
                 RowBox[{"#1", ",", "ParD"}], "]"}], "&&", 
                RowBox[{"FreeQ", "[", 
                 RowBox[{"#1", ",", "DPlus"}], "]"}]}], "&"}]}], "]"}], " ", 
            RowBox[{"TpD", "[", 
             RowBox[{"pp", ",", 
              RowBox[{"Select", "[", 
               RowBox[{"#1", ",", 
                RowBox[{
                 RowBox[{"\[InvisibleSpace]", 
                  RowBox[{"!", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"FreeQ", "[", 
                    RowBox[{"#1", ",", "ParD"}], "]"}], "&&", 
                    RowBox[{"FreeQ", "[", 
                    RowBox[{"#1", ",", "DPlus"}], "]"}]}], ")"}]}]}], "&"}]}],
                "]"}]}], "]"}]}], "&"}], ")"}], "/@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Expand", "[", "new", "]"}], "+", 
           RowBox[{"dum1", " ", "dum2"}]}], ")"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"dum1", "\[RuleDelayed]", "0"}], ",", 
          RowBox[{"dum2", "\[RuleDelayed]", "0"}]}], "}"}]}]}]}], "]"}]}], 
   ";"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ApplyTarasovT", "Subsection",
 CellTags->"T1.3.6.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyTarasovT", "[", 
   RowBox[{"tij_", ",", " ", "exp_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "dump", "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"dump", "=", 
      RowBox[{"Product", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ParD", "[", "j", "]"}], "^", "dummy"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "5"}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"tij", " ", "exp"}], "]"}], "/.", "\n", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"STLI", "[", 
          RowBox[{"de_", ",", "pp_", ",", "pe__List"}], "]"}], " ", 
         RowBox[{"TpD", "[", 
          RowBox[{"tpp_", ",", 
           RowBox[{
            RowBox[{"DPlus", "^", "i_."}], " ", "t_"}]}], "]"}]}], ")"}], ":>",
        "\n", "\t", 
       RowBox[{"MassDerivative", "[", 
        RowBox[{
         RowBox[{"STLI", "[", " ", 
          RowBox[{
           RowBox[{"de", "/.", 
            RowBox[{"de", ":>", 
             RowBox[{"(", 
              RowBox[{"de", " ", "+", " ", 
               RowBox[{"2", " ", "i"}]}], ")"}]}]}], ",", "pp", ",", "pe"}], 
          "]"}], ",", "\n", "\t\t\t\t\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"t", " ", "dump"}], " ", "/.", 
            RowBox[{"Times", "->", "List"}]}], "/.", 
           RowBox[{
            RowBox[{"Power", "[", 
             RowBox[{"_", ",", "n_"}], "]"}], ":>", 
            RowBox[{"{", 
             RowBox[{"0", ",", "n"}], "}"}]}]}], "/.", 
          RowBox[{"dummy", "->", "0"}]}]}], "]"}]}]}]}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Misc", "Subsection",
 CellTags->"T1.3.7.1"],

Cell[BoxData[
 RowBox[{"Prefactor1", "/:", "\t\t", 
  RowBox[{
   RowBox[{"Prefactor1", "[", "a_", "]"}], "^", "n_"}], ":=", 
  RowBox[{"Prefactor1", "[", 
   RowBox[{"a", "^", "n"}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["Colors", "Subsubsection",
 CellTags->"T1.3.7.1.1"],

Cell[TextData[{
 StyleBox["TFI",
  FontColor->RGBColor[1, 0.6, 0]],
 " ",
 StyleBox["TVI ",
  FontColor->RGBColor[0.2, 0.4, 0.8]],
 StyleBox["TFR ",
  FontColor->RGBColor[0, 0.6, 0]],
 StyleBox["TVR ",
  FontColor->RGBColor[0.2, 0.8, 1]],
 StyleBox["MakeFun ",
  FontColor->RGBColor[1, 0.6, 0.6]],
 StyleBox["Cayley ",
  FontColor->RGBColor[1, 0, 0.4]],
 StyleBox["CayleyD ",
  FontColor->RGBColor[1, 0.2, 1]],
 StyleBox["Cayleyu",
  FontColor->RGBColor[0.8, 0.8, 0.4]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0.2, 1]],
 StyleBox["IFF ",
  FontColor->RGBColor[0.6, 0.4, 1]],
 StyleBox["ToArgs ",
  FontColor->RGBColor[0.2, 0.6, 1]],
 StyleBox["Block",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0.2, 0.2]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"Block", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<Block\>\"", ",", 
     RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
     RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0.2", ",", "0.2"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"Cayley", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<Cayley\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0.4"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"CayleyD", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<CayleyD\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0.2", ",", "1"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"Cayleyu", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<Cayleyu\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.8", ",", "0.8", ",", "0.4"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"IFF", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<IFF\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.6", ",", "0.4", ",", "1"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"MakeFun", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<MakeFun\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0.6", ",", "0.6"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"TFI", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<TFI\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0.6", ",", "0"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"TFR", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<TFR\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "0.6", ",", "0"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"ToArgs", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<ToArgs\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.2", ",", "0.6", ",", "1"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"TVI", ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"StyleBox", "[", 
    RowBox[{"\"\<TVI\>\"", ",", 
     RowBox[{"FontColor", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0.2", ",", "0.4", ",", "0.8"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{"TVR", ",", "StandardForm"}], "]"}], ":=", 
  RowBox[{"StyleBox", "[", 
   RowBox[{"\"\<TVR\>\"", ",", 
    RowBox[{"FontColor", "\[Rule]", 
     RowBox[{"RGBColor", "[", 
      RowBox[{"0.2", ",", "0.8", ",", "1"}], "]"}]}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PQ", "Subsubsection",
 CellTags->"T1.3.7.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PQ", "[", 
    RowBox[{"_Integer", "?", "Positive"}], "]"}], " ", ":=", " ", "True"}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PNQ", "Subsubsection",
 CellTags->"T1.3.7.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PNQ", "[", "0", "]"}], "=", "True"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PNQ", "[", 
    RowBox[{"_Integer", "?", "Positive"}], "]"}], " ", ":=", " ", "True"}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FactorC", "Subsubsection",
 CellTags->"T1.3.7.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FactorC", "[", "z_", "]"}], ":=", 
  RowBox[{
   RowBox[{"FactorC", "[", "z", "]"}], "=", 
   RowBox[{"Factor", "[", "z", "]"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TFI", "Subsubsection",
 CellTags->"T1.3.7.5.1"],

Cell["\<\

TFI[depp__,{a___,b_Integer,c___}]:=TFI[depp,{a,{b,0},c}];
TFI[depp__,{a___,{0,m_/;m=!=0},b___}]:=TFI[depp,{a,{0,0},b}];
TFI[a__,{0,0},b__List]:=TFI[a,b];
TFI[d_,pp_,dp_,{0,0},{x1_,x2_,x3_,x4_,x5_},list_List]:=
    TFI[d,pp,{x1,x2,x3,x4,x5},list];
TFI[d_,pp_,dp_,{a_,b_},{0,0,0,0,0},list_List]:=TFI[d,pp,dp,{a,b},list];
TFI[d_,pp_,dp_/;Head[dp]=!=List,{0,0,0,0,0},list_List]:=TFI[d,pp,list];
TFI[d_,pp_,dp_/;Head[dp]=!=List,list_List]:=TFI[d,pp,list];
TFI[d_,pp_,dp_/;Head[dp]=!=List,{x1_,x2_,x3_,x4_,x5_},list_List]:=
    TFI[d,pp,{x1,x2,x3,x4,x5},list];
TFI[__,{{_,_},{0,0},{_,_},{0,0},{_,0}}]:=0;
TFI[__,{{0,0},{_,_},{0,0},{_,_},{_,0}}]:=0;
TFI[__,{{0,0},{_,_},{_,0},{_,_},{0,0}}]:=0;
TFI[__,{{_,0},{_,_},{0,0},{_,_},{0,0}}]:=0;
TFI[__,{{_,_},{_,0},{_,_},{0,0},{0,0}}]:=0;
TFI[__,{{_,_},{0,0},{_,_},{_,0},{0,0}}]:=0;
TFI[__,{{0,0},{0,0},{0,0},{_,0},{_,_}}]:=0;
TFI[__,{{0,0},{0,0},{_,0},{0,0},{_,_}}]:=0;
TFI[__,{{0,0},{_,0},{0,0},{0,0},{_,_}}]:=0;
TFI[__,{{_,0},{0,0},{0,0},{0,0},{_,_}}]:=0;
TFI[__,{{_,_},{_,0},{0,0},{0,0},{0,0}}]:=0;
TFI[__,{{_,0},{_,_},{0,0},{0,0},{0,0}}]:=0;
TFI[__,{{_,_},{0,0},{0,0},{_,0},{0,0}}]:=0;
TFI[__,{{_,0},{0,0},{0,0},{_,_},{0,0}}]:=0;
TFI[__,{{0,0},{_,0},{_,_},{0,0},{0,0}}]:=0;
TFI[__,{{0,0},{_,_},{_,0},{0,0},{0,0}}]:=0;
TFI[__,{{0,0},{0,0},{_,_},{_,0},{0,0}}]:=0;
TFI[__,{{0,0},{0,0},{_,0},{_,_},{0,0}}]:=0;

If[$Notebooks,

mbt[z_] := ToBoxes[z, TraditionalForm];
  redblue[z_ /; Head[z] =!= Plus] := mbt[z];
  redblue[(z_) - 1] := StyleBox[mbt[z], FontColor -> RGBColor[1, 0, 0]];
  redblue[(z_Subscript) - 2] :=
   StyleBox[SubscriptBox[OverscriptBox[z[[1]], \"_\"], z[[2]]],
    FontColor -> RGBColor[1, 0, 0]];
  redblue[(z_) - 2] :=
   StyleBox[OverscriptBox[mbt[z], \"_\"], FontColor -> RGBColor[1, 0, 0]];
  redblue[(z_) - 3] :=
   StyleBox[UnderscriptBox[OverscriptBox[mbt[z], \"_\"], \"_\"],
    FontColor -> RGBColor[1, 0, 0]];
  redblue[(z_) + 1] := StyleBox[mbt[z], FontColor -> RGBColor[0, 0, 1]];
  redblue[(z_) + 2] :=
   StyleBox[OverscriptBox[mbt[z], \"_\"], FontColor -> RGBColor[0, 0, 1]];
  redblue[(z_Subscript) + 2] :=
   StyleBox[SubscriptBox[OverscriptBox[z[[1]], \"_\"], z[[2]]],
    FontColor -> RGBColor[0, 0, 1]];

  TFI/: MakeBoxes[TFI[d_, pp_, {ur__}, {den__}], TraditionalForm] :=
    InterpretationBox @@
      {SubsuperscriptBox[StyleBox[\"F\", Rule[SingleLetterItalics, False],
         Rule[FontWeight, \"Bold\"]], RowBox @@ {redblue /@ {den}},
        RowBox[{\"(\", ToBoxes[d, TraditionalForm], \")\", \" \", ur}]],
       TFI[d, pp, {ur}, {den}], Editable -> True} /;
     MemberQ[{StandardForm, TraditionalForm}, TraditionalForm];

  TFI/: MakeBoxes[TFI[d_, pp_, dp_, any__, {den__}], TraditionalForm] :=
    (InterpretationBox @@
       {SubsuperscriptBox[StyleBox[\"F\",
          Rule[SingleLetterItalics, False], Rule[FontWeight, \"Bold\"]],
         RowBox @@ {redblue /@ {den}},
         RowBox[{\"(\", ToBoxes[d, TraditionalForm], \")\", \" \",
           Sequence @@ Flatten[{any}]}]], TFI[d, pp, dp, any, {den}],
        Editable -> True}) /; Head[dp] =!= List;

TFI/:
   MakeBoxes[TFI[dpp__, {den__}], TraditionalForm] :=
    InterpretationBox @@
      {SubsuperscriptBox[StyleBox[\"F\", Rule[SingleLetterItalics, False],
         Rule[FontWeight, \"Bold\"]], RowBox @@ {redblue /@ {den}},
        RowBox[{\"(\", ToBoxes[First[{dpp}], TraditionalForm], \")\"}]],
       TFI[dpp, {den}], Editable -> True} /;
     MemberQ[{StandardForm, TraditionalForm}, TraditionalForm] &&
      Head[Last[{dpp}]] =!= List;

];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TJI", "Subsubsection",
 CellTags->"T1.3.7.6.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJI", "[", 
   RowBox[{"de_", ",", "pp_", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_Integer", ",", "m1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n2_Integer", ",", "m2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n3_Integer", ",", "m3_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"TJI", "[", 
      RowBox[{"de", ",", "pp", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}]}], "}"}]}], "]"}], "=", 
     RowBox[{"TJI", "[", 
      RowBox[{"de", ",", "pp", ",", 
       RowBox[{"Reverse", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"n1", ",", "m1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"n2", ",", "m2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"n3", ",", "m3"}], "}"}]}], "}"}], "]"}], "]"}]}], 
      "]"}]}], ")"}], "/;", 
   RowBox[{"\[InvisibleSpace]", 
    RowBox[{"!", 
     RowBox[{"(", 
      RowBox[{"OrderedQ", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}]}], "}"}], "]"}], 
      ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"TJI", "[", 
  RowBox[{"d", ",", "pp", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "m1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "m2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "m3"}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJI", "[", 
   RowBox[{"d_", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TBI", "Subsubsection",
 CellTags->"T1.3.7.7.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["TBI",
    FontColor->RGBColor[1, 0.6, 0]], "[", 
   RowBox[{"de_", ",", "pp_", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_Integer", ",", "m1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n2_Integer", ",", "m2_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"TJI", "[", 
      RowBox[{"de", ",", "pp", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}]}], "}"}]}], "]"}], "=", 
     RowBox[{
      StyleBox["TBI",
       FontColor->RGBColor[1, 0.6, 0]], "[", 
      RowBox[{"de", ",", "pp", ",", 
       RowBox[{"Reverse", "@", 
        RowBox[{"Sort", "@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"n1", ",", "m1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"n2", ",", "m2"}], "}"}]}], "}"}]}]}]}], "]"}]}], ")"}], "/;",
    "\[InvisibleSpace]", 
   RowBox[{"!", 
    RowBox[{"(", 
     RowBox[{"OrderedQ", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n2", ",", "m2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n1", ",", "m1"}], "}"}]}], "}"}], "]"}], 
     ")"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBI", "[", 
   RowBox[{"d_", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TAI", "Subsubsection",
 CellTags->"T1.3.7.8.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["TAI",
     FontColor->RGBColor[1, 0.6, 0]], "[", 
    RowBox[{"de_", ",", "pp_", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n1_Integer", ",", "0"}], "}"}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions and notation", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]\[ScriptCapitalC]", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    RowBox[{"Det", "[", " ", 
     RowBox[{"(", GridBox[{
        {"0", "1", "1", "1", "1"},
        {"1", "0", 
         SubscriptBox["\[Mu]", "6"], 
         SubscriptBox["\[Mu]", "4"], 
         SubscriptBox["\[Mu]", "3"]},
        {"1", 
         SubscriptBox["\[Mu]", "6"], "0", 
         SubscriptBox["\[Mu]", "2"], 
         SubscriptBox["\[Mu]", "1"]},
        {"1", 
         SubscriptBox["\[Mu]", "4"], 
         SubscriptBox["\[Mu]", "2"], "0", 
         SubscriptBox["\[Mu]", "5"]},
        {"1", 
         SubscriptBox["\[Mu]", "3"], 
         SubscriptBox["\[Mu]", "1"], 
         SubscriptBox["\[Mu]", "5"], "0"}
       }], ")"}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkli", " ", "=", " ", 
   RowBox[{"{", "\n", "\t\t", 
    RowBox[{
     RowBox[{"\[ScriptCapitalC]", "->", "\[CapitalDelta]\[ScriptCapitalC]"}], 
     ",", "\n", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "i_"], ":>", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        SubscriptBox["\[Mu]", "i"]], "\[CapitalDelta]\[ScriptCapitalC]"}]}], 
     ",", "\n", "\t\t", 
     RowBox[{
      SubscriptBox["\[Mu]", "6"], ":>", "PP"}], ",", 
     RowBox[{
      SubscriptBox["\[Mu]", "i_"], ":>", 
      RowBox[{
       RowBox[{"ToExpression", "[", 
        RowBox[{"\"\<m\>\"", "<>", 
         RowBox[{"ToString", "[", "i", "]"}]}], "]"}], "^", "2"}]}], ",", 
     "\n", "\t\t", 
     RowBox[{
      SubscriptBox["m", "1"], ":>", 
      SqrtBox[
       SuperscriptBox["m1", "2"]]}], ",", 
     RowBox[{
      SubscriptBox["m", "2"], ":>", 
      SqrtBox[
       SuperscriptBox["m2", "2"]]}], ",", 
     RowBox[{
      SubscriptBox["m", "3"], ":>", 
      SqrtBox[
       SuperscriptBox["m3", "2"]]}], ",", 
     RowBox[{
      SubscriptBox["m", "4"], ":>", 
      SqrtBox[
       SuperscriptBox["m4", "2"]]}], ",", 
     RowBox[{
      SubscriptBox["m", "5"], ":>", 
      SqrtBox[
       SuperscriptBox["m5", "2"]]}], ",", "\n", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", 
       RowBox[{"i_", ",", "j_", ",", "k_"}]], ":>", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "i", "2"], "+", 
       SubsuperscriptBox["\[Mu]", "j", "2"], "+", 
       SubsuperscriptBox["\[Mu]", "k", "2"], "-", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "i"], 
           SubscriptBox["\[Mu]", "j"]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "j"], 
           SubscriptBox["\[Mu]", "k"]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "k"], 
           SubscriptBox["\[Mu]", "i"]}]}], ")"}]}]}]}], ",", "\n", 
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"i_", ",", "j_", ",", "k_"}]], ":>", 
      RowBox[{
       SubscriptBox["\[Mu]", "i"], "-", 
       SubscriptBox["\[Mu]", "j"], "-", 
       SubscriptBox["\[Mu]", "k"]}]}], ",", "\n", 
     RowBox[{
      SubscriptBox["\[CapitalSigma]", "i_"], ":>", 
      RowBox[{
       RowBox[{"3", " ", "d"}], " ", "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Sum]", 
           RowBox[{"j", "=", "1"}], "i"], 
          SubscriptBox["\[Nu]", "j"]}], ")"}]}], "-", "2"}]}], ",", "\n", 
     "\t", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "\[RuleDelayed]", "n1"}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "\[RuleDelayed]", "n2"}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], "\[RuleDelayed]", "n3"}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "4"], "\[RuleDelayed]", "n4"}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "5"], "\[RuleDelayed]", "n5"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "Define symmetry property for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"i", ",", "j", ",", "k"}]], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalDelta]", 
   RowBox[{"i_", ",", "j_", ",", "k_"}]], ":=", 
  RowBox[{
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"Sequence", "@@", 
     RowBox[{"Sort", "[", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}]], "/;", 
   RowBox[{"!", 
    RowBox[{"OrderedQ", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 SubscriptBox["\[CapitalDelta]", 
  RowBox[{"3", ",", "1", ",", "2"}]]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["ToArgs",
  FontColor->RGBColor[0.2, 0.6, 1]]], "Subsection",
 CellTags->"T1.4.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["ToArgs",
     FontColor->RGBColor[0.2, 0.6, 1]], "[", "z_", "]"}], ":=", 
   RowBox[{"Expand", "[", 
    RowBox[{"z", "//.", "checkli"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ToArgs", "[", 
   SubscriptBox["\[CapitalSigma]", "4"], "]"}], "//", "InputForm"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["Cayley",
  FontColor->RGBColor[1, 0, 0.4]]], "Subsection",
 CellTags->"T1.4.2.1"],

Cell[TextData[{
 "This is (40).  ( p = ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    SuperscriptBox["p", "2"]], TraditionalForm]]],
 ")"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"setd", "[", 
   RowBox[{
    RowBox[{"hCayley", "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "1"],
        m1], ":", "_"}], ",", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "2"],
        m2], ":", "_"}], ",", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "3"],
        m3], ":", "_"}], ",", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4], ":", "_"}], ",", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "5"],
        m5], ":", "_"}], ",", "p_"}], "]"}], ",", 
    RowBox[{"set", "[", 
     RowBox[{
      RowBox[{"hCayley", "[", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "1"],
         m1], ",", 
        InterpretationBox[
         SubscriptBox["m", "2"],
         m2], ",", 
        InterpretationBox[
         SubscriptBox["m", "3"],
         m3], ",", 
        InterpretationBox[
         SubscriptBox["m", "4"],
         m4], ",", 
        InterpretationBox[
         SubscriptBox["m", "5"],
         m5], ",", "p"}], "]"}], ",", 
      RowBox[{"factor", "[", 
       RowBox[{
        RowBox[{
         StyleBox["ToArgs",
          FontColor->RGBColor[0.2, 0.6, 1]], "[", "\[ScriptCapitalC]", "]"}], 
        "/.", 
        RowBox[{
         InterpretationBox[
          SuperscriptBox["p", "2"],
          PP], "\[Rule]", 
         SuperscriptBox["p", "2"]}]}], "]"}]}], "]"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hCayley", "\[RuleDelayed]", 
     StyleBox["Cayley",
      FontColor->RGBColor[1, 0, 0.4]]}], ",", 
    RowBox[{"setd", "\[RuleDelayed]", "SetDelayed"}], ",", 
    RowBox[{"set", "\[RuleDelayed]", "Set"}], ",", 
    RowBox[{"factor", "\[RuleDelayed]", "Factor"}]}], "}"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["Cayley",
    FontColor->RGBColor[1, 0, 0.4]], "[", "i", "]"}], "=", 
  SubscriptBox["\[CapitalDelta]", "i"]}]], "Subsection",
 CellTags->"T1.4.3.1"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"setd", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hCayley", "[", "i", "]"}], "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "1"],
           m1], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "2"],
           m2], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "3"],
           m3], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "4"],
           m4], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "5"],
           m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
      RowBox[{"set", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"hCayley", "[", "i", "]"}], "[", 
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            SubscriptBox["m", "1"],
            m1], ",", 
           InterpretationBox[
            SubscriptBox["m", "2"],
            m2], ",", 
           InterpretationBox[
            SubscriptBox["m", "3"],
            m3], ",", 
           InterpretationBox[
            SubscriptBox["m", "4"],
            m4], ",", 
           InterpretationBox[
            SubscriptBox["m", "5"],
            m5], ",", "p"}], "}"}], "]"}], ",", 
        RowBox[{"factor", "[", 
         RowBox[{
          RowBox[{
           StyleBox["ToArgs",
            FontColor->RGBColor[0.2, 0.6, 1]], "[", 
           SubscriptBox["\[CapitalDelta]", "i"], "]"}], "/.", 
          RowBox[{
           InterpretationBox[
            SuperscriptBox["p", "2"],
            PP], "\[Rule]", 
           SuperscriptBox["p", "2"]}]}], "]"}]}], "]"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"hCayley", "\[RuleDelayed]", 
       StyleBox["Cayley",
        FontColor->RGBColor[1, 0, 0.4]]}], ",", 
      RowBox[{"setd", "\[RuleDelayed]", "SetDelayed"}], ",", 
      RowBox[{"set", "\[RuleDelayed]", "Set"}], ",", 
      RowBox[{"factor", "\[RuleDelayed]", "Factor"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "6"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox["ToArgs",
   FontColor->RGBColor[0.2, 0.6, 1]], "[", 
  SubscriptBox["\[CapitalDelta]", 
   RowBox[{"1", ",", "2", ",", "6"}]], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["Cayley",
      FontColor->RGBColor[1, 0, 0.4]], "[", 
     RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "m_List", "]"}], ":=", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["Cayley",
       FontColor->RGBColor[1, 0, 0.4]], "[", 
      RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "m", "]"}], "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mm", "=", "m"}], "}"}], ",", "\n", "\t\t\t", 
      RowBox[{
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "mm", "]"}], "<", "7"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mm", ",", 
           RowBox[{"Last", "[", "mm", "]"}]}], "]"}]}], "]"}], ";", "\n", 
       "\t\t\t", 
       RowBox[{"FactorC", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
          "mm", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "4"], 
         "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
           "mm", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "2"],
           " ", 
          SuperscriptBox[
           RowBox[{
           "mm", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
           "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
           "mm", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], "2"],
           " ", 
          SuperscriptBox[
           RowBox[{
           "mm", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
           "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
          "mm", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "4"], 
         "+", 
         SuperscriptBox[
          RowBox[{
          "mm", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], "4"], 
         "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
           "mm", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "2"],
           " ", 
          SuperscriptBox[
           RowBox[{
           "mm", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
           "2"]}]}], "]"}]}]}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["Cayleyu",
      FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
     RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "m_List", "]"}], ":=", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["Cayleyu",
       FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
      RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "mm", "]"}], "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mm", "=", "m"}], "}"}], ",", "\n", "\t\t\t\t\t", 
      RowBox[{
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "mm", "]"}], "<", "7"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mm", ",", 
           RowBox[{"Last", "[", "mm", "]"}]}], "]"}]}], "]"}], ";", 
       RowBox[{"FactorC", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
          "mm", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "2"], 
         "-", 
         SuperscriptBox[
          RowBox[{
          "mm", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "2"], 
         "-", 
         SuperscriptBox[
          RowBox[{
          "mm", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
          "2"]}], "]"}]}]}], "]"}]}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["CayleyD",
    FontColor->RGBColor[1, 0.2, 1]], "[", "i", "]"}], "=", 
  FractionBox[
   SubscriptBox["\[CapitalDelta]", "i"], "\[CapitalDelta]"]}]], "Subsection",
 CellTags->"T1.4.4.1"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"setd", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hCayleyD", "[", "i", "]"}], "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "1"],
           m1], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "2"],
           m2], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "3"],
           m3], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "4"],
           m4], ":", "_"}], ",", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "5"],
           m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
      RowBox[{"set", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"hCayleyD", "[", "i", "]"}], "[", 
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            SubscriptBox["m", "1"],
            m1], ",", 
           InterpretationBox[
            SubscriptBox["m", "2"],
            m2], ",", 
           InterpretationBox[
            SubscriptBox["m", "3"],
            m3], ",", 
           InterpretationBox[
            SubscriptBox["m", "4"],
            m4], ",", 
           InterpretationBox[
            SubscriptBox["m", "5"],
            m5], ",", "p"}], "}"}], "]"}], ",", 
        RowBox[{"factor", "[", 
         FractionBox[
          RowBox[{
           RowBox[{
            StyleBox["ToArgs",
             FontColor->RGBColor[0.2, 0.6, 1]], "[", 
            SubscriptBox["\[CapitalDelta]", "i"], "]"}], "/.", 
           RowBox[{
            InterpretationBox[
             SuperscriptBox["p", "2"],
             PP], "\[Rule]", 
            SuperscriptBox["p", "2"]}]}], 
          RowBox[{"\[ScriptCapitalC]", "[", 
           RowBox[{
            InterpretationBox[
             SubscriptBox["m", "1"],
             m1], ",", 
            InterpretationBox[
             SubscriptBox["m", "2"],
             m2], ",", 
            InterpretationBox[
             SubscriptBox["m", "3"],
             m3], ",", 
            InterpretationBox[
             SubscriptBox["m", "4"],
             m4], ",", 
            InterpretationBox[
             SubscriptBox["m", "5"],
             m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"hCayleyD", "\[RuleDelayed]", 
       StyleBox["CayleyD",
        FontColor->RGBColor[1, 0.2, 1]]}], ",", 
      RowBox[{"setd", "\[RuleDelayed]", "SetDelayed"}], ",", 
      RowBox[{"set", "\[RuleDelayed]", "Set"}], ",", 
      RowBox[{"factor", "\[RuleDelayed]", "Factor"}], ",", 
      RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
       StyleBox["Cayley",
        FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "6"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"setd", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"hCayleyD", "[", 
      RowBox[{"1", ",", "2", ",", "5"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "1"],
         m1], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "2"],
         m2], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "3"],
         m3], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "4"],
         m4], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "5"],
         m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
    RowBox[{"set", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hCayleyD", "[", 
        RowBox[{"1", ",", "2", ",", "5"}], "]"}], "[", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", "p"}], "}"}], "]"}], ",", 
      RowBox[{"factor", "[", 
       FractionBox[
        RowBox[{
         RowBox[{
          StyleBox["ToArgs",
           FontColor->RGBColor[0.2, 0.6, 1]], "[", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"1", ",", "2", ",", "5"}]], "]"}], "/.", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "\[Rule]", 
          SuperscriptBox["p", "2"]}]}], 
        RowBox[{"\[ScriptCapitalC]", "[", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "1"],
           m1], ",", 
          InterpretationBox[
           SubscriptBox["m", "2"],
           m2], ",", 
          InterpretationBox[
           SubscriptBox["m", "3"],
           m3], ",", 
          InterpretationBox[
           SubscriptBox["m", "4"],
           m4], ",", 
          InterpretationBox[
           SubscriptBox["m", "5"],
           m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hCayleyD", "\[RuleDelayed]", 
     StyleBox["CayleyD",
      FontColor->RGBColor[1, 0.2, 1]]}], ",", 
    RowBox[{"setd", "\[RuleDelayed]", "SetDelayed"}], ",", 
    RowBox[{"set", "\[RuleDelayed]", "Set"}], ",", 
    RowBox[{"factor", "\[RuleDelayed]", "Factor"}], ",", 
    RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
     StyleBox["Cayley",
      FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"setd", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"hCayleyD", "[", 
      RowBox[{"1", ",", "3", ",", "6"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "1"],
         m1], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "2"],
         m2], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "3"],
         m3], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "4"],
         m4], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "5"],
         m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
    RowBox[{"set", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hCayleyD", "[", 
        RowBox[{"1", ",", "3", ",", "6"}], "]"}], "[", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", "p"}], "}"}], "]"}], ",", 
      RowBox[{"factor", "[", 
       FractionBox[
        RowBox[{
         RowBox[{
          StyleBox["ToArgs",
           FontColor->RGBColor[0.2, 0.6, 1]], "[", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"1", ",", "3", ",", "6"}]], "]"}], "/.", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "\[Rule]", 
          SuperscriptBox["p", "2"]}]}], 
        RowBox[{"\[ScriptCapitalC]", "[", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "1"],
           m1], ",", 
          InterpretationBox[
           SubscriptBox["m", "2"],
           m2], ",", 
          InterpretationBox[
           SubscriptBox["m", "3"],
           m3], ",", 
          InterpretationBox[
           SubscriptBox["m", "4"],
           m4], ",", 
          InterpretationBox[
           SubscriptBox["m", "5"],
           m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hCayleyD", "\[RuleDelayed]", 
     StyleBox["CayleyD",
      FontColor->RGBColor[1, 0.2, 1]]}], ",", 
    RowBox[{"setd", "\[RuleDelayed]", "SetDelayed"}], ",", 
    RowBox[{"set", "\[RuleDelayed]", "Set"}], ",", 
    RowBox[{"factor", "\[RuleDelayed]", "Factor"}], ",", 
    RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
     StyleBox["Cayley",
      FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"setd", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"hCayleyD", "[", 
      RowBox[{"3", ",", "4", ",", "5"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "1"],
         m1], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "2"],
         m2], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "3"],
         m3], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "4"],
         m4], ":", "_"}], ",", 
       RowBox[{
        InterpretationBox[
         SubscriptBox["m", "5"],
         m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
    RowBox[{"set", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hCayleyD", "[", 
        RowBox[{"3", ",", "4", ",", "5"}], "]"}], "[", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", "p"}], "}"}], "]"}], ",", 
      RowBox[{"factor", "[", 
       FractionBox[
        RowBox[{
         RowBox[{
          StyleBox["ToArgs",
           FontColor->RGBColor[0.2, 0.6, 1]], "[", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "4", ",", "5"}]], "]"}], "/.", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "\[Rule]", 
          SuperscriptBox["p", "2"]}]}], 
        RowBox[{"\[ScriptCapitalC]", "[", 
         RowBox[{
          InterpretationBox[
           SubscriptBox["m", "1"],
           m1], ",", 
          InterpretationBox[
           SubscriptBox["m", "2"],
           m2], ",", 
          InterpretationBox[
           SubscriptBox["m", "3"],
           m3], ",", 
          InterpretationBox[
           SubscriptBox["m", "4"],
           m4], ",", 
          InterpretationBox[
           SubscriptBox["m", "5"],
           m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hCayleyD", "\[RuleDelayed]", 
     StyleBox["CayleyD",
      FontColor->RGBColor[1, 0.2, 1]]}], ",", 
    RowBox[{"setd", "\[RuleDelayed]", "SetDelayed"}], ",", 
    RowBox[{"set", "\[RuleDelayed]", "Set"}], ",", 
    RowBox[{"factor", "\[RuleDelayed]", "Factor"}], ",", 
    RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
     StyleBox["Cayley",
      FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox["ToArgs",
   FontColor->RGBColor[0.2, 0.6, 1]], "[", 
  SubscriptBox["\[CapitalDelta]", 
   RowBox[{"i", ",", "j", ",", "k"}]], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox["ToArgs",
   FontColor->RGBColor[0.2, 0.6, 1]], "[", 
  SubscriptBox["\[CapitalDelta]", 
   RowBox[{"1", ",", "2", ",", "6"}]], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox["ToArgs",
   FontColor->RGBColor[0.2, 0.6, 1]], "[", 
  SubscriptBox["u", 
   RowBox[{"i", ",", "j", ",", "k"}]], "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utility Functions", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.5.1"],

Cell[CellGroupData[{

Cell["MakeFun and friends", "Subsection",
 CellTags->"T1.5.1.1"],

Cell["\<\
This function generates the recursion function definitions for 
TARCER starting from the entered relations.\
\>", "Text"],

Cell["The idea is to recurse TFR into TFI's step by step.", "Text"],

Cell[TextData[{
 "Define: S cD[ijk__] := ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ScriptCapitalC]", 
     RowBox[{"-", "1"}]], 
    SubscriptBox["\[CapitalDelta]", "ijk"]}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nutonand\[CapitalDelta]u", "[", 
    RowBox[{"w_", ",", "5"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"w", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "1"], "\[RuleDelayed]", "n1"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], "\[RuleDelayed]", "n2"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], "\[RuleDelayed]", "n3"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "4"], "\[RuleDelayed]", "n4"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "5"], "\[RuleDelayed]", "n5"}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"\[ScriptCapitalC]", " ", 
         RowBox[{"cD", "[", "ijk", "]"}]}]}], ",", 
       RowBox[{
        SubscriptBox["u", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"cu", "[", "ijk", "]"}]}], ",", "\n", "\t\t", 
       RowBox[{
        SubscriptBox["D", "ijk__"], ":>", 
        RowBox[{"TA", "[", 
         RowBox[{"D", ",", "ijk"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", "ijk__"], ":>", 
        RowBox[{"TA", "[", 
         RowBox[{"\[Rho]", ",", "ijk"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"ijk__", " "}]], ":>", 
        RowBox[{"TA", "[", 
         RowBox[{"\[Phi]", ",", "ijk"}], "]"}]}], ",", "\n", "\t\t\t", 
       RowBox[{
        SubscriptBox["\[Sigma]", 
         RowBox[{"i_", ",", "j_", ",", "k_"}]], ":>", 
        RowBox[{"TA", "[", 
         RowBox[{"\[Sigma]", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
          SubscriptBox["\[Nu]", "i"], ",", 
          SubscriptBox["\[Nu]", "j"], ",", 
          SubscriptBox["\[Nu]", "k"]}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["h", 
         RowBox[{"i_", ",", "j_", ",", "k_"}]], ":>", 
        RowBox[{"TA", "[", 
         RowBox[{"h", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
          SubscriptBox["\[Nu]", "i"], ",", 
          SubscriptBox["\[Nu]", "j"], ",", 
          SubscriptBox["\[Nu]", "k"]}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["S", 
         RowBox[{"i_", ",", "j_", ",", "k_"}]], ":>", 
        RowBox[{"TA", "[", 
         RowBox[{"S", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
          SubscriptBox["\[Nu]", "i"], ",", 
          SubscriptBox["\[Nu]", "j"], ",", 
          SubscriptBox["\[Nu]", "k"]}], "]"}]}], ",", "\n", "\t\t\t", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[CapitalSigma]", "i_"], ":>", 
         RowBox[{"ToArgs", "[", 
          SubscriptBox["\[CapitalSigma]", "i"], "]"}]}], "\n"}]}], "\t\t", 
      "}"}]}], "/.", 
    RowBox[{"{", "\t", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "\[RuleDelayed]", "n1"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "\[RuleDelayed]", "n2"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "\[RuleDelayed]", "n3"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "4"], "\[RuleDelayed]", "n4"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "5"], "\[RuleDelayed]", "n5"}], ",", 
      RowBox[{
       SubscriptBox["m", "1"], ":>", "m1"}], ",", 
      RowBox[{
       SubscriptBox["m", "2"], ":>", "m2"}], ",", 
      RowBox[{
       SubscriptBox["m", "3"], ":>", "m3"}], ",", 
      RowBox[{
       SubscriptBox["m", "4"], ":>", "m4"}], ",", 
      RowBox[{
       SubscriptBox["m", "5"], ":>", "m5"}]}], "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nutonand\[CapitalDelta]u", "[", "w_", "]"}], ":=", 
   RowBox[{
    RowBox[{"w", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "1"], "\[RuleDelayed]", "n1"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], "\[RuleDelayed]", "n2"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], "\[RuleDelayed]", "n3"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "4"], "\[RuleDelayed]", "n4"}], ",", 
       RowBox[{
        SubscriptBox["\[Nu]", "5"], "\[RuleDelayed]", "n5"}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"cD", "[", "ijk", "]"}]}], ",", 
       RowBox[{
        SubscriptBox["u", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"cu", "[", "ijk", "]"}]}], ",", 
       RowBox[{
        SubscriptBox["D", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"TA", "[", 
         RowBox[{"D", ",", "ijk"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"TA", "[", 
         RowBox[{"\[Rho]", ",", "ijk"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[Phi]", "ijk__"], "\[RuleDelayed]", 
        RowBox[{"TA", "[", 
         RowBox[{"\[Phi]", ",", "ijk"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]", 
         RowBox[{"i_", ",", "j_", ",", "k_"}]], "\[RuleDelayed]", 
        RowBox[{"TA", "[", 
         RowBox[{"\[Sigma]", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
          SubscriptBox["\[Nu]", "i"], ",", 
          SubscriptBox["\[Nu]", "j"], ",", 
          SubscriptBox["\[Nu]", "k"]}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["h", 
         RowBox[{"i_", ",", "j_", ",", "k_"}]], "\[RuleDelayed]", 
        RowBox[{"TA", "[", 
         RowBox[{"h", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
          SubscriptBox["\[Nu]", "i"], ",", 
          SubscriptBox["\[Nu]", "j"], ",", 
          SubscriptBox["\[Nu]", "k"]}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["S", 
         RowBox[{"i_", ",", "j_", ",", "k_"}]], "\[RuleDelayed]", 
        RowBox[{"TA", "[", 
         RowBox[{"S", ",", "d", ",", "i", ",", "j", ",", "k", ",", 
          SubscriptBox["\[Nu]", "i"], ",", 
          SubscriptBox["\[Nu]", "j"], ",", 
          SubscriptBox["\[Nu]", "k"]}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalSigma]", "i_"], "\[RuleDelayed]", 
        RowBox[{"ToArgs", "[", 
         SubscriptBox["\[CapitalSigma]", "i"], "]"}]}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "\[RuleDelayed]", "n1"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "\[RuleDelayed]", "n2"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "\[RuleDelayed]", "n3"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "4"], "\[RuleDelayed]", "n4"}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "5"], "\[RuleDelayed]", "n5"}], ",", 
      RowBox[{
       SubscriptBox["m", "1"], "\[RuleDelayed]", "m1"}], ",", 
      RowBox[{
       SubscriptBox["m", "2"], "\[RuleDelayed]", "m2"}], ",", 
      RowBox[{
       SubscriptBox["m", "3"], "\[RuleDelayed]", "m3"}], ",", 
      RowBox[{
       SubscriptBox["m", "4"], "\[RuleDelayed]", "m4"}], ",", 
      RowBox[{
       SubscriptBox["m", "5"], "\[RuleDelayed]", "m5"}]}], "}"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TFR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "li1_", ",", "rest_"}], "]"}], "]"}], ":=", 
   RowBox[{"TFR", "[", 
    RowBox[{"d", ",", "pp", ",", "li1", ",", "rest"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TFI", "[", 
     RowBox[{"d_", ",", "pp_", ",", "li1_List"}], "]"}], "]"}], ":=", 
   RowBox[{"TFI", "[", 
    RowBox[{"d", ",", "pp", ",", "li1"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TFR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_Symbol", ",", "li1_", ",", "rest_"}], 
     "]"}], "]"}], ":=", 
   RowBox[{"TFR", "[", 
    RowBox[{"d", ",", "pp", ",", "dp", ",", "li1", ",", "rest"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TFI", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_Symbol", ",", "li1_List"}], "]"}], 
    "]"}], ":=", 
   RowBox[{"TFI", "[", 
    RowBox[{"d", ",", "pp", ",", "dp", ",", "li1"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TVI", "[", 
     RowBox[{"d_", ",", "pp_", ",", "li1_List"}], "]"}], "]"}], ":=", 
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", "pp", ",", "li1"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nnnnnaddPeP", "[", 
   RowBox[{"any_", "[", 
    RowBox[{"d_", ",", "pp_", ",", "li1_List", ",", "rest__List"}], "]"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"any", "[", 
    RowBox[{"d", ",", "pp", ",", "li1", ",", "rest"}], "]"}], "/;", 
   RowBox[{"any", "=!=", "List"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", "z_List", "]"}], ":=", 
   RowBox[{"Append", "[", 
    RowBox[{"z", ",", 
     SqrtBox["PP"]}], "]"}]}], ";"}]], "Input"],

Cell["addPeP[TFI[d_, z_List]] := TFI[d, PP, z]; ", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TVI", "[", 
     RowBox[{"d_", ",", "z_List"}], "]"}], "]"}], ":=", 
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", "PP", ",", "z"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TJI", "[", 
     RowBox[{"d_", ",", "z_List"}], "]"}], "]"}], ":=", 
   RowBox[{"TJI", "[", 
    RowBox[{"d", ",", "PP", ",", "z"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TFR", "[", 
     RowBox[{"d_", ",", "z_List"}], "]"}], "]"}], ":=", 
   RowBox[{"TFR", "[", 
    RowBox[{"d", ",", "PP_", ",", "z"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TFR", "[", 
     RowBox[{"d_", ",", "pl_List", ",", "z_List"}], "]"}], "]"}], ":=", 
   RowBox[{"TFR", "[", 
    RowBox[{"d", ",", "PP_", ",", "pl", ",", "z"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TVR", "[", 
     RowBox[{"d_", ",", "z__List"}], "]"}], "]"}], ":=", 
   RowBox[{"TVR", "[", 
    RowBox[{"d", ",", "PP_", ",", "z"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"addPeP", "[", 
    RowBox[{"TJR", "[", 
     RowBox[{"d_", ",", "z__List"}], "]"}], "]"}], ":=", 
   RowBox[{"TJR", "[", 
    RowBox[{"d", ",", "PP_", ",", "z"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nutomass", "[", "w_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "+", "i1_."}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n1", "+", "i1"}], ",", "m1"}], "}"}]}], ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "+", "i2_."}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n2", "+", "i2"}], ",", "m2"}], "}"}]}], ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "3"], "+", "i3_."}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n3", "+", "i3"}], ",", "m3"}], "}"}]}], ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "4"], "+", "i4_."}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n4", "+", "i4"}], ",", "m4"}], "}"}]}], ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "5"], "+", "i5_."}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n5", "+", "i5"}], ",", "m5"}], "}"}]}]}], "}"}]}], "/.", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "in1_Integer", ",", "in2_Integer", ",", "in3_Integer", ",", 
        "in4_Integer"}], "}"}], "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"in1", ",", "m1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"in2", ",", "m2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"in3", ",", "m3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"in4", ",", "m4"}], "}"}]}], "}"}]}]}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"in1_Integer", ",", "in2_Integer", ",", "in3_Integer"}], "}"}], 
     "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"in1", ",", "m1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"in2", ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"in3", ",", "m3"}], "}"}]}], "}"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "maybeF", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"maybeF", "[", "z_Times", "]"}], ":=", 
   RowBox[{
    RowBox[{"FactorC", "[", "z", "]"}], "/;", 
    RowBox[{
     RowBox[{"FreeQ", "[", 
      RowBox[{"z", ",", "TFI"}], "]"}], "&&", 
     RowBox[{"FreeQ", "[", 
      RowBox[{"z", ",", "TVI"}], "]"}], "&&", 
     RowBox[{"FreeQ", "[", 
      RowBox[{"z", ",", "TJI"}], "]"}], "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"Cases", "[", 
        RowBox[{"z", ",", 
         RowBox[{"cD", "[", "__", "]"}], ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], ">", "1"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"maybeF", "[", "z_", "]"}], ":=", "z"}], ";", 
  RowBox[{"SetAttributes", "[", 
   RowBox[{"top", ",", "Listable"}], "]"}], ";"}]], "Input"],

Cell["This is the function for the information of side conditions.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{
    StyleBox["IFF",
     FontColor->RGBColor[0.6, 0.4, 1]], ",", "HoldAll"}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{
        StyleBox["TFI",
         FontColor->RGBColor[1, 0.6, 0]], "[", "t__", "]"}]}], "==", "rhs_"}],
      ",", "eqn_String", ",", 
     RowBox[{
      StyleBox["IFF",
       FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{
    StyleBox["Block",
     CellFrame->True,
     FontSize->16,
     FontWeight->"Bold",
     FontColor->RGBColor[1, 0.2, 0.2]], "[", 
    RowBox[{
     RowBox[{"{", "nm", "}"}], ",", 
     RowBox[{
      RowBox[{"nmrel", "=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"{", "mrel", "}"}], "]"}], ",", 
         RowBox[{
          RowBox[{"FreeQ", "[", 
           RowBox[{"#1", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"HoldForm", "@@", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"setdel", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    StyleBox["TFR",
                    FontColor->RGBColor[0, 0.6, 0]], "@@", 
                    RowBox[{"top", "/@", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"{", "t", "}"}], "]"}]}]}], "]"}], "/.", 
                    "nmrel"}], ",", 
                    RowBox[{
                    RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "CompoundExpression", "]"}], "[", 
                    "\t", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "TComment", "]"}], "[", 
                    RowBox[{"eqn", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"TFR", "[", "t", "]"}], "]"}], "]"}], "/.", 
                    RowBox[{"TFR", "->", "TFIC"}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Pattern", ":>", "pat"}], ",", 
                    RowBox[{"Blank", ":>", "blank"}]}], "}"}]}], "/.", 
                    RowBox[{
                    RowBox[{"pat", "[", 
                    RowBox[{"PP", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ":>", "PP"}]}], "/.",
                     "nmrel"}]}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"TT", "=", 
                    RowBox[{"Expand3", "[", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "c"], 
                    RowBox[{"(", 
                    RowBox[{"rhs", "/.", 
                    RowBox[{
                    RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "te__", "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "te", "]"}], "]"}], 
                    "]"}]}]}], ")"}]}], ",", "5"}], "]"}], "]"}]}], ",", 
                    RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "__", "]"}], ",", 
                    RowBox[{
                    RowBox[{"maybeF", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Numerator", "[", "#1", "]"}], ",", 
                    RowBox[{"cD", "[", "__", "]"}], ",", "Factor"}], "]"}], 
                    "/", 
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Denominator", "[", "#1", "]"}], ",", 
                    RowBox[{"cD", "[", "__", "]"}], ",", "Factor"}], "]"}]}], 
                    "&"}], ")"}], "/@", 
                    RowBox[{"Factor", "[", "#1", "]"}]}], "]"}], "&"}]}], 
                    "]"}], "/.", "nmrel"}]}], "]"}], ",", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    RowBox[{
                    StyleBox["IFF",
                    FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds", "]"}], 
                    ",", "5"}], "]"}]}], "]"}]}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"top", "[", "i_Integer", "]"}], "\[Rule]", 
                    "i"}]}], "/.", 
                    RowBox[{"top", "\[RuleDelayed]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{"#1", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "PQ"}], "]"}], 
                    "&"}], ")"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{
                    RowBox[{"dm_", "/;", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"d", ",", 
                    InterpretationBox[
                    SuperscriptBox["p", "2"],
                    PP], ",", "DP", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "5"],
                    m5]}], "}"}], ",", "dm"}], "]"}]}], ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "_"}], "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"pattern", "[", 
                    RowBox[{"dm", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}]}]}], "/.", "\n", 
                    "\t\t\t\t\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"blank", "\[RuleDelayed]", "Blank"}], ",", 
                    RowBox[{"pattern", "\[RuleDelayed]", "Pattern"}], ",", 
                    RowBox[{
                    "patternTest", "\[RuleDelayed]", "PatternTest"}]}], 
                    "}"}]}], "}"}]}], "/.", 
                 RowBox[{
                  RowBox[{"cD", "[", "ijk__", "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Hold", "[", 
                    RowBox[{
                    StyleBox["CayleyD",
                    FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", "]"}], "]"}],
                    "[", 
                   RowBox[{"addPeP", "[", 
                    RowBox[{"BLA", "=", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_"}], "}"}], "\[RuleDelayed]", 
                    "ma"}]}]}], "]"}], "]"}]}]}], "/.", 
                RowBox[{"addPeP", "->", "Identity"}]}], "/.", 
               RowBox[{
                RowBox[{"Hold", "[", "CompoundExpression", "]"}], "\[Rule]", 
                "CompoundExpression"}]}], "/.", 
              RowBox[{
               RowBox[{
                RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                RowBox[{"a_", ",", 
                 RowBox[{
                  StyleBox["IFF",
                   FontColor->RGBColor[0.6, 0.4, 1]], "[", "b_", "]"}]}], 
                "]"}], "\[Rule]", 
               RowBox[{"a", "/;", "b"}]}]}], "/.", 
             RowBox[{
              RowBox[{"Hold", "[", "Set", "]"}], "\[Rule]", "Set"}]}], "/.", 
            RowBox[{
             RowBox[{"Hold", "[", "TComment", "]"}], "->", "TComment"}]}], "/.", 
           RowBox[{
            RowBox[{"Hold", "[", 
             RowBox[{
              StyleBox["CayleyD",
               FontColor->RGBColor[1, 0.2, 1]], "[", "ijk__", "]"}], "]"}], 
            "\[Rule]", 
            RowBox[{
             StyleBox["CayleyD",
              FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", "]"}]}]}], "/.", 
          RowBox[{"{", 
           RowBox[{"setdel", "\[RuleDelayed]", "SetDelayed"}], "}"}]}], ")"}],
         "/.", 
        RowBox[{"Identity", "->", "identit"}]}], "/.", 
       RowBox[{
        RowBox[{"identit", "[", "a_", "]"}], "->", "a"}]}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{
        StyleBox["TFI",
         FontColor->RGBColor[1, 0.6, 0]], "[", "t__", "]"}]}], "==", "rhs_"}],
      ",", "eqn_String", ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     StyleBox["Block",
      CellFrame->True,
      FontSize->16,
      FontWeight->"Bold",
      FontColor->RGBColor[1, 0.2, 0.2]], "[", 
     RowBox[{
      RowBox[{"{", "nm", "}"}], ",", 
      RowBox[{
       RowBox[{"nmrel", "=", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", "mrel", "}"}], "]"}], ",", 
          RowBox[{
           RowBox[{"FreeQ", "[", 
            RowBox[{"#1", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"HoldForm", "@@", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"setdel", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    StyleBox["TFR",
                    FontColor->RGBColor[0, 0.6, 0]], "@@", 
                    RowBox[{"top", "/@", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"{", "t", "}"}], "]"}]}]}], "]"}], "/.", 
                    "nmrel"}], ",", 
                    RowBox[{
                    RowBox[{"Hold", "[", "CompoundExpression", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "TComment", "]"}], "[", 
                    RowBox[{"eqn", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"TFR", "[", "t", "]"}], "]"}], "]"}], "/.", 
                    RowBox[{"TFR", "->", "TFIC"}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Pattern", ":>", "pat"}], ",", 
                    RowBox[{"Blank", ":>", "blank"}]}], "}"}]}], "/.", 
                    RowBox[{
                    RowBox[{"pat", "[", 
                    RowBox[{"PP", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ":>", "PP"}]}], "/.",
                     "nmrel"}]}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"TT", "=", 
                    RowBox[{"Expand3", "[", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    FractionBox["1", "c"], 
                    RowBox[{"(", 
                    RowBox[{"rhs", "/.", 
                    RowBox[{
                    RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "te__", "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "te", "]"}], "]"}], 
                    "]"}]}]}], ")"}]}], "]"}], "]"}]}], ",", 
                    RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "__", "]"}], ",", 
                    RowBox[{
                    RowBox[{"maybeF", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Numerator", "[", "#1", "]"}], ",", 
                    RowBox[{"cD", "[", "__", "]"}], ",", "Factor"}], "]"}], 
                    "/", 
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Denominator", "[", "#1", "]"}], ",", 
                    RowBox[{"cD", "[", "__", "]"}], ",", "Factor"}], "]"}]}], 
                    "&"}], ")"}], "/@", 
                    RowBox[{"Factor", "[", "#1", "]"}]}], "]"}], "&"}]}], 
                    "]"}], "/.", "nmrel"}]}], "]"}]}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"top", "[", "i_Integer", "]"}], "\[Rule]", 
                    "i"}]}], "/.", 
                    RowBox[{"top", "\[RuleDelayed]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{"#1", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "PQ"}], "]"}], 
                    "&"}], ")"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{
                    RowBox[{"dm_", "/;", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"d", ",", 
                    InterpretationBox[
                    SuperscriptBox["p", "2"],
                    PP], ",", "DP", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "5"],
                    m5]}], "}"}], ",", "dm"}], "]"}]}], ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "_"}], "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"pattern", "[", 
                    RowBox[{"dm", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}]}]}], "/.", "\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"blank", "\[RuleDelayed]", "Blank"}], ",", 
                    RowBox[{"pattern", "\[RuleDelayed]", "Pattern"}], ",", 
                    RowBox[{
                    "patternTest", "\[RuleDelayed]", "PatternTest"}]}], 
                    "}"}]}], "}"}]}], "/.", 
                  RowBox[{
                   RowBox[{"cD", "[", "ijk__", "]"}], "\[Rule]", 
                   RowBox[{
                    RowBox[{"Hold", "[", 
                    RowBox[{
                    StyleBox["CayleyD",
                    FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", "]"}], "]"}],
                     "[", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", 
                    RowBox[{"addPeP", "->", "Identity"}]}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_"}], "}"}], "\[RuleDelayed]", 
                    "ma"}]}], "]"}], "]"}]}]}], "/.", 
                 RowBox[{
                  RowBox[{"Hold", "[", "CompoundExpression", "]"}], "\[Rule]",
                   "CompoundExpression"}]}], "/.", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                  RowBox[{"a_", ",", 
                   RowBox[{
                    StyleBox["IFF",
                    FontColor->RGBColor[0.6, 0.4, 1]], "[", "b_", "]"}]}], 
                  "]"}], "\[Rule]", 
                 RowBox[{"a", "/;", "b"}]}]}], "/.", 
               RowBox[{
                RowBox[{"Hold", "[", "Set", "]"}], "\[Rule]", "Set"}]}], "/.", 
              RowBox[{
               RowBox[{"Hold", "[", "TComment", "]"}], "->", "TComment"}]}], "/.", 
             RowBox[{
              RowBox[{"Hold", "[", 
               RowBox[{
                StyleBox["CayleyD",
                 FontColor->RGBColor[1, 0.2, 1]], "[", "ijk__", "]"}], "]"}], 
              "\[Rule]", 
              RowBox[{
               StyleBox["CayleyD",
                FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", "]"}]}]}], "/.", 
            
            RowBox[{"{", 
             RowBox[{"setdel", "\[RuleDelayed]", "SetDelayed"}], "}"}]}], 
           ")"}], "/.", 
          RowBox[{"addPeP", "->", "Identity"}]}], "/.", 
         RowBox[{"Identity", "->", "identit"}]}], "/.", 
        RowBox[{
         RowBox[{"identit", "[", "a_", "]"}], "->", "a"}]}]}]}], "]"}], "/;", 
    
    RowBox[{
     RowBox[{"Head", "[", "mrel", "]"}], "=!=", 
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{
        StyleBox["TVI",
         FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], "==", 
      "rhs_"}], ",", "eqn_String", ",", 
     RowBox[{
      StyleBox["IFF",
       FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{
    StyleBox["Block",
     FontSize->16,
     FontWeight->"Bold",
     FontColor->RGBColor[1, 0.2, 0.2]], "[", 
    RowBox[{
     RowBox[{"{", "nm", "}"}], ",", 
     RowBox[{
      RowBox[{"nmrel", "=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"{", "mrel", "}"}], "]"}], ",", 
         RowBox[{
          RowBox[{"FreeQ", "[", 
           RowBox[{"#1", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], ";", 
      RowBox[{"nmrel", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"nmrel", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["m", "1"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "1"],
             m1]}], ",", 
           RowBox[{
            SubscriptBox["m", "2"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "2"],
             m2]}], ",", 
           RowBox[{
            SubscriptBox["m", "3"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "3"],
             m3]}], ",", 
           RowBox[{
            SubscriptBox["m", "4"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "4"],
             m4]}], ",", 
           RowBox[{
            SubscriptBox["\[CapitalSigma]", "i_"], ":>", 
            RowBox[{"ToArgs", "[", 
             SubscriptBox["\[CapitalSigma]", "i"], "]"}]}]}], "}"}]}], 
        "]"}]}], ";", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"HoldForm", "@@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"setdel", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    StyleBox["TVR",
                    FontColor->RGBColor[0.2, 0.8, 1]], "@@", 
                    RowBox[{"top", "/@", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"{", "t", "}"}], "]"}]}]}], "]"}], "/.", 
                    "nmrel"}], ",", 
                    RowBox[{
                    RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "CompoundExpression", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "TComment", "]"}], "[", 
                    RowBox[{"eqn", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"TVR", "[", "t", "]"}], "]"}], "]"}], "/.", 
                    RowBox[{"TVR", "->", "TVIC"}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Pattern", ":>", "pat"}], ",", 
                    RowBox[{"Blank", ":>", "blank"}]}], "}"}]}], "/.", 
                    RowBox[{
                    RowBox[{"pat", "[", 
                    RowBox[{"PP", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ":>", "PP"}]}], "/.",
                     "nmrel"}]}], "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"TT", "=", 
                    RowBox[{"Expand3", "[", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    FractionBox["1", "c"], 
                    RowBox[{"(", 
                    RowBox[{"rhs", "/.", 
                    RowBox[{
                    RowBox[{
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "te__", "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "te", "]"}], 
                    "]"}], "]"}]}]}], ")"}]}], "]"}], "]"}]}], ",", 
                    RowBox[{
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "__", "]"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"maybeF", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Numerator", "[", "#1", "]"}], ",", 
                    RowBox[{"cu", "[", "__", "]"}], ",", "Factor"}], "]"}], 
                    "/", 
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Denominator", "[", "#1", "]"}], ",", 
                    RowBox[{"cu", "[", "__", "]"}], ",", "Factor"}], "]"}]}], 
                    "&"}], ")"}], "/@", 
                    RowBox[{"Factor", "[", "#1", "]"}]}], "]"}], "&"}]}], 
                    "]"}], "/.", 
                    RowBox[{"\[ScriptCapitalC]", "->", "1"}]}], "/.", 
                    "nmrel"}]}], "]"}], ",", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    StyleBox["IFF",
                    FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds", "]"}], 
                    "]"}]}], "]"}]}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"top", "[", "i_Integer", "]"}], "\[Rule]", 
                    "i"}]}], "/.", 
                    RowBox[{"top", "\[RuleDelayed]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{"#1", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "PQ"}], "]"}], 
                    "&"}], ")"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{
                    RowBox[{"dm_", "/;", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"d", ",", 
                    InterpretationBox[
                    SuperscriptBox["p", "2"],
                    PP], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4]}], "}"}], ",", "dm"}], "]"}]}], ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "_"}], "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"pattern", "[", 
                    RowBox[{"dm", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}]}]}], "/.", "\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"blank", "\[RuleDelayed]", "Blank"}], ",", 
                    RowBox[{"pattern", "\[RuleDelayed]", "Pattern"}], ",", 
                    RowBox[{
                    "patternTest", "\[RuleDelayed]", "PatternTest"}]}], 
                    "}"}]}], "}"}]}], "/.", "\n", "\t\t\t", 
                    RowBox[{
                    RowBox[{"HoldPattern", "[", 
                    RowBox[{"TA", "[", "aijk__", "]"}], "]"}], "\[Rule]", 
                    RowBox[{
                    RowBox[{"Hold", "[", 
                    RowBox[{"TA", "[", "aijk", "]"}], "]"}], "[", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_"}], "}"}], "\[RuleDelayed]", 
                    "ma"}]}], "]"}], "]"}]}]}], "/.", "\n", "\t\t\t", 
                   RowBox[{
                    RowBox[{"cD", "[", "ijk__", "]"}], "\[Rule]", 
                    RowBox[{
                    RowBox[{"Hold", "[", 
                    RowBox[{"Cayley", "[", "ijk", "]"}], "]"}], "[", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_"}], "}"}], "\[RuleDelayed]", 
                    "ma"}]}], "]"}], "]"}]}]}], "/.", 
                  RowBox[{
                   RowBox[{"cu", "[", "ijk__", "]"}], "\[Rule]", 
                   RowBox[{
                    RowBox[{"Hold", "[", 
                    RowBox[{
                    StyleBox["Cayleyu",
                    FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk", "]"}], 
                    "]"}], "[", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", 
                    RowBox[{"addPeP", "->", "Identity"}]}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_"}], "}"}], "\[RuleDelayed]", 
                    "ma"}]}], "]"}], "]"}]}]}], "/.", 
                 RowBox[{
                  RowBox[{"Hold", "[", "CompoundExpression", "]"}], "\[Rule]",
                   "CompoundExpression"}]}], "/.", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                  RowBox[{"a_", ",", 
                   RowBox[{
                    StyleBox["IFF",
                    FontColor->RGBColor[0.6, 0.4, 1]], "[", "b_", "]"}]}], 
                  "]"}], "\[Rule]", 
                 RowBox[{"a", "/;", "b"}]}]}], "/.", 
               RowBox[{
                RowBox[{"Hold", "[", "Set", "]"}], "\[Rule]", "Set"}]}], "/.", 
              RowBox[{
               RowBox[{"Hold", "[", "TComment", "]"}], "->", "TComment"}]}], "/.", 
             RowBox[{"addPeP", "->", "Identity"}]}], "/.", 
            RowBox[{
             RowBox[{"Hold", "[", 
              RowBox[{
               StyleBox["Cayleyu",
                FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk__", "]"}], 
              "]"}], "\[Rule]", 
             RowBox[{
              StyleBox["Cayleyu",
               FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk", "]"}]}]}], "/.", 
           RowBox[{
            RowBox[{"Hold", "[", 
             RowBox[{
              StyleBox["Cayley",
               FontColor->RGBColor[1, 0.2, 1]], "[", "ijk__", "]"}], "]"}], 
            "\[Rule]", 
            RowBox[{
             StyleBox["Cayley",
              FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", "]"}]}]}], "/.", 
          "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"Hold", "[", "TA", "]"}], "->", "TA"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{"setdel", "\[RuleDelayed]", "SetDelayed"}], "}"}]}], "/.", 
        RowBox[{"Identity", "->", "identit"}]}], "/.", 
       RowBox[{
        RowBox[{"identit", "[", "a_", "]"}], "->", "a"}]}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{
        StyleBox["TVI",
         FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], "==", 
      "rhs_"}], ",", "eqn_String", ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     StyleBox["Block",
      FontSize->16,
      FontWeight->"Bold",
      FontColor->RGBColor[1, 0.2, 0.2]], "[", 
     RowBox[{
      RowBox[{"{", "nm", "}"}], ",", 
      RowBox[{
       RowBox[{"nmrel", "=", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", "mrel", "}"}], "]"}], ",", 
          RowBox[{
           RowBox[{"FreeQ", "[", 
            RowBox[{"#1", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], ";", 
       RowBox[{"nmrel", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"nmrel", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["m", "1"], "\[RuleDelayed]", 
             InterpretationBox[
              SubscriptBox["m", "1"],
              m1]}], ",", 
            RowBox[{
             SubscriptBox["m", "2"], "\[RuleDelayed]", 
             InterpretationBox[
              SubscriptBox["m", "2"],
              m2]}], ",", 
            RowBox[{
             SubscriptBox["m", "3"], "\[RuleDelayed]", 
             InterpretationBox[
              SubscriptBox["m", "3"],
              m3]}], ",", 
            RowBox[{
             SubscriptBox["m", "4"], "\[RuleDelayed]", 
             InterpretationBox[
              SubscriptBox["m", "4"],
              m4]}], ",", 
            RowBox[{
             SubscriptBox["\[CapitalSigma]", "i_"], "\[RuleDelayed]", 
             RowBox[{
              StyleBox["ToArgs",
               FontColor->RGBColor[0.2, 0.6, 1]], "[", 
              SubscriptBox["\[CapitalSigma]", "i"], "]"}]}]}], "}"}]}], 
         "]"}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"HoldForm", "@@", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"setdel", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    StyleBox["TVR",
                    FontColor->RGBColor[0.2, 0.8, 1]], "@@", 
                    RowBox[{"top", "/@", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"{", "t", "}"}], "]"}]}]}], "]"}], "/.", 
                    "nmrel"}], ",", 
                    RowBox[{
                    RowBox[{"Hold", "[", "CompoundExpression", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "TComment", "]"}], "[", 
                    RowBox[{"eqn", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"TVR", "[", "t", "]"}], "]"}], "]"}], "/.", 
                    RowBox[{"TVR", "->", "TVIC"}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Pattern", ":>", "pat"}], ",", 
                    RowBox[{"Blank", ":>", "blank"}]}], "}"}]}], "/.", 
                    RowBox[{
                    RowBox[{"pat", "[", 
                    RowBox[{"PP", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ":>", "PP"}]}], "/.",
                     "nmrel"}]}], "]"}], "\n", "\t\t\t\t\t\t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"TT", "=", 
                    RowBox[{"Expand3", "[", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    FractionBox["1", "c"], 
                    RowBox[{"(", 
                    RowBox[{"rhs", "/.", 
                    RowBox[{
                    RowBox[{
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "te__", "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "te", "]"}], 
                    "]"}], "]"}]}]}], ")"}]}], "]"}], "]"}]}], ",", 
                    RowBox[{
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "__", "]"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"maybeF", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Numerator", "[", "#1", "]"}], ",", 
                    RowBox[{"cu", "[", "__", "]"}], ",", "Factor"}], "]"}], 
                    "/", 
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Denominator", "[", "#1", "]"}], ",", 
                    RowBox[{"cu", "[", "__", "]"}], ",", "Factor"}], "]"}]}], 
                    "&"}], ")"}], "/@", 
                    RowBox[{"Factor", "[", "#1", "]"}]}], "]"}], "&"}]}], 
                    "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{"\[ScriptCapitalC]", "\[Rule]", "1"}]}]}], 
                    "]"}]}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"top", "[", "i_Integer", "]"}], "\[Rule]", 
                    "i"}]}], "/.", 
                    RowBox[{"top", "\[RuleDelayed]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{"#1", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "PQ"}], "]"}], 
                    "&"}], ")"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{
                    RowBox[{"dm_", "/;", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"d", ",", 
                    InterpretationBox[
                    SuperscriptBox["p", "2"],
                    PP], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4]}], "}"}], ",", "dm"}], "]"}]}], ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "_"}], "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"pattern", "[", 
                    RowBox[{"dm", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}]}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"blank", "\[RuleDelayed]", "Blank"}], ",", 
                    RowBox[{"pattern", "\[RuleDelayed]", "Pattern"}], ",", 
                    RowBox[{
                    "patternTest", "\[RuleDelayed]", "PatternTest"}]}], 
                    "}"}]}], "}"}]}], "/.", 
                  RowBox[{
                   RowBox[{"cD", "[", "ijk__", "]"}], "\[Rule]", 
                   RowBox[{
                    RowBox[{"Hold", "[", 
                    RowBox[{
                    StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", "ijk", "]"}], "]"}],
                     "[", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_Symbol"}], "}"}], 
                    "\[RuleDelayed]", "ma"}]}], "]"}], "]"}]}]}], "/.", 
                 RowBox[{
                  RowBox[{"cu", "[", "ijk__", "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Hold", "[", 
                    RowBox[{
                    StyleBox["Cayleyu",
                    FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk", "]"}], 
                    "]"}], "[", 
                   RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_Symbol"}], "}"}], 
                    "\[RuleDelayed]", "ma"}]}], "]"}], "]"}]}]}], "/.", 
                RowBox[{
                 RowBox[{"Hold", "[", "CompoundExpression", "]"}], "\[Rule]", 
                 "CompoundExpression"}]}], "/.", 
               RowBox[{
                RowBox[{"Hold", "[", "Set", "]"}], "\[Rule]", "Set"}]}], "/.", 
              RowBox[{
               RowBox[{"Hold", "[", "TComment", "]"}], "->", "TComment"}]}], "/.", 
             RowBox[{"addPeP", "->", "Identity"}]}], "/.", 
            RowBox[{
             RowBox[{"Hold", "[", 
              RowBox[{
               StyleBox["Cayleyu",
                FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk__", "]"}], 
              "]"}], "\[Rule]", 
             RowBox[{
              StyleBox["Cayleyu",
               FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk", "]"}]}]}], "/.", 
           RowBox[{
            RowBox[{"Hold", "[", 
             RowBox[{
              StyleBox["Cayley",
               FontColor->RGBColor[1, 0, 0.4]], "[", "ijk__", "]"}], "]"}], 
            "\[Rule]", 
            RowBox[{
             StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]], "[", "ijk", "]"}]}]}], "/.", 
          RowBox[{"{", 
           RowBox[{"setdel", "\[RuleDelayed]", "SetDelayed"}], "}"}]}], "/.", 
         
         RowBox[{"Identity", "->", "identit"}]}], "/.", 
        RowBox[{
         RowBox[{"identit", "[", "a_", "]"}], "->", "a"}]}]}]}], "]"}], "/;", 
    
    RowBox[{
     RowBox[{"Head", "[", "mrel", "]"}], "=!=", 
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{"TJI", "[", "t__", "]"}]}], "==", "rhs_"}], ",", "eqn_String", 
     ",", 
     RowBox[{
      StyleBox["IFF",
       FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{
    StyleBox["Block",
     FontSize->16,
     FontWeight->"Bold",
     FontColor->RGBColor[1, 0.2, 0.2]], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nm", ",", "nmrel", ",", " ", "result"}], "}"}], ",", 
     RowBox[{
      RowBox[{"\[ScriptCapitalC]", "=", "1"}], ";", 
      RowBox[{"nmrel", "=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"{", "mrel", "}"}], "]"}], ",", 
         RowBox[{
          RowBox[{"FreeQ", "[", 
           RowBox[{"#1", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], ";", 
      RowBox[{"nmrel", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"nmrel", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["m", "1"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "1"],
             m1]}], ",", 
           RowBox[{
            SubscriptBox["m", "2"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "2"],
             m2]}], ",", 
           RowBox[{
            SubscriptBox["m", "3"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "3"],
             m3]}], ",", 
           RowBox[{
            SubscriptBox["m", "4"], "\[RuleDelayed]", 
            InterpretationBox[
             SubscriptBox["m", "4"],
             m4]}], ",", 
           RowBox[{
            SubscriptBox["\[CapitalSigma]", "i_"], "\[RuleDelayed]", 
            RowBox[{
             StyleBox["ToArgs",
              FontColor->RGBColor[0.2, 0.6, 1]], "[", 
             SubscriptBox["\[CapitalSigma]", "i"], "]"}]}]}], "}"}]}], 
        "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"result", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"HoldForm", "@@", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"setdel", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{"TJR", "@@", 
                    RowBox[{"top", "/@", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"{", 
                    RowBox[{"tT", "=", "t"}], "}"}], "]"}]}]}], "]"}], "/.", 
                    "nmrel"}], ",", 
                    RowBox[{
                    RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "CompoundExpression", "]"}], "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "TComment", "]"}], "[", 
                    RowBox[{"eqn", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"TJR", "[", "t", "]"}], "]"}], "]"}], "/.", 
                    RowBox[{"TJR", "->", "TJIC"}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Pattern", ":>", "pat"}], ",", 
                    RowBox[{"Blank", ":>", "blank"}]}], "}"}]}], "/.", 
                    RowBox[{
                    RowBox[{"pat", "[", 
                    RowBox[{"PP", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ":>", "PP"}]}], "/.",
                     "nmrel"}]}], "]"}], "\t", ",", 
                    RowBox[{"TJ", "=", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"TT", "=", 
                    RowBox[{"Expand3", "[", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    FractionBox["1", "c"], 
                    RowBox[{"(", 
                    RowBox[{"rhs", "/.", 
                    RowBox[{
                    RowBox[{"TJI", "[", "te__", "]"}], "\[RuleDelayed]", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{"nutomass", "[", 
                    RowBox[{"TJI", "[", "te", "]"}], "]"}], "]"}]}]}], 
                    ")"}]}], "]"}], "]"}]}], ",", 
                    RowBox[{"TJI", "[", "__", "]"}], ",", 
                    RowBox[{
                    RowBox[{"maybeF", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Numerator", "[", "#1", "]"}], ",", 
                    RowBox[{"cu", "[", "__", "]"}], ",", "Factor"}], "]"}], 
                    "/", 
                    RowBox[{"Collect", "[", 
                    RowBox[{
                    RowBox[{"Denominator", "[", "#1", "]"}], ",", 
                    RowBox[{"cu", "[", "__", "]"}], ",", "Factor"}], "]"}]}], 
                    "&"}], ")"}], "/@", 
                    RowBox[{"Factor", "[", "#1", "]"}]}], "]"}], "&"}]}], 
                    "]"}], "/.", 
                    RowBox[{"\[ScriptCapitalC]", "\[Rule]", "1"}]}], "/.", 
                    "nmrel"}]}]}], "]"}], ",", 
                    RowBox[{"nutonand\[CapitalDelta]u", "[", 
                    RowBox[{
                    StyleBox["IFF",
                    FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds", "]"}], 
                    "]"}]}], "]"}]}], "]"}], "/.", 
                    RowBox[{
                    RowBox[{"top", "[", "i_Integer", "]"}], "\[Rule]", 
                    "i"}]}], "/.", 
                    RowBox[{"top", "\[RuleDelayed]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{"#1", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "PQ"}], "]"}], 
                    "&"}], ")"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"patternTest", "[", 
                    RowBox[{
                    RowBox[{"pattern", "[", 
                    RowBox[{
                    RowBox[{"dm_", "/;", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"d", ",", 
                    InterpretationBox[
                    SuperscriptBox["p", "2"],
                    PP], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3], ",", 
                    InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4]}], "}"}], ",", "dm"}], "]"}]}], ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}], ",", "_"}], "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"pattern", "[", 
                    RowBox[{"dm", ",", 
                    RowBox[{"blank", "[", "]"}]}], "]"}]}]}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"blank", "\[RuleDelayed]", "Blank"}], ",", 
                    RowBox[{"pattern", "\[RuleDelayed]", "Pattern"}], ",", 
                    RowBox[{
                    "patternTest", "\[RuleDelayed]", "PatternTest"}]}], 
                    "}"}]}], "}"}]}], "/.", 
                  RowBox[{
                   RowBox[{"HoldPattern", "[", 
                    RowBox[{"TA", "[", "aijk__", "]"}], "]"}], "\[Rule]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Hold", "[", "TA", "]"}], "[", "aijk", "]"}], "[", 
                    RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_"}], "}"}], "\[RuleDelayed]", 
                    "ma"}]}], "]"}], "]"}]}]}], "/.", 
                 RowBox[{
                  RowBox[{"cD", "[", "ijk__", "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Hold", "[", 
                    RowBox[{
                    StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", "ijk", "]"}], "]"}],
                    "[", 
                   RowBox[{"addPeP", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_Symbol"}], "}"}], 
                    "\[RuleDelayed]", "ma"}]}], "]"}], "]"}]}]}], "/.", 
                RowBox[{
                 RowBox[{"cu", "[", "ijk__", "]"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"Hold", "[", 
                   RowBox[{
                    StyleBox["Cayleyu",
                    FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk", "]"}], 
                   "]"}], "[", 
                  RowBox[{"addPeP", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"nutomass", "[", 
                    RowBox[{"Last", "[", 
                    RowBox[{"{", "t", "}"}], "]"}], "]"}], "/.", "nmrel"}], "/.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"nuu_", ",", "ma_Symbol"}], "}"}], 
                    "\[RuleDelayed]", "ma"}]}], "]"}], "]"}]}]}], "/.", 
               RowBox[{
                RowBox[{"Hold", "[", "CompoundExpression", "]"}], "\[Rule]", 
                "CompoundExpression"}]}], "/.", 
              RowBox[{
               RowBox[{
                RowBox[{"Hold", "[", "Condition", "]"}], "[", 
                RowBox[{"a_", ",", 
                 RowBox[{
                  StyleBox["IFF",
                   FontColor->RGBColor[0.6, 0.4, 1]], "[", "b_", "]"}]}], 
                "]"}], "\[Rule]", 
               RowBox[{"a", "/;", "b"}]}]}], "/.", 
             RowBox[{
              RowBox[{"Hold", "[", "Set", "]"}], "\[Rule]", "Set"}]}], "/.", 
            RowBox[{
             RowBox[{"Hold", "[", "TComment", "]"}], "->", "TComment"}]}], "/.", 
           RowBox[{
            RowBox[{"Hold", "[", 
             RowBox[{
              StyleBox["Cayleyu",
               FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk__", "]"}], 
             "]"}], "\[Rule]", 
            RowBox[{
             StyleBox["Cayleyu",
              FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk", "]"}]}]}], "/.", 
          RowBox[{
           RowBox[{"Hold", "[", 
            RowBox[{
             StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]], "[", "ijk__", "]"}], "]"}], 
           "\[Rule]", 
           RowBox[{
            StyleBox["Cayley",
             FontColor->RGBColor[1, 0, 0.4]], "[", "ijk", "]"}]}]}], "/.", 
         RowBox[{
          RowBox[{"Hold", "[", "TA", "]"}], "\[Rule]", "TA"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"setdel", "\[RuleDelayed]", "SetDelayed"}], "}"}]}]}], ";", 
      RowBox[{"\[ScriptCapitalC]", "=", "."}], ";", " ", "result"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"paTT", ",", "HoldFirst"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"c_.", " ", 
      RowBox[{
       StyleBox["TKI",
        FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], "==", 
     "rhs_"}], ",", "eqn_String", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], ",", 
    RowBox[{"mrel_", ":", 
     RowBox[{"{", "}"}]}]}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"MakeFun", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"c", " ", 
           RowBox[{"TJI", "[", "t", "]"}]}], "==", "rhs"}], "/.", 
         RowBox[{"TKI", "->", "TJI"}]}], ",", "eqn", ",", 
        RowBox[{"IFF", "[", "conds", "]"}], ",", "mrel"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PP", ":>", "0"}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "PP", "]"}], ":>", "0"}], ",", 
        RowBox[{"Pattern", ":>", "paTT"}]}], "}"}]}], "/.", 
     RowBox[{
      RowBox[{"paTT", "[", 
       RowBox[{"0", ",", "_"}], "]"}], "->", "0"}]}], "/.", 
    RowBox[{"paTT", "->", "Pattern"}]}], "/.", 
   RowBox[{
    RowBox[{"TJIC", "[", 
     RowBox[{"d_", ",", "li_List"}], "]"}], ":>", 
    RowBox[{"TJIC", "[", 
     RowBox[{"d", ",", "0", ",", "li"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{
        StyleBox["TBI",
         FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], "==", 
      "rhs_"}], ",", "eqn_String", ",", 
     RowBox[{
      StyleBox["IFF",
       FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"MakeFun", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"TJI", "[", "t", "]"}]}], "==", "rhs"}], "/.", 
       RowBox[{"TBI", "->", "TJI"}]}], ",", "eqn", ",", 
      RowBox[{"IFF", "[", "conds", "]"}], ",", "mrel"}], "]"}], "/.", 
    RowBox[{"{", "\n", "\t\t\t", 
     RowBox[{
      RowBox[{"TJI", ":>", "TBI"}], ",", 
      RowBox[{"TJR", ":>", "TBR"}], ",", 
      RowBox[{"TJIC", ":>", "TBIC"}]}], "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["MakeFun",
     FontColor->RGBColor[1, 0.6, 0.6]], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c_.", " ", 
       RowBox[{
        StyleBox["TAI",
         FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], "==", 
      "rhs_"}], ",", "eqn_String", ",", 
     RowBox[{
      StyleBox["IFF",
       FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], ",", 
     RowBox[{"mrel_", ":", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"MakeFun", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"TJI", "[", "t", "]"}]}], "==", "rhs"}], "/.", 
       RowBox[{"TAI", "->", "TJI"}]}], ",", "eqn", ",", 
      RowBox[{"IFF", "[", "conds", "]"}], ",", "mrel"}], "]"}], "/.", 
    RowBox[{"{", "\n", "\t\t\t", 
     RowBox[{
      RowBox[{"TJI", ":>", "TAI"}], ",", 
      RowBox[{"TJR", ":>", "TAR"}], ",", 
      RowBox[{"TJIC", ":>", "TAIC"}]}], "}"}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Interchange", "Subsubsection",
 CellTags->"T1.5.1.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Interchange", "[", 
   RowBox[{"z_", ",", 
    RowBox[{"i_", "\[LeftRightArrow]", "j_"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Nu]explicit", "[", "z", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "i"], ":>", 
       SubscriptBox["\[Nu]", "j"]}], ",", 
      RowBox[{
       SubscriptBox["\[Nu]", "j"], ":>", 
       SubscriptBox["\[Nu]", "i"]}], ",", 
      RowBox[{
       SubscriptBox["m", "i"], ":>", 
       SubscriptBox["m", "j"]}], ",", 
      RowBox[{
       SubscriptBox["m", "j"], ":>", 
       SubscriptBox["m", "i"]}], ",", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[CapitalDelta]", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["u", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["u", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}], ",", "\n", "\t\t", 
      RowBox[{
       SubscriptBox["h", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["h", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Phi]", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Rho]", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Rho]", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Sigma]", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Sigma]", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}], ",", 
      RowBox[{
       SubscriptBox["D", "ij__"], ":>", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["D", "ij"], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", ":>", "j"}], ",", 
           RowBox[{"j", ":>", "i"}]}], "}"}]}], ")"}]}]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["TFI",
        FontColor->RGBColor[1, 0.6, 0]], "[", 
       RowBox[{"depp__", ",", "args_List"}], "]"}], ":>", 
      RowBox[{
       RowBox[{
        StyleBox["TFI",
         FontColor->RGBColor[1, 0.6, 0]], "[", 
        RowBox[{"depp", ",", 
         RowBox[{"Sort", "[", "args", "]"}]}], "]"}], "/;", 
       "\[InvisibleSpace]", 
       RowBox[{"!", 
        RowBox[{"(", 
         RowBox[{"OrderedQ", "[", "args", "]"}], ")"}]}]}]}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{
       StyleBox["TVI",
        FontColor->RGBColor[1, 0.6, 0]], "[", 
       RowBox[{"depp__", ",", "args_List"}], "]"}], ":>", 
      RowBox[{
       RowBox[{
        StyleBox["TVI",
         FontColor->RGBColor[1, 0.6, 0]], "[", 
        RowBox[{"depp", ",", 
         RowBox[{"Sort", "[", "args", "]"}]}], "]"}], "/;", 
       "\[InvisibleSpace]", 
       RowBox[{"!", 
        RowBox[{"(", 
         RowBox[{"OrderedQ", "[", "args", "]"}], ")"}]}]}]}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{
       StyleBox["TJI",
        FontColor->RGBColor[1, 0.6, 0]], "[", 
       RowBox[{"depp__", ",", "args_List"}], "]"}], ":>", 
      RowBox[{
       RowBox[{
        StyleBox["TJI",
         FontColor->RGBColor[1, 0.6, 0]], "[", 
        RowBox[{"depp", ",", 
         RowBox[{"Sort", "[", "args", "]"}]}], "]"}], "/;", 
       "\[InvisibleSpace]", 
       RowBox[{"!", 
        RowBox[{"(", 
         RowBox[{"OrderedQ", "[", "args", "]"}], ")"}]}]}]}], ",", "\n", 
     "\t\t\t", 
     RowBox[{
      RowBox[{
       StyleBox["TBI",
        FontColor->RGBColor[1, 0.6, 0]], "[", 
       RowBox[{"depp__", ",", "args_List"}], "]"}], ":>", 
      RowBox[{
       RowBox[{
        StyleBox["TBI",
         FontColor->RGBColor[1, 0.6, 0]], "[", 
        RowBox[{"depp", ",", 
         RowBox[{"Sort", "[", "args", "]"}]}], "]"}], "/;", 
       "\[InvisibleSpace]", 
       RowBox[{"!", 
        RowBox[{"(", 
         RowBox[{"OrderedQ", "[", "args", "]"}], ")"}]}]}]}]}], 
    "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Interchange", "[", 
    RowBox[{"z_", ",", 
     RowBox[{"i_", "\[LeftRightArrow]", "j_"}], ",", "vw__"}], "]"}], ":=", 
   RowBox[{"Interchange", "[", 
    RowBox[{
     RowBox[{"Interchange", "[", 
      RowBox[{"z", ",", 
       RowBox[{"i", "\[LeftRightArrow]", "j"}]}], "]"}], ",", "vw"}], "]"}]}],
   ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Interchange", "[", 
    RowBox[{"z_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", "\[LeftRightArrow]", "j_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"Interchange", "[", 
    RowBox[{"Interchange", "[", 
     RowBox[{"z", ",", 
      RowBox[{"i", "\[LeftRightArrow]", "j"}]}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Interchange", "[", 
    RowBox[{"z_", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"i_", "\[LeftRightArrow]", "j_"}], ",", "vw__"}], "}"}]}], 
    "]"}], ":=", 
   RowBox[{"Interchange", "[", 
    RowBox[{
     RowBox[{"Interchange", "[", 
      RowBox[{"z", ",", 
       RowBox[{"i", "\[LeftRightArrow]", "j"}]}], "]"}], ",", "vw"}], "]"}]}],
   ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Interchange", "[", 
  RowBox[{
   RowBox[{"test", "[", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"x", ",", "b", ",", "y"}]], ",", 
     SubscriptBox["\[Nu]", "x"], ",", 
     SubscriptBox["\[Nu]", "y"], ",", 
     SubscriptBox["\[Nu]", "a"], ",", 
     SubscriptBox["\[Nu]", "b"], ",", 
     SubscriptBox["m", "x"]}], "]"}], ",", " ", 
   RowBox[{"x", "\[LeftRightArrow]", "y"}], ",", 
   RowBox[{"a", "\[LeftRightArrow]", "b"}]}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[Nu]explicit", "Subsection",
 CellTags->"T1.5.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Nu]explicit", "[", "z_", "]"}], ":=", 
  RowBox[{
   RowBox[{"z", "/.", 
    RowBox[{
     SubscriptBox["\[CapitalSigma]", "i_"], ":>", 
     RowBox[{"(", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"3", " ", "d"}], " ", "-", "2", " ", "-", 
        RowBox[{"2", " ", 
         RowBox[{
          SubsuperscriptBox["\[Sum]", 
           RowBox[{"j", "=", "1"}], "i"], 
          SubscriptBox["\[Nu]", "j"]}]}]}], "]"}], ")"}]}]}], "/.", "\n", 
   "\t", 
   RowBox[{"{", "\t", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", 
       RowBox[{"i_", ",", "j_", ",", "k_"}]], ":>", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "i"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "j"]}]}], ")"}], 
        SubscriptBox["\[Phi]", 
         RowBox[{"i", ",", "j", ",", "k"}]]}], "-", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "i"]}], "-", 
          SubscriptBox["\[Nu]", "j"]}], ")"}], 
        SubscriptBox["\[Phi]", 
         RowBox[{"j", ",", "i", ",", "k"}]]}], "-", "\n", "\t\t\t\t\t", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "d"}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "i"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "j"]}], "-", 
          SubscriptBox["\[Nu]", "k"], "-", "1"}], ")"}], 
        SubscriptBox["\[Phi]", 
         RowBox[{"k", ",", "i", ",", "j"}]]}]}]}], ",", "\n", "\t\t\t", 
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"i_", ",", "j_", ",", "k_", " "}]], ":>", "\n", "\t\t\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "j"]}], "-", 
          SubscriptBox["\[Nu]", "k"]}], ")"}], 
        SuperscriptBox[
         SubscriptBox["m", "k"], "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"i", ",", "j", ",", "k"}]]}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "d"}], "-", 
          SubscriptBox["\[Nu]", "i"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "j"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "k"]}], "-", "1"}], ")"}], 
        SuperscriptBox[
         SubscriptBox["m", "i"], "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"k", ",", "i", ",", "j"}]]}], "+", "\n", "\t\t\t\t\t", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "j"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Nu]", "k"]}]}], ")"}], 
        SubscriptBox["\[Rho]", 
         RowBox[{"i", ",", "j", ",", "k"}]]}]}]}], ",", "\n", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"i_", ",", "j_", ",", "k_", " "}]], ":>", "\n", "\t\t\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"d", "-", 
           RowBox[{"2", 
            SubscriptBox["\[Nu]", "j"]}], "-", 
           SubscriptBox["\[Nu]", "k"]}], ")"}]}], 
        SuperscriptBox[
         SubscriptBox["m", "k"], "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"j", ",", "i", ",", "k"}]]}], " ", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "j"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "k"]}]}], ")"}], 
        SuperscriptBox[
         SubscriptBox["m", "j"], "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"k", ",", "i", ",", "j"}]]}], "+", "\n", "\t\t\t\t\t", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "d"}], "-", 
          SubscriptBox["\[Nu]", "i"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "j"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "k"]}], "-", "1"}], ")"}], 
        SubscriptBox["\[Rho]", 
         RowBox[{"i", ",", "j", ",", "k"}]]}]}]}]}], "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell["TA", "Subsubsection",
 CellTags->"T1.5.2.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TA", "[", 
      RowBox[{"a_", ",", "d___Symbol", ",", "ijk___Integer"}], "]"}], "[", 
     "__", "]"}], ",", "fmt_"}], "]"}], ":=", 
  RowBox[{"SubscriptBox", "[", 
   RowBox[{"a", ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", "ijk", "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TA", "[", 
      RowBox[{
      "a_", ",", "d___Symbol", ",", "ijk___Integer", ",", "___Symbol"}], 
      "]"}], "[", "__", "]"}], ",", "fmt_"}], "]"}], ":=", 
  RowBox[{"SubscriptBox", "[", 
   RowBox[{"a", ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", "ijk", "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"TA", "[", "args__", "]"}], "[", "mar_List", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"TA", "[", "args", "]"}], "[", "mar", "]"}], "=", 
     RowBox[{
      RowBox[{"ta", "[", "args", "]"}], "[", "mar", "]"}]}], ")"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "Assume that the last argument of {em__} is always p =",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{" ", 
     FormBox[
      SuperscriptBox["p", "2"],
      TraditionalForm]}]], TraditionalForm]]],
 "."
}], "Text"],

Cell["(72)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ta", "[", 
     RowBox[{"D", ",", "i_Integer", ",", "j_Integer", ",", "k_Integer"}], 
     "]"}], "[", 
    RowBox[{"{", "em__", "}"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "=", 
        RowBox[{"Last", "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], ",", 
       RowBox[{"mi", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "i", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mj", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "j", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mk", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "k", 
         "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
     RowBox[{"Factor", "[", 
      RowBox[{
       SuperscriptBox["q", "8"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["q", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mi", "2"], "+", 
          SuperscriptBox["mj", "2"], "+", 
          SuperscriptBox["mk", "2"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["q", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mi", "4"], "+", 
             SuperscriptBox["mj", "4"], "+", 
             SuperscriptBox["mk", "4"]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["mi", "2"], " ", 
              SuperscriptBox["mj", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["mk", "2"], " ", 
              SuperscriptBox["mi", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["mk", "2"], " ", 
              SuperscriptBox["mj", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mi", "6"], "+", 
          SuperscriptBox["mj", "6"], "+", 
          SuperscriptBox["mk", "6"], "-", 
          RowBox[{
           SuperscriptBox["mi", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mj", "4"], "+", 
             SuperscriptBox["mk", "4"]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["mj", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mi", "4"], "+", 
             SuperscriptBox["mk", "4"]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["mk", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mi", "4"], "+", 
             SuperscriptBox["mj", "4"]}], ")"}]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["mi", "2"], " ", 
           SuperscriptBox["mj", "2"], " ", 
           SuperscriptBox["mk", "2"]}]}], ")"}]}], "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          StyleBox["Cayley",
           FontColor->RGBColor[1, 0, 0.4]], "[", 
          RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}], "2"]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["(73)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ta", "[", 
     RowBox[{"\[Rho]", ",", "i_Integer", ",", "j_Integer", ",", "k_Integer"}],
      "]"}], "[", 
    RowBox[{"{", "em__", "}"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "=", 
        RowBox[{"Last", "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], ",", 
       RowBox[{"mi", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "i", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mj", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "j", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mk", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "k", 
         "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["q", "6"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["q", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mi", "2"], "+", 
          SuperscriptBox["mj", "2"], "+", 
          SuperscriptBox["mk", "2"]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mi", "4"], "+", 
             SuperscriptBox["mj", "4"], "+", 
             SuperscriptBox["mk", "4"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["mi", "2"], " ", 
              SuperscriptBox["mj", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["mk", "2"], " ", 
              SuperscriptBox["mi", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["mk", "2"], " ", 
              SuperscriptBox["mj", "2"]}]}], ")"}]}]}], ")"}]}], "+", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mi", "6"], "+", 
         SuperscriptBox["mj", "6"], "+", 
         SuperscriptBox["mk", "6"], "-", 
         RowBox[{
          SuperscriptBox["mi", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["mj", "4"], "+", 
            SuperscriptBox["mk", "4"]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["mj", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["mi", "4"], "+", 
            SuperscriptBox["mk", "4"]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["mk", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["mi", "4"], "+", 
            SuperscriptBox["mj", "4"]}], ")"}]}], "+", 
         RowBox[{"10", " ", 
          SuperscriptBox["mi", "2"], " ", 
          SuperscriptBox["mj", "2"], " ", 
          SuperscriptBox["mk", "2"]}]}], ")"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["(74)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ta", "[", 
     RowBox[{"\[Phi]", ",", "i_Integer", ",", "j_Integer", ",", "k_Integer"}],
      "]"}], "[", 
    RowBox[{"{", "em__", "}"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "=", 
        RowBox[{"Last", "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], ",", 
       RowBox[{"mi", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "i", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mj", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "j", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mk", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "k", 
         "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
     RowBox[{"4", 
      RowBox[{"Factor", "[", 
       RowBox[{
        SuperscriptBox["q", "4"], " ", "+", 
        RowBox[{"2", 
         SuperscriptBox["q", "2"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mi", "2"], "-", 
           SuperscriptBox["mj", "2"], "-", 
           SuperscriptBox["mk", "2"]}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mj", "2"], "-", 
           SuperscriptBox["mk", "2"]}], ")"}], "2"], "+", 
        RowBox[{
         SuperscriptBox["mi", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            SuperscriptBox["mj", "2"]}], "+", 
           RowBox[{"2", 
            SuperscriptBox["mk", "2"]}], "-", 
           RowBox[{"3", 
            SuperscriptBox["mi", "2"]}]}], ")"}]}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["(75)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ta", "[", 
     RowBox[{
     "\[Sigma]", ",", "d_", ",", "i_Integer", ",", "j_Integer", ",", 
      "k_Integer", ",", "\[Nu]i_Integer", ",", "\[Nu]j_Integer", ",", 
      "\[Nu]k_Integer"}], "]"}], "[", 
    RowBox[{"{", "em__", "}"}], "]"}], ":=", 
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], 
       RowBox[{"(", 
        RowBox[{"d", "-", "\[Nu]i", "-", 
         RowBox[{"2", "\[Nu]j"}]}], ")"}], 
       RowBox[{
        RowBox[{"TA", "[", 
         RowBox[{"\[Phi]", ",", "i", ",", "j", ",", "k"}], "]"}], "[", 
        RowBox[{"{", "em", "}"}], "]"}]}], " ", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", "\[Nu]i"}], "-", "\[Nu]j"}], ")"}], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Phi]", ",", "j", ",", "i", ",", "k"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}]}]}]}], "-", 
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "d"}], "-", 
        RowBox[{"2", "\[Nu]i"}], "-", 
        RowBox[{"2", "\[Nu]j"}], "-", "\[Nu]k", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"TA", "[", 
        RowBox[{"\[Phi]", ",", "k", ",", "i", ",", "j"}], "]"}], "[", 
       RowBox[{"{", "em", "}"}], "]"}], " "}]}], "  ", "]"}]}], 
  ";"}]], "Input"],

Cell["(76)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ta", "[", 
     RowBox[{
     "h", ",", "d_", ",", "i_Integer", ",", "j_Integer", ",", "k_Integer", 
      ",", "\[Nu]i_Integer", ",", "\[Nu]j_Integer", ",", "\[Nu]k_Integer"}], 
     "]"}], "[", 
    RowBox[{"{", "em__", "}"}], "]"}], ":=", "\n", "\t", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "=", 
        RowBox[{"Last", "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], ",", 
       RowBox[{"mi", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "i", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mj", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "j", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mk", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "k", 
         "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", "\[Nu]j"}], "-", "\[Nu]k"}], ")"}], 
        SuperscriptBox["mk", "2"], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Phi]", ",", "i", ",", "j", ",", "k"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "d"}], "-", "\[Nu]i", "-", 
          RowBox[{"2", "\[Nu]j"}], "-", 
          RowBox[{"2", "\[Nu]k"}], "-", "1"}], ")"}], 
        SuperscriptBox["mi", "2"], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Phi]", ",", "k", ",", "i", ",", "j"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", "\[Nu]j", "-", 
          RowBox[{"2", " ", "\[Nu]k"}]}], ")"}], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Rho]", ",", "i", ",", "j", ",", "k"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}], " "}]}], "  ", "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["(79)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ta", "[", 
     RowBox[{
     "S", ",", "d_", ",", "i_Integer", ",", "j_Integer", ",", "k_Integer", 
      ",", "\[Nu]i_Integer", ",", "\[Nu]j_Integer", ",", "\[Nu]k_Integer"}], 
     "]"}], "[", 
    RowBox[{"{", "em__", "}"}], "]"}], ":=", "\n", "\t\t", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "=", 
        RowBox[{"Last", "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], ",", 
       RowBox[{"mi", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "i", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mj", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "j", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"mk", "=", 
        RowBox[{
         RowBox[{"{", "em", "}"}], "\[LeftDoubleBracket]", "k", 
         "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"d", "-", 
           RowBox[{"2", "\[Nu]j"}], "-", "\[Nu]k"}], ")"}]}], 
        SuperscriptBox["mk", "2"], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Phi]", ",", "j", ",", "i", ",", "k"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}]}], " ", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", "\[Nu]j", "-", 
          RowBox[{"2", "\[Nu]k"}]}], ")"}], 
        SuperscriptBox["mj", "2"], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Phi]", ",", "k", ",", "i", ",", "j"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}], "test", "\n", 
        FormBox["test",
         TraditionalForm], "2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "d"}], "-", "\[Nu]i", "-", 
          RowBox[{"2", "\[Nu]j"}], "-", 
          RowBox[{"2", "\[Nu]k"}], "-", "1"}], ")"}], 
        RowBox[{
         RowBox[{"TA", "[", 
          RowBox[{"\[Rho]", ",", "i", ",", "j", ",", "k"}], "]"}], "[", 
         RowBox[{"{", "em", "}"}], "]"}]}]}], "   ", "]"}]}], "]"}]}], 
  ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CheckRecursion", "Subsection",
 CellTags->"T1.5.3.1"],

Cell["\<\
The following functions check the recurrence relations for J and V (using the \
final form as generated by MakeFun) via their Mellin-Integral Kernels.\
\>", "Text"],

Cell["\<\
This test is applicable in the general case  and if some of the 
masses vanish, but not for other special cases !!!\
\>", "Text"],

Cell[CellGroupData[{

Cell["CheckTVIRecursion", "Subsubsection",
 CellTags->"T1.5.3.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TVIKernel", "[", 
    RowBox[{"d_", ",", "PP", ",", " ", "lis_"}], "]"}], ":=", "\n", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "PP"}], ")"}], 
     RowBox[{"d", "-", "n1", "-", "n2", "-", "n3", "-", "n4"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m1", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s1"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m2", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s2"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m3", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s3"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m4", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s4"], "*", 
    RowBox[{"TVIpsi", " ", "[", 
     RowBox[{"d", ",", " ", 
      RowBox[{"(", 
       RowBox[{"lis", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m1", "->", "s1"}], ",", 
          RowBox[{"m2", "->", "s2"}], ",", 
          RowBox[{"m3", "->", "s3"}], ",", 
          RowBox[{"m4", "->", "s4"}]}], "}"}]}], ")"}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TVIPsi", "[", 
    RowBox[{"d_", ",", "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n1_", ",", " ", "s1_"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"n2_", ",", "s2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n3_", ",", "s3_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n4_", ",", "s4_"}], "}"}]}], "}"}]}], "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"n1", "+", "n2", "+", "n3", "+", "n4", "+", "1"}]], 
    FractionBox[
     RowBox[{
      RowBox[{"gamma", "[", 
       RowBox[{"-", "s1"}], "]"}], 
      RowBox[{"gamma", "[", 
       RowBox[{
        RowBox[{"d", "/", "2"}], "-", "n1", "-", "s1"}], "]"}]}], 
     RowBox[{"gamma", "[", "n1", "]"}]], 
    FractionBox[
     RowBox[{
      RowBox[{"gamma", "[", 
       RowBox[{"-", "s2"}], "]"}], 
      RowBox[{"gamma", "[", 
       RowBox[{
        RowBox[{"d", "/", "2"}], "-", "n2", "-", "s2"}], "]"}]}], 
     RowBox[{"gamma", "[", "n2", "]"}]], 
    FractionBox[
     RowBox[{
      RowBox[{"gamma", "[", 
       RowBox[{"-", "s3"}], "]"}], 
      RowBox[{"gamma", "[", 
       RowBox[{
        RowBox[{"d", "/", "2"}], "-", "n3", "-", "s3"}], "]"}]}], 
     RowBox[{"gamma", "[", "n3", "]"}]], 
    FractionBox[
     RowBox[{
      RowBox[{"gamma", "[", 
       RowBox[{"-", "s4"}], "]"}], 
      RowBox[{"gamma", "[", 
       RowBox[{"n4", "+", "s4"}], "]"}]}], 
     RowBox[{"gamma", "[", "n4", "]"}]], 
    RowBox[{
     RowBox[{"gamma", "[", 
      RowBox[{
      "n1", "+", "n2", "+", "n3", "+", "n4", "+", "s1", "+", "s2", "+", "s3", 
       "+", "s4", "-", "d"}], "]"}], "/", 
     RowBox[{"gamma", "[", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"d", "/", "2"}]}], "-", "n1", "-", "n2", "-", "n3", "-", "n4",
        "-", "s1", "-", "s2", "-", "s3", "-", "s4"}], "]"}]}], 
    FractionBox[
     RowBox[{"gamma", "[", 
      RowBox[{"n1", "+", "n3", "+", "s1", "+", "s3", "-", 
       RowBox[{"d", "/", "2"}]}], "]"}], 
     RowBox[{"gamma", "[", 
      RowBox[{
      "n1", "+", "n3", "+", "n4", "+", "s1", "+", "s3", "+", "s4", "-", 
       RowBox[{"d", "/", "2"}]}], "]"}]], 
    FractionBox[
     RowBox[{"gamma", "[", 
      RowBox[{
      "d", "-", "n1", "-", "n3", "-", "n4", "-", "s1", "-", "s3", "-", "s4"}],
       "]"}], 
     RowBox[{"gamma", "[", 
      RowBox[{"d", "-", "n1", "-", "n3", "-", "s1", "-", "s3"}], "]"}]]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckTVIRecursion", "[", "expr_", "]"}], ":=", " ", 
  RowBox[{"If", "[", " ", 
   RowBox[{
    RowBox[{"$CheckRecursion", "===", "True"}], ",", "\n", "\t", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rel", ",", "kern", ",", " ", "nkern"}], "}"}], ",", "\n", 
      RowBox[{
       RowBox[{"rel", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Extract", "[", 
            RowBox[{
             RowBox[{"expr", "/.", 
              RowBox[{"TVIC", "->", "TVIkernel"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "2"}], "}"}]}], 
            "]"}], ")"}], "-", 
          RowBox[{"Extract", "[", 
           RowBox[{
            RowBox[{"expr", "/.", 
             RowBox[{"TVI", "->", "TVIkernel"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}]}], "]"}]}], 
         ")"}]}], ";", "\n", 
       RowBox[{"If", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", "TVIkernel", "}"}], "===", 
          RowBox[{"Union", "[", 
           RowBox[{"Head", "/@", 
            RowBox[{"Cases", "[", 
             RowBox[{"rel", ",", 
              RowBox[{
               RowBox[{"ff_", "[", "__", "]"}], "/;", 
               RowBox[{
                RowBox[{"Context", "[", "ff", "]"}], "=!=", 
                "\"\<System`\>\""}]}], ",", "4"}], "]"}]}], "]"}]}], ",", 
         "\t", "\n", 
         RowBox[{
          RowBox[{"rel", "=", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Numerator", "[", 
              RowBox[{"Together", "[", "rel", "]"}], "]"}], ",", " ", 
             RowBox[{"TVI", "[", "__", "]"}], ",", "Factor"}], "]"}]}], ";", 
          "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"rel", "/.", 
            RowBox[{"TVIkernel", "->", "TVIKernel"}]}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"kern", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PP", "->", 
               RowBox[{"-", "1"}]}], ",", 
              RowBox[{"m1", "->", 
               RowBox[{"Sqrt", "[", "z1", "]"}]}], ",", 
              RowBox[{"m2", "->", 
               RowBox[{"Sqrt", "[", "z2", "]"}]}], ",", 
              RowBox[{"m3", "->", 
               RowBox[{"Sqrt", "[", "z3", "]"}]}], ",", 
              RowBox[{"m4", "->", 
               RowBox[{"Sqrt", "[", "z4", "]"}]}]}], "}"}]}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"PowerExpand", "[", "kern", "]"}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"Expand", "[", "kern", "]"}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"kern", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z1", 
                RowBox[{"s1", "+", "w1_."}]], 
               SuperscriptBox["z2", 
                RowBox[{"s2", "+", "w2_."}]], 
               SuperscriptBox["z3", 
                RowBox[{"s3", "+", "w3_."}]], 
               SuperscriptBox["z4", 
                RowBox[{"s4", "+", "w4_."}]], "fac_"}], ":>", 
              RowBox[{"(", 
               RowBox[{"fac", "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s1", "->", 
                   RowBox[{"s1", "-", "w1"}]}], ",", 
                  RowBox[{"s2", "->", 
                   RowBox[{"s2", "-", "w2"}]}], ",", 
                  RowBox[{"s3", "->", 
                   RowBox[{"s3", "-", "w3"}]}], ",", 
                  RowBox[{"s4", "->", 
                   RowBox[{"s4", "-", "w4"}]}]}], "}"}]}], ")"}]}], "}"}]}]}],
           " ", ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"kern", "/.", 
              RowBox[{"TVIpsi", "->", "TVIPsi"}]}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"gamma", "[", "zz_", "]"}], ":>", 
               RowBox[{"gamma", "[", 
                RowBox[{"Expand", "[", "zz", "]"}], "]"}]}], "}"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"gamma", "[", 
               RowBox[{"zz_", "+", "nn_Integer"}], "]"}], ":>", 
              RowBox[{
               RowBox[{"gamma", "[", "zz", "]"}], 
               RowBox[{"Pochhammer", "[", 
                RowBox[{"zz", ",", "nn"}], "]"}]}]}], "}"}]}]}], ";", "\n", 
          "\t\t\t\t", 
          RowBox[{"KERN", "=", "kern"}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"kern", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"gamma", "[", "zz_", "]"}], ":>", "1"}], "}"}]}]}], ";",
           "\n", 
          RowBox[{"kern", "=", 
           RowBox[{
            RowBox[{"kern", "/.", 
             RowBox[{"{", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], 
                RowBox[{"nn_", "+", "ww_Integer"}]], ":>", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], "ww"]}], "}"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "nn_"], ":>", "1"}], "}"}]}]}], 
          ";", "\n", 
          RowBox[{"nkern", "=", 
           RowBox[{"Table", "[", "\n", "\t\t\t", 
            RowBox[{
             RowBox[{"kern", "/.", 
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "d", ",", " ", "n1", ",", " ", "n2", ",", " ", "n3", ",", 
                  "n4", ",", "s1", ",", "s2", ",", " ", "s3", ",", "s4"}], 
                 "}"}], "->", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Random", "[", "]"}], ",", 
                  RowBox[{"{", "9", "}"}]}], "]"}]}], "]"}]}], ",", 
             RowBox[{"{", "3", "}"}]}], "]"}]}], ";", "\n", "nkern"}], "  ", 
         ",", "\n", "\t\t", 
         RowBox[{"Print", "[", "\"\<Matching Error\>\"", "]"}]}], " ", 
        "]"}]}]}], " ", "]"}], ",", "\n", "\t\t", 
    RowBox[{"If", "[", 
     RowBox[{"$Notebooks", ",", 
      RowBox[{"Print", "[", "\"\<Off\>\"", "]"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CheckTJIRecursion", "Subsubsection",
 CellTags->"T1.5.3.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TJIKernel", "[", 
    RowBox[{"d_", ",", "PP", ",", " ", "lis_"}], "]"}], ":=", "\n", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "PP"}], ")"}], 
     RowBox[{"d", "-", "n1", "-", "n2", "-", "n3"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m1", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s1"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m2", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s2"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox["m3", "2"], 
       RowBox[{"-", "PP"}]], ")"}], "s3"], "*", 
    RowBox[{"TJIpsi", " ", "[", 
     RowBox[{"d", ",", " ", 
      RowBox[{"(", 
       RowBox[{"lis", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m1", "->", "s1"}], ",", 
          RowBox[{"m2", "->", "s2"}], ",", 
          RowBox[{"m3", "->", "s3"}]}], "}"}]}], ")"}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIPsi", " ", "[", 
   RowBox[{"d_", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", " ", "s1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2_", ",", "s2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n3_", ",", "s3_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{"TVIPsi", "[", 
     RowBox[{"d", ",", "\n", "\t", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1", ",", " ", "s1"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"n2", ",", "s2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3", ",", "s3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"gamma", "[", "0", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "CheckTJIRecursion", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckTJIRecursion", "[", "expr_", "]"}], ":=", " ", 
  RowBox[{"If", "[", " ", 
   RowBox[{
    RowBox[{"$CheckRecursion", "===", "True"}], ",", "\n", "\t", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rel", ",", "kern", ",", "nkern"}], "}"}], ",", "\n", 
      RowBox[{
       RowBox[{"rel", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Extract", "[", 
            RowBox[{
             RowBox[{"expr", "/.", 
              RowBox[{"TJIC", "->", "TJIkernel"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "2"}], "}"}]}], 
            "]"}], ")"}], "-", 
          RowBox[{"Extract", "[", 
           RowBox[{
            RowBox[{"expr", "/.", 
             RowBox[{"TJI", "->", "TJIkernel"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}]}], "]"}]}], 
         ")"}]}], ";", "\n", "\t\t\t", 
       RowBox[{"REL", "=", "rel"}], ";", "\t\t\t", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", "TJIkernel", "}"}], "===", 
          RowBox[{"Union", "[", 
           RowBox[{"Head", "/@", 
            RowBox[{"Cases", "[", 
             RowBox[{"rel", ",", 
              RowBox[{
               RowBox[{"ff_", "[", "__", "]"}], "/;", 
               RowBox[{
                RowBox[{"Context", "[", "ff", "]"}], "=!=", 
                "\"\<System`\>\""}]}], ",", "4"}], "]"}]}], "]"}]}], " ", ",",
          "\t\t\t", "\n", 
         RowBox[{
          RowBox[{"rel", "=", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Numerator", "[", 
              RowBox[{"Together", "[", "rel", "]"}], "]"}], ",", " ", 
             RowBox[{"TJI", "[", "__", "]"}], ",", "Factor"}], "]"}]}], ";", 
          "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"rel", "/.", 
            RowBox[{"TJIkernel", "->", "TJIKernel"}]}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"kern", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PP", "->", 
               RowBox[{"-", "1"}]}], ",", 
              RowBox[{"m1", "->", 
               RowBox[{"Sqrt", "[", "z1", "]"}]}], ",", 
              RowBox[{"m2", "->", 
               RowBox[{"Sqrt", "[", "z2", "]"}]}], ",", 
              RowBox[{"m3", "->", 
               RowBox[{"Sqrt", "[", "z3", "]"}]}]}], "}"}]}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"PowerExpand", "[", "kern", "]"}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"Expand", "[", "kern", "]"}]}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"kern", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               SuperscriptBox["z1", 
                RowBox[{"s1", "+", "w1_."}]], 
               SuperscriptBox["z2", 
                RowBox[{"s2", "+", "w2_."}]], 
               SuperscriptBox["z3", 
                RowBox[{"s3", "+", "w3_."}]], "fac_"}], ":>", 
              RowBox[{"(", 
               RowBox[{"fac", "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s1", "->", 
                   RowBox[{"s1", "-", "w1"}]}], ",", 
                  RowBox[{"s2", "->", 
                   RowBox[{"s2", "-", "w2"}]}], ",", 
                  RowBox[{"s3", "->", 
                   RowBox[{"s3", "-", "w3"}]}]}], "}"}]}], ")"}]}], "}"}]}]}],
           ";", " ", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"kern", "/.", 
              RowBox[{"TJIpsi", "->", "TJIPsi"}]}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"gamma", "[", "zz_", "]"}], ":>", 
               RowBox[{"gamma", "[", 
                RowBox[{"Expand", "[", "zz", "]"}], "]"}]}], "}"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"gamma", "[", 
               RowBox[{"zz_", "+", "nn_Integer"}], "]"}], ":>", 
              RowBox[{
               RowBox[{"gamma", "[", "zz", "]"}], 
               RowBox[{"Pochhammer", "[", 
                RowBox[{"zz", ",", "nn"}], "]"}]}]}], "}"}]}]}], ";", "\n", 
          "      ", 
          RowBox[{"KERN", "=", "kern"}], ";", "\n", 
          RowBox[{"kern", "=", 
           RowBox[{"kern", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"gamma", "[", "zz_", "]"}], ":>", "1"}], "}"}]}]}], ";",
           "\n", 
          RowBox[{"kern", "=", 
           RowBox[{
            RowBox[{"kern", "/.", 
             RowBox[{"{", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], 
                RowBox[{"nn_", "+", "ww_Integer"}]], ":>", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], "ww"]}], "}"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "nn_"], ":>", "1"}], "}"}]}]}], 
          ";", "\n", 
          RowBox[{"nkern", "=", 
           RowBox[{"Table", "[", "\n", "\t\t\t", 
            RowBox[{
             RowBox[{"kern", "/.", 
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "d", ",", " ", "n1", ",", " ", "n2", ",", " ", "n3", ",", 
                  "s1", ",", "s2", ",", " ", "s3"}], "}"}], "->", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Random", "[", "]"}], ",", 
                  RowBox[{"{", "7", "}"}]}], "]"}]}], "]"}]}], ",", 
             RowBox[{"{", "3", "}"}]}], "]"}]}], ";", "\n", "nkern"}], "  ", 
         ",", "\n", "\t\t", 
         RowBox[{"Print", "[", "\"\<Matching Error\>\"", "]"}]}], " ", 
        "]"}]}]}], " ", "]"}], ",", "\n", "\t\t", 
    RowBox[{"If", "[", 
     RowBox[{"$Notebooks", ",", 
      RowBox[{"Print", "[", "\"\<Off\>\"", "]"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recurrence Relations Input and Recursion Function Generation", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.6.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "[", 
   RowBox[{"d_", ",", "pp_", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", "m1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n2_", ",", "m2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "pp", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n1", ",", "m1"}], "}"}], "}"}]}], "]"}], " ", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], "}"}]}], "]"}]}]}]], "Input"],

Cell[TextData[{
 "Most ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", 
    RowBox[{"...", " "}]], TraditionalForm]]],
 "equations below were entered by the palettes which show up when \
$PutPalettes is set to True.\nExamples of alternative (hand) input are  (50) \
, (201) -- (205)."
}], "Text"],

Cell[CellGroupData[{

Cell["Input (35)", "Subsection",
 CellTags->"T1.6.1.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "35"], "=", "\n", 
   RowBox[{
    RowBox[{"2", 
     SubscriptBox["\[Nu]", "1"], "\[ScriptCapitalC]", " ", 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "3"], "-", 
          SubscriptBox["\[Nu]", "5"]}], ")"}], 
        SubscriptBox["\[CapitalDelta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"3", ",", "4", ",", "5"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "5"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["5", "+"],
             FontWeight->"Bold"],
            Schiebe[5, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "-"],
             FontWeight->"Bold"],
            Schiebe[1, "-"],
            Editable->True]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["5", "-"],
               FontWeight->"Bold"],
              Schiebe[5, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"],
              Editable->True]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["5", "-"],
               FontWeight->"Bold"],
              Schiebe[5, "-"]], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"],
              Editable->True]}], ")"}]}], "+", 
          SubscriptBox["\[Nu]", "5"], "-", 
          SubscriptBox["\[Nu]", "1"]}], ")"}]}], "+", "\n", "\t\t\t\t", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "6"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "-"],
             FontWeight->"Bold"],
            Schiebe[3, "-"],
            Editable->True]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "5"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["5", "+"],
             FontWeight->"Bold"],
            Schiebe[5, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"],
              Editable->True]}], ")"}]}], "+", 
          SubscriptBox["\[Nu]", "3"], "-", 
          SubscriptBox["\[Nu]", "1"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "35"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "35"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (35)", "Subsection",
 CellTags->"T1.6.2.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "351"], "=", 
  RowBox[{
   SubscriptBox["s", "35"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "-", "1"}], ")"}]}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["1", 
    RowBox[{"+", " "}]], TraditionalForm]]],
 " (35_1)"
}], "Subsubsection",
 CellTags->"T1.6.2.1.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "351"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "351"], ",", "\"\<(35_1)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       RowBox[{
        StyleBox["Cayley",
         FontColor->RGBColor[1, 0, 0.4]], "[", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", 
         SqrtBox[
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"+", " "}]], TraditionalForm]]],
 " (35_2)"
}], "Subsubsection",
 CellTags->"T1.6.2.2.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "352"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["h", "351"], ",", 
      RowBox[{"1", "\[LeftRightArrow]", "2"}], ",", 
      RowBox[{"3", "\[LeftRightArrow]", "4"}]}], "]"}], ",", "\"\<(35_2)\>\"",
     ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       RowBox[{
        StyleBox["Cayley",
         FontColor->RGBColor[1, 0, 0.4]], "[", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", 
         SqrtBox[
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    RowBox[{"+", " "}]], TraditionalForm]]],
 " (35_3)"
}], "Subsubsection",
 CellTags->"T1.6.2.3.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "353"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["h", "351"], ",", 
      RowBox[{"1", "\[LeftRightArrow]", "3"}], ",", 
      RowBox[{"2", "\[LeftRightArrow]", "4"}]}], "]"}], ",", "\"\<(35_3)\>\"",
     ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{
       RowBox[{
        StyleBox["Cayley",
         FontColor->RGBColor[1, 0, 0.4]], "[", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", 
         SqrtBox[
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["4", 
    RowBox[{"+", " "}]], TraditionalForm]]],
 " (35_4)"
}], "Subsubsection",
 CellTags->"T1.6.2.4.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "354"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["h", "351"], ",", 
      RowBox[{"1", "\[LeftRightArrow]", "4"}], ",", 
      RowBox[{"2", "\[LeftRightArrow]", "3"}]}], "]"}], ",", "\"\<(35_4)\>\"",
     ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "4"], ">", "1"}], "&&", 
      RowBox[{
       RowBox[{
        StyleBox["Cayley",
         FontColor->RGBColor[1, 0, 0.4]], "[", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", 
         SqrtBox[
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (3501)", "Subsection",
 CellTags->"T1.6.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayley", "[", 
   RowBox[{"m1", ",", "m5", ",", "m5", ",", "m4", ",", "m5", ",", "m5"}], 
   "]"}], "//", "Factor"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["m", "1"], "=", "0"}], "  ", ";", "  ", 
   RowBox[{
    SubscriptBox["m", "2"], "=", 
    RowBox[{
     SubscriptBox["m", "3"], "=", 
     SubscriptBox["m", "5"]}]}], ";", "   ", 
   RowBox[{
    SuperscriptBox["p", "2"], "=", 
    SubsuperscriptBox["m", "5", "2"]}]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "3501"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       SubscriptBox["\[Nu]", "3"], "-", 
       SubscriptBox["\[Nu]", "5"]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "5"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["5", "+"],
          FontWeight->"Bold"],
         Schiebe[5, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True], 
        InterpretationBox[
         RowBox[{
          StyleBox[
           SuperscriptBox["3", "+"],
           FontWeight->"Bold"], " "}],
         Schiebe[3, "+"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "3501"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "3501"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "MakeFun (3501) \[CapitalDelta]=0 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p", "2"], "=", 
     SuperscriptBox["m", "2"]}], ")"}], TraditionalForm]]]
}], "Subsection",
 CellTags->"T1.6.4.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "3501"], "=", 
  SubscriptBox["s", "3501"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "3501"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["s", "3501"], ",", "\"\<(3501)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{"PP", "===", 
      RowBox[{"m5", "^", "2"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m1", ":>", "0"}], ",", 
      RowBox[{"m2", ":>", "m5"}], ",", 
      RowBox[{"m3", ":>", "m5"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (3502)", "Subsection",
 CellTags->"T1.6.5.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayley", "[", 
   RowBox[{"m1", ",", "m5", ",", "m5", ",", "m4", ",", "m5", ",", "m5"}], 
   "]"}], "//", "Factor"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["m", "4"], "=", "0"}], "  ", ";", "  ", 
   RowBox[{
    SubscriptBox["m", "2"], "=", 
    RowBox[{
     SubscriptBox["m", "3"], "=", 
     SubscriptBox["m", "5"]}]}], ";", "   ", 
   RowBox[{
    SuperscriptBox["p", "2"], "=", 
    SubsuperscriptBox["m", "5", "2"]}]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "3502"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       SubscriptBox["\[Nu]", "3"], "-", 
       SubscriptBox["\[Nu]", "5"]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "5"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["5", "+"],
          FontWeight->"Bold"],
         Schiebe[5, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True], 
        InterpretationBox[
         RowBox[{
          StyleBox[
           SuperscriptBox["3", "+"],
           FontWeight->"Bold"], " "}],
         Schiebe[3, "+"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "3502"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "3502"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "MakeFun (3502) \[CapitalDelta]=0 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p", "2"], "=", 
     SuperscriptBox["m", "2"]}], ")"}], TraditionalForm]]]
}], "Subsection",
 CellTags->"T1.6.6.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "3502"], "=", 
  SubscriptBox["s", "3502"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "3502"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "3502"], ",", "\"\<(3502)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{"PP", "===", 
      RowBox[{"m5", "^", "2"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m4", ":>", "0"}], ",", 
      RowBox[{"m2", ":>", "m5"}], ",", 
      RowBox[{"m3", ":>", "m5"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "MakeFun (3503) \[CapitalDelta]=0 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p", "2"], "=", 
     SuperscriptBox["m", "2"]}], ")"}], TraditionalForm]]]
}], "Subsection",
 CellTags->"T1.6.7.1"],

Cell[BoxData[
 RowBox[{"Cayley", "[", 
  RowBox[{"m5", ",", "0", ",", "m3", ",", "m5", ",", "m5", ",", "m5"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "3503"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "3502"], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "2"}], ",", " ", 
    RowBox[{"3", "\[LeftRightArrow]", "4"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "3503"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "3503"], ",", "\"\<(3503)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{"PP", "===", 
      RowBox[{"m5", "^", "2"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m2", ":>", "0"}], ",", 
      RowBox[{"m1", ":>", "m5"}], ",", 
      RowBox[{"m4", ":>", "m5"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "MakeFun (3504) \[CapitalDelta]=0 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["p", "2"], "=", 
     SuperscriptBox["m", "2"]}], ")"}], TraditionalForm]]]
}], "Subsection",
 CellTags->"T1.6.8.1"],

Cell[BoxData[
 RowBox[{"Cayley", "[", 
  RowBox[{"m5", ",", "m2", ",", "0", ",", "m5", ",", "m5", ",", "m5"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "3504"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "3502"], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "3"}], ",", " ", 
    RowBox[{"2", "\[LeftRightArrow]", "4"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "3504"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "3504"], ",", "\"\<(3504)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{"PP", "===", 
      RowBox[{"m5", "^", "2"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m3", ":>", "0"}], ",", 
      RowBox[{"m1", ":>", "m5"}], ",", 
      RowBox[{"m4", ":>", "m5"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (41)", "Subsection",
 CellTags->"T1.6.9.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "41"], "=", "\n", 
   RowBox[{
    RowBox[{"2", 
     SubscriptBox["\[Nu]", "5"], " ", "\[ScriptCapitalC]", " ", 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["5", "+"],
       FontWeight->"Bold"],
      Schiebe[5, "+"]], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}]]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"1", ",", "3", ",", "6"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"]], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"]], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["5", "-"],
               FontWeight->"Bold"],
              Schiebe[5, "-"]]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"]], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"]], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["5", "-"],
               FontWeight->"Bold"],
              Schiebe[5, "-"]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "5"]}]}], ")"}], 
        SubscriptBox["\[CapitalDelta]", "5"]}], "+", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "5"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["5", "+"],
             FontWeight->"Bold"],
            Schiebe[5, "+"]], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"]], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"]]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"]], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "-"],
             FontWeight->"Bold"],
            Schiebe[1, "-"]]}], "+", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "5"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "4"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"]], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "-"],
             FontWeight->"Bold"],
            Schiebe[3, "-"]]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "5"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["5", "+"],
             FontWeight->"Bold"],
            Schiebe[5, "+"]], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"]], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"]]}], ")"}]}], "+", 
          SubscriptBox["\[Nu]", "3"], "-", 
          SubscriptBox["\[Nu]", "5"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}]]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "41"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "41"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (41)", "Subsection",
 CellTags->"T1.6.10.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "41"], "=", 
  RowBox[{
   SubscriptBox["s", "41"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "5"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "5"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "41"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "41"], ",", "\"\<(41)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "5"], ">", "1"}], "&&", 
      RowBox[{
       RowBox[{
        StyleBox["Cayley",
         FontColor->RGBColor[1, 0, 0.4]], "[", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "1"],
          m1], ",", 
         InterpretationBox[
          SubscriptBox["m", "2"],
          m2], ",", 
         InterpretationBox[
          SubscriptBox["m", "3"],
          m3], ",", 
         InterpretationBox[
          SubscriptBox["m", "4"],
          m4], ",", 
         InterpretationBox[
          SubscriptBox["m", "5"],
          m5], ",", 
         SqrtBox[
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (43)", "Subsection",
 CellTags->"T1.6.11.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SuperscriptBox["p", "2"]]],
 " and ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["m", "5", "2"], "==", "0"}], TraditionalForm]]],
 "  &&  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "1", "2"], TraditionalForm]]],
 "==",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "2", "2"], TraditionalForm]]],
 " && ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "3", "2"], TraditionalForm]]],
 "== ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "4", "2"], TraditionalForm]]],
 " ) \[DoubleLongRightArrow] \[CapitalDelta] == 0"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "43"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "1"], "-", 
       SubscriptBox["\[Nu]", "3"], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "5"]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["5", "-"],
            FontWeight->"Bold"],
           Schiebe[5, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["5", "-"],
            FontWeight->"Bold"],
           Schiebe[5, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "43"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "43"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (44)", "Subsection",
 CellTags->"T1.6.12.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SuperscriptBox["p", "2"]]],
 " and ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["m", "5", "2"], "==", "0"}], TraditionalForm]]],
 "  &&  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "1", "2"], TraditionalForm]]],
 "==",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "2", "2"], TraditionalForm]]],
 " && ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "3", "2"], TraditionalForm]]],
 "== ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "4", "2"], TraditionalForm]]],
 " ) \[DoubleLongRightArrow] \[CapitalDelta] == 0"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "44"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "4"], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "5"]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["5", "-"],
            FontWeight->"Bold"],
           Schiebe[5, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", "4"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["5", "-"],
            FontWeight->"Bold"],
           Schiebe[5, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "44"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "44"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (45)", "Subsection",
 CellTags->"T1.6.13.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "45"], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"1", ",", "3", ",", "6"}]], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"6", ",", "1", ",", "3"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "-"],
             FontWeight->"Bold"],
            Schiebe[3, "-"],
            Editable->True]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "5"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["5", "+"],
             FontWeight->"Bold"],
            Schiebe[5, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"],
              Editable->True]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"2", 
        SubscriptBox["u", 
         RowBox[{"1", ",", "3", ",", "6"}]], 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "2"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "+"],
             FontWeight->"Bold"],
            Schiebe[2, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["5", "-"],
               FontWeight->"Bold"],
              Schiebe[5, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True]}], ")"}]}], "+", " ", 
          RowBox[{
           SubscriptBox["\[Nu]", "4"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["4", "+"],
             FontWeight->"Bold"],
            Schiebe[4, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["5", "-"],
               FontWeight->"Bold"],
              Schiebe[5, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"],
              Editable->True]}], ")"}]}], "+", 
          RowBox[{"-", 
           SubscriptBox["\[CapitalSigma]", "5"]}], "-", 
          SubscriptBox["\[Nu]", "1"], "+", 
          RowBox[{"3", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "5"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["5", "+"],
             FontWeight->"Bold"],
            Schiebe[5, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"],
              Editable->True]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "-"],
             FontWeight->"Bold"],
            Schiebe[1, "-"],
            Editable->True]}], "+", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["F",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TFI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4], 
        Subscript[\[Nu], 5]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "45"], "=", 
  RowBox[{"OperatorApplyF", "[", 
   SubscriptBox["e", "45"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (43) and (44)", "Subsection",
 CellTags->"T1.6.14.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "43"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["s", "43"], ",", "\"\<(43)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "+", 
       SubscriptBox["\[Nu]", "3"], "+", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "5"]}], "-", 
       RowBox[{"(", 
        RowBox[{"d", "/.", 
         RowBox[{"dd_Symbol", ":>", "4"}]}], ")"}]}], "=!=", "0"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m5", ":>", "0"}], ",", 
      RowBox[{"m4", ":>", "m3"}], ",", 
      RowBox[{"m2", ":>", "m1"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "44"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["s", "44"], ",", "\"\<(44)\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m5", ":>", "0"}], ",", 
      RowBox[{"m4", ":>", "m3"}], ",", 
      RowBox[{"m2", ":>", "m1"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (50)", "Subsection",
 CellTags->"T1.6.15.1"],

Cell["\<\
Subscript[f, 50] = 
   HoldForm[TFR[d_, PP_, 
      {{(n1_)?PQ, m1_}, {(n2_)?PQ, m2_}, {(n3_)?PQ, m3_}, 
       {(n4_)?PQ, m4_}, {(n5_)?PQ, m5_}}] := 
     (TComment[\"(50)\", TFIC[d, PP, 
          {{n1, m1}, {n2, m2}, {n3, m3}, {n4, m4}, 
           {n5, m5}}]]; 
        Block[{r1 = 3 - d, r2 = 4 - d, 
          r3 = 
           -(m1^2*m2^2*m3^2) + m2^4*m3^2 + m2^2*m3^4 + 
            m1^4*m4^2 - m1^2*m2^2*m4^2 - 
            m1^2*m3^2*m4^2 - m2^2*m3^2*m4^2 + 
            m1^2*m4^4 + m1^2*m2^2*m5^2 - 
            m2^2*m3^2*m5^2 - m1^2*m4^2*m5^2 + 
            m3^2*m4^2*m5^2 + m1^2*m3^2*PP - 
            m2^2*m3^2*PP - m1^2*m4^2*PP + m2^2*m4^2*PP - 
            m1^2*m5^2*PP - m2^2*m5^2*PP - m3^2*m5^2*PP - 
            m4^2*m5^2*PP + m5^4*PP + m5^2*PP^2, 
          r4 = -4 + d, r5 = -3 + d, r6 = -7 + 2*d, 
          r7 = -(m2^2*r4) + m3^2*r5 - m5^2*r5 + m4^2*r6, 
          r8 = -10 + 3*d, r9 = -m3^2 + m4^2, 
          r10 = -11 + 3*d, 
          r11 = -(m4^2*r10) - 3*m5^2*r5 + m3^2*r6, 
          r12 = 
           m2^2*r11 + m5^4*r5 + m2^4*r8 + m4^2*r4*r9 + 
            m5^2*r5*r9, r13 = -6 + d, 
          r14 = -(m4^2*r13) + m5^2*r5, 
          r15 = -3*m3^2 - m4^2*r10 + m5^2*r5, 
          r16 = 
           m3^2*r14 + m2^2*r15 + m2^4*r4 - 2*m3^4*r5 - 
            3*m4^2*m5^2*r5 + m5^4*r5 + m4^4*r8, 
          r17 = m3^2 + 2*m4^2, r18 = -1 + d, 
          r19 = -(m3^2*r13) - 2*m4^2*r18 + 2*m5^2*r5, 
          r20 = 
           2*m2^4 - 3*m3^4 + d*m3^4 - 3*m3^2*m4^2 + 
            2*m4^4 + m2^2*r19 - 2*m5^4*r5 + m5^2*r17*r5, 
          r21 = 2 + d, r22 = 
           2*m5^2 - m4^2*r21 + m2^2*r4 - m3^2*r4, 
          r23 = -7 + d, r24 = 6*m4^2 - 4*m5^2, 
          r25 = 3*m3^2 + m4^2*r18 + m5^2*r23, 
          r26 = 
           -6*m4^4 - 2*m4^2*m5^2*r23 + m3^2*r24 + 
            2*m2^2*r25 - 2*m2^4*r4 - m3^4*r4, 
          r27 = m3^4 + m3^2*m4^2 - 2*m4^4, 
          r28 = m3^2 + m4^2*r23, 
          r29 = -2*m4^2*r18 + m3^2*r21 + 2*m5^2*r23, 
          r30 = -6*m2^4 + 2*m5^2*r28 - m2^2*r29 + r27*r4, 
          r31 = m1^4*r22 + m1^2*r26 + m3^2*r30 + m1^6*r4, 
          r32 = m3 - m4, r33 = m3 + m4, 
          r34 = 2*m3^2 + m4^2, r35 = -17 + 3*d, 
          r36 = m3^2*r23 + m4^2*r35, r37 = -9 + d, 
          r38 = 17 - 3*d, 
          r39 = 5*m3^2 + m4^2*r37 + m5^2*r38, 
          r40 = 1 + d, r41 = 
           5*m4^2 - m5^2*r23 + m2^2*r4 - m3^2*r40, 
          r42 = 
           m5^4*r35 - m5^2*r36 + m2^2*r39 - 2*m1^4*r4 + 
            m2^4*r4 - r32*r33*r34*r4 + m1^2*r41, 
          r43 = m1^2 - m2^2 + m3^2 - m4^2, 
          r44 = 2*m5^2*r13 + r4*r43, 
          r45 = 
           m3^4*r12 + m1^4*r16 + m1^2*m3^2*r20 + 
            PP*r31 + PP^2*r42 + PP^3*r44 + m1^6*r7, 
          r46 = m2^2 + m4^2, r47 = 13 - 3*d, 
          r48 = m4^2*r47 - m5^2*r5 + m3^2*r6, 
          r49 = m5^4*r5 + m5^2*r32*r33*r5 + m4^2*r4*r9, 
          r50 = -18 + 4*d, r51 = -(m4^2*r13) - 3*m5^2*r5, 
          r52 = 
           2*m3^4*r5 + m4^2*m5^2*r5 + m5^4*r5 + 
            m4^4*r50 + m3^2*r51, 
          r53 = -3*m4^2 + 2*m5^2*r5, 
          r54 = 
           m4^4*r47 + 2*m3^4*r5 + m4^2*m5^2*r5 - 
            2*m5^4*r5 + m3^2*r53, 
          r55 = m4^2*r13 + 6*m3^2*r5 - 2*m5^2*r5, 
          r56 = 3*m4^2 + m3^2*r5 - m5^2*r5, 
          r57 = 7 - 2*d, 
          r58 = m3^2*r5 + 3*m5^2*r5 + m4^2*r57, 
          r59 = 
           m2^6*r4 + m2^2*m4^2*r55 + m2^4*r56 + m4^4*r58, 
          r60 = m4^2 - m3^2*r5, r61 = 10 - 3*d, 
          r62 = 2*m5^2 + 3*m4^2*r4 + m3^2*r61, 
          r63 = m4^2 + m5^2*r5, 
          r64 = 
           -4*m4^2*m5^2 + 3*m4^4*r4 - 2*m3^4*r5 + 
            2*m3^2*r63, r65 = m4^2 + m3^2*r5 - m5^2*r5, 
          r66 = 2*m3^2*r5 + 2*m5^2*r5 + m4^2*r61, 
          r67 = 3*m2^4*r4 + 2*m2^2*r65 + m4^2*r66, 
          r68 = 
           -3*m2^6*r4 - 2*m1^4*m4^2*r5 + 
            2*m4^2*m5^2*r60 + m2^4*r62 + m2^2*r64 + 
            m1^2*r67 - 3*m4^4*r4*r9, r69 = -13 + 3*d, 
          r70 = m3^2*r5 + m4^2*r69, 
          r71 = m4^2 - 3*m2^2*r4 - m3^2*r5 + m5^2*r5, 
          r72 = -5 + d, r73 = m3^2 + m5^2*r69 + m4^2*r72, 
          r74 = 
           3*m2^4*r4 - m5^4*r5 + m5^2*r70 + m1^2*r71 + 
            m2^2*r73 + 3*m4^2*r4*r9, 
          r75 = m1^2 - m2^2 + m3^2 - m4^2 - 2*m5^2, 
          r76 = 
           m2^8*r4 + m2^6*r48 + m4^4*r49 + 
            2*m1^4*m4^2*r46*r5 + m2^4*r52 + 
            m2^2*m4^2*r54 - m1^2*r59 + PP*r68 + 
            PP^2*r74 + PP^3*r4*r75, 
          r77 = m3^2 - m4^2 + m5^2, 
          r78 = -2*m2^2 + m4^2 + m5^2, 
          r79 = -2*m1^2 - m3^2 - m4^2 + m5^2, 
          r80 = 
           m1^4 + PP^2 - m1^2*r77 + m3^2*r78 + PP*r79, 
          r81 = m3^2 + m4^2, r82 = m3^2 + m4^2 + m5^2, 
          r83 = m1^2 + m3^2 - m5^2, 
          r84 = 
           m1^4 + 2*m3^2*m4^2 - m4^4 + PP^2 - m2^2*r77 + 
            m5^2*r81 - m1^2*r82 - 2*PP*r83, 
          r85 = m1 - m3, r86 = -PP + r85^2, 
          r87 = m1 + m3, r88 = -PP + r87^2, 
          r89 = m2 - m4, r90 = m2 + m4, 
          r91 = -m1^2 - m2^2 - m3^2 - m4^2 + 2*m5^2, 
          r92 = PP^2 + r85*r87*r89*r90 + PP*r91, 
          r93 = m2^2 - 3*m4^2, r94 = m4 - m5, 
          r95 = m4 + m5, r96 = 2*m3^2 - m4^2 + m5^2, 
          r97 = -m1^2 - m2^2 - 2*m3^2 + 3*m5^2, 
          r98 = 
           PP^2 + m1^2*r93 + m2^2*r94*r95 + m4^2*r96 + 
            PP*r97, r99 = -2 + d, r100 = -m1^2 + m2^2, 
          r101 = m2^2 + m1^2*r72, 
          r102 = m3^2*r101 - 2*m3^4*r4 + m2^2*r100*r4, 
          r103 = 9 - 2*d, r104 = m2^2*r23 + m3^2*r72, 
          r105 = 
           2*m1^4 + m2^4*r103 + m1^2*r104 + m2^2*m3^2*r5, 
          r106 = -9 + 2*d, r107 = m1 - m2, 
          r108 = m1 + m2, 
          r109 = -(r106*r107*r108) + m3^2*r4, 
          r110 = 
           m2^2*r102 + m4^2*r105 + m4^4*r109 - m4^6*r4, 
          r111 = m1^2 + m2^2, 
          r112 = m2^2*r4 - 2*m1^2*r72, r113 = -19 + 5*d, 
          r114 = m3^2*r112 + m3^4*r113 + m2^2*r111*r4, 
          r115 = m3^2*r5 + m2^2*r6, 
          r116 = 
           2*m1^4 + 2*m1^2*r115 + m2^4*r13 + m3^4*r72 - 
            2*m2^2*m3^2*r99, 
          r117 = m2^2*r106 + m3^2*r4 - m1^2*r99, 
          r118 = 
           m2^2*r114 - m4^2*r116 + m4^4*r117 - m4^6*r6, 
          r119 = -(m2^2*r5) + 2*m3^2*r57 + m1^2*r72, 
          r120 = m1^2*r18 + 2*m3^2*r4 - m2^2*r5, 
          r121 = m2^2*r119 + m4^2*r120 + 2*m4^4*r5, 
          r122 = m3^2*r5 + m4^2*r72, 
          r123 = -2*m2^2*r4 - m4^2*r69 + m3^2*r72, 
          r124 = 
           m2^2*r122 + m1^2*r123 + 2*m2^4*r4 + 
            2*m4^2*r32*r33*r4, 
          r125 = -3*m4^2 + m2^2*r4 - m3^2*r72, 
          r126 = m3^2 - m4^2*r72, 
          r127 = 
           -2*m3^2*m4^2 - 2*m1^2*r125 - 2*m2^2*r126 + 
            m4^4*r18 - 4*m2^4*r4 + m3^4*r72, 
          r128 = 
           -(m2^2*r18) + 2*m4^2*r5 + m1^2*r72 + 
            2*m3^2*r72, 
          r129 = 
           m5^2*r127 - m5^4*r128 - r124*r32*r33 + 
            m5^6*r72, r130 = -m1^2 + m2^2 + m3^2 - m4^2, 
          r131 = -14 + 3*d, 
          r132 = 
           -(m3^2*r13) + m4^2*r131 + m1^2*r4 + 5*m2^2*r4, 
          r133 = -2*m5^4 + m5^2*r132 + r130*r32*r33*r4, 
          r134 = 
           m5^2*r118 + m5^4*r121 + PP*r129 + PP^2*r133 + 
            r110*r32*r33 - 2*m5^2*PP^3*r4 + 
            m5^6*r5*r89*r90, r135 = m3 - m4 - m5, 
          r136 = m3 + m4 - m5, r137 = m3 - m4 + m5, 
          r138 = m3 + m4 + m5, r139 = -10 + d, 
          r140 = 13 - 2*d, r141 = d*m4^2 + 2*m3^2*r5, 
          r142 = -8 + d, 
          r143 = m4^2*r142 - m3^2*r99 + m5^2*r99, 
          r144 = 
           m3^2*m4^2*r139 + m4^4*r140 - m5^2*r141 + 
            m2^2*r143 + m3^4*r5 + m5^4*r5, 
          r145 = 3*m3^4 - 12*m3^2*m4^2 + 7*m4^4, 
          r146 = 3*m3^2 + 4*m4^2, r147 = m3^2 - 11*m4^2, 
          r148 = 
           7*m3^4 + 10*m3^2*m4^2 - 17*m4^4 - 5*m5^4 - 
            2*m5^2*r147, r149 = m2^2 + 2*m3^2 + m4^2, 
          r150 = 
           -m2^4 + m2^2*m3^2 + m3^4 + 3*m2^2*m4^2 + 
            m3^2*m4^2 - m4^4 + m5^4 - m5^2*r149, 
          r151 = 
           3*m3^6 + 6*m3^4*m4^2 - 17*m3^2*m4^4 + 
            8*m4^6 + 3*m5^6 - m5^2*r145 - m5^4*r146 + 
            m2^2*r148 - d*r150*r77 + 6*m2^4*r94*r95, 
          r152 = -(m3^2*m4) + m4^3, r153 = 11 - 2*d, 
          r154 = -(d*m3^2*m4^2) + m4^4*r153 + m3^4*r5, 
          r155 = m4^2 + m3^2*r5, 
          r156 = r142*r32*r33 + m5^2*r99, 
          r157 = 11 - 3*d, r158 = -8 + 3*d, 
          r159 = m5^2*r158 + m4^2*r21, 
          r160 = 
           -3*m3^4 + 2*m4^2*m5^2*r106 + m5^4*r157 + 
            m3^2*r159 - m4^4*r18, 
          r161 = 
           -2*m2^6 + m5^2*r154 - 2*m5^4*r155 + 
            m2^4*r156 + m2^2*r160 + r152^2*r4 + m5^6*r5, 
          r162 = m4^2*r23 - 3*m3^2*r72, 
          r163 = -4*m2^2 + m4^2*r18 + m3^2*r23, 
          r164 = -m3^4 + m4^4, 
          r165 = 
           -(m2^4*r13) + m2^2*r162 + m1^2*r163 + 
            r164*r4 + m1^4*r99, r166 = -19 + 4*d, 
          r167 = m4^2 + m3^2*r72, r168 = m3^2 + m4^2*r69, 
          r169 = -2*r168 + 4*m2^2*r4, 
          r170 = 
           -m3^4 + m2^4*r13 - m4^4*r166 + 2*m2^2*r167 + 
            m1^2*r169 + 2*m3^2*m4^2*r72 + m1^4*r99, 
          r171 = m1^2 - m2^2 + 4*m4^2, 
          r172 = 
           -(m5^2*r170) + r165*r32*r33 + m5^6*r72 - 
            m5^4*r171*r72, r173 = m2^2 + m3^2, 
          r174 = -(m4^2*r13) + r131*r173 + m1^2*r8, 
          r175 = m5^2*r174 - 2*m5^4*r4 + r130*r32*r33*r4, 
          r176 = 
           2*m1^6*m4^2 + m1^4*r144 + m1^2*r151 + 
            m3^2*r161 + PP*r172 + PP^2*r175 - 
            2*m5^2*PP^3*r4, r177 = m3^2 + m4^2 - m5^2, 
          r178 = -2*m1^2 + m3^2 - m4^2 + m5^2, 
          r179 = -m3^2 + m4^2 + m5^2, 
          r180 = m2^2*r177 + m4^2*r178 + PP*r179, 
          r181 = -2*m2^2 - m3^2 + m4^2 + m5^2, 
          r182 = m1^2*r177 + m3^2*r181 + PP*r77, 
          r183 = -(m2^2*r13) - 2*m3^2*r5, 
          r184 = 
           m1^2*r183 - 2*m3^4*r4 + m2^4*r57 + m1^4*r72 - 
            m2^2*m3^2*r99, r185 = 3*m2^2*r4 + m3^2*r72, 
          r186 = 
           m2^4*r106 + 2*m1^2*r185 + m1^4*r40 - 
            2*m2^2*m3^2*r6, r187 = r111*r13 - m3^2*r4, 
          r188 = 
           m2^2*r184 + m4^2*r186 - m4^4*r187 + m4^6*r4, 
          r189 = 2*m1^2 + m3^2*r10 + 2*m2^2*r5, 
          r190 = m2^2*r5 + m3^2*r72 + 2*m1^2*r99, 
          r191 = m2^2*r189 - m4^2*r190 - m4^4*r5, 
          r192 = -(m3^2*r5) - m4^2*r72, 
          r193 = 2*m2^2*r4 + m4^2*r69 - m3^2*r72, 
          r194 = 
           m2^2*r192 + m1^2*r193 - 2*m2^4*r4 + 
            2*m4^2*r4*r9, r195 = m2^2 + m4^2 + m3^2*r72, 
          r196 = -(m3^2*r6) - m4^2*r72, 
          r197 = 
           m2^4*r157 + 2*m1^2*r195 + 2*m2^2*r196 + 
            2*m4^2*r17*r4 + m1^4*r72, 
          r198 = 
           m4^2*r10 - 2*m2^2*r5 + 2*m1^2*r72 + m3^2*r72, 
          r199 = 
           r107*r108*r194 + m5^2*r197 - m5^4*r198 + 
            m5^6*r72, r200 = m1^2 - m2^2 - m3^2 + m4^2, 
          r201 = m1^2 + m2^2 + m3^2 + 5*m4^2, 
          r202 = 2*m5^4 - r107*r108*r200 - m5^2*r201, 
          r203 = 
           r107*r108*r110 - m5^2*r188 - m5^4*r191 + 
            PP*r199 + 2*m5^2*PP^3*r4 + PP^2*r202*r4 + 
            m5^6*r5*r89*r90, r204 = m4^2 + m5^2, 
          r205 = -2*m5^2*r5 + m4^2*r99, r206 = 18 - 5*d, 
          r207 = m4^2*r206 + m5^2*r8 - 2*m3^2*r99, 
          r208 = 
           m2^2*r207 + 2*m2^4*r4 - m3^4*r5 - 
            m3^2*r204*r5 + r205*r94*r95, 
          r209 = 2*m3^2*m4^2 + m4^4*r142 + 2*m3^4*r5, 
          r210 = -(m4^2*r18) + m3^2*r5, r211 = 3 - 2*d, 
          r212 = m5^2 + m4^2*r157 + m3^2*r211, 
          r213 = m4^2*r106 + m3^2*r4, 
          r214 = 
           -(d*m3^4) + 10*m3^2*m4^2 - 2*d*m3^2*m4^2 - 
            2*m4^4 + d*m4^4 + 2*m5^2*r213 - 2*m5^4*r4, 
          r215 = 
           d*m3^2*m4^4 - 2*m4^6 - m5^2*r209 + 
            m5^4*r210 + m2^4*r212 + m2^2*r214 + 
            m2^6*r4 + m5^6*r5 - m3^4*m4^2*r99, 
          r216 = m4^2*r13 + m3^2*r99, 
          r217 = m3^2*r5 - m4^2*r72, r218 = 13 - 4*d, 
          r219 = 3*m3^2 + m5^2*r218 + m4^2*r23, 
          r220 = m4^2*r142 + m5^2*r61, 
          r221 = 
           2*m3^4 + 2*m4^2*m5^2 - m4^4*r13 + m3^2*r220 + 
            2*m5^4*r6, r222 = 
           m4^2*m5^2*r216 + m5^4*r217 + m2^4*r219 + 
            m2^2*r221 - m5^6*r5 + m2^6*r99, 
          r223 = -(m3^2*r10) + m4^2*r5, 
          r224 = 
           4*m3^2*m4^2 + m1^2*r122 + m4^4*r13 + 
            m2^2*r223 + m1^4*r4 - m2^4*r4 - m3^4*r99, 
          r225 = -m3^2 + m2^2*r72 - m4^2*r72, 
          r226 = -2*m4^2*r106 + 2*m3^2*r69, 
          r227 = 
           m1^4*r106 + m2^4*r106 - m4^4*r13 - 
            2*m1^2*r225 + m2^2*r226 - 4*m3^2*m4^2*r4 - 
            m3^4*r99, r228 = m3^2 + 3*m4^2, 
          r229 = 
           r107*r108*r224 - m5^2*r227 + m5^6*r72 - 
            m5^4*r228*r72, 
          r230 = m4^2*r131 + m1^2*r4 + m2^2*r4 + m3^2*r8, 
          r231 = 
           2*m5^4*r106 - m5^2*r230 - r107*r108*r200*r4, 
          r232 = 
           m1^4*r208 - m1^2*r215 - m3^2*r222 + PP*r229 + 
            PP^2*r231 + 2*m5^2*PP^3*r4 + m1^6*r7, 
          r233 = -2*m3^2 + m4^2, 
          r234 = -m2^2 + m4^2 - 2*m5^2, 
          r235 = -m1^2 + m2^2 + m5^2, 
          r236 = 
           m1^4 + m5^4 + m2^2*r233 + m1^2*r234 + 
            PP*r235 - m5^2*r46, r237 = -m2^2 + m5^2, 
          r238 = m2^2 + m3^2 - 2*m4^2 + m5^2, 
          r239 = -m1^2 + m2^2 - m5^2, 
          r240 = m1^4 + m3^2*r237 - m1^2*r238 + PP*r239, 
          r241 = m3^2 + 3*m4^2 - m5^2, 
          r242 = -3*m3^2 - m4^2 + m5^2, 
          r243 = 
           m5^4 - m5^2*r228 + m1^2*r241 + m2^2*r242 + 
            2*PP*r32*r33 + 2*m4^2*r9, 
          r244 = 2*m1^2 + m2^2 + m4^2, 
          r245 = -2*m1^2 - m3^2 - m4^2 + 3*m5^2, 
          r246 = 
           m1^4 - 3*m2^2*m3^2 + m5^4 + PP^2 + 
            m4^2*r173 - m5^2*r244 + PP*r245, 
          r247 = -2*m3^2 + m4^2 + m5^2, 
          r248 = 
           -m2^4 - m4^2*m5^2 + PP*r235 + m2^2*r247 + 
            m1^2*r46, r249 = m2^2*r153 + m1^2*r5, 
          r250 = 2*m1^2 + m2^2*r4, 
          r251 = m2^2*r13 + m1^2*r139, 
          r252 = r107*r108*r250 + m3^2*r251 - m3^4*r4, 
          r253 = m1^2*r140 + 2*m3^2*r4 + m2^2*r72, 
          r254 = 
           m3^4*r249 + m4^2*r252 + m4^4*r253 - m4^6*r4 + 
            m2^2*m3^2*r100*r99, r255 = 2*m3^2 + m4^2*r13, 
          r256 = -2*m3^2*r5 + m2^2*r99 - m4^2*r99, 
          r257 = -11 + 2*d, 
          r258 = 
           -(m4^4*r106) + 2*m3^2*m4^2*r23 - m3^4*r257, 
          r259 = 4*m4^2 + m3^2*r13, 
          r260 = 
           -2*m2^4 + 6*m3^2*m4^2 + 2*m2^2*r259 + 
            m4^4*r37 + m3^4*r5, 
          r261 = 
           -5*m3^4*m4^2 + m2^4*r255 + m1^4*r256 + 
            m2^2*r258 + m1^2*r260 - m2^6*r4 + m3^6*r5 + 
            m4^6*r6 - 3*m3^2*m4^4*r72, 
          r262 = m3^4 + m3^2*m4^2 + m4^4, 
          r263 = 
           m1^4 + m2^4 - 2*r262 + m1^2*r81 + m2^2*r81, 
          r264 = m1^2 + m2^2 - m3^2 - m4^2, 
          r265 = -(r13*r32*r33) + m2^2*r99, 
          r266 = 
           -2*m1^2*r265 - r32^2*r33^2*r4 + 
            2*m2^2*r13*r9 + m1^4*r99 + m2^4*r99, 
          r267 = m3^2*r13 + m4^2*r4, r268 = -16 + 3*d, 
          r269 = m3^2*r13 - m4^2*r268 + m2^2*r4, 
          r270 = 
           2*m2^2*r267 + 2*m1^2*r269 + 
            r13*r228*r32*r33 + m2^4*r61 + m1^4*r99, 
          r271 = 2*m2^2 + m4^2*r23 - m3^2*r72, 
          r272 = 
           -(m5^2*r270) - 2*m5^4*r271 + r266*r32*r33, 
          r273 = 2*m3^2 - 2*m4^2 - m5^2, 
          r274 = m1^2*r5 - m2^2*r5 + r273*r72, 
          r275 = 
           r200*r254 + m5^2*r261 + PP*r272 + 
            2*m5^2*PP^2*r274 + m5^4*r263*r5 - 
            m5^6*r264*r5, 
          r276 = 
           -2*m2^2*m3^2 - 2*m3^4 + 3*m3^2*m4^2 - m4^4 + 
            3*m3^2*m5^2 + 2*m4^2*m5^2 - m5^4 + 
            m1^2*r177 + PP*r77, 
          r277 = -(m4^2*r106) + m2^2*r4 - m3^2*r5, 
          r278 = 
           -2*m3^4 - m3^2*m4^2*r13 + m2^2*r196 + 
            m2^4*r4 + m4^4*r4, 
          r279 = m4^2*r131 + m3^2*r8, 
          r280 = 
           m2^2*r279 - 2*m2^4*r4 + m4^2*r32*r33*r99, 
          r281 = m1^4*r277 + m2^2*r278 + m1^2*r280, 
          r282 = 11*m3^2 - 3*d*m3^2 + 9*m4^2 - 2*d*m4^2, 
          r283 = 15 - 4*d, 
          r284 = m4^2*r106 + m2^2*r283 + m3^2*r5, 
          r285 = m4^4*r13 + 4*m3^2*m4^2*r5 - m3^4*r99, 
          r286 = -m4^2 + m3^2*r5, 
          r287 = -(m4^2*r5) + m3^2*r6, 
          r288 = 2*m2^2*r287 + m2^4*r72 - 2*r286*r81, 
          r289 = 
           -2*m3^2*m4^4 + m2^4*r282 + m1^4*r284 + 
            m2^2*r285 + m1^2*r288 - m4^6*r4 + m1^6*r5 + 
            m2^6*r6 + m3^4*m4^2*r99, 
          r290 = 2*m2^2 - m3^2 - m4^2, 
          r291 = 
           2*m1^4 + 2*m2^4 - m3^4 - m4^4 + m1^2*r290 - 
            m2^2*r81, r292 = m2^2 - m3^2 + m4^2, 
          r293 = 
           m1^4*r4 + m2^4*r4 - 2*m1^2*r292*r4 + 
            2*m2^2*r4*r9 - r32^2*r33^2*r99, 
          r294 = m3^2*r13 - m4^2*r131, 
          r295 = m2^2*r13 - r4*r81, 
          r296 = 
           m1^4*r131 + 2*m2^2*r294 - 2*m1^2*r295 - 
            2*m3^2*m4^2*r4 + m4^4*r8 - m2^4*r99 - 
            m3^4*r99, r297 = 2*m4^2 - m2^2*r5 + m1^2*r72, 
          r298 = 
           r107*r108*r293 - m5^2*r296 + 2*m5^4*r297, 
          r299 = -2*m5^2*r32*r33*r5 + 2*m5^4*r72, 
          r300 = 
           r130*r281 - m5^2*r289 + PP*r298 + PP^2*r299 - 
            m5^6*r264*r5 + m5^4*r291*r5, 
          r301 = 
           -2*m2^2*m3^2 - m3^2*m4^2 + m4^4 + m5^4 - 
            m5^2*r17 + m1^2*r177 + PP*r77, 
          r302 = m2^2 + 2*m3^2 - 3*m4^2, 
          r303 = -m1^2 + m2^2 - 3*m5^2, 
          r304 = 
           m1^4 - m2^2*m4^2 - m5^4 + m5^2*r149 - 
            m1^2*r302 + PP*r303, 
          r305 = 
           -((r45*TBI[d, PP, {{1, m4}, {1, m2}}]*
                 TBI[d, PP, {{2, m1}, {1, m3}}])/(4*r3)) 
+ (r76*TBI[d, PP, {{1, m3}, {1, m1}}]*
               TBI[d, PP, {{2, m2}, {1, m4}}])/(4*r3) - 
            (r80*TBI[d, PP, {{2, m1}, {1, m3}}]*
               TBI[d, PP, {{2, m2}, {1, m4}}])/2 - 
            (r45*TBI[d, PP, {{1, m4}, {1, m2}}]*
               TBI[d, PP, {{2, m3}, {1, m1}}])/(4*r3) - 
            (r84*TBI[d, PP, {{2, m2}, {1, m4}}]*
               TBI[d, PP, {{2, m3}, {1, m1}}])/2 - 
            r86*r88*TBI[d, PP, {{1, m4}, {1, m2}}]*
             TBI[d, PP, {{2, m3}, {2, m1}}] + 
            (r76*TBI[d, PP, {{1, m3}, {1, m1}}]*
               TBI[d, PP, {{2, m4}, {1, m2}}])/(4*r3) - 
            (r92*TBI[d, PP, {{2, m1}, {1, m3}}]*
               TBI[d, PP, {{2, m4}, {1, m2}}])/2 - 
            (r98*TBI[d, PP, {{2, m3}, {1, m1}}]*
               TBI[d, PP, {{2, m4}, {1, m2}}])/2 - 
            r86*r88*TBI[d, PP, {{1, m4}, {1, m2}}]*
             TBI[d, PP, {{3, m1}, {1, m3}}] - 
            r86*r88*TBI[d, PP, {{1, m4}, {1, m2}}]*
             TBI[d, PP, {{3, m3}, {1, m1}}] - 
            r3*TFI[r99, PP, 
              {{1, m1}, {1, m2}, {1, m3}, {1, m4}, 
               {1, m5}}] - 
            (r134*TVI[d, PP, 
                {{1, m5}, {1, m1}, {2, m4}, {1, m3}}])/
             (4*r3) - (r135*r136*r137*r138*
               TVI[d, PP, 
                {{1, m5}, {1, m1}, {2, m4}, {2, m3}}])/2 
- (r176*TVI[d, PP, {{1, m5}, {1, m2}, {2, m3}, 
                 {1, m4}}])/(4*r3) + 
            (r180*TVI[d, PP, 
                {{1, m5}, {1, m2}, {2, m3}, {2, m4}}])/2 
- r182*TVI[d, PP, {{1, m5}, {1, m2}, {3, m3}, 
               {1, m4}}] + 
            (r203*TVI[d, PP, 
                {{1, m5}, {1, m3}, {2, m2}, {1, m1}}])/
             (4*r3) + (r232*
               TVI[d, PP, 
                {{1, m5}, {1, m4}, {2, m1}, {1, m2}}])/
             (4*r3) + (r236*
               TVI[d, PP, 
                {{1, m5}, {1, m4}, {2, m1}, {2, m2}}])/2 
+ r240*TVI[d, PP, {{1, m5}, {1, m4}, {3, m1}, 
               {1, m2}}] + 
            (r45*TVI[d, PP, 
                {{1, m5}, {2, m1}, {1, m4}, {1, m3}}])/
             (4*r3) + (r86*r88*
               TVI[d, PP, 
                {{1, m5}, {2, m1}, {1, m4}, {2, m3}}])/2 
+ (r92*TVI[d, PP, {{1, m5}, {2, m1}, {2, m4}, 
                 {1, m3}}])/2 - 
            (r76*TVI[d, PP, 
                {{1, m5}, {2, m2}, {1, m3}, {1, m4}}])/
             (4*r3) - (r243*
               TVI[d, PP, 
                {{1, m5}, {2, m2}, {2, m3}, {1, m4}}])/2 
+ (r45*TVI[d, PP, {{1, m5}, {2, m3}, {1, m2}, 
                 {1, m1}}])/(4*r3) + 
            (r86*r88*TVI[d, PP, 
                {{1, m5}, {2, m3}, {1, m2}, {2, m1}}])/2 
+ (r246*TVI[d, PP, {{1, m5}, {2, m3}, {2, m2}, 
                 {1, m1}}])/2 - 
            (r76*TVI[d, PP, 
                {{1, m5}, {2, m4}, {1, m1}, {1, m2}}])/
             (4*r3) + (r248*
               TVI[d, PP, 
                {{1, m5}, {2, m4}, {2, m1}, {1, m2}}])/2 
+ r86*r88*TVI[d, PP, {{1, m5}, {3, m1}, {1, m4}, 
               {1, m3}}] + 
            r86*r88*TVI[d, PP, 
              {{1, m5}, {3, m3}, {1, m2}, {1, m1}}] + 
            (r275*TVI[d, PP, 
                {{2, m5}, {1, m1}, {1, m4}, {1, m3}}])/
             (4*r3) + (r276*
               TVI[d, PP, 
                {{2, m5}, {1, m1}, {1, m4}, {2, m3}}])/2 
- (r180*TVI[d, PP, {{2, m5}, {1, m1}, {2, m4}, 
                 {1, m3}}])/2 - 
            (r275*TVI[d, PP, 
                {{2, m5}, {1, m2}, {1, m3}, {1, m4}}])/
             (4*r3) + (r180*
               TVI[d, PP, 
                {{2, m5}, {1, m2}, {1, m3}, {2, m4}}])/2 
- (r276*TVI[d, PP, {{2, m5}, {1, m2}, {2, m3}, 
                 {1, m4}}])/2 - 
            (r300*TVI[d, PP, 
                {{2, m5}, {1, m3}, {1, m2}, {1, m1}}])/
             (4*r3) - (r240*
               TVI[d, PP, 
                {{2, m5}, {1, m3}, {1, m2}, {2, m1}}])/2 
- (r236*TVI[d, PP, {{2, m5}, {1, m3}, {2, m2}, 
                 {1, m1}}])/2 + 
            (r300*TVI[d, PP, 
                {{2, m5}, {1, m4}, {1, m1}, {1, m2}}])/
             (4*r3) + (r236*
               TVI[d, PP, 
                {{2, m5}, {1, m4}, {1, m1}, {2, m2}}])/2 
+ (r240*TVI[d, PP, {{2, m5}, {1, m4}, {2, m1}, 
                 {1, m2}}])/2 + 
            (r182*TVI[d, PP, 
                {{2, m5}, {2, m1}, {1, m4}, {1, m3}}])/2 
- (r301*TVI[d, PP, {{2, m5}, {2, m2}, {1, m3}, 
                 {1, m4}}])/2 - 
            (r304*TVI[d, PP, 
                {{2, m5}, {2, m3}, {1, m2}, {1, m1}}])/2 
+ (r248*TVI[d, PP, {{2, m5}, {2, m4}, {1, m1}, 
                 {1, m2}}])/2, r306}, 
         r306 = Factor /@ r305/(PP*r1*r2); r306]) /; 
         n1 === 1 && n2 === 1 && n3 === 1 && n4 === 1 && n5 === 1 &&  
       MatchQ[d, _Symbol + _Integer?Positive] && PP =!= 0 &&
       Cayley[m1, m2, m3, m4, m5, Sqrt[PP]] =!= 0]; \
\>", "Input",
 Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (51)", "Subsection",
 CellTags->"T1.6.16.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "51"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"1", ",", "3", ",", "4"}]], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"1", ",", "3", ",", "4"}]], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "51"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "51"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (51)", "Subsection",
 CellTags->"T1.6.17.1"],

Cell[BoxData[
 SubscriptBox["s", "51"]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "51"], "=", 
  RowBox[{
   SubscriptBox["s", "51"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "51"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "51"], ",", "\"\<(51)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "3", ",", "4"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "51"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845371555643`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (52)", "Subsection",
 CellTags->"T1.6.18.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "52"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"2", ",", "4", ",", "6"}]], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SubsuperscriptBox["m", "1", "2"], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}]}], "-", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "4", "2"], 
        SubscriptBox["\[Nu]", "4"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           SubsuperscriptBox["m", "2", "2"]}], "-", 
          SubscriptBox["u", 
           RowBox[{"4", ",", "2", ",", "6"}]]}], ")"}], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalSigma]", "4"], "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"2", ",", "4", ",", "6"}]], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"3", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "4", "2"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "4"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "52"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "52"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (52)", "Subsection",
 CellTags->"T1.6.19.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "52"], "=", 
  RowBox[{
   RowBox[{"\[Nu]explicit", "[", 
    SubscriptBox["s", "52"], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "2"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "52"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "52"], ",", "\"\<(52)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"2", ",", "4", ",", "6"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "52"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845373196297`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (53)", "Subsection",
 CellTags->"T1.6.20.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "53"], "=", 
  RowBox[{
   RowBox[{"Interchange", "[", 
    RowBox[{
     SubscriptBox["s", "51"], ",", 
     RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "3"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "53"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "53"], ",", "\"\<(53)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"3", ",", "1", ",", "4"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "53"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884537451167*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (54)", "Subsection",
 CellTags->"T1.6.21.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "54"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubsuperscriptBox["m", "3", "2"], 
     SubscriptBox["\[Nu]", "3"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["3", "+"],
       FontWeight->"Bold"],
      Schiebe[3, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}], "+", "\n", "\t\t\t\t", 
       RowBox[{"(", 
        RowBox[{"d", "-", 
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "54"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "54"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (54)", "Subsection",
 CellTags->"T1.6.22.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "54"], "=", 
  RowBox[{
   SubscriptBox["s", "54"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "3"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "54"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "54"], ",", "\"\<(54)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", " ", 
      RowBox[{"m3", "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "54"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884537889615*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (55)", "Subsection",
 CellTags->"T1.6.23.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "55"], "=", 
   RowBox[{
    RowBox[{"2", " ", 
     SubsuperscriptBox["m", "4", "2"], 
     SubscriptBox["\[Nu]", "4"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["4", "+"],
       FontWeight->"Bold"],
      Schiebe[4, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"3", ",", "1", ",", "4"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"6", ",", "2", ",", "4"}]], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", "\n", "\t\t\t\t", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True]}], "+", 
       RowBox[{"(", 
        RowBox[{"d", "-", 
         SubscriptBox["\[Nu]", "1"], "-", 
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "4"]}]}], ")"}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "55"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "55"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (55)", "Subsection",
 CellTags->"T1.6.24.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "55"], "=", 
  RowBox[{
   SubscriptBox["s", "55"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "4"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "4"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "55"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "55"], ",", "\"\<(55)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "4"], ">", "1"}], "&&", " ", 
      RowBox[{"m4", "=!=", "0"}], " ", "&&", " ", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "55"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884538226131*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (56)", "Subsection",
 CellTags->"T1.6.25.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "56"], "=", 
   RowBox[{
    RowBox[{"2", " ", 
     SubsuperscriptBox["m", "4", "2"], 
     SubscriptBox["\[Nu]", "4"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["4", "+"],
       FontWeight->"Bold"],
      Schiebe[4, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        SubsuperscriptBox["m", "1", "2"], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"6", ",", "2", ",", "4"}]], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "-", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "-", "\n", "\t\t\t\t", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True]}], "+", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "d"}], "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "3"]}], "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "4"]}]}], ")"}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "56"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "56"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (56)", "Subsection",
 CellTags->"T1.6.26.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "56"], "=", 
  RowBox[{
   SubscriptBox["s", "56"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "4"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "4"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "56"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "56"], ",", "\"\<(56)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "4"], ">", "1"}], "&&", " ", 
      RowBox[{"m4", "=!=", "0"}], " ", "&&", " ", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "===", "1"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "56"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884539464283*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (59)", "Subsection",
 CellTags->"T1.6.27.1"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"1", ",", "3", ",", "4"}]], TraditionalForm]]],
 "== 0 but all  ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 " != 0"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "59"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SubsuperscriptBox["m", "1", "2"], 
        SubscriptBox["u", 
         RowBox[{"1", ",", "3", ",", "4"}]], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}], 
        SubsuperscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}], "2"]}], "+", "\n", "\t", 
       RowBox[{"4", 
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True]}], ")"}]}], "-", "\n", "\t", 
       RowBox[{"4", 
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", 
           SubsuperscriptBox["m", "1", "2"], 
           SubsuperscriptBox["m", "3", "2"]}], "+", 
          SubsuperscriptBox["u", 
           RowBox[{"4", ",", "1", ",", "3"}], "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True]}], "-", "\n", "\t\t", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "3"], "+", "1"}], ")"}], 
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "-"],
          FontWeight->"Bold"],
         Schiebe[3, "-"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}], "+", "1"}], ")"}], 
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "59"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "59"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (59)", "Subsection",
 CellTags->"T1.6.28.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "59"], "=", 
  SubscriptBox["s", "59"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "59"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "59"], ",", "\"\<(59)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "3", ",", "4"}]], "==", "0"}], "&&", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SubsuperscriptBox["m", "3", "2"], " ", 
          SubsuperscriptBox["m", "1", "2"]}], "-", 
         RowBox[{"4", " ", 
          SubsuperscriptBox["m", "3", "2"], " ", 
          SubscriptBox["\[Nu]", "3"], " ", 
          SubsuperscriptBox["m", "1", "2"]}], "+", 
         RowBox[{"2", " ", "d", " ", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "3", ",", "4"}]], " ", 
          SubsuperscriptBox["m", "1", "2"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["\[Nu]", "3"], " ", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "3", ",", "4"}]], " ", 
          SubsuperscriptBox["m", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "3", ",", "4"}]], " ", 
          SubsuperscriptBox["m", "1", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "3"], " ", 
          SubsuperscriptBox["u", 
           RowBox[{"4", ",", "1", ",", "3"}], "2"]}], "-", 
         SubsuperscriptBox["u", 
          RowBox[{"4", ",", "1", ",", "3"}], "2"]}], ")"}], "  ", "=!=", 
       "0"}], "&&", 
      RowBox[{"n1", " ", "===", " ", "1"}], "&&", " ", 
      RowBox[{"n2", " ", "===", " ", "1"}], "&&", " ", 
      RowBox[{"n4", " ", "===", " ", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", "_Integer"}], "]"}]}], "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (60) ", "Subsection",
 CellTags->"T1.6.29.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "60"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubsuperscriptBox["m", "1", "2"], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"4", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True]}], ")"}]}], "+", "\n", "\t\t\t\t", 
       RowBox[{"(", 
        RowBox[{"d", "-", 
         SubscriptBox["\[Nu]", "3"], "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "1"]}]}], ")"}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "60"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "60"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (60)", "Subsection",
 CellTags->"T1.6.30.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "60"], "=", 
  RowBox[{
   SubscriptBox["s", "60"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["notnecessaryf", "60"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "60"], ",", "\"\<(60)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", " ", 
      RowBox[{"m1", "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["notnecessaryf", "60"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884542176589*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (61) ", "Subsection",
 CellTags->"T1.6.31.1"],

Cell[TextData[{
 " ( ",
 Cell[BoxData[
  SubsuperscriptBox["m", "1", "2"]]],
 "== 0 && ",
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== ",
 Cell[BoxData[
  SubsuperscriptBox["m", "3", "2"]]],
 " )  \[DoubleLongRightArrow] ( ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"1", ",", "3", ",", "4"}]], TraditionalForm]]],
 "== 0 )"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "61"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       SubscriptBox["\[Nu]", "3"]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["3", "+"],
       FontWeight->"Bold"],
      Schiebe[3, "+"],
      Editable->True], 
     RowBox[{"(", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SuperscriptBox["1", "-"],
         FontWeight->"Bold"],
        Schiebe[1, "-"],
        Editable->True], "-", 
       InterpretationBox[
        StyleBox[
         SuperscriptBox["4", "-"],
         FontWeight->"Bold"],
        Schiebe[4, "-"],
        Editable->True]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "61"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "61"], "]"}]}]], "Input"],

Cell[TextData[{
 "For  ( ",
 Cell[BoxData[
  SubsuperscriptBox["m", "3", "2"]]],
 "== 0 && ",
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== ",
 Cell[BoxData[
  SubsuperscriptBox["m", "1", "2"]]],
 " )  \[DoubleLongRightArrow] ( ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"1", ",", "3", ",", "4"}]], TraditionalForm]]],
 "== 0 )\nuse ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["V",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TVI[d, {
         Subscript[\[Nu], 1], 
         Subscript[\[Nu], 2], 
         Subscript[\[Nu], 3], 
         Subscript[\[Nu], 4]}],
       Editable->True], "==", 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["V",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TVI[d, {
         Subscript[\[Nu], 1], 
         Subscript[\[Nu], 2], 
         Subscript[\[Nu], 3], 
         Subscript[\[Nu], 4]}],
       Editable->True]}], ")"}], " "}], TextForm]]],
 " and switch the masses accordingly."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (61)", "Subsection",
 CellTags->"T1.6.32.1"],

Cell[TextData[{
 "( ",
 Cell[BoxData[
  SubsuperscriptBox["m", "1", "2"]]],
 "== 0 && ",
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== ",
 Cell[BoxData[
  SubsuperscriptBox["m", "3", "2"]]],
 " )  \[DoubleLongRightArrow] ( ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"1", ",", "3", ",", "4"}]], TraditionalForm]]],
 "== 0 )"
}], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "61"], "=", 
  SubscriptBox["s", "61"]}]], "Input"],

Cell["\<\
Don't need the restriction to n1=1 and n4=1 (I hope ...). Changed September \
24th 2003.\
\>", "SmallText"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "61"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "61"], ",", "\"\<(61)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "1"],
        m1], "===", "0"}], "&&", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "3"],
        m3], "===", 
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n1", ":>", "1"}], ",", 
      RowBox[{"n4", ":>", "1"}]}], "}"}]}], "]"}]}]], "SmallText"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "61"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "61"], ",", "\"\<(61)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "1"],
        m1], "===", "0"}], "&&", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "3"],
        m3], "===", 
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4]}]}], "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6153)", "Subsection",
 CellTags->"T1.6.33.1"],

Cell[TextData[{
 " ( ",
 Cell[BoxData[
  SubsuperscriptBox["m", "3", "2"]]],
 "== 0 && ",
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== ",
 Cell[BoxData[
  SubsuperscriptBox["m", "1", "2"]]],
 ")  \[DoubleLongRightArrow] ( ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"1", ",", "3", ",", "4"}]], TraditionalForm]]],
 "== 0 )"
}], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "6153"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "61"], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}]}]], "Input"],

Cell["\<\
Don't need the restriction to n1=1 and n4=1 (I hope ...). Changed September \
24th 2003.\
\>", "SmallText"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6153"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "6153"], ",", "\"\<(6153)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "3"],
        m3], "===", "0"}], "&&", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "1"],
        m1], "===", 
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n3", ":>", "1"}], ",", 
      RowBox[{"n4", ":>", "1"}]}], "}"}]}], "]"}]}]], "SmallText"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6153"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "6153"], ",", "\"\<(6153)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "3"],
        m3], "===", "0"}], "&&", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "1"],
        m1], "===", 
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4]}]}], "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (62) ", "Subsection",
 CellTags->"T1.6.34.1"],

Cell[TextData[{
 "( ",
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== 0 && ",
 Cell[BoxData[
  SubsuperscriptBox["m", "1", "2"]]],
 "== ",
 Cell[BoxData[
  SubsuperscriptBox["m", "3", "2"]]],
 " ) \[DoubleLongRightArrow] (",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["\[CapitalDelta]", 
     RowBox[{"1", ",", "3", ",", "4"}]]}], TraditionalForm]]],
 "== 0 )\nlower ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "2"], TraditionalForm]]],
 " via (52) to one first"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "62"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       InterpretationBox[
        SuperscriptBox["p", "2"],
        PP], "-", 
       SubsuperscriptBox["m", "2", "2"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "2"]}], "+", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "4"]}], "+", "2"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["4", "+"],
       FontWeight->"Bold"],
      Schiebe[4, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", "\n", "\t\t", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["m", "1", "2"], "-", 
          SubscriptBox["u", 
           RowBox[{"6", ",", "1", ",", "2"}]]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{"4", 
        SubsuperscriptBox["m", "2", "2"], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "1", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", "\n", "\t\t\t\t", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalSigma]", "4"], "-", 
          RowBox[{"2", 
           SubsuperscriptBox["m", "1", "2"], 
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True]}], "-", 
          RowBox[{"2", 
           SubsuperscriptBox["m", "1", "2"], 
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True]}]}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          SubsuperscriptBox["m", "2", "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "-"],
          FontWeight->"Bold"],
         Schiebe[3, "-"],
         Editable->True]}], "-", "\n", "\t\t\t\t", 
       SubscriptBox["\[CapitalSigma]", "4"]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "62"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "62"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (62)", "Subsection",
 CellTags->"T1.6.35.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "62"], "=", 
  RowBox[{
   RowBox[{"\[Nu]explicit", "[", 
    SubscriptBox["s", "62"], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "4"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "4"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "62"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "62"], ",", "\"\<(62)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SuperscriptBox["p", "2"],
        PP], "=!=", 
       InterpretationBox[
        SubsuperscriptBox["m", "2", "2"],
        m2^2]}], "&&", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "1"], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Nu]", "2"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Nu]", "4"]}]}], "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4], "\[RuleDelayed]", "0"}], ",", 
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "3"],
        m3], "\[RuleDelayed]", 
       InterpretationBox[
        SubscriptBox["m", "1"],
        m1]}], ",", 
      RowBox[{"n2", "\[RuleDelayed]", "1"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (63) ", "Subsection",
 CellTags->"T1.6.36.1"],

Cell[TextData[{
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== 0  && ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["\[CapitalDelta]", 
     RowBox[{"1", ",", "3", ",", "4"}]]}], TraditionalForm]]],
 " != 0\nreplace (55) by the following"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "63"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       InterpretationBox[
        SuperscriptBox["p", "2"],
        PP], "-", 
       SubsuperscriptBox["m", "2", "2"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["m", "3", "2"], "-", 
          SubsuperscriptBox["m", "1", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}], "+", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "4"]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "3"], "-", 
          SubscriptBox["\[Nu]", "1"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", "\n", "\t\t", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["m", "1", "2"], "-", 
          SubsuperscriptBox["m", "3", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SubsuperscriptBox["m", "1", "2"], 
              SubscriptBox["\[Nu]", "1"], 
              InterpretationBox[
               StyleBox[
                SuperscriptBox["1", "+"],
                FontWeight->"Bold"],
               Schiebe[1, "+"],
               Editable->True]}], "+", 
             RowBox[{"2", 
              SubsuperscriptBox["m", "3", "2"], 
              SubscriptBox["\[Nu]", "3"], 
              InterpretationBox[
               StyleBox[
                SuperscriptBox["3", "+"],
                FontWeight->"Bold"],
               Schiebe[3, "+"],
               Editable->True]}], "-", 
             SubscriptBox["\[CapitalSigma]", "4"], "-", "2"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"],
              Editable->True]}], ")"}]}], "-", 
          RowBox[{"4", 
           SubsuperscriptBox["m", "2", "2"], 
           SubscriptBox["\[Nu]", "2"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "+"],
             FontWeight->"Bold"],
            Schiebe[2, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["4", "-"],
             FontWeight->"Bold"],
            Schiebe[4, "-"],
            Editable->True]}]}], ")"}]}], "+", "\n", "\t\t\t\t", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          SubsuperscriptBox["m", "2", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["m", "3", "2"], 
           SubscriptBox["\[Nu]", "3"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"],
              Editable->True]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["m", "1", "2"], 
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               SuperscriptBox["4", "-"],
               FontWeight->"Bold"],
              Schiebe[4, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"],
              Editable->True]}], ")"}]}]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "63"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "63"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (63)", "Subsection",
 CellTags->"T1.6.37.1"],

Cell[TextData[{
 Cell[BoxData[
  SubsuperscriptBox["m", "4", "2"]]],
 "== 0  && ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["\[CapitalDelta]", 
     RowBox[{"1", ",", "3", ",", "4"}]]}], TraditionalForm]]],
 " != 0"
}], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "63"], "=", 
  RowBox[{"\[Nu]explicit", "[", 
   SubscriptBox["s", "63"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "63"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "63"], ",", "\"\<(63)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{"PP", " ", "=!=", " ", 
       RowBox[{"m2", "^", "2"}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"Cayley", "[", 
         RowBox[{"1", ",", "3", ",", "4"}], "]"}], "[", 
        RowBox[{"{", 
         RowBox[{"m1", ",", "m2", ",", "m3", ",", "m4"}], "}"}], "]"}], "=!=",
        "0"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      InterpretationBox[
       SubscriptBox["m", "4"],
       m4], "\[RuleDelayed]", "0"}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "63"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884542973016*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "63"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "63"], ",", "\"\<(63)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{"PP", " ", "=!=", " ", 
       RowBox[{"m2", "^", "2"}]}], "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"Cayley", "[", 
         RowBox[{"1", ",", "3", ",", "4"}], "]"}], "[", 
        RowBox[{"{", 
         RowBox[{"m1", ",", "m2", ",", "m3", ",", "m4"}], "}"}], "]"}], "=!=",
        "0"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        SubscriptBox["m", "4"],
        m4], "\[RuleDelayed]", "0"}], ",", 
      RowBox[{"n1", ":>", "1"}], ",", 
      RowBox[{"n3", ":>", "1"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\

CheckTVIRecursion not applicable for special indices since A's and 
B's appear .
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6552)", "Subsection",
 CellTags->"T1.6.38.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "6552"], "=", 
  RowBox[{
   RowBox[{"\[Nu]explicit", "[", 
    SubscriptBox["e", "52"], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[CapitalDelta]", 
     RowBox[{"2", ",", "4", ",", "6"}]], "->", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"formal", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["e", "55"], "/.", 
       RowBox[{
        RowBox[{"TVI", "[", "__", "]"}], "->", "1"}]}], ",", 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["4", "+"],
        FontWeight->"Bold"],
       Schiebe[4, "+"],
       Editable->True]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "2"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "6552"], "/.", "formal"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "6552"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   RowBox[{
    SubscriptBox["r", "6552"], "/.", "formal"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "6552"], "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "4"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "6552"], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["n", "6552"], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "4"}], "]"}], "]"}]}], "==", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["n", "6552"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "-", 
     RowBox[{
      SubscriptBox["n", "6552"], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "4"}], "]"}], "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6552"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["s", "6552"], ",", "\"\<(6552)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"2", ",", "4", ",", "6"}]], "===", "0"}], "&&", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Nu]", "2"], "-", 
            SubscriptBox["\[Nu]", "4"]}], ")"}], " ", 
          InterpretationBox[
           SubsuperscriptBox["m", "4", "2"],
           m4^2]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SubscriptBox["\[Nu]", "2"]}], "-", "d"}], ")"}], " ", 
          SubscriptBox["u", 
           RowBox[{"2", ",", "4", ",", "6"}]]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["u", 
           RowBox[{"6", ",", "2", ",", "4"}]]}]}], "]"}], "=!=", "0"}]}], 
     "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6552)", "Subsection",
 CellTags->"T1.6.39.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "6552"], "=", 
  RowBox[{
   RowBox[{"\[Nu]explicit", "[", 
    SubscriptBox["e", "52"], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[CapitalDelta]", 
     RowBox[{"2", ",", "4", ",", "6"}]], "->", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "6552"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["r", "6552"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "6552"], "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "5"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "6552"], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["n", "6552"], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "5"}], "]"}], "]"}]}], "==", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["n", "6552"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "-", 
     RowBox[{
      SubscriptBox["n", "6552"], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "5"}], "]"}], "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6552"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["s", "6552"], ",", "\"\<(6552)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"2", ",", "4", ",", "6"}]], "===", "0"}], "&&", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["\[Nu]", "2"], " ", 
           SubsuperscriptBox["m", "4", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Nu]", "4"], " ", 
           SubsuperscriptBox["m", "4", "2"]}], "+", 
          RowBox[{"d", " ", 
           SubscriptBox["u", 
            RowBox[{"2", ",", "4", ",", "6"}]]}], "-", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Nu]", "2"], " ", 
           SubscriptBox["u", 
            RowBox[{"2", ",", "4", ",", "6"}]]}]}], ")"}], "]"}], "=!=", 
       "0"}]}], "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6553)", "Subsection",
 CellTags->"T1.6.40.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "6553"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Nu]explicit", "[", 
      SubscriptBox["s", "55"], "]"}], "/.", 
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"3", ",", "1", ",", "4"}]], "->", "0"}]}], "/.", 
    RowBox[{
     SubscriptBox["u", 
      RowBox[{"6", ",", "2", ",", "4"}]], "->", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["m", "4"], "->", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "6553"], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["r", "6553"], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "==", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["r", "6553"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "-", 
     RowBox[{
      SubscriptBox["r", "6553"], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6553"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "6553"], ",", "\"\<(6553)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["u", 
        RowBox[{"6", ",", "2", ",", "4"}]], "===", "0"}], "&&", 
      RowBox[{
       SubscriptBox["u", 
        RowBox[{"1", ",", "3", ",", "4"}]], "===", "0"}]}], "]"}], ",", 
    RowBox[{"m4", ":>", "0"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (66) ", "Subsection",
 CellTags->"T1.6.41.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "66"], "=", 
   RowBox[{
    RowBox[{"4", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "3"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["3", "+"],
       FontWeight->"Bold"],
      Schiebe[3, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "+", "2"}],
         TraditionalForm], ")"}]],
      TVI[2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", "d"}], "-", 
          RowBox[{"6", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          RowBox[{"5", 
           SubscriptBox["\[Nu]", "2"]}], "-", 
          RowBox[{"6", 
           SubscriptBox["\[Nu]", "3"]}], "-", 
          RowBox[{"4", 
           SubscriptBox["\[Nu]", "4"]}], "-", 
          RowBox[{"6", 
           SubsuperscriptBox["m", "1", "2"], 
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True]}]}], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["u", 
            RowBox[{"6", ",", "2", ",", "4"}]], "-", 
           RowBox[{"4", 
            SubsuperscriptBox["m", "2", "2"]}]}], ")"}], 
         SubscriptBox["\[Nu]", "2"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["2", "+"],
           FontWeight->"Bold"],
          Schiebe[2, "+"],
          Editable->True]}], "-", 
        RowBox[{"6", 
         SubsuperscriptBox["m", "3", "2"], 
         SubscriptBox["\[Nu]", "3"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["3", "+"],
           FontWeight->"Bold"],
          Schiebe[3, "+"],
          Editable->True]}], "+", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["u", 
            RowBox[{"6", ",", "2", ",", "4"}]], "-", 
           SubsuperscriptBox["m", "4", "2"]}], ")"}], 
         SubscriptBox["\[Nu]", "4"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["4", "+"],
           FontWeight->"Bold"],
          Schiebe[4, "+"],
          Editable->True]}], "-", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["2", "+"],
           FontWeight->"Bold"],
          Schiebe[2, "+"],
          Editable->True], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["4", "-"],
           FontWeight->"Bold"],
          Schiebe[4, "-"],
          Editable->True]}], "-", 
        RowBox[{"2", 
         SubscriptBox["\[Nu]", "4"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["4", "+"],
           FontWeight->"Bold"],
          Schiebe[4, "+"],
          Editable->True], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["2", "-"],
           FontWeight->"Bold"],
          Schiebe[2, "-"],
          Editable->True]}]}], ")"}]}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "66"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "66"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (66)", "Subsection",
 CellTags->"T1.6.42.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "66"], "=", 
  RowBox[{
   SubscriptBox["s", "66"], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", "1"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "1"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "-", "1"}]}], ",", 
     RowBox[{"d", ":>", 
      RowBox[{"d", "-", "2"}]}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "66"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "66"], ",", "\"\<(66)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "66"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845437386*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (alternative67)", "Subsection",
 CellTags->"T1.6.43.1"],

Cell["\<\
we dereived an alternative formula for Tarasov's (67), but do not save it by \
default.\
\>", "Text"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "67"], "=", 
   RowBox[{
    RowBox[{"4", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     SubscriptBox["\[Nu]", "1"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "+", "1"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "+", "2"}],
         TraditionalForm], ")"}]],
      TVI[2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], " ", "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", "d"}], "-", 
         RowBox[{"6", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         RowBox[{"5", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         RowBox[{"6", 
          SubscriptBox["\[Nu]", "3"]}], "-", 
         RowBox[{"4", 
          SubscriptBox["\[Nu]", "4"]}]}], ")"}], "-", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["u", 
           RowBox[{"2", ",", "4", ",", "6"}]], "+", 
          RowBox[{"3", 
           SubsuperscriptBox["m", "1", "2"]}]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["u", 
           RowBox[{"6", ",", "2", ",", "4"}]], "-", 
          RowBox[{"4", 
           SubsuperscriptBox["m", "2", "2"]}]}], ")"}], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "-", 
       RowBox[{"6", 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["u", 
           RowBox[{"6", ",", "2", ",", "4"}]], "-", 
          SubsuperscriptBox["m", "4", "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "4"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "-"],
          FontWeight->"Bold"],
         Schiebe[4, "-"],
         Editable->True]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "4"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "67"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "67"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (67)", "Subsection",
 CellTags->"T1.6.44.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "67"], "=", 
   RowBox[{
    RowBox[{"4", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     SubscriptBox["\[Nu]", "1"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "+", "1"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "+", "2"}],
         TraditionalForm], ")"}]],
      TVI[2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], " ", "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "d"}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}], "-", 
          SubscriptBox["\[Nu]", "4"]}], ")"}]}], "-", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["u", 
           RowBox[{"2", ",", "4", ",", "6"}]], "+", 
          RowBox[{"2", 
           SubsuperscriptBox["m", "1", "2"]}]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"-", "4"}], 
        SubsuperscriptBox["m", "2", "2"], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "-", 
       RowBox[{"4", 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        SubscriptBox["u", 
         RowBox[{"6", ",", "2", ",", "4"}]], 
        SubscriptBox["\[Nu]", "4"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["4", "-"],
            FontWeight->"Bold"],
           Schiebe[4, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True]}], ")"}]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "4"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["4", "+"],
          FontWeight->"Bold"],
         Schiebe[4, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SubscriptBox["\[Nu]", "2"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {
       Subscript[\[Nu], 1], 1 + Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 
       Subscript[\[Nu], 4]}],
     Editable->True], " ", 
    SubsuperscriptBox["m", "2", "2"]}], "-", 
   RowBox[{"2", " ", 
    SubscriptBox["\[Nu]", "4"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        FontColor->RGBColor[1, 0, 0]], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {
       Subscript[\[Nu], 1], -1 + Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 1 + Subscript[\[Nu], 4]}],
     Editable->True]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "d"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "1"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "3"]}], "-", 
      SubscriptBox["\[Nu]", "4"]}], ")"}], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {
       Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 
       Subscript[\[Nu], 4]}],
     Editable->True]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["m", "2", "2"], "+", 
      SubsuperscriptBox["m", "4", "2"], "-", 
      SuperscriptBox["p", "2"]}], ")"}], " ", 
    SubscriptBox["\[Nu]", "4"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {
       Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 1 + Subscript[\[Nu], 4]}],
     Editable->True]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["m", "3", "2"], " ", 
    SubscriptBox["\[Nu]", "3"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {
       Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 1 + Subscript[\[Nu], 3], 
       Subscript[\[Nu], 4]}],
     Editable->True]}], "-", 
   RowBox[{"2", " ", 
    SubscriptBox["\[Nu]", "1"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        FontColor->RGBColor[1, 0, 0]], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {1 + Subscript[\[Nu], 1], -1 + Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 
       Subscript[\[Nu], 4]}],
     Editable->True]}], "+", 
   RowBox[{"2", " ", 
    SubscriptBox["\[Nu]", "1"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm],
        FontColor->RGBColor[1, 0, 0]]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {1 + Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], -1 + Subscript[\[Nu], 4]}],
     Editable->True]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SubsuperscriptBox["m", "1", "2"]}], "+", 
      SubsuperscriptBox["m", "2", "2"], "-", 
      SubsuperscriptBox["m", "4", "2"], "-", 
      SuperscriptBox["p", "2"]}], ")"}], " ", 
    SubscriptBox["\[Nu]", "1"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TVI[d, {1 + Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 
       Subscript[\[Nu], 4]}],
     Editable->True]}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["p", "2"], " ", 
    SubscriptBox["\[Nu]", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "+", "1"}], ")"}], " ", 
    SubscriptBox["\[Nu]", "2"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["V",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm],
        FontWeight->"Bold",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox[
        RowBox[{"d", "+", "2"}],
        TraditionalForm], ")"}]],
     TVI[2 + d, {2 + Subscript[\[Nu], 1], 1 + Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3], 
       Subscript[\[Nu], 4]}],
     Editable->True]}]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "67"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "67"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (67)", "Subsection",
 CellTags->"T1.6.45.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "67"], "=", 
  RowBox[{
   SubscriptBox["s", "67"], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", "1"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "2"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "1"}]}], ",", 
     RowBox[{"d", ":>", 
      RowBox[{"d", "-", "2"}]}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "67"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "67"], ",", "\"\<(67)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "2"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "67"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884543938695*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6713)", "Subsection",
 CellTags->"T1.6.46.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "6713"], "=", 
  RowBox[{
   RowBox[{"Interchange", "[", 
    RowBox[{
     SubscriptBox["s", "67"], ",", 
     RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", "3"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "-", "2"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "1"}]}], ",", 
     RowBox[{"d", ":>", 
      RowBox[{"d", "-", "2"}]}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6713"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "6713"], ",", "\"\<(6713)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "2"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "6713"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884544035701*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (68)", "Subsection",
 CellTags->"T1.6.47.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "68"], "=", 
   RowBox[{
    RowBox[{"4", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     SubsuperscriptBox["m", "4", "2"], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "2"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "+", "1"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "+", "2"}],
         TraditionalForm], ")"}]],
      TVI[2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["m", "1", "2"], "-", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             SubscriptBox["\[Nu]", "2"], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "3"]}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["m", "4", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "+", 
             SubscriptBox["\[Nu]", "2"], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "3"]}]}], ")"}]}]}], ")"}], "-", 
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"1", ",", "3", ",", "4"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            SubsuperscriptBox["m", "1", "2"], 
            SubscriptBox["\[Nu]", "1"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["1", "+"],
              FontWeight->"Bold"],
             Schiebe[1, "+"],
             Editable->True]}], "+", 
           RowBox[{
            SubscriptBox["u", 
             RowBox[{"2", ",", "4", ",", "6"}]], 
            SubscriptBox["\[Nu]", "2"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"3", ",", "1", ",", "4"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            SubsuperscriptBox["m", "3", "2"], 
            SubscriptBox["\[Nu]", "3"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["3", "+"],
              FontWeight->"Bold"],
             Schiebe[3, "+"],
             Editable->True]}], "+", 
           RowBox[{
            SubscriptBox["\[Nu]", "2"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["4", "-"],
              FontWeight->"Bold"],
             Schiebe[4, "-"],
             Editable->True]}]}], ")"}]}], "-", 
        RowBox[{"2", 
         SubsuperscriptBox["m", "4", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[Nu]", "2"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True]}], "+", 
           RowBox[{
            SubscriptBox["\[Nu]", "4"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["4", "+"],
              FontWeight->"Bold"],
             Schiebe[4, "+"],
             Editable->True]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "-"],
             FontWeight->"Bold"],
            Schiebe[3, "-"],
            Editable->True], "-", 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "-"],
             FontWeight->"Bold"],
            Schiebe[1, "-"],
            Editable->True]}], ")"}]}]}], ")"}]}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3], 
        Subscript[\[Nu], 4]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "68"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "68"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (68)", "Subsection",
 CellTags->"T1.6.48.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "68"], "=", 
  RowBox[{
   SubscriptBox["s", "68"], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", "1"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "2"}]}], ",", 
     RowBox[{"d", ":>", 
      RowBox[{"d", "-", "2"}]}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "68"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "68"], ",", "\"\<(68)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{"m4", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "2"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "68"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884544203258*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6813)", "Subsection",
 CellTags->"T1.6.49.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "6813"], "=", 
  RowBox[{
   RowBox[{"Interchange", "[", 
    RowBox[{
     SubscriptBox["s", "68"], ",", 
     RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", "2"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "2"}]}], ",", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], ":>", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "-", "1"}]}], ",", 
     RowBox[{"d", ":>", 
      RowBox[{"d", "-", "2"}]}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "6813"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "6813"], ",", "\"\<(6813)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PP", "=!=", "0"}], "&&", 
       RowBox[{"m4", "=!=", "0"}]}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "2"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTVIRecursion", "[", 
  SubscriptBox["f", "6813"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884544307301*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (70)", "Subsection",
 CellTags->"T1.6.50.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "70"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "d"}], "-", "10"}], ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"d", "-", "3"}], ")"}], "2"], 
     SubsuperscriptBox["m", "4", "2"], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["V",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TVI[d, {1, 1, 1, 1}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", 
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", "d"}], "-", "10"}], ")"}], 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"1", ",", "3", ",", "4"}]], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "4", ",", "6"}]], "+", 
           RowBox[{
            SubscriptBox["u", 
             RowBox[{"2", ",", "4", ",", "6"}]], 
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SuperscriptBox["2", "-"],
                FontWeight->"Bold"],
               Schiebe[2, "-"],
               Editable->True], "-", 
              InterpretationBox[
               StyleBox[
                SuperscriptBox["4", "-"],
                FontWeight->"Bold"],
               Schiebe[4, "-"],
               Editable->True]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{"8", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "4"}], ")"}], "2"], 
         InterpretationBox[
          SuperscriptBox["p", "2"],
          PP], 
         SubsuperscriptBox["m", "3", "2"], 
         SubsuperscriptBox["m", "4", "2"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["4", "-"],
           FontWeight->"Bold"],
          Schiebe[4, "-"],
          Editable->True]}]}], ")"}], 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["V",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox[
          RowBox[{"d", "-", "2"}],
          TraditionalForm], ")"}]],
       TVI[-2 + d, {1, 1, 1, 1}],
       Editable->True]}], "+", "\n", "\t\t\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", "-", "3"}], ")"}], 
         SubsuperscriptBox["m", "4", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", 
            SubsuperscriptBox["m", "1", "2"], 
            RowBox[{"(", 
             RowBox[{"d", "-", "4"}], ")"}], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["1", "+"],
              FontWeight->"Bold"],
             Schiebe[1, "+"],
             Editable->True], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["1", "+"],
              FontWeight->"Bold"],
             Schiebe[1, "+"],
             Editable->True]}], "-", 
           RowBox[{"8", 
            RowBox[{"(", 
             RowBox[{"d", "-", "3"}], ")"}], 
            SubsuperscriptBox["m", "2", "2"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", "d"}], "-", "10"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "-", "3"}], ")"}], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"6", ",", "2", ",", "4"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", "d"}], "-", "10"}], ")"}], 
            SubscriptBox["u", 
             RowBox[{"1", ",", "3", ",", "4"}]], 
            RowBox[{"(", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                SuperscriptBox["1", "+"],
                FontWeight->"Bold"],
               Schiebe[1, "+"],
               Editable->True], "-", 
              InterpretationBox[
               StyleBox[
                SuperscriptBox["3", "+"],
                FontWeight->"Bold"],
               Schiebe[3, "+"],
               Editable->True]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"d", "-", "2"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"d", "-", "3"}], ")"}], 
            SubsuperscriptBox["m", "4", "2"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["1", "+"],
              FontWeight->"Bold"],
             Schiebe[1, "+"],
             Editable->True]}]}], ")"}], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["2", "+"],
           FontWeight->"Bold"],
          Schiebe[2, "+"],
          Editable->True]}], "-", 
        RowBox[{
         SubsuperscriptBox["m", "4", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"d", "-", "4"}], ")"}], "2"], 
            SubscriptBox["u", 
             RowBox[{"1", ",", "3", ",", "4"}]], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", "d"}], "-", "10"}], ")"}], 
            SubscriptBox["u", 
             RowBox[{"4", ",", "1", ",", "3"}]], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["3", "+"],
              FontWeight->"Bold"],
             Schiebe[3, "+"],
             Editable->True]}]}], ")"}], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["1", "+"],
           FontWeight->"Bold"],
          Schiebe[1, "+"],
          Editable->True]}]}], ")"}], 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["4", "-"],
        FontWeight->"Bold"],
       Schiebe[4, "-"],
       Editable->True], 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["V",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TVI[d, {1, 1, 1, 1}],
       Editable->True]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"d", "-", "3"}], ")"}], 
      SubsuperscriptBox["m", "4", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", 
         RowBox[{"(", 
          RowBox[{"d", "-", "4"}], ")"}], 
         SubsuperscriptBox["m", "1", "2"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["1", "+"],
           FontWeight->"Bold"],
          Schiebe[1, "+"],
          Editable->True]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", "-", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["u", 
             RowBox[{"6", ",", "2", ",", "4"}]], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["2", "+"],
              FontWeight->"Bold"],
             Schiebe[2, "+"],
             Editable->True]}], "-", 
           RowBox[{"2", 
            SubsuperscriptBox["m", "4", "2"], 
            InterpretationBox[
             StyleBox[
              SuperscriptBox["4", "+"],
              FontWeight->"Bold"],
             Schiebe[4, "+"],
             Editable->True]}]}], ")"}]}]}], ")"}], 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["1", "+"],
        FontWeight->"Bold"],
       Schiebe[1, "+"],
       Editable->True], 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["3", "-"],
        FontWeight->"Bold"],
       Schiebe[3, "-"],
       Editable->True], 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["V",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TVI[d, {1, 1, 1, 1}],
       Editable->True]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", "d"}], "-", "10"}], ")"}], 
      SubscriptBox["u", 
       RowBox[{"1", ",", "3", ",", "4"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"6", ",", "2", ",", "4"}]], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["2", "+"],
           FontWeight->"Bold"],
          Schiebe[2, "+"],
          Editable->True]}], "-", 
        RowBox[{"2", 
         SubsuperscriptBox["m", "4", "2"], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["4", "+"],
           FontWeight->"Bold"],
          Schiebe[4, "+"],
          Editable->True]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SuperscriptBox["3", "+"],
           FontWeight->"Bold"],
          Schiebe[3, "+"],
          Editable->True], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["1", "-"],
           FontWeight->"Bold"],
          Schiebe[1, "-"],
          Editable->True]}], "-", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SuperscriptBox["1", "+"],
           FontWeight->"Bold"],
          Schiebe[1, "+"],
          Editable->True], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["3", "-"],
           FontWeight->"Bold"],
          Schiebe[3, "-"],
          Editable->True]}]}], ")"}], 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["V",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm], 
         FormBox["1",
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TVI[d, {1, 1, 1, 1}],
       Editable->True]}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "70"], "=", 
  RowBox[{"OperatorApplyV", "[", 
   SubscriptBox["e", "70"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (70)", "Subsection",
 CellTags->"T1.6.51.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "70"], "=", 
  SubscriptBox["s", "70"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "70"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "70"], ",", "\"\<(70)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"m4", "=!=", "0"}], " ", "&&", " ", 
       RowBox[{"PP", "=!=", "0"}]}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell["\<\
CheckTVIRecursion not applicable for special indices since A's and 
B's appear .\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (71)", "Subsection",
 CellTags->"T1.6.52.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Nu]", "1"], ",", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], ">", "0"}]}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "71"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubscriptBox["D", 
      RowBox[{"1", ",", "2", ",", "3"}]], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", 
       RowBox[{"4", 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Sigma]", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Rho]", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "-"],
          FontWeight->"Bold"],
         Schiebe[3, "-"],
         Editable->True]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        SubscriptBox["\[CapitalSigma]", "3"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "2", ",", "1"}]]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "71"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "71"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (71)", "Subsection",
 CellTags->"T1.6.53.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "71"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Nu]explicit", "[", 
     SubscriptBox["s", "71"], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "2"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "71"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "71"], ",", "\"\<(71)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["D", 
        RowBox[{"1", ",", "2", ",", "3"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "71"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884544657681*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (7123)", "Subsection",
 CellTags->"T1.6.54.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "7123"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["s", "71"], ",", 
      RowBox[{"2", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "3"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "7123"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "7123"], ",", "\"\<(7123)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["D", 
        RowBox[{"1", ",", "3", ",", "2"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "7123"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884544808745*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (7113)", "Subsection",
 CellTags->"T1.6.55.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "7113"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["s", "71"], ",", 
      RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "3"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "7113"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "7113"], ",", "\"\<(7113)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["D", 
        RowBox[{"3", ",", "2", ",", "1"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "7113"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884544952129*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (78)", "Subsection",
 CellTags->"T1.6.56.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Nu]", "1"], ">", "0"}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "78"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubsuperscriptBox["m", "1", "2"], " ", 
     SubscriptBox["D", 
      RowBox[{"1", ",", "2", ",", "3"}]], 
     SubscriptBox["\[Nu]", "1"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "+", "1"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[CapitalSigma]", "3"]}], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], 
        SubscriptBox["\[Rho]", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "2", "2"], 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "1", ",", "2"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "-"],
          FontWeight->"Bold"],
         Schiebe[3, "-"],
         Editable->True]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", "2", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}]}], ")"}], 
        SubscriptBox["D", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubscriptBox["S", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], 
        SubscriptBox["S", 
         RowBox[{"2", ",", "1", ",", "3"}]], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["S", 
         RowBox[{"3", ",", "1", ",", "2"}]], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "78"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "78"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (78)", "Subsection",
 CellTags->"T1.6.57.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "78"], "=", 
  RowBox[{
   RowBox[{"\[Nu]explicit", "[", 
    SubscriptBox["s", "78"], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "78"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "78"], ",", "\"\<(78)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Nu]", "1"], ">", "2"}], "&&", 
       RowBox[{"m1", "=!=", "0"}]}], "&&", 
      RowBox[{
       SubscriptBox["D", 
        RowBox[{"1", ",", "2", ",", "3"}]], "=!=", "0"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "78"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884545162314*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (80)", "Subsection",
 CellTags->"T1.6.58.1"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["m", "1", "2"], "==", "0"}]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Nu]", "1"], ">", "0"}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "80"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Nu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "1"]}], "-", "2"}], ")"}], 
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"2", ",", "3", ",", "6"}]], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], 
        SubsuperscriptBox["m", "2", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True]}], "+", "\n", "\t\t\t\t", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             SubsuperscriptBox["m", "2", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             SubscriptBox["\[Nu]", "2"], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "3"]}], "-", "1"}], ")"}]}], "-", 
          RowBox[{
           SubsuperscriptBox["m", "3", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             SubscriptBox["\[Nu]", "2"], "-", "1"}], ")"}]}]}], ")"}], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", "\n", "\t\t\t  ", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "2"]}], "-", 
             SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}]}], "-", 
          RowBox[{
           SubsuperscriptBox["m", "2", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}]}]}], ")"}], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "-", "\n", "\t\t\t\t", 
       RowBox[{
        SubscriptBox["\[CapitalSigma]", "3"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], 
        SubscriptBox["u", 
         RowBox[{"6", ",", "2", ",", "3"}]]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "80"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "80"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (80)", "Subsection",
 CellTags->"T1.6.59.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "80"], "=", 
  RowBox[{
   RowBox[{"\[Nu]explicit", "[", 
    SubscriptBox["s", "80"], "]"}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "80"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "80"], ",", "\"\<(80)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"2", ",", "3", ",", "6"}]], "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m1", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "80"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845453256817`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (81)", "Subsection",
 CellTags->"T1.6.60.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 "and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Nu]", "1"], ",", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], ">", "0"}]}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "81"], "=", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[CapitalSigma]", "3"], "+", "2"}], ")"}], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "+", "2"}],
         TraditionalForm], ")"}]],
      TJI[2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}]}], "-", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}], "-", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          SubsuperscriptBox["m", "3", "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          SubsuperscriptBox["m", "1", "2"], "-", 
          RowBox[{"3", 
           SubsuperscriptBox["m", "2", "2"]}], "+", 
          RowBox[{"3", 
           SubsuperscriptBox["m", "3", "2"]}], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True], "+", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          RowBox[{"3", 
           SubsuperscriptBox["m", "1", "2"]}], "-", 
          SubsuperscriptBox["m", "2", "2"], "+", 
          RowBox[{"3", 
           SubsuperscriptBox["m", "3", "2"]}], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "+", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "81"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "81"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (81)", "Subsection",
 CellTags->"T1.6.61.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "81"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Nu]explicit", "[", 
      SubscriptBox["s", "81"], "]"}], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}], "/.", 
   RowBox[{"d", "->", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "81"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "81"], ",", "\"\<(81)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "81"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.50088454555925*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8123)", "Subsection",
 CellTags->"T1.6.62.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "8123"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Interchange", "[", 
      RowBox[{
       SubscriptBox["s", "81"], ",", 
       RowBox[{"2", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}], "/.", 
   RowBox[{"d", "->", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "8123"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "8123"], ",", "\"\<(8123)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "8123"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884545697321*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8113)", "Subsection",
 CellTags->"T1.6.63.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "8113"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Interchange", "[", 
      RowBox[{
       SubscriptBox["s", "81"], ",", 
       RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}], "/.", 
   RowBox[{"d", "\[Rule]", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "8113"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "8113"], ",", "\"\<(8113)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "8113"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845458486013`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (82)", "Subsection",
 CellTags->"T1.6.64.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 "and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Nu]", "1"], ">", "0"}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "82"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        SuperscriptBox["p", "2"],
        PP]}], 
      SubsuperscriptBox["m", "1", "2"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[CapitalSigma]", "3"], "+", "2"}], ")"}], 
      SubscriptBox["\[Nu]", "1"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], "+", "1"}], ")"}], 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["1", "+"],
        FontWeight->"Bold"],
       Schiebe[1, "+"],
       Editable->True], 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["1", "+"],
        FontWeight->"Bold"],
       Schiebe[1, "+"],
       Editable->True], 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox[
          RowBox[{"d", "+", "2"}],
          TraditionalForm], ")"}]],
       TJI[2 + d, {
         Subscript[\[Nu], 1], 
         Subscript[\[Nu], 2], 
         Subscript[\[Nu], 3]}],
       Editable->True]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      InterpretationBox[
       SuperscriptBox["p", "2"],
       PP], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[CapitalSigma]", "3"], "+", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[CapitalSigma]", "3"], "+", "4"}], ")"}], 
      SubscriptBox["\[Nu]", "1"], 
      InterpretationBox[
       StyleBox[
        SuperscriptBox["1", "+"],
        FontWeight->"Bold"],
       Schiebe[1, "+"],
       Editable->True], 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox[
          RowBox[{"d", "+", "2"}],
          TraditionalForm], ")"}]],
       TJI[2 + d, {
         Subscript[\[Nu], 1], 
         Subscript[\[Nu], 2], 
         Subscript[\[Nu], 3]}],
       Editable->True]}]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"d", "+", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["m", "1", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", 
              SubscriptBox["\[Nu]", "1"]}], "+", 
             RowBox[{"6", 
              SubscriptBox["\[Nu]", "2"]}], "+", 
             RowBox[{"6", 
              SubscriptBox["\[Nu]", "3"]}], "-", 
             RowBox[{"7", "d"}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["m", "2", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             RowBox[{"4", 
              SubscriptBox["\[Nu]", "2"]}], "-", 
             RowBox[{"10", 
              SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["m", "3", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             RowBox[{"10", 
              SubscriptBox["\[Nu]", "2"]}], "-", 
             RowBox[{"4", 
              SubscriptBox["\[Nu]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["m", "2", "2"], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["m", "3", "2"], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "-", 
       RowBox[{"4", 
        SubsuperscriptBox["m", "2", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           SuperscriptBox[
            RowBox[{"(", 
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], ")"}], "2"]}], "-", 
          RowBox[{
           InterpretationBox[
            SuperscriptBox["p", "2"],
            PP], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SubsuperscriptBox["m", "1", "2"]}], "+", 
             SubsuperscriptBox["m", "2", "2"], "+", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["m", "1", "2"], 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["m", "2", "2"], "+", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}]}], "+", 
          RowBox[{"3", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["m", "2", "2"], "-", 
              SubsuperscriptBox["m", "3", "2"]}], ")"}], "2"]}]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SuperscriptBox["p", "2"],
             PP], ")"}], "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             SubsuperscriptBox["m", "2", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              SubsuperscriptBox["m", "1", "2"]}], "-", 
             RowBox[{"5", 
              SubsuperscriptBox["m", "3", "2"]}], "+", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"],
              Editable->True]}], ")"}]}], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            SubsuperscriptBox["m", "2", "2"], ")"}], "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SuperscriptBox["p", "2"],
             PP], ")"}], "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              SubsuperscriptBox["m", "1", "2"]}], "-", 
             RowBox[{"5", 
              SubsuperscriptBox["m", "2", "2"]}], "+", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"],
              Editable->True]}], ")"}]}], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            SubsuperscriptBox["m", "3", "2"], ")"}], "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalSigma]", "3"], "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["m", "2", "2"], "-", 
          SubsuperscriptBox["m", "3", "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "82"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "82"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "82"], "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["s", "82"], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["r", "82"], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], "==", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["r", "82"], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["r", "82"], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (82)", "Subsection",
 CellTags->"T1.6.65.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "82"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Nu]explicit", "[", 
     SubscriptBox["s", "82"], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "-", "2"}]}]}], "/.", 
   RowBox[{"d", "->", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "82"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "82"], ",", "\"\<(82)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PP", "=!=", "0"}], "&&", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], ">", "2"}], "&&", 
       RowBox[{"m1", "=!=", "0"}]}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "82"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.50088454621826*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8213)", "Subsection",
 CellTags->"T1.6.66.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "8213"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["s", "82"], ",", 
      RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], "-", "2"}]}]}], "/.", 
   RowBox[{"d", "->", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "8213"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "8213"], ",", "\"\<(8213)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PP", "=!=", "0"}], "&&", 
       RowBox[{"m3", "=!=", "0"}]}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "2"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "8213"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845464076977`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8212)", "Subsection",
 CellTags->"T1.6.67.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "8212"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Interchange", "[", 
     RowBox[{
      SubscriptBox["s", "82"], ",", 
      RowBox[{"1", "\[LeftRightArrow]", "2"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "-", "2"}]}]}], "/.", 
   RowBox[{"d", "->", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "8212"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "8212"], ",", "\"\<(8212)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PP", "=!=", "0"}], "&&", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], ">", "2"}], "&&", 
       RowBox[{"m2", "=!=", "0"}]}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "8212"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884546619176*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (83)", "Subsection",
 CellTags->"T1.6.68.1"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["m", "1", "2"], "==", "0"}]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Nu]", "1"], ">", "0"}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "83"], "=", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[CapitalSigma]", "3"], "+", "2"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[CapitalSigma]", "3"], "+", "4"}], ")"}], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "+", "2"}],
         TraditionalForm], ")"}]],
      TJI[2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            SuperscriptBox["p", "2"],
            PP], ")"}], "2"]}], 
        RowBox[{"(", 
         RowBox[{"d", "+", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["m", "2", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             RowBox[{"4", 
              SubscriptBox["\[Nu]", "2"]}], "-", 
             RowBox[{"10", 
              SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["m", "3", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "1"]}], "-", 
             RowBox[{"10", 
              SubscriptBox["\[Nu]", "2"]}], "-", 
             RowBox[{"4", 
              SubscriptBox["\[Nu]", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["m", "2", "2"], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}]}], "+", 
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["m", "3", "2"], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}], "-", 
       RowBox[{"8", 
        SubsuperscriptBox["m", "2", "2"], 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SuperscriptBox["p", "2"],
             PP], ")"}], "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             SubsuperscriptBox["m", "2", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", 
              SubsuperscriptBox["m", "3", "2"]}], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True], "+", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["3", "-"],
               FontWeight->"Bold"],
              Schiebe[3, "-"],
              Editable->True]}], ")"}]}], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            SubsuperscriptBox["m", "2", "2"], ")"}], "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SuperscriptBox["p", "2"],
             PP], ")"}], "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", 
              SubsuperscriptBox["m", "2", "2"]}], "-", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["1", "-"],
               FontWeight->"Bold"],
              Schiebe[1, "-"],
              Editable->True], "+", 
             InterpretationBox[
              StyleBox[
               SuperscriptBox["2", "-"],
               FontWeight->"Bold"],
              Schiebe[2, "-"],
              Editable->True]}], ")"}]}], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            SubsuperscriptBox["m", "3", "2"], ")"}], "2"]}], ")"}], 
        SubscriptBox["\[Nu]", "3"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "-", 
       RowBox[{
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalSigma]", "3"], "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "83"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "83"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (83)", "Subsection",
 CellTags->"T1.6.69.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "83"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Nu]explicit", "[", 
     SubscriptBox["s", "83"], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], "/.", 
   RowBox[{"d", "->", 
    RowBox[{"d", "-", "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "83"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "83"], ",", "\"\<(83)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}], ",", 
    RowBox[{"m1", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "83"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884546907449*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (87)", "Subsection",
 CellTags->"T1.6.70.1"],

Cell[CellGroupData[{

Cell["(88)", "Subsubsection",
 CellTags->"T1.6.70.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["t", "1"], "=", 
   RowBox[{
    SubsuperscriptBox["m", "1", "2"], "+", 
    SubsuperscriptBox["m", "2", "2"], "+", 
    SubsuperscriptBox["m", "3", "2"]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["t", "2"], "=", 
   RowBox[{
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", "1", "4"], "+", 
       SubsuperscriptBox["m", "2", "4"], "+", 
       SubsuperscriptBox["m", "3", "4"]}], ")"}]}], "+", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "2", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "1", "2"], 
        SubsuperscriptBox["m", "3", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], 
        SubsuperscriptBox["m", "3", "2"]}]}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["t", "3"], "=", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["m", "1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", "1", "4"], "-", 
       SubsuperscriptBox["m", "2", "4"], "-", 
       SubsuperscriptBox["m", "3", "4"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["m", "2", "2"], 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", "2", "4"], "-", 
       SubsuperscriptBox["m", "1", "4"], "-", 
       SubsuperscriptBox["m", "3", "4"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["m", "3", "2"], 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", "3", "4"], "-", 
       SubsuperscriptBox["m", "1", "4"], "-", 
       SubsuperscriptBox["m", "2", "4"]}], ")"}]}], "+", 
    RowBox[{"10", 
     SubsuperscriptBox["m", "1", "2"], 
     SubsuperscriptBox["m", "2", "2"], 
     SubsuperscriptBox["m", "3", "2"]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"\[Mu]1_", ",", "\[Mu]2_", ",", " ", "\[Mu]3_"}], "]"}], ":=", 
   RowBox[{"\[Mu]1", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       SuperscriptBox["p", "2"],
       PP], "-", "\[Mu]1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{"(", 
        RowBox[{"d", "-", "4"}], ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          SuperscriptBox["p", "2"],
          PP], ")"}], "2"]}], "+", 
      RowBox[{
       InterpretationBox[
        SuperscriptBox["p", "2"],
        PP], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", 
          SubscriptBox["t", "1"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", "d"}], "-", "18"}], ")"}]}], "-", 
         RowBox[{"24", "\[Mu]1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "d"}], "-", "7"}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "d"}], "-", "13"}], ")"}], 
       SuperscriptBox[
        SubscriptBox["t", "1"], "2"]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9", "d"}], "-", "31"}], ")"}], 
       SubscriptBox["t", "2"]}], "-", 
      RowBox[{"24", "\[Mu]2", " ", "\[Mu]3", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "d"}], "-", "13"}], ")"}]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["\[Mu]1", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "d"}], "-", "7"}], ")"}]}]}], ")"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"1", ",", "2", ",", "3"}]], "=", 
   RowBox[{"f", "[", 
    RowBox[{
     SubsuperscriptBox["m", "1", "2"], ",", 
     SubsuperscriptBox["m", "2", "2"], ",", 
     SubsuperscriptBox["m", "3", "2"]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"2", ",", "1", ",", "3"}]], "=", 
   RowBox[{"f", "[", 
    RowBox[{
     SubsuperscriptBox["m", "2", "2"], ",", 
     SubsuperscriptBox["m", "1", "2"], ",", 
     SubsuperscriptBox["m", "3", "2"]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"3", ",", "2", ",", "1"}]], "=", 
   RowBox[{"f", "[", 
    RowBox[{
     SubsuperscriptBox["m", "3", "2"], ",", 
     SubsuperscriptBox["m", "2", "2"], ",", 
     SubsuperscriptBox["m", "1", "2"]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(89)", "Subsubsection",
 CellTags->"T1.6.70.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"\[Mu]1_", ",", "\[Mu]2_", ",", " ", "\[Mu]3_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"\[Mu]1", " ", "\[Mu]2"}], 
     RowBox[{"d", "-", "4"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{"d", "-", "4"}], ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          SuperscriptBox["p", "2"],
          PP], ")"}], "2"]}], "-", 
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7", "d"}], "-", "24"}], ")"}], 
       InterpretationBox[
        SuperscriptBox["p", "2"],
        PP], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "\[Mu]3"}], "-", 
         RowBox[{"2", 
          SubscriptBox["t", "1"]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["t", "1"], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"23", "d"}], "-", "80"}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["t", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9", "d"}], "-", "32"}], ")"}]}], "-", 
      RowBox[{"12", 
       SuperscriptBox["\[Mu]3", "2"], 
       RowBox[{"(", 
        RowBox[{"d", "-", "4"}], ")"}]}], "+", 
      RowBox[{"12", "\[Mu]1", " ", "\[Mu]2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"7", "d"}], "-", "24"}], ")"}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["g", 
    RowBox[{"1", ",", "2", ",", "3"}]], "=", 
   RowBox[{"g", "[", 
    RowBox[{
     SubsuperscriptBox["m", "1", "2"], ",", 
     SubsuperscriptBox["m", "2", "2"], ",", 
     SubsuperscriptBox["m", "3", "2"]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["g", 
    RowBox[{"1", ",", "3", ",", "2"}]], "=", 
   RowBox[{"g", "[", 
    RowBox[{
     SubsuperscriptBox["m", "1", "2"], ",", 
     SubsuperscriptBox["m", "3", "2"], ",", 
     SubsuperscriptBox["m", "2", "2"]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["g", 
    RowBox[{"2", ",", "3", ",", "1"}]], "=", 
   RowBox[{"g", "[", 
    RowBox[{
     SubsuperscriptBox["m", "2", "2"], ",", 
     SubsuperscriptBox["m", "3", "2"], ",", 
     SubsuperscriptBox["m", "1", "2"]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 SubscriptBox["g", 
  RowBox[{"1", ",", "2", ",", "3"}]]], "Input"],

Cell[TextData[{
 "general  ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 " "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "87"], "=", 
   RowBox[{
    RowBox[{"3", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     RowBox[{"(", 
      RowBox[{"d", "-", "3"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", "4"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "d"}], "-", "8"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "d"}], "-", "10"}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {1, 1, 1}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "-", "4"}], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], ")"}], "3"]}], "-", 
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], ")"}], "2"], 
        SubscriptBox["t", "1"], 
        RowBox[{"(", 
         RowBox[{"d", "-", "4"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", "d"}], "-", "23"}], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", 
           SuperscriptBox[
            SubscriptBox["t", "1"], "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15", 
              SuperscriptBox["d", "2"]}], "-", 
             RowBox[{"117", "d"}], "+", "224"}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["t", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"42", 
              SuperscriptBox["d", "2"]}], "-", 
             RowBox[{"331", "d"}], "+", "640"}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"(", 
         RowBox[{"d", "-", "5"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["t", "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"27", "d"}], "-", "90"}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["t", "1"], 
           SubscriptBox["t", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", "d"}], "-", "2"}], ")"}]}], "-", 
          RowBox[{"2", 
           SuperscriptBox[
            SubscriptBox["t", "1"], "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", "d"}], "-", "26"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["f", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["f", 
         RowBox[{"2", ",", "1", ",", "3"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["f", 
         RowBox[{"3", ",", "2", ",", "1"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["g", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "-"],
          FontWeight->"Bold"],
         Schiebe[3, "-"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["g", 
         RowBox[{"1", ",", "3", ",", "2"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["g", 
         RowBox[{"2", ",", "3", ",", "1"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TJI[-2 + d, {1, 1, 1}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "87"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "87"], "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (87)", "Subsection",
 CellTags->"T1.6.71.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "87"], "=", 
  SubscriptBox["s", "87"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["f", "87"], "=", 
   RowBox[{"MakeFun", "[", 
    RowBox[{
     SubscriptBox["h", "87"], ",", "\"\<(87)\>\"", ",", 
     RowBox[{"IFF", "[", 
      RowBox[{
       RowBox[{"PP", "=!=", "0"}], "&&", 
       RowBox[{"MatchQ", "[", 
        RowBox[{"d", ",", 
         RowBox[{"_Symbol", "+", 
          RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (90)", "Subsection",
 CellTags->"T1.6.72.1"],

Cell[TextData[{
 "general  ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]],
 " "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "90"], "=", 
   RowBox[{
    RowBox[{"3", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     RowBox[{"(", 
      RowBox[{"d", "-", "3"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", "4"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "d"}], "-", "10"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {1, 1, 1}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", "1", "2"]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], ")"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", "24"}], ")"}]}], "-", 
          RowBox[{"2", 
           InterpretationBox[
            SuperscriptBox["p", "2"],
            PP], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", "d"}], "-", "15"}], ")"}], 
              SubscriptBox["t", "1"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"d", "-", "5"}], ")"}], 
              SubsuperscriptBox["m", "1", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["3", "2"], 
           RowBox[{"(", 
            RowBox[{"d", "-", "5"}], ")"}], 
           SuperscriptBox[
            SubscriptBox["t", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "2"], 
           RowBox[{"(", 
            RowBox[{"d", "-", "3"}], ")"}], 
           SubscriptBox["t", "2"]}], "-", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", "d"}], "-", "17"}], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["m", "1", "2"], ")"}], "2"]}], "-", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"13", "d"}], "-", "45"}], ")"}], 
           SubsuperscriptBox["m", "2", "2"], 
           SubsuperscriptBox["m", "3", "2"]}]}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", "\n", "\t\t\t\t", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          SubsuperscriptBox["m", "2", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "-", "3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "+", 
             SubsuperscriptBox["m", "2", "2"], "-", 
             RowBox[{"5", 
              SubsuperscriptBox["m", "3", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", "25"}], ")"}], 
           SubsuperscriptBox["m", "1", "2"]}]}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True]}], "+", "\n", "\t\t\t\t", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "3", "2"], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], "-", 
          SubsuperscriptBox["m", "3", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "-", "3"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              SuperscriptBox["p", "2"],
              PP], "-", 
             RowBox[{"5", 
              SubsuperscriptBox["m", "2", "2"]}], "+", 
             SubsuperscriptBox["m", "3", "2"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", "25"}], ")"}], 
           SubsuperscriptBox["m", "1", "2"]}]}], ")"}], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["3", "+"],
          FontWeight->"Bold"],
         Schiebe[3, "+"],
         Editable->True]}], "-", "\n", "\t\t\t\t", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "-", "3"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "-", "4"}], ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           SuperscriptBox["p", "2"],
           PP], ")"}], "2"]}], "+", 
       RowBox[{
        InterpretationBox[
         SuperscriptBox["p", "2"],
         PP], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", "30"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"d", "-", "3"}], ")"}], 
           SubscriptBox["t", "1"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "d"}], "-", "31"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", "d"}], "-", "10"}], ")"}], 
           SubsuperscriptBox["m", "1", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"(", 
         RowBox[{"d", "-", "5"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"17", "d"}], "-", "66"}], ")"}], 
           SuperscriptBox[
            SubscriptBox["t", "1"], "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", "d"}], "-", "14"}], ")"}], 
           SubscriptBox["t", "2"]}], "-", 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", "d"}], "-", "10"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["m", "1", "2"], ")"}], "2"], "+", 
             RowBox[{"5", 
              SubsuperscriptBox["m", "2", "2"], 
              SubsuperscriptBox["m", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       "\t", 
       RowBox[{
        FractionBox["2", 
         RowBox[{"d", "-", "4"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 SuperscriptBox["p", "2"],
                 PP], "+", 
                SubsuperscriptBox["m", "2", "2"]}], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", "d"}], "-", "24"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"d", "-", "4"}], ")"}], 
              SubsuperscriptBox["m", "1", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", "d"}], "-", "18"}], ")"}], 
              SubsuperscriptBox["m", "3", "2"]}]}], ")"}], 
           SubsuperscriptBox["m", "1", "2"], 
           SubsuperscriptBox["m", "2", "2"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "+"],
             FontWeight->"Bold"],
            Schiebe[2, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "-"],
             FontWeight->"Bold"],
            Schiebe[3, "-"],
            Editable->True]}], "+", "\n", "\t\t\t\t\t\t", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 SuperscriptBox["p", "2"],
                 PP], "+", 
                SubsuperscriptBox["m", "3", "2"]}], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", "d"}], "-", "24"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"d", "-", "4"}], ")"}], 
              SubsuperscriptBox["m", "1", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", "d"}], "-", "18"}], ")"}], 
              SubsuperscriptBox["m", "2", "2"]}]}], ")"}], 
           SubsuperscriptBox["m", "1", "2"], 
           SubsuperscriptBox["m", "3", "2"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "-"],
             FontWeight->"Bold"],
            Schiebe[2, "-"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True]}], "-", "\n", "\t\t\t\t\t\t", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                InterpretationBox[
                 SuperscriptBox["p", "2"],
                 PP], "+", 
                SubsuperscriptBox["m", "2", "2"], "+", 
                SubsuperscriptBox["m", "3", "2"]}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "-", "3"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"d", "-", "4"}], ")"}], 
              SubsuperscriptBox["m", "1", "2"]}]}], ")"}], 
           SubsuperscriptBox["m", "2", "2"], 
           SubsuperscriptBox["m", "3", "2"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "-"],
             FontWeight->"Bold"],
            Schiebe[1, "-"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "+"],
             FontWeight->"Bold"],
            Schiebe[2, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "+"],
             FontWeight->"Bold"],
            Schiebe[3, "+"],
            Editable->True]}]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm], 
        FormBox["1",
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TJI[-2 + d, {1, 1, 1}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "90"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "90"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (90)", "Subsection",
 CellTags->"T1.6.73.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["h", "90"], "=", 
   SubscriptBox["s", "90"]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "90"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "90"], ",", "\"\<(90)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{"PP", "=!=", "0"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (91)", "Subsection",
 CellTags->"T1.6.74.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "91.1"], "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", "2"}], ")"}], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["u", 
         RowBox[{"1", ",", "2", ",", "3"}]]}], "-", 
       InterpretationBox[
        StyleBox[
         SuperscriptBox["1", "-"],
         FontWeight->"Bold"],
        Schiebe[1, "-"],
        Editable->True], "+", 
       InterpretationBox[
        StyleBox[
         SuperscriptBox["2", "-"],
         FontWeight->"Bold"],
        Schiebe[2, "-"],
        Editable->True], "+", 
       InterpretationBox[
        StyleBox[
         SuperscriptBox["3", "-"],
         FontWeight->"Bold"],
        Schiebe[3, "-"],
        Editable->True]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TKI[-2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "91.1"], "=", 
  RowBox[{"OperatorApplyK", "[", 
   SubscriptBox["e", "91.1"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "91.2"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", "2"}], ")"}], 
     SubscriptBox["\[Nu]", "2"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "+"],
       FontWeight->"Bold"],
      Schiebe[2, "+"],
      Editable->True], 
     SubscriptBox["\[Nu]", "3"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["3", "+"],
       FontWeight->"Bold"],
      Schiebe[3, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        SubsuperscriptBox["m", "1", "2"], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True]}], "+", 
       RowBox[{"(", 
        RowBox[{"d", "-", "2", "-", 
         RowBox[{"2", 
          SubscriptBox["\[Nu]", "1"]}]}], ")"}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TKI[-2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "91.2"], "=", 
  RowBox[{"OperatorApplyK", "[", 
   SubscriptBox["e", "91.2"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "91.3"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", "2"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "1"], "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "3"]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"1", ",", "2", ",", "3"}]], "+", 
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"1", ",", "2", ",", "3"}]], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["1", "-"],
           FontWeight->"Bold"],
          Schiebe[1, "-"],
          Editable->True]}], "+", 
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"2", ",", "1", ",", "3"}]], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["2", "-"],
           FontWeight->"Bold"],
          Schiebe[2, "-"],
          Editable->True]}], "+", 
        RowBox[{
         SubscriptBox["u", 
          RowBox[{"3", ",", "1", ",", "2"}]], 
         InterpretationBox[
          StyleBox[
           SuperscriptBox["3", "-"],
           FontWeight->"Bold"],
          Schiebe[3, "-"],
          Editable->True]}]}], ")"}]}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TKI[-2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "91.3"], "=", 
  RowBox[{"OperatorApplyK", "[", 
   SubscriptBox["e", "91.3"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "91.4"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"1", ",", "2", ",", "3"}]], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"1", ",", "2", ",", "3"}]], 
        RowBox[{"(", 
         RowBox[{"d", "-", 
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"3", ",", "1", ",", "2"}]], 
        SubscriptBox["\[Nu]", "1"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "+"],
          FontWeight->"Bold"],
         Schiebe[1, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["2", "-"],
            FontWeight->"Bold"],
           Schiebe[2, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "2", "2"], 
        SubscriptBox["\[Nu]", "2"], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "+"],
          FontWeight->"Bold"],
         Schiebe[2, "+"],
         Editable->True], 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            SuperscriptBox["1", "-"],
            FontWeight->"Bold"],
           Schiebe[1, "-"],
           Editable->True], "-", 
          InterpretationBox[
           StyleBox[
            SuperscriptBox["3", "-"],
            FontWeight->"Bold"],
           Schiebe[3, "-"],
           Editable->True]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "91.4"], "=", 
  RowBox[{"OperatorApplyK", "[", 
   SubscriptBox["e", "91.4"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (911)", "Subsection",
 CellTags->"T1.6.75.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "911"], "=", 
  RowBox[{
   SubscriptBox["s", "91.1"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "911"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "911"], ",", "\"\<(911)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (912)", "Subsection",
 CellTags->"T1.6.76.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "912"], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["s", "91.2"], "/.", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "3"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "912"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "912"], ",", "\"\<(912)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (913)", "Subsection",
 CellTags->"T1.6.77.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "913"], "=", 
  SubscriptBox["s", "91.3"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "913"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "913"], ",", "\"\<(913)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n2", "===", "1"}], " ", "||", " ", 
        RowBox[{"n3", "===", "1"}]}], ")"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}], ",", 
    RowBox[{"n1", ":>", "1"}]}], "]"}]}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (914)", "Subsection",
 CellTags->"T1.6.78.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "914"], "=", 
  RowBox[{
   SubscriptBox["s", "91.4"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "914"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "914"], ",", "\"\<(914)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "2", ",", "3"}]], "=!=", "0"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], " ", ">", " ", "1"}], " ", ")"}], "&&", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", "_Symbol"}], "]"}]}], "]"}]}], "]"}]}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (92)", "Subsection",
 CellTags->"T1.6.79.1"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", 
    RowBox[{"1", ",", "2", ",", "3"}]], TraditionalForm]]],
 " = Cayley[1,2,3][{m1,m2,m3}]"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cayley", "[", 
   RowBox[{"1", ",", "2", ",", "3"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"m1", ",", "m2", ",", "m3"}], "}"}], "]"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     SubsuperscriptBox["m", "1", "2"], "==", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "2"], "+", 
        SubscriptBox["m", "3"]}], ")"}], "2"]}], " ", ")"}], " ", 
   "\[DoubleLongRightArrow]", " ", 
   RowBox[{"(", " ", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"1", ",", "2", ",", "3"}]], "==", "0"}], " ", ")"}]}], 
  TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "92"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubscriptBox["m", "2"], 
     SubscriptBox["m", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["m", "2"], "+", 
       SubscriptBox["m", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "2"]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "3"]}], "-", "1"}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "-", 
             SubscriptBox["\[Nu]", "1"], "-", 
             SubscriptBox["\[Nu]", "2"], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "3"]}], "-", "1"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SuperscriptBox["1", "+"],
                FontWeight->"Bold"],
               Schiebe[1, "+"],
               Editable->True], 
              InterpretationBox[
               StyleBox[
                SuperscriptBox["2", "-"],
                FontWeight->"Bold"],
               Schiebe[2, "-"],
               Editable->True]}], "-", "1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Nu]", "1"], "-", 
             SubscriptBox["\[Nu]", "2"], "+", "1"}], ")"}], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["3", "-"],
             FontWeight->"Bold"],
            Schiebe[3, "-"],
            Editable->True]}]}], ")"}]}], "+", "\n", "\t\t\t", 
       RowBox[{
        SubscriptBox["m", "3"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "-", 
             SubscriptBox["\[Nu]", "1"], "-", 
             RowBox[{"2", 
              SubscriptBox["\[Nu]", "2"]}], "-", 
             SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SuperscriptBox["1", "+"],
                FontWeight->"Bold"],
               Schiebe[1, "+"],
               Editable->True], 
              InterpretationBox[
               StyleBox[
                SuperscriptBox["3", "-"],
                FontWeight->"Bold"],
               Schiebe[3, "-"],
               Editable->True]}], "-", "1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Nu]", "1"], "-", 
             SubscriptBox["\[Nu]", "3"], "+", "1"}], ")"}], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "-"],
             FontWeight->"Bold"],
            Schiebe[2, "-"],
            Editable->True]}]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "92"], "=", 
  RowBox[{"OperatorApplyK", "[", 
   SubscriptBox["e", "92"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (93)", "Subsection",
 CellTags->"T1.6.80.1"],

Cell[TextData[{
 "( ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "1"], "==", "0"}], ")"}], " ", "&&", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "2"], "==", 
        SubscriptBox["m", "3"]}], ")"}]}], " ", " ", ")"}], " ", 
    "\[DoubleLongRightArrow]", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", 
       RowBox[{"1", ",", "2", ",", "3"}]], "==", "0"}], " ", ")"}]}], 
   TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "93"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubsuperscriptBox["m", "2", "2"], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", "2"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "3"]}], ")"}], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "3"]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}], "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "2"]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "1"], "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "3"]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TKI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "93"], "=", 
  RowBox[{"OperatorApplyK", "[", 
   SubscriptBox["e", "93"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (93)", "Subsection",
 CellTags->"T1.6.81.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "93"], "=", 
  RowBox[{
   SubscriptBox["s", "93"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "93"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "93"], ",", "\"\<(93)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{
       SubscriptBox["m", "2"], "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m1", ":>", "0"}], ",", 
      RowBox[{"m3", ":>", "m2"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (94)", "Subsection",
 CellTags->"T1.6.82.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "94"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"1", ",", "2", ",", "6"}]], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TBI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"6", ",", "1", ",", "2"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "1"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "+"],
             FontWeight->"Bold"],
            Schiebe[1, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "-"],
             FontWeight->"Bold"],
            Schiebe[2, "-"],
            Editable->True]}], "-", "d", "+", 
          SubscriptBox["\[Nu]", "1"], "+", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        SubsuperscriptBox["m", "2", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", "2"], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["2", "+"],
             FontWeight->"Bold"],
            Schiebe[2, "+"],
            Editable->True], 
           InterpretationBox[
            StyleBox[
             SuperscriptBox["1", "-"],
             FontWeight->"Bold"],
            Schiebe[1, "-"],
            Editable->True]}], "-", "d", "+", 
          RowBox[{"2", 
           SubscriptBox["\[Nu]", "1"]}], "+", 
          SubscriptBox["\[Nu]", "2"]}], ")"}]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TBI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "94"], "=", 
  RowBox[{"OperatorApplyB", "[", 
   SubscriptBox["e", "94"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (94)", "Subsection",
 CellTags->"T1.6.83.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "94"], "=", 
  RowBox[{
   SubscriptBox["s", "94"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "94"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "94"], ",", "\"\<(94)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "2", ",", "6"}]], "=!=", "0"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9401)", "Subsection",
 CellTags->"T1.6.84.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "9401"], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["s", "94"], "/.", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", 
      RowBox[{"1", ",", "2", ",", "6"}]], "->", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"6", ",", "1", ",", "2"}]], "->", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "9401"], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["n", "9401"], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "==", 
   RowBox[{
    SubscriptBox["n", "9401"], "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "1"}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "9401"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "9401"], ",", "\"\<(9401)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "2", ",", "6"}]], "===", "0"}], "&&", 
      RowBox[{
       SubscriptBox["u", 
        RowBox[{"6", ",", "1", ",", "2"}]], "===", "0"}], "&&", 
      RowBox[{"m2", "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9402)", "Subsection",
 CellTags->"T1.6.85.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "9402"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["s", "94"], "/.", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "2", ",", "6"}]], "->", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"6", ",", "1", ",", "2"}]], "->", "0"}]}], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "9402"], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["n", "9402"], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "==", 
   RowBox[{
    SubscriptBox["n", "9402"], "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "9402"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "9402"], ",", "\"\<(9402)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "2", ",", "6"}]], "===", "0"}], "&&", 
      RowBox[{
       SubscriptBox["u", 
        RowBox[{"6", ",", "1", ",", "2"}]], "===", "0"}], "&&", 
      RowBox[{"m1", "=!=", "0"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (95)", "Subsection",
 CellTags->"T1.6.86.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "95"], "=", 
   RowBox[{
    RowBox[{"2", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TBI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["u", 
        RowBox[{"1", ",", "2", ",", "6"}]], "+", 
       InterpretationBox[
        StyleBox[
         SuperscriptBox["1", "-"],
         FontWeight->"Bold"],
        Schiebe[1, "-"],
        Editable->True], "-", 
       InterpretationBox[
        StyleBox[
         SuperscriptBox["2", "-"],
         FontWeight->"Bold"],
        Schiebe[2, "-"],
        Editable->True]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TBI[-2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "95"], "=", 
  RowBox[{"OperatorApplyB", "[", 
   SubscriptBox["e", "95"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (95)", "Subsection",
 CellTags->"T1.6.87.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "95"], "=", 
  RowBox[{
   SubscriptBox["s", "95"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "95"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "95"], ",", "\"\<(95)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], " ", "&&", " ", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", 
        RowBox[{"_Symbol", "+", 
         RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (96)", "Subsection",
 CellTags->"T1.6.88.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "96"], "=", 
   RowBox[{
    RowBox[{"2", 
     InterpretationBox[
      SuperscriptBox["p", "2"],
      PP], 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "1"], "-", 
       SubscriptBox["\[Nu]", "2"], "-", "1"}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TBI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", 
        RowBox[{"1", ",", "2", ",", "6"}]], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"1", ",", "2", ",", "6"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["1", "-"],
          FontWeight->"Bold"],
         Schiebe[1, "-"],
         Editable->True]}], "+", 
       RowBox[{
        SubscriptBox["u", 
         RowBox[{"2", ",", "1", ",", "6"}]], 
        InterpretationBox[
         StyleBox[
          SuperscriptBox["2", "-"],
          FontWeight->"Bold"],
         Schiebe[2, "-"],
         Editable->True]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TBI[-2 + d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "96"], "=", 
  RowBox[{"OperatorApplyB", "[", 
   SubscriptBox["e", "96"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (96)", "Subsection",
 CellTags->"T1.6.89.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "96"], "=", 
  SubscriptBox["s", "96"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "96"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "96"], ",", "\"\<(96)\>\"", ",", 
    RowBox[{"IFF", "[", " ", 
     RowBox[{"MatchQ", "[", 
      RowBox[{"d", ",", 
       RowBox[{"_Symbol", "+", 
        RowBox[{"_Integer", " ", "?", "Positive"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"n1", ":>", "1"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (97)", "Subsection",
 CellTags->"T1.6.90.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "97"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubsuperscriptBox["m", "1", "2"], 
     SubscriptBox["\[Nu]", "1"], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["A",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TAI[d, {
        Subscript[\[Nu], 1]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["A",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TAI[d, {
        Subscript[\[Nu], 1]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "97"], "=", 
  RowBox[{"OperatorApplyA", "[", 
   SubscriptBox["e", "97"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (97)", "Subsection",
 CellTags->"T1.6.91.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "97"], "=", 
  RowBox[{
   SubscriptBox["s", "97"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "97"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "97"], ",", "\"\<(97)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", " ", 
      RowBox[{"MatchQ", "[", 
       RowBox[{"d", ",", "_Symbol"}], " ", "]"}]}], "]"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (98)", "Subsection",
 CellTags->"T1.6.92.1"],

Cell[TextData[{
 "general ",
 Cell[BoxData[
  SubsuperscriptBox["m", "i", "2"]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "98"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", 
        SubscriptBox["\[Nu]", "1"]}]}], ")"}], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["A",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TAI[d, {
        Subscript[\[Nu], 1]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{"-", "2"}], 
     SubsuperscriptBox["m", "1", "2"], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["A",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       RowBox[{"(", 
        FormBox[
         RowBox[{"d", "-", "2"}],
         TraditionalForm], ")"}]],
      TAI[-2 + d, {
        Subscript[\[Nu], 1]}],
      Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "98"], "=", 
  RowBox[{"OperatorApplyA", "[", 
   SubscriptBox["e", "98"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (98)", "Subsection",
 CellTags->"T1.6.93.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "98"], "=", 
  SubscriptBox["s", "98"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "98"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "98"], ",", "\"\<(98)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{"MatchQ", "[", 
      RowBox[{"d", ",", 
       RowBox[{"_Symbol", " ", "+", 
        RowBox[{"_Integer", "?", "Positive"}]}]}], "]"}], "]"}]}], 
   "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (99)", "Subsection",
 CellTags->"T1.6.94.1"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["m", "1"], "=", "M"}], ",", " ", 
   RowBox[{
    SuperscriptBox["p", "2"], "=", 
    SuperscriptBox["M", "2"]}], ",", 
   RowBox[{
    SubscriptBox["m", "2"], "=", 
    RowBox[{
     SubscriptBox["m", "3"], "=", "0"}]}]}], TraditionalForm]]]], "Text"],

Cell[TextData[{
 "Herleitung in three.nb ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Nu]", "1"]}], " ", 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}], " ", 
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]]}], "==", 
    RowBox[{
     SubscriptBox["\[Nu]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "d"}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "2"]}], "+", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "d"}], "+", 
       SubscriptBox["\[Nu]", "1"], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "2"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "3"]}], "+", "2"}], ")"}], " ", 
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]]}]}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["e", "99"], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Nu]", "1"], " ", 
    RowBox[{"(", 
     RowBox[{"d", "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"d", "-", 
      SubscriptBox["\[Nu]", "2"], "-", 
      SubscriptBox["\[Nu]", "3"], "-", "1"}], ")"}], " ", 
    InterpretationBox[
     StyleBox[
      SuperscriptBox["1", "+"],
      FontWeight->"Bold"],
     Schiebe[1, "+"],
     Editable->True], 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TJI[d, {
       Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3]}],
     Editable->True]}], "==", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["\[Nu]", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "d"}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "2"]}], "+", "2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d"}], "+", 
      SubscriptBox["\[Nu]", "1"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "2"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Nu]", "3"]}], "+", "2"}], ")"}], 
    InterpretationBox[
     StyleBox[
      SuperscriptBox["2", "+"],
      FontWeight->"Bold"],
     Schiebe[2, "+"],
     Editable->True], 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TJI[d, {
       Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3]}],
     Editable->True]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "99"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "99"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (99)", "Subsection",
 CellTags->"T1.6.95.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "99"], "=", 
  RowBox[{
   SubscriptBox["s", "99"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "99"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "99"], ",", "\"\<(99)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"m1", "^", "2"}], "===", "PP"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m2", ":>", "0"}], ",", 
      RowBox[{"m3", ":>", "0"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9912)", "Subsection",
 CellTags->"T1.6.96.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "9912"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["s", "99"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "9912"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "9912"], ",", "\"\<(9912)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"m2", "^", "2"}], "===", "PP"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "1"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m1", ":>", "0"}], ",", 
      RowBox[{"m3", ":>", "0"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9913)", "Subsection",
 CellTags->"T1.6.97.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "9913"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["s", "99"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "9913"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "9913"], ",", "\"\<(9913)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"m3", "^", "2"}], "===", "PP"}], "&&", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "1"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m1", ":>", "0"}], ",", 
      RowBox[{"m2", ":>", "0"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (100)", "Subsection",
 CellTags->"T1.6.98.1"],

Cell["Herleitung in three.nb ", "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SubsuperscriptBox["m", "2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
    SubscriptBox["\[Nu]", "2"], " ", 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       StyleBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        FontColor->RGBColor[0, 0, 1]], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TJI[d, {
       Subscript[\[Nu], 1], 1 + Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3]}],
     Editable->True]}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "-", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "d"}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "1"]}], "+", "2"}], ")"}], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        StyleBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         FontColor->RGBColor[0, 0, 1]], 
        StyleBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         FontColor->RGBColor[1, 0, 0]], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {1 + Subscript[\[Nu], 1], -1 + Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}], TraditionalForm]], "Input"]], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["m", "1"], "=", "0"}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["e", "100"], "=", 
  RowBox[{
   RowBox[{"2", " ", 
    SubsuperscriptBox["m", "2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
    SubscriptBox["\[Nu]", "2"], " ", 
    InterpretationBox[
     StyleBox[
      SuperscriptBox["2", "+"],
      FontWeight->"Bold"],
     Schiebe[2, "+"],
     Editable->True], 
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d",
        TraditionalForm], ")"}]],
     TJI[d, {
       Subscript[\[Nu], 1], 
       Subscript[\[Nu], 2], 
       Subscript[\[Nu], 3]}],
     Editable->True]}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "-", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "d"}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Nu]", "1"]}], "+", "2"}], ")"}], " ", 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["1", "+"],
       FontWeight->"Bold"],
      Schiebe[1, "+"],
      Editable->True], 
     InterpretationBox[
      StyleBox[
       SuperscriptBox["2", "-"],
       FontWeight->"Bold"],
      Schiebe[2, "-"],
      Editable->True], 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {
        Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "100"], "=", 
  RowBox[{"OperatorApplyJ", "[", 
   SubscriptBox["e", "100"], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (100)", "Subsection",
 CellTags->"T1.6.99.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "100"], "=", 
  SubscriptBox["s", "100"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "100"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "100"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}], ",", "\"\<(100)\>\"", ",", 
    
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "2"}], "&&", 
      RowBox[{"m2", "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m1", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "100"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884549105921*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1002)", "Subsection",
 CellTags->"T1.6.100.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "1002"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "100"], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "3"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "1002"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "1002"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "2"], "-", "1"}]}]}], ",", "\"\<(1002)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "2"], ">", "2"}], "&&", 
      RowBox[{"m2", "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m3", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "1002"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884549168622*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1003)", "Subsection",
 CellTags->"T1.6.101.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "1003"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "100"], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "3"}], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "1003"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "1003"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], ",", "\"\<(1003)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "2"}], "&&", 
      RowBox[{"m1", "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m3", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "1003"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845492174587`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1004)", "Subsection",
 CellTags->"T1.6.102.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "1004"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "100"], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "1004"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "1004"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}], ",", "\"\<(1004)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "2"}], "&&", 
      RowBox[{"m1", "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m2", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "1004"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845492708073`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1005)", "Subsection",
 CellTags->"T1.6.103.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "1005"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "100"], ",", 
    RowBox[{"2", "\[LeftRightArrow]", "3"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "1005"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "1005"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}], ",", "\"\<(1005)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "2"}], "&&", 
      RowBox[{"m3", "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m1", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "1005"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.5008845493855267`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1006)", "Subsection",
 CellTags->"T1.6.104.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "1006"], "=", 
  RowBox[{"Interchange", "[", 
   RowBox[{
    SubscriptBox["s", "100"], ",", 
    RowBox[{"2", "\[LeftRightArrow]", "3"}], ",", 
    RowBox[{"1", "\[LeftRightArrow]", "2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "1006"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "1006"], "/.", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], "->", 
      RowBox[{
       SubscriptBox["\[Nu]", "3"], "-", "1"}]}]}], ",", "\"\<(1006)\>\"", ",", 
    RowBox[{"IFF", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "3"], ">", "2"}], "&&", 
      RowBox[{"m3", "=!=", "0"}]}], "]"}], ",", 
    RowBox[{"m2", ":>", "0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckTJIRecursion", "[", 
  SubscriptBox["f", "1006"], "]"}]], "Input"],

Cell[BoxData["\<\"Off\"\>"], "Print",
 CellChangeTimes->{3.500884549471513*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (150)", "Subsection",
 CellTags->"T1.6.105.1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Nu]", "4"], "=", 
   RowBox[{"-", "1"}]}], TextForm]], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["q", "2"], "-", "p"}], " ", ")"}], "2"], "-", 
    SubsuperscriptBox["m", "4", "2"]}], "=", " ", 
   RowBox[{
    SubsuperscriptBox["q", "2", "2"], "-", 
    SubsuperscriptBox["m", "2", "2"], "-", 
    RowBox[{"2", "p", " ", 
     SubscriptBox["q", "2"]}], "+", 
    SuperscriptBox["p", "2"], "+", 
    SubsuperscriptBox["m", "2", "2"], "-", 
    SubsuperscriptBox["m", "4", "2"]}]}], TextForm]], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "150"], "=", 
  RowBox[{
   RowBox[{"TFI", "[", 
    RowBox[{"d", ",", "PP", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n1", ",", "m1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n2", ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n3", ",", "m3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "m4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}], "==", 
   RowBox[{
    RowBox[{"TFI", "[", 
     RowBox[{"d", ",", "PP", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1", ",", "m1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n2", "-", "1"}], ",", "m2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3", ",", "m3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}], "-", 
    RowBox[{"2", 
     RowBox[{"TFI", "[", 
      RowBox[{"d", ",", "PP", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"PP", "+", 
       RowBox[{"m2", "^", "2"}], "-", 
       RowBox[{"m4", "^", "2"}]}], ")"}], 
     RowBox[{"TFI", "[", 
      RowBox[{"d", ",", "PP", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (150)", "Subsection",
 CellTags->"T1.6.106.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "150"], "=", 
  SubscriptBox["s", "150"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "150"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "150"], ",", "\"\<(150)\>\""}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (151)", "Subsection",
 CellTags->"T1.6.107.1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Nu]", "4"], "=", 
   RowBox[{"-", "1"}]}], TextForm]], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["q", "2"], "-", "p"}], " ", ")"}], "2"], "-", 
    SubsuperscriptBox["m", "4", "2"]}], "=", " ", 
   RowBox[{
    SubsuperscriptBox["q", "2", "2"], "-", 
    SubsuperscriptBox["m", "2", "2"], "-", 
    RowBox[{"2", "p", " ", 
     SubscriptBox["q", "2"]}], "+", 
    SuperscriptBox["p", "2"], "+", 
    SubsuperscriptBox["m", "2", "2"], "-", 
    SubsuperscriptBox["m", "4", "2"]}]}], TextForm]], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "151"], "=", 
  RowBox[{
   RowBox[{"TFI", "[", 
    RowBox[{"d", ",", "PP", ",", "DP", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n1", ",", "m1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n2", ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n3", ",", "m3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "m4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}], "==", 
   RowBox[{
    RowBox[{"TFI", "[", 
     RowBox[{"d", ",", "PP", ",", "DP", ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1", ",", "m1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n2", "-", "1"}], ",", "m2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3", ",", "m3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}], "-", 
    RowBox[{"2", 
     RowBox[{"TFI", "[", 
      RowBox[{"d", ",", "PP", ",", "DP", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"PP", "+", 
       RowBox[{"m2", "^", "2"}], "-", 
       RowBox[{"m4", "^", "2"}]}], ")"}], 
     RowBox[{"TFI", "[", 
      RowBox[{"d", ",", "PP", ",", "DP", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (151)", "Subsection",
 CellTags->"T1.6.108.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "151"], "=", 
  SubscriptBox["s", "151"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "151"], "=", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{
    RowBox[{"MakeFun", "[", 
     RowBox[{
      SubscriptBox["h", "151"], ",", "\"\<(151)\>\""}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "4"}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (152)", "Subsection",
 CellTags->"T1.6.109.1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Nu]", "4"], "=", 
   RowBox[{"-", "1"}]}], TextForm]], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["q", "2"], "-", "p"}], " ", ")"}], "2"], "-", 
    SubsuperscriptBox["m", "4", "2"]}], "=", " ", 
   RowBox[{
    SubsuperscriptBox["q", "2", "2"], "-", 
    SubsuperscriptBox["m", "2", "2"], "-", 
    RowBox[{"2", "p", " ", 
     SubscriptBox["q", "2"]}], "+", 
    SuperscriptBox["p", "2"], "+", 
    SubsuperscriptBox["m", "2", "2"], "-", 
    SubsuperscriptBox["m", "4", "2"]}]}], TextForm]], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "152"], "=", 
  RowBox[{
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", "PP", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n1", ",", "m1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n2", ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n3", ",", "m3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "m4"}], "}"}]}], "}"}]}], "]"}], "==", 
   RowBox[{
    RowBox[{"TVI", "[", 
     RowBox[{"d", ",", "PP", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1", ",", "m1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n2", "-", "1"}], ",", "m2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3", ",", "m3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], "-", 
    RowBox[{"2", 
     RowBox[{"TFI", "[", 
      RowBox[{"d", ",", "PP", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}]}], "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"PP", "+", 
       RowBox[{"m2", "^", "2"}], "-", 
       RowBox[{"m4", "^", "2"}]}], ")"}], 
     RowBox[{"TVI", "[", 
      RowBox[{"d", ",", "PP", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2", ",", "m2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (152)", "Subsection",
 CellTags->"T1.6.110.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "152"], "=", 
  SubscriptBox["s", "152"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "152"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "152"], ",", "\"\<(152)\>\""}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (153)", "Subsection",
 CellTags->"T1.6.111.1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Nu]", "2"], "=", 
   RowBox[{"-", "1"}]}], TextForm]], "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "153"], "=", 
  RowBox[{
   RowBox[{"TVI", "[", 
    RowBox[{"d", ",", "PP", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n1", ",", "m1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n3", ",", "m3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}], "==", "\n", 
   "\t\t", 
   RowBox[{
    RowBox[{"TFI", "[", 
     RowBox[{"d", ",", " ", "PP", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3", ",", "m3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n4", ",", "m4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n1", ",", "m1"}], "}"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     RowBox[{"m2", "^", "2"}], " ", 
     RowBox[{"TVI", "[", 
      RowBox[{"d", ",", " ", "PP", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1", ",", "m1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n3", ",", "m3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (153)", "Subsection",
 CellTags->"T1.6.112.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "153"], "=", 
  SubscriptBox["s", "153"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "153"], "=", 
  RowBox[{"MakeFun", "[", 
   RowBox[{
    SubscriptBox["h", "153"], ",", "\"\<(153)\>\""}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (200)", "Subsection",
 CellTags->"T1.6.113.1"],

Cell["Derivation in TJRspecial.nb", "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["m", "3"], "=", 
    RowBox[{
     SubscriptBox["m", "2"], "=", 
     SubscriptBox["m", "1"]}]}], ",", " ", 
   RowBox[{
    SuperscriptBox["p", "2"], "=", 
    SubsuperscriptBox["m", "1", "2"]}]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["s", "200"], "=", 
   RowBox[{
    RowBox[{"16", " ", 
     SubsuperscriptBox["m", "1", "2"], " ", 
     SubscriptBox["\[Nu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["\[Nu]", "1"], "-", 
       SubscriptBox["\[Nu]", "2"], "-", 
       SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        StyleBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         FontColor->RGBColor[0, 0, 1]], 
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm], 
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d",
         TraditionalForm], ")"}]],
      TJI[d, {1 + Subscript[\[Nu], 1], 
        Subscript[\[Nu], 2], 
        Subscript[\[Nu], 3]}],
      Editable->True]}], "==", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"3", " ", "d"}], "-", 
         RowBox[{"3", " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}]}], " ", 
      SubscriptBox["\[Nu]", "3"], " ", 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "1"],
           TraditionalForm],
          FontColor->RGBColor[1, 0, 0]], 
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm], 
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "3"],
           TraditionalForm],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TJI[d, {-1 + Subscript[\[Nu], 1], 
         Subscript[\[Nu], 2], 1 + Subscript[\[Nu], 3]}],
       Editable->True]}], "-", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"3", " ", "d"}], "-", 
        RowBox[{"3", " ", 
         SubscriptBox["\[Nu]", "1"]}], "-", 
        RowBox[{"4", " ", 
         SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "1"],
           TraditionalForm],
          FontColor->RGBColor[1, 0, 0]], 
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "2"],
           TraditionalForm],
          FontColor->RGBColor[0, 0, 1]], 
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TJI[d, {-1 + Subscript[\[Nu], 1], 1 + Subscript[\[Nu], 2], 
         Subscript[\[Nu], 3]}],
       Editable->True]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "d"}], "-", 
        SubscriptBox["\[Nu]", "1"], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
      SubscriptBox["\[Nu]", "3"], " ", 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "2"],
           TraditionalForm],
          FontColor->RGBColor[1, 0, 0]], 
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "3"],
           TraditionalForm],
          FontColor->RGBColor[0, 0, 1]]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TJI[d, {
         Subscript[\[Nu], 1], -1 + Subscript[\[Nu], 2], 1 + 
         Subscript[\[Nu], 3]}],
       Editable->True]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", 
         SuperscriptBox["d", "2"]}], "+", 
        RowBox[{"22", " ", "d", " ", 
         SubscriptBox["\[Nu]", "1"]}], "-", 
        RowBox[{"16", " ", 
         SubsuperscriptBox["\[Nu]", "1", "2"]}], "-", 
        SubscriptBox["\[Nu]", "2"], "+", 
        RowBox[{"6", " ", "d", " ", 
         SubscriptBox["\[Nu]", "2"]}], "-", 
        RowBox[{"13", " ", 
         SubscriptBox["\[Nu]", "1"], " ", 
         SubscriptBox["\[Nu]", "2"]}], "-", 
        SubscriptBox["\[Nu]", "3"], "+", 
        RowBox[{"6", " ", "d", " ", 
         SubscriptBox["\[Nu]", "3"]}], "-", 
        RowBox[{"13", " ", 
         SubscriptBox["\[Nu]", "1"], " ", 
         SubscriptBox["\[Nu]", "3"]}], "-", 
        RowBox[{"4", " ", 
         SubscriptBox["\[Nu]", "2"], " ", 
         SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TJI[d, {
         Subscript[\[Nu], 1], 
         Subscript[\[Nu], 2], 
         Subscript[\[Nu], 3]}],
       Editable->True]}], "+", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "d"}], "-", 
        SubscriptBox["\[Nu]", "1"], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
      InterpretationBox[
       SubsuperscriptBox[
        StyleBox["J",
         SingleLetterItalics->False,
         FontWeight->"Bold"], 
        RowBox[{
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm], 
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "2"],
           TraditionalForm],
          FontColor->RGBColor[0, 0, 1]], 
         StyleBox[
          FormBox[
           SubscriptBox["\[Nu]", "3"],
           TraditionalForm],
          FontColor->RGBColor[1, 0, 0]]}], 
        RowBox[{"(", 
         FormBox["d",
          TraditionalForm], ")"}]],
       TJI[d, {
         Subscript[\[Nu], 1], 1 + Subscript[\[Nu], 2], -1 + 
         Subscript[\[Nu], 3]}],
       Editable->True]}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Due", " ", "to", " ", "sorting", "  ", 
    SubscriptBox["\[Nu]", "1"]}], "\[GreaterSlantEqual]", 
   SubscriptBox["\[Nu]", "2"], "\[GreaterSlantEqual]", 
   RowBox[{
    SubscriptBox["\[Nu]", "3"], "  ", "by", " ", "TJI", " ", "only", " ", 
    "this", " ", "rule", " ", "is", " ", 
    RowBox[{"necessary", "."}]}]}], TextForm]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (200)", "Subsection",
 CellTags->"T1.6.114.1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "200"], "=", 
  RowBox[{
   SubscriptBox["s", "200"], "/.", 
   RowBox[{
    SubscriptBox["\[Nu]", "1"], "->", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], "-", "1"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "200"], "=", 
  RowBox[{
   StyleBox["MakeFun",
    FontColor->RGBColor[1, 0.6, 0.6]], "[", 
   RowBox[{
    SubscriptBox["h", "200"], ",", "\"\<(200)\>\"", ",", 
    RowBox[{
     StyleBox["IFF",
      FontColor->RGBColor[0.6, 0.4, 1]], "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", "1"], ">", "1"}], "&&", 
      RowBox[{"m1", "=!=", "0"}], "&&", 
      RowBox[{"PP", "===", 
       RowBox[{"m1", "^", "2"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m2", ":>", "m1"}], ",", 
      RowBox[{"m3", ":>", "m1"}]}], "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (201)", "Subsection",
 CellTags->"T1.6.115.1"],

Cell["\<\
Subscript[f, 201] = 
  HoldForm[TJR[d_, PP_, 
     {{(n1_)?PQ, 0}, 
      {(n2_)?PQ, 0}, 
      {(n3_)?PQ, m3_}}] := 
    (TComment[\"(201)\", 
        TJIC[d, 
         {{n1, 0}, {n2, 0}, 
          {n3, m3}}]]; 
       -(((d - n1 - n2)*
          (-2 - d + 
         2*n1 + 2*n2)*
          (3*d - 2*n1 - 
         2*n2 - 2*n3)*
          (-1 - d + n1 + 
          n2 + n3)*
          TJI[d, PP, 
          {{-1 + n1, 0}, 
          {n2, 0}, {n3, m3}}]
)/(2*m3^2*(d - 2*n1)*
          (-1 + n1)*
          (2*d - 2*n1 - 
          2*n2 - n3)*
          (1 + 2*d - 2*n1 - 
          2*n2 - n3)))) /; 
     n1 > 1 && m3 =!= 0 && 
      PP === m3^2]\
\>", "Input",
 Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (202)", "Subsection",
 CellTags->"T1.6.116.1"],

Cell["\<\
Subscript[f, 202] = 
  HoldForm[TJR[d_, PP_, 
     {{(n1_)?PQ, 0}, 
      {(n3_)?PQ, m3_}, 
      {(n2_)?PQ, 0}}] := 
    (TComment[\"(202)\", 
        TJIC[d, 
         {{n1, 0}, {n2, 0}, 
          {n3, m3}}]]; 
       -(((d - n1 - n2)*
          (-2 - d + 2*n1 + 
          2*n2)*
          (3*d - 2*n1 - 
          2*n2 - 2*n3)*
          (-1 - d + n1 + 
          n2 + n3)*
          TJI[d, m3^2, 
          {{-1 + n1, 0}, 
          {n2, 0}, {n3, m3}}
])/(2*m3^2*(d - 2*n1)*
          (-1 + n1)*
          (2*d - 2*n1 - 
          2*n2 - n3)*
          (1 + 2*d - 2*n1 - 
          2*n2 - n3)))) /; 
     n1 > 1 && m3 =!= 0 && 
      PP === m3^2]\
\>", "Input",
 Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[" MakeFun (203)", "Subsection",
 CellTags->"T1.6.117.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Subscript", "[", 
   RowBox[{"f", ",", " ", "203"}], "]"}], " ", "=", 
  RowBox[{"HoldForm", "[", "\n", "\t\t ", 
   RowBox[{
    RowBox[{"TJR", "[", 
     RowBox[{"d_", ",", " ", "0", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n1_", ")"}], "?", "PQ"}], ",", " ", "0"}], "}"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n2_", ")"}], "?", "PQ"}], ",", " ", "m2_"}], "}"}], 
        ",", " ", "\n", "    ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n3_", ")"}], "?", "PQ"}], ",", " ", "m2_"}], "}"}]}],
        "}"}]}], "]"}], " ", ":=", 
    RowBox[{"(", "\n", "\t\t\t\t ", 
     RowBox[{
      RowBox[{"TComment", "[", 
       RowBox[{"\"\<(203)\>\"", ",", " ", "\n", "        ", 
        RowBox[{"TJIC", "[", 
         RowBox[{"d", ",", "0", ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n1", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"n2", ",", " ", "m2"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"n3", ",", " ", "m2"}], "}"}]}], "}"}]}], "]"}]}], "]"}],
       ";", " ", "\n", "\t\t\t\t", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", "n1", " ", "+", " ", "n2"}], 
             ")"}]}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{
          "1", " ", "+", " ", "d", " ", "-", " ", "n1", " ", "-", " ", "n2", 
           " ", "-", " ", "n3"}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", "n1", " ", "+", " ", "n3"}], 
             ")"}]}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"TJR", "[", 
          RowBox[{"d", ",", " ", "0", ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], " ", "+", " ", "n1"}], ",", " ", "0"}], 
              "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"n2", ",", " ", "m2"}], "}"}], ",", " ", "\n", 
             "       ", 
             RowBox[{"{", 
              RowBox[{"n3", ",", " ", "m2"}], "}"}]}], "}"}]}], "]"}]}], 
        ")"}], "/", "\n", "   ", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"m2", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", "d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}], " ", "-", " ", "n2", " ", "-", " ", 
           "n3"}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"2", " ", "+", " ", "d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}], " ", "-", " ", "n2", " ", "-", " ", 
           "n3"}], ")"}]}], ")"}]}]}], "\n", "\t\t\t", "\n", "\t\t\t", 
     ")"}]}], "]"}]}]], "Input",
 Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[" MakeFun (204)", "Subsection",
 CellTags->"T1.6.118.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Subscript", "[", 
   RowBox[{"f", ",", " ", "204"}], "]"}], " ", "=", 
  RowBox[{"HoldForm", "[", "\n", "\t\t ", 
   RowBox[{
    RowBox[{"TJR", "[", 
     RowBox[{"d_", ",", " ", "0", ",", " ", 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n2_", ")"}], "?", "PQ"}], ",", " ", "m2_"}], "}"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n1_", ")"}], "?", "PQ"}], ",", " ", "0"}], "}"}], 
        ",", "\n", "    ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n3_", ")"}], "?", "PQ"}], ",", " ", "m2_"}], "}"}]}],
        "}"}]}], "]"}], " ", ":=", 
    RowBox[{"(", "\n", "\t ", 
     RowBox[{
      RowBox[{"TComment", "[", 
       RowBox[{"\"\<(204)\>\"", ",", " ", "\n", "        ", 
        RowBox[{"TJIC", "[", 
         RowBox[{"d", ",", "0", ",", " ", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n2", ",", " ", "m2"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"n1", ",", " ", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"n3", ",", " ", "m2"}], "}"}]}], "}"}]}], "]"}]}], "]"}],
       ";", " ", "\n", "\t", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", "n1", " ", "+", " ", "n2"}], 
             ")"}]}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{
          "1", " ", "+", " ", "d", " ", "-", " ", "n1", " ", "-", " ", "n2", 
           " ", "-", " ", "n3"}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", "n1", " ", "+", " ", "n3"}], 
             ")"}]}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"TJR", "[", 
          RowBox[{"d", ",", " ", "0", ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], " ", "+", " ", "n1"}], ",", " ", "0"}], 
              "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"n2", ",", " ", "m2"}], "}"}], ",", " ", "\n", 
             "       ", 
             RowBox[{"{", 
              RowBox[{"n3", ",", " ", "m2"}], "}"}]}], "}"}]}], "]"}]}], 
        ")"}], "/", "\n", "   ", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"m2", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", "d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}], " ", "-", " ", "n2", " ", "-", " ", 
           "n3"}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"2", " ", "+", " ", "d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}], " ", "-", " ", "n2", " ", "-", " ", 
           "n3"}], ")"}]}], ")"}]}]}], "\n", "\t\t\t", ")"}]}], 
   "]"}]}]], "Input",
 Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[" MakeFun (205)", "Subsection",
 CellTags->"T1.6.119.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Subscript", "[", 
   RowBox[{"f", ",", " ", "205"}], "]"}], " ", "=", 
  RowBox[{"HoldForm", "[", "\n", "\t\t ", 
   RowBox[{
    RowBox[{"TJR", "[", 
     RowBox[{"d_", ",", " ", "0", ",", " ", 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n2_", ")"}], "?", "PQ"}], ",", " ", "m2_"}], "}"}], 
        ",", "\n", "    ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n3_", ")"}], "?", "PQ"}], ",", " ", "m2_"}], "}"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "n1_", ")"}], "?", "PQ"}], ",", " ", "0"}], "}"}]}], 
       "}"}]}], "]"}], " ", ":=", 
    RowBox[{"(", "\n", "\t ", 
     RowBox[{
      RowBox[{"TComment", "[", 
       RowBox[{"\"\<(205)\>\"", ",", " ", "\n", "        ", 
        RowBox[{"TJIC", "[", 
         RowBox[{"d", ",", "0", ",", " ", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n2", ",", " ", "m2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"n3", ",", " ", "m2"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"n1", ",", " ", "0"}], "}"}]}], "}"}]}], "]"}]}], "]"}], 
      ";", " ", "\n", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", "n1", " ", "+", " ", "n2"}], 
             ")"}]}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{
          "1", " ", "+", " ", "d", " ", "-", " ", "n1", " ", "-", " ", "n2", 
           " ", "-", " ", "n3"}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", "n1", " ", "+", " ", "n3"}], 
             ")"}]}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"TJR", "[", 
          RowBox[{"d", ",", " ", "0", ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], " ", "+", " ", "n1"}], ",", " ", "0"}], 
              "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"n2", ",", " ", "m2"}], "}"}], ",", " ", "\n", 
             "       ", 
             RowBox[{"{", 
              RowBox[{"n3", ",", " ", "m2"}], "}"}]}], "}"}]}], "]"}]}], 
        ")"}], "/", "\n", "   ", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"m2", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}]}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", "d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}], " ", "-", " ", "n2", " ", "-", " ", 
           "n3"}], ")"}], "*", "\n", "     ", 
         RowBox[{"(", 
          RowBox[{"2", " ", "+", " ", "d", " ", "-", " ", 
           RowBox[{"2", "*", "n1"}], " ", "-", " ", "n2", " ", "-", " ", 
           "n3"}], ")"}]}], ")"}]}]}], "\n", "\t\t\t", ")"}]}], 
   "]"}]}]], "Input",
 Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (1xxxx)", "Subsection",
 CellTags->"T1.6.120.1"],

Cell["\<\
If[MatchQ[$RankLimit, {_Integer?NonNegative, 
     _Integer?NonNegative}], 
   $TarasovTdeltaplimit = $RankLimit[[1]]; 
    ($TarasovTplimit = $RankLimit[[2]]; ), 
   $TarasovTdeltaplimit = 2; $TarasovTplimit = 2]; \
\>", "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tarti", "=", 
  RowBox[{"Timing", "[", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"0", "<", 
        RowBox[{"a", "+", "b", "+", "r", "+", "es"}]}], ",", 
       RowBox[{
        RowBox[{"WriteString", "[", 
         RowBox[{"\"\<stdout\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "r", ",", "es"}], "}"}]}], "]"}], ";", 
        
        RowBox[{"Set", "@@", 
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["s", 
            RowBox[{
             SuperscriptBox["10", "4"], "+", 
             RowBox[{"1000", " ", "a"}], "+", 
             RowBox[{"100", " ", "b"}], "+", 
             RowBox[{"10", " ", "r"}], "+", "es"}]], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              StyleBox["TFI",
               FontColor->RGBColor[1, 0.6, 0]], "[", 
              RowBox[{"d", ",", 
               InterpretationBox[
                SuperscriptBox["p", "2"],
                PP], ",", "DP", ",", 
               RowBox[{"{", 
                RowBox[{"a", ",", "b"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "r", ",", "es", ",", "0"}], "}"}],
                ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"n1", ",", 
                   InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n2", ",", 
                   InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n3", ",", 
                   InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n4", ",", 
                   InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n5", ",", 
                   InterpretationBox[
                    SubscriptBox["m", "5"],
                    m5]}], "}"}]}], "}"}]}], "]"}], "==", 
             RowBox[{"ApplyTarasovT", "[", 
              RowBox[{
               RowBox[{"TarasovT", "[", 
                RowBox[{"a", ",", "b", ",", "r", ",", "es", ",", 
                 InterpretationBox[
                  SuperscriptBox["p", "2"],
                  PP], ",", "DP"}], "]"}], ",", 
               RowBox[{"STLI", "[", 
                RowBox[{"d", ",", 
                 InterpretationBox[
                  SuperscriptBox["p", "2"],
                  PP], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"n1", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "1"],
                    m1]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"n2", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "2"],
                    m2]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"n3", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "3"],
                    m3]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"n4", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "4"],
                    m4]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"n5", ",", 
                    InterpretationBox[
                    SubscriptBox["m", "5"],
                    m5]}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], "/.", 
            RowBox[{"STLI", "\[Rule]", 
             StyleBox["TFI",
              FontColor->RGBColor[1, 0.6, 0]]}]}]}], "}"}]}]}]}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "$TarasovTdeltaplimit"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "0", ",", 
       RowBox[{"$TarasovTdeltaplimit", "-", "a"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "$TarasovTplimit"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"es", ",", "0", ",", 
       RowBox[{"$TarasovTplimit", "-", "r"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell["\<\
{0, 0, 0, 1}{0, 0, 0, 2}{0, 0, 0, 3}{0, 0, 0, 4}{0, 0, 0, 5}{0, 0, 1, 0}{0, \
0, 1, 1}{0, 0, 1, 2}{0, 0, 1, 3}{0, 0, 1, 4}{0, 0, 2, 0}{0, 0, 2, 1}{0, 0, 2, \
2}{0, 0, 2, 3}{0, 0, 3, 0}{0, 0, 3, 1}{0, 0, 3, 2}{0, 0, 4, 0}{0, 0, 4, 1}{0, \
0, 5, 0}{0, 1, 0, 0}{0, 1, 0, 1}{0, 1, 0, 2}{0, 1, 0, 3}{0, 1, 0, 4}{0, 1, 0, \
5}{0, 1, 1, 0}{0, 1, 1, 1}{0, 1, 1, 2}{0, 1, 1, 3}{0, 1, 1, 4}{0, 1, 2, 0}{0, \
1, 2, 1}{0, 1, 2, 2}{0, 1, 2, 3}{0, 1, 3, 0}{0, 1, 3, 1}{0, 1, 3, 2}{0, 1, 4, \
0}{0, 1, 4, 1}{0, 1, 5, 0}{0, 2, 0, 0}{0, 2, 0, 1}{0, 2, 0, 2}{0, 2, 0, 3}{0, \
2, 0, 4}{0, 2, 0, 5}{0, 2, 1, 0}{0, 2, 1, 1}{0, 2, 1, 2}{0, 2, 1, 3}{0, 2, 1, \
4}{0, 2, 2, 0}{0, 2, 2, 1}{0, 2, 2, 2}{0, 2, 2, 3}{0, 2, 3, 0}{0, 2, 3, 1}{0, \
2, 3, 2}{0, 2, 4, 0}{0, 2, 4, 1}{0, 2, 5, 0}{1, 0, 0, 0}{1, 0, 0, 1}{1, 0, 0, \
2}{1, 0, 0, 3}{1, 0, 0, 4}{1, 0, 0, 5}{1, 0, 1, 0}{1, 0, 1, 1}{1, 0, 1, 2}{1, \
0, 1, 3}{1, 0, 1, 4}{1, 0, 2, 0}{1, 0, 2, 1}{1, 0, 2, 2}{1, 0, 2, 3}{1, 0, 3, \
0}{1, 0, 3, 1}{1, 0, 3, 2}{1, 0, 4, 0}{1, 0, 4, 1}{1, 0, 5, 0}{1, 1, 0, 0}{1, \
1, 0, 1}{1, 1, 0, 2}{1, 1, 0, 3}{1, 1, 0, 4}{1, 1, 0, 5}{1, 1, 1, 0}{1, 1, 1, \
1}{1, 1, 1, 2}{1, 1, 1, 3}{1, 1, 1, 4}{1, 1, 2, 0}{1, 1, 2, 1}{1, 1, 2, 2}{1, \
1, 2, 3}{1, 1, 3, 0}{1, 1, 3, 1}{1, 1, 3, 2}{1, 1, 4, 0}{1, 1, 4, 1}{1, 1, 5, \
0}{2, 0, 0, 0}{2, 0, 0, 1}{2, 0, 0, 2}{2, 0, 0, 3}{2, 0, 0, 4}{2, 0, 0, 5}{2, \
0, 1, 0}{2, 0, 1, 1}{2, 0, 1, 2}{2, 0, 1, 3}{2, 0, 1, 4}{2, 0, 2, 0}{2, 0, 2, \
1}{2, 0, 2, 2}{2, 0, 2, 3}{2, 0, 3, 0}{2, 0, 3, 1}{2, 0, 3, 2}{2, 0, 4, 0}{2, \
0, 4, 1}{2, 0, 5, 0}\
\>", "Print",
 CellChangeTimes->{3.5008845500499763`*^9}]
}, Open  ]],

Cell["Share[]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matarti", "=", 
  RowBox[{"Timing", "[", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"0", "<", 
        RowBox[{"ia", "+", "ib", "+", "ir", "+", "es"}]}], ",", 
       RowBox[{
        RowBox[{"WriteString", "[", 
         RowBox[{"\"\<stdout\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"ia", ",", "ib", ",", "ir", ",", "es"}], "}"}]}], "]"}], 
        ";", 
        RowBox[{"Set", "[", 
         RowBox[{
          SubscriptBox["f", 
           RowBox[{
            SuperscriptBox["10", "4"], "+", 
            RowBox[{"1000", " ", "ia"}], "+", 
            RowBox[{"100", " ", "ib"}], "+", 
            RowBox[{"10", " ", "ir"}], "+", "es"}]], ",", 
          RowBox[{
           RowBox[{"MakeFun", "[", 
            RowBox[{
             SubscriptBox["s", 
              RowBox[{
               SuperscriptBox["10", "4"], "+", 
               RowBox[{"1000", " ", "ia"}], "+", 
               RowBox[{"100", " ", "ib"}], "+", 
               RowBox[{"10", " ", "ir"}], "+", "es"}]], ",", 
             RowBox[{"\"\<(1\>\"", "<>", 
              RowBox[{"ToString", "[", "ia", "]"}], "<>", 
              RowBox[{"ToString", "[", "ib", "]"}], "<>", 
              RowBox[{"ToString", "[", "ir", "]"}], "<>", 
              RowBox[{"ToString", "[", "es", "]"}], "<>", "\"\<)\>\""}]}], 
            "]"}], "/.", 
           RowBox[{"PQ", ":>", "PNQ"}]}]}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"ia", ",", "0", ",", " ", "$TarasovTdeltaplimit"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"ib", ",", "0", ",", 
       RowBox[{"$TarasovTdeltaplimit", "-", "ia"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ir", ",", "0", ",", "  ", "$TarasovTplimit"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"es", ",", "0", ",", 
       RowBox[{"$TarasovTplimit", "-", "ir"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell["\<\
{0, 0, 0, 1}{0, 0, 0, 2}{0, 0, 0, 3}{0, 0, 0, 4}{0, 0, 0, 5}{0, 0, 1, 0}{0, \
0, 1, 1}{0, 0, 1, 2}{0, 0, 1, 3}{0, 0, 1, 4}{0, 0, 2, 0}{0, 0, 2, 1}{0, 0, 2, \
2}{0, 0, 2, 3}{0, 0, 3, 0}{0, 0, 3, 1}{0, 0, 3, 2}{0, 0, 4, 0}{0, 0, 4, 1}{0, \
0, 5, 0}{0, 1, 0, 0}{0, 1, 0, 1}{0, 1, 0, 2}{0, 1, 0, 3}{0, 1, 0, 4}{0, 1, 0, \
5}{0, 1, 1, 0}{0, 1, 1, 1}{0, 1, 1, 2}{0, 1, 1, 3}{0, 1, 1, 4}{0, 1, 2, 0}{0, \
1, 2, 1}{0, 1, 2, 2}{0, 1, 2, 3}{0, 1, 3, 0}{0, 1, 3, 1}{0, 1, 3, 2}{0, 1, 4, \
0}{0, 1, 4, 1}{0, 1, 5, 0}{0, 2, 0, 0}{0, 2, 0, 1}{0, 2, 0, 2}{0, 2, 0, 3}{0, \
2, 0, 4}{0, 2, 0, 5}{0, 2, 1, 0}{0, 2, 1, 1}{0, 2, 1, 2}{0, 2, 1, 3}{0, 2, 1, \
4}{0, 2, 2, 0}{0, 2, 2, 1}{0, 2, 2, 2}{0, 2, 2, 3}{0, 2, 3, 0}{0, 2, 3, 1}{0, \
2, 3, 2}{0, 2, 4, 0}{0, 2, 4, 1}{0, 2, 5, 0}{1, 0, 0, 0}{1, 0, 0, 1}{1, 0, 0, \
2}{1, 0, 0, 3}{1, 0, 0, 4}{1, 0, 0, 5}{1, 0, 1, 0}{1, 0, 1, 1}{1, 0, 1, 2}{1, \
0, 1, 3}{1, 0, 1, 4}{1, 0, 2, 0}{1, 0, 2, 1}{1, 0, 2, 2}{1, 0, 2, 3}{1, 0, 3, \
0}{1, 0, 3, 1}{1, 0, 3, 2}{1, 0, 4, 0}{1, 0, 4, 1}{1, 0, 5, 0}{1, 1, 0, 0}{1, \
1, 0, 1}{1, 1, 0, 2}{1, 1, 0, 3}{1, 1, 0, 4}{1, 1, 0, 5}{1, 1, 1, 0}{1, 1, 1, \
1}{1, 1, 1, 2}{1, 1, 1, 3}{1, 1, 1, 4}{1, 1, 2, 0}{1, 1, 2, 1}{1, 1, 2, 2}{1, \
1, 2, 3}{1, 1, 3, 0}{1, 1, 3, 1}{1, 1, 3, 2}{1, 1, 4, 0}{1, 1, 4, 1}{1, 1, 5, \
0}{2, 0, 0, 0}{2, 0, 0, 1}{2, 0, 0, 2}{2, 0, 0, 3}{2, 0, 0, 4}{2, 0, 0, 5}{2, \
0, 1, 0}{2, 0, 1, 1}{2, 0, 1, 2}{2, 0, 1, 3}{2, 0, 1, 4}{2, 0, 2, 0}{2, 0, 2, \
1}{2, 0, 2, 2}{2, 0, 2, 3}{2, 0, 3, 0}{2, 0, 3, 1}{2, 0, 3, 2}{2, 0, 4, 0}{2, \
0, 4, 1}{2, 0, 5, 0}\
\>", "Print",
 CellChangeTimes->{3.500884560258574*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Share", "[", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["symmetry", "Subsection",
 CellTags->"Tsymmetry"],

Cell["Uncomment this ...", "Text"],

Cell["\<\
TVR[d_, pp_, {a_, b_, c_, z_}] := 
  TVR[d, pp, {c, b, a, z}] /;  !OrderedQ[{a, c}]\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["special TVR reductions", "Subsection",
 CellTags->"specialTVR"],

Cell["\<\
TVR[2 + d_Symbol, pp_, {{1, m1_}, {1, m1_}, {2, 0}, {1, m1_}}] := 
   ((-6*m1^2 + 2*d*m1^2 + 3*pp)*TAI[d, 0, {{1, m1}}]^2)/
      (12*(-3 + d)*(-1 + d)*m1^2*pp) + 
     ((4*m1^2 - pp)*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (4*(-3 + d)*(-1 + d)*m1^2) - 
     ((6*m1^2 - 2*d*m1^2 - 7*pp + 2*d*pp)*
        TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/(6*(-2 + d)*(-1 + d)*pp) + 
     ((-4*m1^2 + pp)*(-6*m1^2 + 2*d*m1^2 + 3*pp)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (6*(-3 + d)*(-2 + d)*(-1 + d)*pp) /; (m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
TVR[4 + d_Symbol, pp_, {{1, m1_}, {1, m1_}, {2, 0}, {1, m1_}}] := 
   -((-96*d*m1^6 + 352*d^2*m1^6 - 384*d^3*m1^6 + 128*d^4*m1^6 - 
           192*m1^4*pp + 1008*d*m1^4*pp - 1632*d^2*m1^4*pp + 
           912*d^3*m1^4*pp - 144*d^4*m1^4*pp + 288*m1^2*pp^2 - 
           1536*d*m1^2*pp^2 + 2316*d^2*m1^2*pp^2 - 1086*d^3*m1^2*pp^2 + 
           66*d^4*m1^2*pp^2 + 72*d*pp^3 - 166*d^2*pp^3 + 81*d^3*pp^3 + 
           4*d^4*pp^3)*TAI[d, 0, {{1, m1}}]^2)/
      (36*(-1 + d)^2*d^2*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) + 
     ((4*m1^2 - pp)^2*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (4*(-1 + d)^2*d*(1 + d)) - 
     ((288*m1^8 - 1152*d*m1^8 + 1504*d^2*m1^8 - 768*d^3*m1^8 + 
          128*d^4*m1^8 - 816*m1^6*pp + 2480*d*m1^6*pp - 
          2224*d^2*m1^6*pp + 736*d^3*m1^6*pp - 80*d^4*m1^6*pp + 
          864*m1^4*pp^2 - 2196*d*m1^4*pp^2 + 1446*d^2*m1^4*pp^2 - 
          252*d^3*m1^4*pp^2 - 6*d^4*m1^4*pp^2 - 432*m1^2*pp^3 + 
          1086*d*m1^2*pp^3 - 895*d^2*m1^2*pp^3 + 315*d^3*m1^2*pp^3 - 
          44*d^4*m1^2*pp^3 + 4*d*pp^4 - 2*d^2*pp^4 - 4*d^3*pp^4 + 
          2*d^4*pp^4)*TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (18*(-2 + d)*(-1 + d)^2*d*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) + 
     (m1^2*(4*m1^2 - pp)*(-96*m1^6 + 352*d*m1^6 - 384*d^2*m1^6 + 
          128*d^3*m1^6 + 240*m1^4*pp - 624*d*m1^4*pp + 384*d^2*m1^4*pp - 
          48*d^3*m1^4*pp - 192*m1^2*pp^2 + 420*d*m1^2*pp^2 - 
          162*d^2*m1^2*pp^2 - 18*d^3*m1^2*pp^2 + 72*pp^3 - 154*d*pp^3 + 
          81*d^2*pp^3 - 8*d^3*pp^3)*TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (18*(-2 + d)*(-1 + d)^2*d*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) /; \
(m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
TVR[4 + d_Symbol, pp_, {{1, m1_}, {1, m1_}, {3, 0}, {1, m1_}}] := 
   ((-72*d^2*m1^6 + 144*d^3*m1^6 - 88*d^4*m1^6 + 16*d^5*m1^6 - 
          240*d*m1^4*pp + 572*d^2*m1^4*pp - 398*d^3*m1^4*pp + 
          84*d^4*m1^4*pp - 2*d^5*m1^4*pp - 96*m1^2*pp^2 + 
          480*d*m1^2*pp^2 - 744*d^2*m1^2*pp^2 + 390*d^3*m1^2*pp^2 - 
          50*d^4*m1^2*pp^2 + 4*d^5*m1^2*pp^2 - 24*d*pp^3 + 54*d^2*pp^3 - 
          27*d^3*pp^3)*TAI[d, 0, {{1, m1}}]^2)/
      (24*(-3 + d)*(-1 + d)^2*d*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*m1^2*pp^2) + 
     ((4*m1^2 - pp)^2*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (8*(-3 + d)*(-1 + d)^2*(1 + d)*m1^2) + 
     ((-72*d*m1^6 + 144*d^2*m1^6 - 88*d^3*m1^6 + 16*d^4*m1^6 - 
          96*m1^4*pp + 260*d*m1^4*pp - 166*d^2*m1^4*pp + 
          12*d^3*m1^4*pp + 6*d^4*m1^4*pp + 160*m1^2*pp^2 - 
          300*d*m1^2*pp^2 + 50*d^2*m1^2*pp^2 + 90*d^3*m1^2*pp^2 - 
          24*d^4*m1^2*pp^2 - 48*pp^3 + 114*d*pp^3 - 67*d^2*pp^3 + 
          4*d^3*pp^3 + 2*d^4*pp^3)*TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (12*(-2 + d)*(-1 + d)^2*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) - 
     ((-4*m1^2 + pp)*(72*d*m1^6 - 144*d^2*m1^6 + 88*d^3*m1^6 - 
          16*d^4*m1^6 + 96*m1^4*pp - 236*d*m1^4*pp + 122*d^2*m1^4*pp + 
          12*d^3*m1^4*pp - 10*d^4*m1^4*pp - 96*m1^2*pp^2 + 
          180*d*m1^2*pp^2 - 30*d^2*m1^2*pp^2 - 46*d^3*m1^2*pp^2 + 
          8*d^4*m1^2*pp^2 + 24*pp^3 - 54*d*pp^3 + 27*d^2*pp^3)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
(12*(-3 + d)*(-2 + d)*(-1 + d)^2*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) /; \
(m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
TVR[6 + d_Symbol, pp_, 
    {{1, m1_}, {1, m1_}, {4, 0}, {1, m1_}}] := 
   ((2304*d*m1^10 - 4608*d^2*m1^10 - 3520*d^3*m1^10 + 6976*d^4*m1^10 + 
          1472*d^5*m1^10 - 2624*d^6*m1^10 - 256*d^7*m1^10 + 
          256*d^8*m1^10 + 4608*m1^8*pp - 9600*d*m1^8*pp - 
          7680*d^2*m1^8*pp + 9312*d^3*m1^8*pp + 11680*d^4*m1^8*pp - 
          6560*d^5*m1^8*pp - 2880*d^6*m1^8*pp + 1088*d^7*m1^8*pp + 
          32*d^8*m1^8*pp + 6912*m1^6*pp^2 - 35712*d*m1^6*pp^2 + 
          1056*d^2*m1^6*pp^2 + 85296*d^3*m1^6*pp^2 - 
          37032*d^4*m1^6*pp^2 - 20484*d^5*m1^6*pp^2 + 
          8700*d^6*m1^6*pp^2 - 12*d^7*m1^6*pp^2 - 84*d^8*m1^6*pp^2 - 
          20736*m1^4*pp^3 + 58752*d*m1^4*pp^3 + 40560*d^2*m1^4*pp^3 - 
          150536*d^3*m1^4*pp^3 + 18980*d^4*m1^4*pp^3 + 
          48946*d^5*m1^4*pp^3 - 6748*d^6*m1^4*pp^3 - 146*d^7*m1^4*pp^3 + 
          128*d^8*m1^4*pp^3 + 3456*m1^2*pp^4 - 13824*d*m1^2*pp^4 - 
          4176*d^2*m1^2*pp^4 + 35784*d^3*m1^2*pp^4 - 
          8332*d^4*m1^2*pp^4 - 10162*d^5*m1^2*pp^4 + 
          1122*d^6*m1^2*pp^4 - 80*d^7*m1^2*pp^4 - 8*d^8*m1^2*pp^4 + 
          864*d*pp^5 - 216*d^2*pp^5 - 2268*d^3*pp^5 + 486*d^4*pp^5 + 
          729*d^5*pp^5)*TAI[d, 0, {{1, m1}}]^2)/
      (432*(-3 + d)*(-1 + d)^2*d^2*(1 + d)*(2 + d)*(3 + d)*(-4 + 3*d)*
        (-2 + 3*d)*(2 + 3*d)*m1^2*pp^3) + 
     ((4*m1^2 - pp)^3*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (16*(-3 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*m1^2) - 
     ((-1152*m1^10 + 2880*d*m1^10 + 320*d^2*m1^10 - 3648*d^3*m1^10 + 
          1088*d^4*m1^10 + 768*d^5*m1^10 - 256*d^6*m1^10 - 192*m1^8*pp + 
          1312*d*m1^8*pp + 2080*d^2*m1^8*pp - 6880*d^3*m1^8*pp + 
          4032*d^4*m1^8*pp - 192*d^5*m1^8*pp - 160*d^6*m1^8*pp + 
          6336*m1^6*pp^2 - 6960*d*m1^6*pp^2 - 16960*d^2*m1^6*pp^2 + 
          17292*d^3*m1^6*pp^2 - 1828*d^4*m1^6*pp^2 - 828*d^5*m1^6*pp^2 + 
          68*d^6*m1^6*pp^2 - 9504*m1^4*pp^3 + 3624*d*m1^4*pp^3 + 
          26104*d^2*m1^4*pp^3 - 10938*d^3*m1^4*pp^3 - 
          4976*d^4*m1^4*pp^3 + 330*d^5*m1^4*pp^3 + 400*d^6*m1^4*pp^3 + 
          6336*m1^2*pp^4 - 3640*d*m1^2*pp^4 - 14584*d^2*m1^2*pp^4 + 
          9190*d^3*m1^2*pp^4 + 1374*d^4*m1^2*pp^4 - 600*d^5*m1^2*pp^4 - 
          56*d^6*m1^2*pp^4 - 864*pp^5 + 732*d*pp^5 + 1864*d^2*pp^5 - 
          1695*d^3*pp^5 + 148*d^4*pp^5 + 36*d^5*pp^5 + 4*d^6*pp^5)*
        TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (216*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*pp^3) + ((-4*m1^2 + pp)*
        (1152*m1^10 - 2880*d*m1^10 - 320*d^2*m1^10 + 3648*d^3*m1^10 - 
          1088*d^4*m1^10 - 768*d^5*m1^10 + 256*d^6*m1^10 + 576*m1^8*pp - 
          2208*d*m1^8*pp - 2304*d^2*m1^8*pp + 8000*d^3*m1^8*pp - 
          4256*d^4*m1^8*pp - 32*d^5*m1^8*pp + 224*d^6*m1^8*pp - 
          6336*m1^6*pp^2 + 6288*d*m1^6*pp^2 + 16320*d^2*m1^6*pp^2 - 
          14868*d^3*m1^6*pp^2 + 684*d^4*m1^6*pp^2 + 804*d^5*m1^6*pp^2 - 
          12*d^6*m1^6*pp^2 + 6912*m1^4*pp^3 - 3192*d*m1^4*pp^3 - 
          18160*d^2*m1^4*pp^3 + 7950*d^3*m1^4*pp^3 + 3128*d^4*m1^4*pp^3 - 
          78*d^5*m1^4*pp^3 - 160*d^6*m1^4*pp^3 - 3456*m1^2*pp^4 + 
          1800*d*m1^2*pp^4 + 8136*d^2*m1^2*pp^4 - 4322*d^3*m1^2*pp^4 - 
          1042*d^4*m1^2*pp^4 + 128*d^5*m1^2*pp^4 + 16*d^6*m1^2*pp^4 + 
          432*pp^5 - 324*d*pp^5 - 972*d^2*pp^5 + 729*d^3*pp^5)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (216*(-3 + d)*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*
        (-2 + 3*d)*(2 + 3*d)*pp^3) /; (m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
 TVR[6 + d_Symbol, pp_, {{2, m1_}, {1, m1_}, {3, 0}, {1, m1_}}] := 
   -((-1536*d*m1^10 + 2560*d^2*m1^10 + 3200*d^3*m1^10 - 3584*d^4*m1^10 - 
           2176*d^5*m1^10 + 1024*d^6*m1^10 + 512*d^7*m1^10 - 
           3072*m1^8*pp + 6528*d*m1^8*pp + 5376*d^2*m1^8*pp - 
           7520*d^3*m1^8*pp - 5568*d^4*m1^8*pp + 3232*d^5*m1^8*pp + 
           1344*d^6*m1^8*pp - 320*d^7*m1^8*pp - 2304*m1^6*pp^2 + 
           13824*d*m1^6*pp^2 + 192*d^2*m1^6*pp^2 - 31584*d^3*m1^6*pp^2 + 
           11232*d^4*m1^6*pp^2 + 8088*d^5*m1^6*pp^2 - 
           2304*d^6*m1^6*pp^2 - 24*d^7*m1^6*pp^2 + 6912*m1^4*pp^3 - 
           19584*d*m1^4*pp^3 - 12688*d^2*m1^4*pp^3 + 
           50584*d^3*m1^4*pp^3 - 7516*d^4*m1^4*pp^3 - 
           16982*d^5*m1^4*pp^3 + 2564*d^6*m1^4*pp^3 + 310*d^7*m1^4*pp^3 - 
           1152*m1^2*pp^4 + 4608*d*m1^2*pp^4 + 1392*d^2*m1^2*pp^4 - 
           11896*d^3*m1^2*pp^4 + 2820*d^4*m1^2*pp^4 + 
           3374*d^5*m1^2*pp^4 - 414*d^6*m1^2*pp^4 + 8*d^7*m1^2*pp^4 - 
           288*d*pp^5 + 72*d^2*pp^5 + 756*d^3*pp^5 - 162*d^4*pp^5 - 
           243*d^5*pp^5)*TAI[d, 0, {{1, m1}}]^2)/
      (144*(-1 + d)^2*d^2*(1 + d)*(2 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*m1^2*pp^3) + 
     ((4*m1^2 - pp)^3*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (16*(-1 + d)^2*d*(1 + d)*(3 + d)*m1^2) - 
     ((2304*m1^10 - 5760*d*m1^10 - 640*d^2*m1^10 + 7296*d^3*m1^10 - 
          2176*d^4*m1^10 - 1536*d^5*m1^10 + 512*d^6*m1^10 - 
          1344*m1^8*pp + 1120*d*m1^8*pp - 1376*d^2*m1^8*pp + 
          5280*d^3*m1^8*pp - 4896*d^4*m1^8*pp + 1280*d^5*m1^8*pp - 
          64*d^6*m1^8*pp - 5184*m1^6*pp^2 + 7584*d*m1^6*pp^2 + 
          14800*d^2*m1^6*pp^2 - 21496*d^3*m1^6*pp^2 + 
          6120*d^4*m1^6*pp^2 + 280*d^5*m1^6*pp^2 - 184*d^6*m1^6*pp^2 + 
          9504*m1^4*pp^3 - 3720*d*m1^4*pp^3 - 27296*d^2*m1^4*pp^3 + 
          15378*d^3*m1^4*pp^3 + 4114*d^4*m1^4*pp^3 - 666*d^5*m1^4*pp^3 - 
          674*d^6*m1^4*pp^3 - 6336*m1^2*pp^4 + 5720*d*m1^2*pp^4 + 
          13712*d^2*m1^2*pp^4 - 13926*d^3*m1^2*pp^4 + 
          1284*d^4*m1^2*pp^4 + 946*d^5*m1^2*pp^4 - 80*d^6*m1^2*pp^4 + 
          864*pp^5 - 1020*d*pp^5 - 1636*d^2*pp^5 + 2311*d^3*pp^5 - 
          693*d^4*pp^5 + 20*d^5*pp^5 + 4*d^6*pp^5)*
        TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (72*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*pp^3) + ((4*m1^2 - pp)*
        (-768*m1^10 + 1664*d*m1^10 + 768*d^2*m1^10 - 2176*d^3*m1^10 + 
          512*d^5*m1^10 + 192*m1^8*pp + 288*d*m1^8*pp + 704*d^2*m1^8*pp - 
          2272*d^3*m1^8*pp + 1024*d^4*m1^8*pp + 64*d^5*m1^8*pp + 
          1920*m1^6*pp^2 - 1824*d*m1^6*pp^2 - 5472*d^2*m1^6*pp^2 + 
          4584*d^3*m1^6*pp^2 - 168*d^5*m1^6*pp^2 - 2304*m1^4*pp^3 + 
          616*d*m1^4*pp^3 + 6192*d^2*m1^4*pp^3 - 1946*d^3*m1^4*pp^3 - 
          1128*d^4*m1^4*pp^3 - 230*d^5*m1^4*pp^3 + 1152*m1^2*pp^4 - 
          600*d*m1^2*pp^4 - 2744*d^2*m1^2*pp^4 + 1414*d^3*m1^2*pp^4 + 
          374*d^4*m1^2*pp^4 - 16*d^5*m1^2*pp^4 - 144*pp^5 + 108*d*pp^5 + 
          324*d^2*pp^5 - 243*d^3*pp^5)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (72*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*pp^3) /; (m1=!=0)&&(pp=!=0);\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["five -> four", "Subsection",
 CellTags->"T1.6.121.1"],

Cell["\<\
TFI[d_, PP_/;Head[PP]=!=List,{ {0, m1_}, {n2_, m2_}, 
                               {n3_, m3_}, {n4_, m4_}, 
                               {n5_, m5_} }] := 
TVI[d,PP, {{n5,m5}, {n2,m2}, {n3,m3}, {n4,m4}}]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "[", 
   RowBox[{"d_", ",", " ", 
    RowBox[{"PP_", "/;", 
     RowBox[{
      RowBox[{"Head", "[", "PP", "]"}], "=!=", "List"}]}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2_", ",", " ", "m2_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{"n3_", ",", " ", "m3_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4_", ",", " ", "m4_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{"n5_", ",", " ", "m5_"}], "}"}]}], " ", "}"}]}], "]"}], " ", ":=",
   " ", "\n", 
  RowBox[{"TVI", "[", 
   RowBox[{"d", ",", "PP", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n5", ",", "m5"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
TFI[d_,  PP_/;Head[PP]=!=List,{ {(n2_), m2_},{0, m1_},
                               {(n4_), m4_}, {(n3_), m3_}, 
                               {(n5_), m5_} }] := 
TVI[d,PP, {{n5,m5}, {n2,m2}, {n3,m3}, {n4,m4}}]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "[", 
   RowBox[{"d_", ",", "  ", 
    RowBox[{"PP_", "/;", 
     RowBox[{
      RowBox[{"Head", "[", "PP", "]"}], "=!=", "List"}]}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n2_", ")"}], ",", " ", "m2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n4_", ")"}], ",", " ", "m4_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n3_", ")"}], ",", " ", "m3_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n5_", ")"}], ",", " ", "m5_"}], "}"}]}], " ", "}"}]}], 
   "]"}], " ", ":=", " ", "\n", 
  RowBox[{"TVI", "[", 
   RowBox[{"d", ",", "PP", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n5", ",", "m5"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
TFI[d_,   PP_/;Head[PP]=!=List,{ {(n3_), m3_}, {(n4_), m4_},
\t\t                           {0, m1_}, {(n2_), m2_}, 
                               {(n5_), m5_} }] := 
TVI[d,PP, {{n5,m5}, {n2,m2}, {n3,m3}, {n4,m4}}]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "[", 
   RowBox[{"d_", ",", "   ", 
    RowBox[{"PP_", "/;", 
     RowBox[{
      RowBox[{"Head", "[", "PP", "]"}], "=!=", "List"}]}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n3_", ")"}], ",", " ", "m3_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n4_", ")"}], ",", " ", "m4_"}], "}"}], ",", "\n", 
      "\t\t                           ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n2_", ")"}], ",", " ", "m2_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n5_", ")"}], ",", " ", "m5_"}], "}"}]}], " ", "}"}]}], 
   "]"}], " ", ":=", " ", "\n", 
  RowBox[{"TVI", "[", 
   RowBox[{"d", ",", "PP", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n5", ",", "m5"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
TFI[d_,   PP_/;Head[PP]=!=List,{ {(n4_), m4_},{(n3_), m3_},
\t\t                           {(n2_), m2_}, {0, m1_}, 
                               {(n5_), m5_} }] := 
TVI[d,PP, {{n5,m5}, {n2,m2}, {n3,m3}, {n4,m4}}]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TFR", "[", 
   RowBox[{"d_", ",", "   ", 
    RowBox[{"PP_", "/;", 
     RowBox[{
      RowBox[{"Head", "[", "PP", "]"}], "=!=", "List"}]}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n4_", ")"}], ",", " ", "m4_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n3_", ")"}], ",", " ", "m3_"}], "}"}], ",", "\n", 
      "\t\t                           ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n2_", ")"}], ",", " ", "m2_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n5_", ")"}], ",", " ", "m5_"}], "}"}]}], " ", "}"}]}], 
   "]"}], " ", ":=", " ", "\n", 
  RowBox[{"TVI", "[", 
   RowBox[{"d", ",", "PP", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n5", ",", "m5"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\

TFI[d_,  PP_/;Head[PP]=!=List,{{(n1_), m1_}, 

    {(n2_), m2_}, 

    {(n3_), m3_}, 

    {(n4_), m4_}, {0, m5_}}] := 

  TBI[d, PP, {{n1, m1}, {n3, m3}}]*

   TBI[d, PP, {{n2, m2}, {n4, m4}}]
\
\>", "Text"],

Cell["\<\
TFR[d_, PP_ /; Head[PP] =!= List, 
   {{n1_, m1_}, {n2_, m2_}, {n3_, m3_}, {n4_, m4_}, 
    {0, m5_}}] := TBI[d, PP, {{n1, m1}, {n3, m3}}]*
   TBI[d, PP, {{n2, m2}, {n4, m4}}]\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["four -> three", "Subsection",
 CellTags->"T1.6.122.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TVI", "[", 
   RowBox[{"d_", ",", " ", "PP_", ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2_", ",", " ", "m2_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{"n3_", ",", " ", "m3_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4_", ",", " ", "m4_"}], "}"}]}], " ", "}"}]}], "]"}], " ", ":=",
   " ", "\n", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], "}"}]}], "]"}], " ", 
   RowBox[{"TBI", "[", 
    RowBox[{"d", ",", "PP", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n2", ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TVI", "[", 
   RowBox[{"d_", ",", " ", "PP_", ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2_", ",", " ", "m2_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m3_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n4_", ",", " ", "m4_"}], "}"}]}], " ", "}"}]}], "]"}], " ", ":=",
   " ", "\n", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n1", ",", "m1"}], "}"}], "}"}]}], "]"}], " ", 
   RowBox[{"TBI", "[", 
    RowBox[{"d", ",", "PP", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n2", ",", "m2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n4", ",", "m4"}], "}"}]}], "}"}]}], "]"}]}]}]], "Input"],

Cell["\<\
TVI[d_, PP_, {{n1_, m1_}, {0, m2_}, {n3_, m3_}, {n4_, m4_}}] := 
  TJI[d, 0, {{n1, m1}, {n3, m3}, {n4, m4}}]\
\>", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TVI", "[", 
   RowBox[{"d_", ",", " ", "PP_", ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n2_", ",", " ", "m2_"}], "}"}], ",", " ", "\n", 
      "                               ", 
      RowBox[{"{", 
       RowBox[{"n3_", ",", " ", "m3_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m4_"}], "}"}]}], " ", "}"}]}], "]"}], " ", ":=",
   " ", "\n", 
  RowBox[{"TJI", "[", 
   RowBox[{"d", ",", "PP", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n1", ",", "m1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}]}], " ", "}"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["three -> two", "Subsection",
 CellTags->"T1.6.123.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJI", "[", 
   RowBox[{"d_", ",", " ", "PP_", ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n2_", ")"}], ",", " ", "m2_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n3_", ")"}], ",", " ", "m3_"}], "}"}]}], " ", "}"}]}], 
   "]"}], " ", ":=", " ", "\n", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], "}"}]}], "]"}], "  ", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJI", "[", 
   RowBox[{"d_", ",", " ", "PP_", ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n1_", ")"}], ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m2_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n3_", ")"}], ",", " ", "m3_"}], "}"}]}], " ", "}"}]}], 
   "]"}], " ", ":=", " ", "\n", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n1", ",", "m1"}], "}"}], "}"}]}], "]"}], "  ", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n3", ",", "m3"}], "}"}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJI", "[", 
   RowBox[{"d_", ",", " ", "PP_", ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n1_", ")"}], ",", " ", "m1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", "n2_", ")"}], ",", " ", "m2_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "m3_"}], "}"}]}], " ", "}"}]}], "]"}], " ", ":=",
   " ", "\n", 
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n1", ",", "m1"}], "}"}], "}"}]}], "]"}], "  ", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n2", ",", "m2"}], "}"}], "}"}]}], "]"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["two -> one", "Subsection",
 CellTags->"T1.6.124.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TBI", "[", 
    RowBox[{"d_", ",", " ", "PP_", ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "m1_"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", "n2_", ")"}], ",", " ", "m2_"}], "}"}]}], " ", "}"}]}], 
    "]"}], " "}], ":=", " ", "\n", 
  RowBox[{"TAI", "[", 
   RowBox[{"d", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"n2", ",", "m2"}], "}"}], "}"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TBI", "[", 
    RowBox[{"d_", ",", " ", "PP_", ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", "n1_", ")"}], ",", " ", "m1_"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "m2_"}], "}"}]}], " ", "}"}]}], "]"}], " "}], ":=",
   " ", "\n", 
  RowBox[{"TAI", "[", 
   RowBox[{"d", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"n1", ",", "m1"}], "}"}], "}"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d_", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n_Integer", ",", "m_"}], "}"}], "}"}]}], "]"}], ":=", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "m"}], "}"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d_", ",", 
     RowBox[{"{", 
      RowBox[{"n_Integer", ",", "m_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "m"}], "}"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TAI", "[", 
    RowBox[{"d_", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"n_Integer", ",", "m_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"TAI", "[", 
    RowBox[{"d", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "m"}], "}"}], "}"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarcerRecurse and TFIRecurse", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.7.1"],

Cell[CellGroupData[{

Cell["TFIRecurse & TFISimplify", "Subsection",
 CellTags->"T1.7.1.1"],

Cell["This cancels scalar products.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TLRComment", "=", "False"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLRComment", "[", "s_String", "]"}], ":=", 
   RowBox[{
    RowBox[{"WriteString", "[", 
     RowBox[{"\"\<stdout\>\"", ",", "s", ",", "\"\< \>\""}], "]"}], "/;", 
    RowBox[{"$TLRComment", "===", "True"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"applytlrules", "[", 
    RowBox[{"y_", ",", "fun_"}], "]"}], " ", ":=", 
   RowBox[{"fun", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"y", " ", "/.", 
       RowBox[{
        StyleBox["TFI",
         FontColor->RGBColor[1, 0.6, 0]], "->", "TLR"}]}], "/.", "TLRules"}], 
     "/.", 
     RowBox[{"TLR", "->", 
      StyleBox["TFI",
       FontColor->RGBColor[1, 0.6, 0]]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TFIRecurse", "[", 
    RowBox[{"z_", ",", 
     RowBox[{"f_", ":", "Identity"}]}], "]"}], " ", ":=", " ", 
   RowBox[{"FixedPoint", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"applytlrules", "[", 
       RowBox[{"#", ",", "f"}], "]"}], "&"}], ",", "z", ",", "1000"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"applytlrules2", "[", 
    RowBox[{"y_", ",", "fun_"}], "]"}], " ", ":=", 
   RowBox[{"fun", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"y", " ", "/.", 
       RowBox[{
        StyleBox["TFI",
         FontColor->RGBColor[1, 0.6, 0]], "->", "TLR"}]}], "/.", "TLRules2"}],
      "/.", 
     RowBox[{"TLR", "->", 
      StyleBox["TFI",
       FontColor->RGBColor[1, 0.6, 0]]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TFISimplify", "[", 
    RowBox[{"z_", ",", 
     RowBox[{"f_", ":", "Identity"}]}], "]"}], " ", ":=", " ", 
   RowBox[{"FixedPoint", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"applytlrules2", "[", 
       RowBox[{"#", ",", "f"}], "]"}], "&"}], ",", "z", ",", "1000"}], 
    "]"}]}], ";"}]], "Input"],

Cell["\<\
TFIRecurse[z_]:=z/.TFI\[Rule]TLR//.TLRules/.TLR\[Rule]TFI;\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExpandMaybe", "=", "Identity"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fN", "[", "li_List", "]"}], ":=", 
   RowBox[{
    RowBox[{"fN", "[", "li", "]"}], "=", 
    RowBox[{"li", "/.", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "_"}], "}"}], "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}]}]}]}], ";"}]], "Input"],

Cell["\<\
RM: new Feb. 1999  
need TLR[ ...]:= rule;
(copy from TFI definition) (in order to get e.g. 
TarcerRecurse[TFI[D,pp,{1,1,1,1,1},{{1,0},{1,M},{0,0},{1,m},{1,M}}]]
to work)\
\>", "Text",
 CellTags->"TLRdef"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"depp__", ",", 
     RowBox[{"{", 
      RowBox[{"a___", ",", "b_Integer", ",", "c___"}], "}"}]}], "]"}], ":=", 
   RowBox[{"TLR", "[", 
    RowBox[{"depp", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", "0"}], "}"}], ",", "c"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      "pr_"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"NoTLRComment", "[", "\"\<tlrule1\>\"", "]"}], ";", 
      RowBox[{
       StyleBox["TFI",
        FontColor->RGBColor[1, 0.6, 0]], "[", 
       RowBox[{"d", ",", "pp", ",", 
        RowBox[{"pr", "/.", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "_"}], "}"}], "\[RuleDelayed]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}]}]}], "]"}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell["(* q1^2 *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v_", "?", "PQ"}], ",", "w_", ",", "x_", ",", "y_", ",", 
        "z_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n1_", "?", "PQ"}], ",", "m1_"}], "}"}], ",", "nm2_", ",", 
        "nm3_", ",", "nm4_", ",", "nm5_"}], "}"}]}], "]"}], "\[RuleDelayed]", 
    
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule2\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"v", "\[LessEqual]", "n1"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m1", "===", "0"}], ",", 
           RowBox[{"TLR", "[", 
            RowBox[{"dpp", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "w", ",", "x", ",", "y", ",", "z"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n1", "-", "v"}], ",", "0"}], "}"}], ",", "nm2", ",",
                "nm3", ",", "nm4", ",", "nm5"}], "}"}]}], "]"}], ",", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], "v"], 
            RowBox[{
             RowBox[{"Binomial", "[", 
              RowBox[{"v", ",", "i"}], "]"}], " ", 
             RowBox[{"TLR", "[", 
              RowBox[{"dpp", ",", " ", 
               RowBox[{"{", 
                RowBox[{"0", ",", "w", ",", "x", ",", "y", ",", "z"}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"fN", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"n1", "-", "i"}], ",", "m1"}], "}"}], "]"}], ",", 
                 "nm2", ",", "nm3", ",", "nm4", ",", "nm5"}], "}"}]}], "]"}], 
             " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox["m1", "2"], ")"}], 
              RowBox[{"v", "-", "i"}]]}]}]}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m1", "===", "0"}], ",", 
           RowBox[{"TLR", "[", 
            RowBox[{"dpp", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"v", "-", "n1"}], ",", "w", ",", "x", ",", "y", ",", 
               "z"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", "nm2", ",", "nm3", ",", 
               "nm4", ",", "nm5"}], "}"}]}], "]"}], ",", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], "n1"], 
            RowBox[{
             RowBox[{"Binomial", "[", 
              RowBox[{"n1", ",", "i"}], "]"}], " ", 
             RowBox[{"TLR", "[", 
              RowBox[{"dpp", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"v", "-", "n1"}], ",", "w", ",", "x", ",", "y", ",", 
                 "z"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"fN", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"n1", "-", "i"}], ",", "m1"}], "}"}], "]"}], ",", 
                 "nm2", ",", "nm3", ",", "nm4", ",", "nm5"}], "}"}]}], "]"}], 
             " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox["m1", "2"], ")"}], 
              RowBox[{"n1", "-", "i"}]]}]}]}], "]"}]}], "]"}], "]"}]}], 
     ")"}]}]}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  SubsuperscriptBox["q", "2", "2"], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", 
        RowBox[{"w_", "?", "PQ"}], ",", "x_", ",", "y_", ",", "z_"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n2_", "?", "PQ"}], ",", "m2_"}], "}"}], ",", "nm3_", ",", 
        "nm4_", ",", "nm5_"}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule3\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"w", "\[LessEqual]", "n2"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m2", "===", "0"}], ",", 
           RowBox[{"TLR", "[", 
            RowBox[{"dpp", ",", 
             RowBox[{"{", 
              RowBox[{"v", ",", "0", ",", "x", ",", "y", ",", "z"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"nm1", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n2", "-", "w"}], ",", "0"}], "}"}], ",", "nm3", ",",
                "nm4", ",", "nm5"}], "}"}]}], "]"}], ",", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], "w"], 
            RowBox[{
             RowBox[{"Binomial", "[", 
              RowBox[{"w", ",", "i"}], "]"}], " ", 
             RowBox[{"TLR", "[", 
              RowBox[{"dpp", ",", 
               RowBox[{"{", 
                RowBox[{"v", ",", "0", ",", "x", ",", "y", ",", "z"}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"nm1", ",", 
                 RowBox[{"fN", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"n2", "-", "i"}], ",", "m2"}], "}"}], "]"}], ",", 
                 "nm3", ",", "nm4", ",", "nm5"}], "}"}]}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox["m2", "2"], ")"}], 
              RowBox[{"w", "-", "i"}]]}]}]}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m2", "===", "0"}], ",", 
           RowBox[{"TLR", "[", 
            RowBox[{"dpp", ",", 
             RowBox[{"{", 
              RowBox[{"v", ",", 
               RowBox[{"w", "-", "n2"}], ",", "x", ",", "y", ",", "z"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"nm1", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", "nm3", ",", "nm4", ",", 
               "nm5"}], "}"}]}], "]"}], ",", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], "n2"], 
            RowBox[{
             RowBox[{"Binomial", "[", 
              RowBox[{"n2", ",", "i"}], "]"}], " ", 
             RowBox[{"TLR", "[", 
              RowBox[{"dpp", ",", 
               RowBox[{"{", 
                RowBox[{"v", ",", 
                 RowBox[{"w", "-", "n2"}], ",", "x", ",", "y", ",", "z"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"nm1", ",", 
                 RowBox[{"fN", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"n2", "-", "i"}], ",", "m2"}], "}"}], "]"}], ",", 
                 "nm3", ",", "nm4", ",", "nm5"}], "}"}]}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox["m2", "2"], ")"}], 
              RowBox[{"n2", "-", "i"}]]}]}]}], "]"}]}], "]"}], "]"}]}], 
     ")"}]}]}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"p", "\[CenterDot]", 
   SubscriptBox["q", "1"]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", "w_", ",", 
        RowBox[{"x_", "?", "PQ"}], ",", "y_", ",", "z_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n1_", "?", "PQ"}], ",", "m1_"}], "}"}], ",", "nm2_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n3_", "?", "PQ"}], ",", "m3_"}], "}"}], ",", "nm4_", ",", 
        "nm5_"}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule4\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"v", "+", "1"}], ",", "w", ",", 
             RowBox[{"x", "-", "1"}], ",", "y", ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", "nm2", ",", 
             RowBox[{"{", 
              RowBox[{"n3", ",", "m3"}], "}"}], ",", "nm4", ",", "nm5"}], 
            "}"}]}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "w", ",", 
             RowBox[{"x", "-", "1"}], ",", "y", ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", "nm2", ",", 
             RowBox[{"fN", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"n3", "-", "1"}], ",", "m3"}], "}"}], "]"}], ",", 
             "nm4", ",", "nm5"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"{", "dpp", "}"}], "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], "-", 
           SuperscriptBox["m3", "2"]}], ")"}], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "w", ",", 
             RowBox[{"x", "-", "1"}], ",", "y", ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", "nm2", ",", 
             RowBox[{"{", 
              RowBox[{"n3", ",", "m3"}], "}"}], ",", "nm4", ",", "nm5"}], 
            "}"}]}], "]"}]}]}], "]"}]}], ")"}]}]}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"p", "\[CenterDot]", 
   SubscriptBox["q", "2"]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", "w_", ",", "x_", ",", 
        RowBox[{"y_", "?", "PQ"}], ",", "z_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1_", ",", "m1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n2_", "?", "PQ"}], ",", "m2_"}], "}"}], ",", "nm3_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n4_", "?", "PQ"}], ",", "m4_"}], "}"}], ",", "nm5_"}], 
       "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule5\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", 
             RowBox[{"w", "+", "1"}], ",", "x", ",", 
             RowBox[{"y", "-", "1"}], ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", 
             RowBox[{"{", 
              RowBox[{"n4", ",", "m4"}], "}"}], ",", "nm5"}], "}"}]}], 
          "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "w", ",", "x", ",", 
             RowBox[{"y", "-", "1"}], ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", 
             RowBox[{"fN", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"n4", "-", "1"}], ",", "m4"}], "}"}], "]"}], ",", 
             "nm5"}], "}"}]}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"{", "dpp", "}"}], "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], "-", 
           SuperscriptBox["m4", "2"]}], ")"}], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "w", ",", "x", ",", 
             RowBox[{"y", "-", "1"}], ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", 
             RowBox[{"{", 
              RowBox[{"n4", ",", "m4"}], "}"}], ",", "nm5"}], "}"}]}], 
          "]"}]}]}], "]"}]}], ")"}]}]}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["q", "1"], "\[CenterDot]", 
   SubscriptBox["q", "2"]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "6", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"dpp__", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", "w_", ",", "x_", ",", "y_", ",", 
        RowBox[{"z_", "?", "PQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1_", ",", "m1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n2_", ",", "m2_"}], "}"}], ",", "nm3_", ",", "nm4_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n5_", "?", "PQ"}], ",", "m5_"}], "}"}]}], "}"}]}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule6\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"v", "+", "1"}], ",", "w", ",", "x", ",", "y", ",", 
             RowBox[{"z", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", "nm4", ",", 
             RowBox[{"{", 
              RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "w", ",", "x", ",", "y", ",", 
             RowBox[{"z", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", "nm4", ",", 
             RowBox[{"fN", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"n5", "-", "1"}], ",", "m5"}], "}"}], "]"}]}], 
            "}"}]}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", 
             RowBox[{"w", "+", "1"}], ",", "x", ",", "y", ",", 
             RowBox[{"z", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", "nm4", ",", 
             RowBox[{"{", 
              RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox["m5", "2"], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"dpp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", "w", ",", "x", ",", "y", ",", 
             RowBox[{"z", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1", ",", "m1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", "nm3", ",", "nm4", ",", 
             RowBox[{"{", 
              RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}]}], "]"}]}],
      ")"}]}]}], ";"}]], "Input"],

Cell["(* q1.q1  --> q1.p *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "7", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp___", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v_", "?", "PQ"}], ",", "w_", ",", "x_", ",", "y_", ",", 
        "z_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", "nm2_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n3_", "?", "PQ"}], ",", "m3_"}], "}"}], ",", "nm4_", ",", 
        "nm5_"}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule7\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"v", "-", "1"}], ",", "w", ",", "x", ",", "y", ",", "z"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "nm2", ",", 
            RowBox[{"fN", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n3", "-", "1"}], ",", "m3"}], "}"}], "]"}], ",", 
            "nm4", ",", "nm5"}], "}"}]}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"v", "-", "1"}], ",", "w", ",", 
             RowBox[{"x", "+", "1"}], ",", "y", ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "nm2", ",", 
             RowBox[{"{", 
              RowBox[{"n3", ",", "m3"}], "}"}], ",", "nm4", ",", "nm5"}], 
            "}"}]}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pp", "-", 
           SuperscriptBox["m3", "2"]}], ")"}], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"v", "-", "1"}], ",", "w", ",", "x", ",", "y", ",", 
             "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "nm2", ",", 
             RowBox[{"{", 
              RowBox[{"n3", ",", "m3"}], "}"}], ",", "nm4", ",", "nm5"}], 
            "}"}]}], "]"}]}]}], "]"}]}], ")"}]}]}], ";"}]], "Input"],

Cell["(* q2.q2  --> q2.p *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "8", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp___", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", 
        RowBox[{"w_", "?", "PQ"}], ",", "x_", ",", "y_", ",", "z_"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", "nm3_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n4_", "?", "PQ"}], ",", "m4_"}], "}"}], ",", "nm5_"}], 
       "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule8\>\"", "]"}], ";", 
      RowBox[{"ExpandMaybe", "[", 
       RowBox[{
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", 
            RowBox[{"w", "-", "1"}], ",", "x", ",", "y", ",", "z"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"nm1", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "nm3", ",", 
            RowBox[{"fN", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n4", "-", "1"}], ",", "m4"}], "}"}], "]"}], ",", 
            "nm5"}], "}"}]}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", 
             RowBox[{"w", "-", "1"}], ",", "x", ",", 
             RowBox[{"y", "+", "1"}], ",", "z"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"nm1", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "nm3", ",", 
             RowBox[{"{", 
              RowBox[{"n4", ",", "m4"}], "}"}], ",", "nm5"}], "}"}]}], 
          "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pp", "-", 
           SuperscriptBox["m4", "2"]}], ")"}], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{"v", ",", 
             RowBox[{"w", "-", "1"}], ",", "x", ",", "y", ",", "z"}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"nm1", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "nm3", ",", 
             RowBox[{"{", 
              RowBox[{"n4", ",", "m4"}], "}"}], ",", "nm5"}], "}"}]}], 
          "]"}]}]}], "]"}]}], ")"}]}]}], ";"}]], "Input"],

Cell["(* eq. (3) - (5) *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "9", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", "w_", ",", "x_", ",", "y_", ",", 
        RowBox[{"z_", "?", "PQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", "nm2_", ",", "nm3_", ",", "nm4_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule9\>\"", "]"}], ";", 
      RowBox[{"FunctionExpand", "[", 
       RowBox[{"ExpandMaybe", "[", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"k", "=", "0"}], 
          RowBox[{"Floor", "[", 
           FractionBox["z", "2"], "]"}]], 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], "k"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"j", "=", "0"}], "k"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Gamma", "[", 
               RowBox[{"k", "+", 
                FractionBox["1", "2"]}], "]"}], " ", 
              RowBox[{"Gamma", "[", 
               RowBox[{
                FractionBox["d", "2"], "-", 
                FractionBox["1", "2"]}], "]"}], " ", 
              RowBox[{"Binomial", "[", 
               RowBox[{"z", ",", 
                RowBox[{"2", " ", "k"}]}], "]"}], " ", 
              RowBox[{"Binomial", "[", 
               RowBox[{"k", ",", "i"}], "]"}], " ", 
              RowBox[{"Binomial", "[", 
               RowBox[{"k", ",", "j"}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"i", "+", "j"}]], " ", 
              SuperscriptBox["pp", 
               RowBox[{"i", "+", "j", "-", "z"}]], " ", 
              RowBox[{"TLR", "[", 
               RowBox[{"d", ",", "pp", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"v", "+", "i"}], ",", 
                  RowBox[{"w", "+", "j"}], ",", 
                  RowBox[{"x", "+", "z", "-", 
                   RowBox[{"2", " ", "i"}]}], ",", 
                  RowBox[{"y", "+", "z", "-", 
                   RowBox[{"2", " ", "j"}]}], ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], ")"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Gamma", "[", 
               FractionBox["1", "2"], "]"}], " ", 
              RowBox[{"Gamma", "[", 
               RowBox[{"k", "+", 
                FractionBox["d", "2"], "-", 
                FractionBox["1", "2"]}], "]"}]}], ")"}]}]}]}]}], "]"}], 
       "]"}]}], ")"}]}]}], ";"}]], "Input"],

Cell[" OLD trule[10]:", "Text"],

Cell["\<\
tlrule[10] = 
(* (9) and (10) *)
TLR[d_, pp_, {v_,w_,x_?PQ,y_?PQ,z_}, {{n1_?PQ,m1_},{n2_?PQ,m2_}, 
                                {0,_},{0,_},nm5_}] :>  
( TLRComment[\"tlrule10\"]; 0 /; OddQ[x+y] );\
\>", "Text"],

Cell["New tlrule[10]:", "Text"],

Cell["\<\
tlrule[10] = 
   TLR[d_, pp_, {v_, w_, (x_)?PNQ, (y_)?PNQ, z_}, 
     {{(n1_)?PQ, m1_}, {(n2_)?PQ, m2_}, {0, _}, {0, _}, nm5_}] :> \
(TLRComment[\"tlrule10\"]; 0 /; OddQ[x + y]); \
\>", "Input"],

Cell["\<\
Bug in  tlrule[11] and tlrule[12] fixed on Feb. 26th 1998 by R.Scharf 
with thanks to York Schroeder for locating the bug.\
\>", "Text"],

Cell["\<\

tlrule[11] = 
TLR[d_, pp_, {v_,w_,x_?PQ,y_?PQ,z_}, {nm1_,nm2_,{0,_},{0,_},{(n5_)?PQ, m5_}}] \
:> 
(
TLRComment[\"tlrule11\"];
 ExpandMaybe[
 pp/(d+x+y-2)( (x-1) TLR[d, pp, {v+1,w,x-2,y,z}, 
                         {{n1,m1},{n2,m2},{0,0},{0,0},{n5,m5}}] +
                   y TLR[d, pp, {v,w,x-1,y-1,z+1}, 
                         {nm1,nm2,{0,0},{0,0},{n5,m5}}]
             )
           ] /; EvenQ[x+y] && x > 1
);\
\>", "Input"],

Cell["\<\

tlrule[12] = 
TLR[d_, pp_, {v_,w_,x_?PQ,y_?PQ,z_}, {nm1_,nm2_,{0,_},{0,_},{(n5_)?PQ, m5_}}] \
:> 
(
TLRComment[\"tlrule12\"];
 ExpandMaybe[
 pp/(d+x+y-2)( (y-1) TLR[d, pp, {v,w+1,x,y-2,z}, 
                         {{n1,m1},{n2,m2},{0,0},{0,0},{n5,m5}}] +
                   x TLR[d, pp, {v,w,x-1,y-1,z+1}, 
                         {nm1,nm2,{0,0},{0,0},{n5,m5}}]
             )
           ] /; EvenQ[x+y] && y > 1
);\
\>", "Input"],

Cell["(*symm.   1 <-> 3  &&  2 <-> 4 *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "13", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{"y_", "?", "PQ"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", "nm3_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n4_", "?", "PQ"}], ",", "m4_"}], "}"}], ",", "nm5_"}], 
       "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule13\>\"", "]"}], ";", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "y"], 
       RowBox[{
        RowBox[{"Binomial", "[", 
         RowBox[{"y", ",", "i"}], "]"}], " ", 
        SuperscriptBox["pp", 
         RowBox[{"y", "-", "i"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "i"], " ", 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0", ",", "i", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"nm3", ",", 
            RowBox[{"{", 
             RowBox[{"n4", ",", "m4"}], "}"}], ",", "nm1", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "nm5"}], "}"}]}], 
         "]"}]}]}]}], ")"}]}]}], ";"}]], "Input"],

Cell["(*symm.   1 <-> 3  &&  2 <-> 4 *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "14", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"x_", "?", "PQ"}], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", "nm2_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n3_", "?", "PQ"}], ",", "m3_"}], "}"}], ",", "nm4_", ",", 
        "nm5_"}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule14\>\"", "]"}], ";", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "x"], 
       RowBox[{
        RowBox[{"Binomial", "[", 
         RowBox[{"x", ",", "i"}], "]"}], " ", 
        SuperscriptBox["pp", 
         RowBox[{"x", "-", "i"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "i"], " ", 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "i", ",", "0", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n3", ",", "m3"}], "}"}], ",", "nm4", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "nm2", ",", "nm5"}], 
           "}"}]}], "]"}]}]}]}], ")"}]}]}], ";"}]], "Input"],

Cell["(* 0's *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "15", "]"}], "=", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"TLR", "[", 
      RowBox[{"d_", ",", "pp_", ",", 
       RowBox[{"{", 
        RowBox[{"v_", ",", "w_", ",", "x_", ",", "y_", ",", "z_"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n2_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule15\>\"", "]"}], ";", "0"}], 
     ")"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "16", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"x_", "?", "PQ"}], ",", 
        RowBox[{"y_", "?", "PQ"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1_", ",", "_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n2_", ",", "_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule16\>\"", "]"}], ";", 
      RowBox[{"0", "/;", 
       RowBox[{
        RowBox[{"OddQ", "[", "x", "]"}], "||", 
        RowBox[{"OddQ", "[", "y", "]"}]}]}]}], ")"}]}]}], ";"}]], "Input"],

Cell["bug in tlrule[17] fixedApril 23rd 1999", "Text",
 CellTags->"tlrule17"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "17", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a_", "?", "PQ"}], ",", "b_", ",", "0", ",", "de_", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n2_", ",", "m2_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n4_", ",", "m4_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n5_", ",", "m5_"}], "}"}]}], "}"}]}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule17\>\"", "]"}], ";", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "a"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "0"}], "i"], 
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{"a", ",", "i"}], "]"}], " ", 
         RowBox[{"Binomial", "[", 
          RowBox[{"i", ",", "j"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "j"]}], ")"}], " ", 
         SuperscriptBox["2", 
          RowBox[{"j", "-", "1"}]], " ", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"a", "-", "i"}], ",", 
             RowBox[{"b", "+", "i", "-", "j"}], ",", "0", ",", "de", ",", 
             "j"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n5", ",", "m5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "m2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"n4", ",", "m4"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]}]}]}], 
     ")"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "18", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a_", "?", "PNQ"}], ",", 
        RowBox[{"b_", "?", "PNQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n2_", ",", "m2_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3_", ",", "m3_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n4_", ",", "m4_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n5_", ",", "m5_"}], "}"}]}], "}"}]}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule18\>\"", "]"}], ";", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "a"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "0"}], "b"], 
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{"a", ",", "i"}], "]"}], " ", 
         RowBox[{"Binomial", "[", 
          RowBox[{"b", ",", "j"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"pp", "+", 
              SuperscriptBox["m3", "2"]}], ")"}], " ", 
            RowBox[{"TLR", "[", 
             RowBox[{"d", ",", "pp", ",", "dp", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"n3", ",", "m3"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n4", ",", "m4"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n2", ",", "m2"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}], "+", 
           RowBox[{"TLR", "[", 
            RowBox[{"d", ",", "pp", ",", "dp", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n3", "-", "1"}], ",", "m3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"n4", ",", "m4"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"n2", ",", "m2"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"TLR", "[", 
             RowBox[{"d", ",", "pp", ",", "dp", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"n3", ",", "m3"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n4", ",", "m4"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n2", ",", "m2"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}]}], 
          ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"i", "+", "j"}]], " ", 
         SuperscriptBox["dp", 
          RowBox[{"a", "+", "b", "-", "i", "-", "j"}]]}]}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "19", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a_", "?", "PNQ"}], ",", 
        RowBox[{"b_", "?", "PNQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1_", ",", "m1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n3_", ",", "m3_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n4_", ",", "m4_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n5_", ",", "m5_"}], "}"}]}], "}"}]}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule18\>\"", "]"}], ";", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "a"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "0"}], "b"], 
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{"a", ",", "i"}], "]"}], " ", 
         RowBox[{"Binomial", "[", 
          RowBox[{"b", ",", "j"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"pp", "+", 
              SuperscriptBox["m4", "2"]}], ")"}], " ", 
            RowBox[{"TLR", "[", 
             RowBox[{"d", ",", "pp", ",", "dp", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"n3", ",", "m3"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n4", ",", "m4"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n1", ",", "m1"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}], "+", 
           RowBox[{"TLR", "[", 
            RowBox[{"d", ",", "pp", ",", "dp", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"n3", ",", "m3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"n4", "-", "1"}], ",", "m4"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"n1", ",", "m1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"TLR", "[", 
             RowBox[{"d", ",", "pp", ",", "dp", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"n3", ",", "m3"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n4", ",", "m4"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n1", ",", "m1"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"n5", ",", "m5"}], "}"}]}], "}"}]}], "]"}]}]}], 
          ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"i", "+", "j"}]], " ", 
         SuperscriptBox["dp", 
          RowBox[{"a", "+", "b", "-", "i", "-", "j"}]]}]}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell["(* q1.q1  --> q1.p *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "20", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v_", "?", "PQ"}], ",", "w_", ",", "x_", ",", "y_", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", "nm2_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", "nm4_", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"n5_", "?", "PQ"}], ",", "m5_"}], "}"}]}], "}"}]}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule20\>\"", "]"}], ";", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], "x"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], "v"], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"r", "=", "0"}], "i"], 
         RowBox[{
          RowBox[{"Binomial", "[", 
           RowBox[{"i", ",", "r"}], "]"}], " ", 
          RowBox[{"Binomial", "[", 
           RowBox[{"v", ",", "i"}], "]"}], " ", 
          RowBox[{"Binomial", "[", 
           RowBox[{"x", ",", "j"}], "]"}], " ", 
          SuperscriptBox["2", "r"], " ", 
          RowBox[{"TLR", "[", 
           RowBox[{"d", ",", "pp", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"v", "-", "i"}], ",", 
              RowBox[{
               RowBox[{"-", "r"}], "+", "i", "+", "w"}], ",", "j", ",", 
              RowBox[{"x", "-", "j", "+", "y"}], ",", "r"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"n5", ",", "m5"}], "}"}], ",", "nm2", ",", "0", ",", 
              "nm4", ",", "0"}], "}"}]}], "]"}]}]}]}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "21", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", 
      RowBox[{"{", 
       RowBox[{"v_", ",", 
        RowBox[{"w_", "?", "PQ"}], ",", "x_", ",", "y_", ",", "0"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", "nm3_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "_"}], "}"}], ",", "nm5_"}], "}"}]}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule21\>\"", "]"}], ";", 
      RowBox[{"TLR", "[", 
       RowBox[{"d", ",", "pp", ",", 
        RowBox[{"{", 
         RowBox[{"w", ",", "v", ",", "y", ",", "x", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "nm1", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "nm3", ",", "nm5"}], "}"}]}], 
       "]"}]}], ")"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "22", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"b_", "?", "PNQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"w_", "?", "PNQ"}], ",", "0", ",", 
        RowBox[{"y_", "?", "PNQ"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", "nm2_", ",", "nm3_", ",", "nm4_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule22\>\"", "]"}], ";", 
      RowBox[{
       FractionBox["1", "pp"], 
       RowBox[{"(", 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "b"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "w", ",", "1", ",", 
            RowBox[{"y", "+", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ")"}]}]}], 
     ")"}]}]}], ";"}]], "Input"],

Cell[TextData[{
 "Using  FeynCalc : \n\n",
 Cell[BoxData[
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"k1", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k1", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", "p", "}"}]}], "]"}]], "Input"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[NoBreak]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FormBox[
           RowBox[{
            FormBox["k1",
             TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            FormBox["p",
             TraditionalForm]}],
           TraditionalForm], ")"}], "2"], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["k1",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FormBox[
            RowBox[{
             FormBox["k1",
              TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], ")"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["k1",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]]}], TraditionalForm]], "Output"],
 "\n",
 Cell[BoxData[
  RowBox[{"Collect2", "[", 
   RowBox[{
    RowBox[{"Calc", "[", " ", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"OPEDelta", ",", "\[Mu]"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"k2", ",", "\[Nu]"}], "]"}], "%"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k1", ",", "k2"}], "}"}]}], "]"}]], "Input"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["k1",
           TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], ")"}], "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]], "-", 
    FractionBox[
     RowBox[{"D", " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["k1",
           TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], ")"}], "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       FormBox["k1",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}]}], 
     RowBox[{"1", "-", "D"}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       FormBox["k1",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]]}], TraditionalForm]], "Output"],
 "\n"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "23", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"b_", "?", "PNQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"w_", "?", "PNQ"}], ",", "0", ",", 
        RowBox[{"y_", "?", "PNQ"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", "nm2_", ",", "nm3_", ",", "nm4_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule23\>\"", "]"}], ";", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "d"}], ")"}], "pp"}]], 
        RowBox[{"(", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"b", "+", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "w", ",", "2", ",", "y", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ")"}]}], "-", 
       
       RowBox[{
        FractionBox[
         RowBox[{"d", "  ", "dp"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "d"}], ")"}], 
          SuperscriptBox["pp", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "b"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "w", ",", "2", ",", 
             RowBox[{"y", "+", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ")"}]}], "-", 
       
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "-", "d"}]], 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"b", "+", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "w", ",", "0", ",", "y", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["dp", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "d"}], ")"}], "pp"}]], 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "b"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "w", ",", "0", ",", 
            RowBox[{"y", "+", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]}]}], 
     ")"}]}]}], ";"}]], "Input"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"k1", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k1", ",", "\[Nu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k1", ",", "\[Rho]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", "p", "}"}]}], "]"}]], "Input"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["k1",
         TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["p",
         TraditionalForm]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"D", "+", "2"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FormBox[
             RowBox[{
              FormBox["k1",
               TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
              FormBox["p",
               TraditionalForm]}],
             TraditionalForm], ")"}], "2"]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           FormBox["k1",
            TraditionalForm], "2"], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "D"}], ")"}], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "6"]}]]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], "\[NoBreak]", 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FormBox[
           RowBox[{
            FormBox["k1",
             TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            FormBox["p",
             TraditionalForm]}],
           TraditionalForm], ")"}], "2"], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["k1",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[NoBreak]", 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FormBox[
           RowBox[{
            FormBox["k1",
             TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            FormBox["p",
             TraditionalForm]}],
           TraditionalForm], ")"}], "2"], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["k1",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[NoBreak]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FormBox[
           RowBox[{
            FormBox["k1",
             TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            FormBox["p",
             TraditionalForm]}],
           TraditionalForm], ")"}], "2"], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["k1",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]]}], TraditionalForm]], "Output"],
 "\n",
 Cell[BoxData[
  RowBox[{"Collect2", "[", 
   RowBox[{
    RowBox[{"Calc", "[", " ", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"OPEDelta", ",", "\[Mu]"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"OPEDelta", ",", "\[Nu]"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"k2", ",", "\[Rho]"}], "]"}], "%"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k1", ",", "k2"}], "}"}]}], "]"}]], "Input"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["k1",
           TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], ")"}], "3"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"D", "+", "2"}], ")"}], " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["k1",
           TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], ")"}], "3"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "6"]}]], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       FormBox["k1",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox[
       FormBox["k1",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["k2",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], ")"}], "2"], " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       FormBox["p",
        TraditionalForm]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "4"]}]]}], TraditionalForm]], "Output"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tlrule", "[", "24", "]"}], "=", 
   RowBox[{
    RowBox[{"TLR", "[", 
     RowBox[{"d_", ",", "pp_", ",", "dp_", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"b_", "?", "PNQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"w_", "?", "PNQ"}], ",", "0", ",", 
        RowBox[{"y_", "?", "PNQ"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nm1_", ",", "nm2_", ",", "nm3_", ",", "nm4_", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TLRComment", "[", "\"\<tlrule24\>\"", "]"}], ";", 
      RowBox[{
       RowBox[{"2", "dp", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "d"}], ")"}], 
           SuperscriptBox["pp", "2"]}]], 
         RowBox[{"(", 
          RowBox[{"TLR", "[", 
           RowBox[{"d", ",", "pp", ",", "dp", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"b", "+", "1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "w", ",", "3", ",", "y", ",", "0"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ")"}]}]}], 
       "-", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "2"}], ")"}], "  ", 
          SuperscriptBox["dp", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "d"}], ")"}], 
          SuperscriptBox["pp", "3"]}]], 
        RowBox[{"(", 
         RowBox[{"TLR", "[", 
          RowBox[{"d", ",", "pp", ",", "dp", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "b"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "w", ",", "3", ",", 
             RowBox[{"y", "+", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}], ")"}]}], "-", 
       
       RowBox[{
        FractionBox[
         RowBox[{"2", "dp"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "d"}], ")"}], "pp"}]], 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"b", "+", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "w", ",", "1", ",", "y", ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"3", 
          SuperscriptBox["dp", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "d"}], ")"}], 
          SuperscriptBox["pp", "2"]}]], 
        RowBox[{"TLR", "[", 
         RowBox[{"d", ",", "pp", ",", "dp", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "b"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "w", ",", "1", ",", 
            RowBox[{"y", "+", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"nm1", ",", "nm2", ",", "nm3", ",", "nm4", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]}]}], 
     ")"}]}]}], ";"}]], "Input"],

Cell["Symmetry 1 <--> 2; added February 21 1999 by R.M.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tlrule", "[", "25", "]"}], "=", 
    RowBox[{
     RowBox[{"TLR", "[", 
      RowBox[{"dim_", ",", "pp_", ",", " ", 
       RowBox[{"{", 
        RowBox[{"a_", ",", " ", "b_", ",", " ", 
         RowBox[{
          RowBox[{"(", "c_", ")"}], "?", "PNQ"}], ",", " ", 
         RowBox[{
          RowBox[{"(", "d_", ")"}], "?", "PQ"}], ",", " ", "0"}], "}"}], ",", 
       " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"nm1_", ",", " ", "nm2_", ",", " ", "nm3_", ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "_"}], "}"}], ",", " ", "nm5_"}], "}"}], 
        "\n"}]}], "   ", "]"}], " ", ":>", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"TLRComment", "[", "\"\<tlrule25\>\"", "]"}], ";", " ", 
        RowBox[{"TLR", "[", 
         RowBox[{"dim", ",", " ", "pp", ",", " ", 
          RowBox[{"{", 
           RowBox[{
           "b", ",", "a", ",", " ", "d", ",", " ", "c", ",", " ", "0"}], 
           "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"nm2", ",", " ", "nm1", ",", " ", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", " ", "nm3", ",", " ", 
            "nm5"}], "}"}]}], "]"}]}], ")"}], " ", "/;", " ", 
      RowBox[{"d", " ", ">", " ", "c"}]}]}]}], ";"}], "\n"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TLRules", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"tlrule", ",", "25"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TLRules2", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"TLRules", ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "9"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"__", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"__", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"__", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"__", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"__", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TLR", "[", 
    RowBox[{"__", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "_"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"seeetDelayed", ",", "HoldAll"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"seeetDelayed", "[", 
   RowBox[{
    RowBox[{"TLR", "[", "a__", "]"}], ",", "b_"}], "]"}], ":=", 
  RowBox[{"SetDelayed", "@@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"TLR", "[", "a", "]"}], ",", "b"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lis1", "=", 
   RowBox[{"Permutations", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0"}], "}"}]}], "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lis2", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"TLR", "[", 
        RowBox[{"__", ",", 
         RowBox[{
         "lis1", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
        "]"}], "\[RuleDelayed]", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "lis1", "]"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"RuleDelayed", "\[Rule]", "seeetDelayed"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"lis1", ",", "lis2"}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["T*IS", "Subsection",
 CellTags->"T1.7.2.1"],

Cell["\<\
These functions below are never used.
They can serve as tests.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", 
    RowBox[{"Power", "[", 
     RowBox[{"M_", ",", " ", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SuperscriptBox["SMu", "2"], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "1"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", " ", 
          SuperscriptBox["M", "2"]}], ")"}], 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "4"}]]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "Pi", " ", 
        RowBox[{"(", 
         RowBox[{"d", "-", "4"}], ")"}]}], "]"}], " ", 
      FractionBox[
       RowBox[{"Gamma", "[", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "d"}], 
        "]"}], 
       RowBox[{"Gamma", "[", 
        RowBox[{
         RowBox[{
          FractionBox["3", "2"], "d"}], "-", "\[Alpha]", "-", "\[Beta]", "-", 
         "\[Gamma]"}], "]"}]], 
      FractionBox[
       RowBox[{"Gamma", "[", 
        RowBox[{
         FractionBox["d", "2"], "-", "\[Alpha]"}], "]"}], 
       RowBox[{"Gamma", "[", "\[Alpha]", "]"}]], 
      FractionBox[
       RowBox[{"Gamma", "[", 
        RowBox[{
         FractionBox["d", "2"], "-", "\[Beta]"}], "]"}], 
       RowBox[{"Gamma", "[", "\[Beta]", "]"}]], 
      FractionBox[
       RowBox[{"Gamma", "[", 
        RowBox[{
         FractionBox["d", "2"], "-", "\[Gamma]"}], "]"}], 
       RowBox[{"Gamma", "[", "\[Gamma]", "]"}]]}], ")"}]}], "\n"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", 
    RowBox[{"Power", "[", 
     RowBox[{"M_", ",", " ", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "M_"}], "}"}]}], "}"}]}], "]"}], ":=", "\n", 
  "\t", 
  RowBox[{"TJIS", "[", 
   RowBox[{"d", ",", 
    RowBox[{"M", "^", "2"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "M"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", 
    RowBox[{"Power", "[", 
     RowBox[{"M_", ",", " ", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "\n", 
  "\t", 
  RowBox[{"TJIS", "[", 
   RowBox[{"d", ",", 
    RowBox[{"M", "^", "2"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "M"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", 
    RowBox[{"Power", "[", 
     RowBox[{"M_", ",", " ", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "\n", 
  RowBox[{
   FractionBox[
    SuperscriptBox["SMu", "2"], 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["M", "2"], ")"}], 
     RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "4"}]]], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "1"}]], 
   FractionBox[
    RowBox[{"Gamma", "[", 
     RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "d"}], "]"}], 
    RowBox[{
     RowBox[{"Gamma", "[", "\[Alpha]", "]"}], 
     RowBox[{"Gamma", "[", "\[Beta]", "]"}], 
     RowBox[{"Gamma", "[", "\[Gamma]", "]"}]}]], 
   FractionBox[
    RowBox[{
     RowBox[{"Gamma", "[", 
      RowBox[{
       FractionBox["d", "2"], "-", "\[Gamma]"}], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{
       FractionBox["d", "2"], "-", "\[Beta]"}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"d", "-", "\[Beta]", "-", "\[Gamma]"}], "]"}]], 
   FractionBox[
    RowBox[{
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Beta]", "+", "\[Gamma]", "-", 
       FractionBox["d", "2"]}], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{
       RowBox[{"2", " ", "d"}], "-", "\[Alpha]", "-", 
       RowBox[{"2", "\[Beta]"}], "-", 
       RowBox[{"2", "\[Gamma]"}]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"3", "d"}], "2"], "-", "\[Alpha]", "-", "\[Beta]", "-", 
      "\[Gamma]"}], "]"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{"TJIS", "[", 
   RowBox[{"d", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "M"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "M_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{"TJIS", "[", 
   RowBox[{"d", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "M"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "0"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "\n", 
  RowBox[{
   FractionBox[
    SuperscriptBox["SMu", "2"], 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["M", "2"], ")"}], 
     RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "4"}]]], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "1"}]], 
   FractionBox[
    RowBox[{"Gamma", "[", 
     RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "d"}], "]"}], 
    RowBox[{
     RowBox[{"Gamma", "[", "\[Alpha]", "]"}], 
     RowBox[{"Gamma", "[", "\[Beta]", "]"}], 
     RowBox[{"Gamma", "[", "\[Gamma]", "]"}]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"\[Beta]", "+", "\[Gamma]", "-", 
        RowBox[{"d", "/", "2"}]}], "]"}], 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"d", "/", "2"}], "-", "\[Beta]"}], "]"}], 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"d", "/", "2"}], "-", "\[Gamma]"}], "]"}]}], ")"}], "/", 
    RowBox[{"Gamma", "[", 
     RowBox[{"d", "/", "2"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "M_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{"TJIS", "[", 
   RowBox[{"d", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "M"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "M"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{"TJIS", "[", 
   RowBox[{"d", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "M"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]", ",", "M"}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "M_"}], "}"}]}], "}"}]}], "]"}], ":=", "\n", 
  
  RowBox[{
   FractionBox[
    SuperscriptBox["SMu", "2"], 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["M", "2"], ")"}], 
     RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "4"}]]], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "1"}]], 
   FractionBox[
    RowBox[{"Gamma", "[", 
     RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "d"}], "]"}], 
    RowBox[{
     RowBox[{"Gamma", "[", "\[Beta]", "]"}], 
     RowBox[{"Gamma", "[", "\[Gamma]", "]"}]}]], 
   FractionBox[
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox["d", "2"], "-", "\[Alpha]"}], "]"}], 
    RowBox[{"Gamma", "[", 
     FractionBox["d", "2"], "]"}]], 
   FractionBox[
    RowBox[{
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Alpha]", "+", "\[Gamma]", "-", 
       FractionBox["d", "2"]}], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       FractionBox["d", "2"]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{
      RowBox[{"2", "\[Alpha]"}], "+", "\[Beta]", "+", "\[Gamma]", "-", "d"}], 
     "]"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]_", ",", "M_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["SMu", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "1"}]], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "d"}], "]"}], 
     " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{
       FractionBox["d", "2"], "-", "\[Alpha]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Gamma", "[", 
        RowBox[{"\[Alpha]", "+", "\[Gamma]", "-", 
         FractionBox["d", "2"]}], "]"}], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         FractionBox["d", "2"]}], "]"}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["M", "2"], ")"}], 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "4"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Gamma", "[", "\[Beta]", "]"}], " ", 
       RowBox[{"Gamma", "[", "\[Gamma]", "]"}]}], ")"}], " ", 
     RowBox[{"Gamma", "[", 
      FractionBox["d", "2"], "]"}], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Alpha]"}], "+", "\[Beta]", "+", "\[Gamma]", "-", 
       "d"}], "]"}]}], ")"}]}]}]], "Input"],

Cell["(2.65)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TAIS", "[", 
   RowBox[{"d_", ",", "0", ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"1", ",", "M_"}], "}"}], "}"}]}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"-", "I"}], "  ", 
   SuperscriptBox["M", "2"], "  ", "SMu", " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", "-", "d"}], ")"}], "/", "2"}], "-", "1"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TBIS", "[", 
    RowBox[{"d_", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Alpha]_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Beta]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", "0"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBIS", "[", 
   RowBox[{"d_", ",", 
    RowBox[{"Power", "[", 
     RowBox[{"M_", ",", " ", "2"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]_", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]_", ",", "0"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"I", " "}], "SMu", " ", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"\[Alpha]", "+", "\[Beta]"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", " ", 
          SuperscriptBox["M", "2"]}], ")"}], 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "2"}]]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "Pi", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"d", "-", "4"}], ")"}], "/", "2"}]}], "]"}], " ", 
      FractionBox[
       RowBox[{"Gamma", "[", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"d", "/", "2"}]}], "]"}], 
       RowBox[{
        RowBox[{"Gamma", "[", "\[Alpha]", "]"}], 
        RowBox[{"Gamma", "[", "\[Beta]", "]"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{"Gamma", "[", 
         RowBox[{
          RowBox[{"d", "/", "2"}], "-", "\[Alpha]"}], "]"}], 
        RowBox[{"Gamma", "[", 
         RowBox[{
          RowBox[{"d", "/", "2"}], "-", "\[Beta]"}], "]"}]}], 
       RowBox[{"Gamma", "[", 
        RowBox[{"d", "-", "\[Alpha]", "-", "\[Beta]"}], "]"}]]}], ")"}]}], 
   "\n"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJIS", "[", 
   RowBox[{"d_Symbol", ",", 
    SuperscriptBox["M_", "2"], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "M_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "M_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["M", "2"], " ", 
   SuperscriptBox["SMu", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["6", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", "d"}], ")"}], "2"]]}], "+", 
     FractionBox["17", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "d"}], ")"}]}]], "+", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "59"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "d"}], ")"}], "3"], " ", "TJI111e"}], "+", 
     RowBox[{
      FractionBox["1", "1920"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "d"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"16755", "-", 
          RowBox[{"4750", " ", 
           SuperscriptBox["\[Pi]", "2"]}], "-", 
          RowBox[{"14", " ", 
           SuperscriptBox["\[Pi]", "4"]}], "+", 
          RowBox[{"3840", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Log", "[", "2", "]"}]}], "-", 
          RowBox[{"12080", " ", 
           RowBox[{"Zeta", "[", "3", "]"}]}]}], ")"}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "96"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "4"}], "+", "d"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"195", "+", 
        RowBox[{"98", " ", 
         SuperscriptBox["\[Pi]", "2"]}], "-", 
        RowBox[{"48", " ", 
         RowBox[{"Zeta", "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TComment", "Subsection",
 CellTags->"T1.7.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$CommentNotebook", "=", "True"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TComment", "[", 
   RowBox[{"s_String", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"\[InvisibleSpace]", 
         RowBox[{"!", 
          RowBox[{"(", 
           RowBox[{"ValueQ", "[", "$TarcerRecursed", "]"}], ")"}]}]}], ",", 
        RowBox[{"$TarcerRecursed", "=", 
         RowBox[{"{", "}"}]}]}], "]"}], ";", 
      RowBox[{"\[InvisibleSpace]", 
       RowBox[{"!", 
        RowBox[{"(", 
         RowBox[{"MemberQ", "[", 
          RowBox[{"$TarcerRecursed", ",", 
           RowBox[{"{", 
            RowBox[{"s", ",", "b"}], "}"}]}], "]"}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"AppendTo", "[", 
       RowBox[{"$TarcerRecursed", ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "b"}], "}"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"$Notebooks", "&&", 
         RowBox[{"$CommentNotebook", "===", "True"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$commentnb", "===", "False"}], ",", 
          RowBox[{
           RowBox[{"$commentnb", "=", "True"}], ";", 
           RowBox[{"$cnb", "=", 
            RowBox[{"NotebookCreate", "[", 
             RowBox[{
              RowBox[{
              "StyleDefinitions", "\[Rule]", "\"\<NaturalColor.nb\>\""}], ",", 
              RowBox[{"Magnification", "\[Rule]", "1.5"}]}], "]"}]}], ";", 
           RowBox[{"SetOptions", "[", 
            RowBox[{"$cnb", ",", 
             RowBox[{"WindowMargins", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "Automatic"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"Automatic", ",", "0"}], "}"}]}], "}"}]}]}], "]"}], 
           ";", 
           RowBox[{"SetOptions", "[", 
            RowBox[{"$cnb", ",", 
             RowBox[{"WindowSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"500", ",", "300"}], "}"}]}]}], "]"}], ";", 
           RowBox[{"NotebookWrite", "[", 
            RowBox[{"$cnb", ",", 
             RowBox[{"Cell", "[", 
              RowBox[{
               RowBox[{"BoxData", "[", 
                RowBox[{"ToBoxes", "[", 
                 RowBox[{
                  RowBox[{"b", "/.", 
                   RowBox[{"TFIC", "\[Rule]", "TFI"}]}], ",", 
                  "StandardForm"}], "]"}], "]"}], ",", "\"\<Input\>\"", ",", 
               RowBox[{"CellDingbat", "\[Rule]", 
                RowBox[{"s", "<>", "\"\< \>\""}]}]}], "]"}]}], "]"}]}], ",", 
          RowBox[{"NotebookWrite", "[", 
           RowBox[{"$cnb", ",", 
            RowBox[{"Cell", "[", 
             RowBox[{
              RowBox[{"BoxData", "[", 
               RowBox[{"ToBoxes", "[", 
                RowBox[{
                 RowBox[{"b", "/.", 
                  RowBox[{"TFIC", "\[Rule]", "TFI"}]}], ",", "StandardForm"}],
                 "]"}], "]"}], ",", "\"\<Input\>\"", ",", 
              RowBox[{"CellDingbat", "\[Rule]", 
               RowBox[{"s", "<>", "\"\< \>\""}]}]}], "]"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"Print", "[", 
         RowBox[{"s", ",", 
          RowBox[{"b", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"TFIC", "\[RuleDelayed]", "TFI"}], ",", 
             RowBox[{"TVIC", "\[RuleDelayed]", "TVI"}], ",", 
             RowBox[{"TJIC", "\[RuleDelayed]", "TJI"}], ",", 
             RowBox[{"TBIC", "\[RuleDelayed]", "TBI"}], ",", 
             RowBox[{"TAIC", "\[RuleDelayed]", "TAI"}]}], "}"}]}]}], "]"}]}], 
       "]"}]}]}], "]"}], "/;", 
   RowBox[{"$Comment", "===", "True"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$TTable", "Subsection",
 CellTags->"$TTable"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TTable", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarcerRecurse", "Subsection",
 CellTags->"T1.7.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FEPrint", "[", "a__String", "]"}], ":=", 
   RowBox[{
    RowBox[{"Print", "[", "a", "]"}], " ", "/;", " ", 
    RowBox[{"$Notebooks", "===", "False"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FEPrint", "[", "a__String", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Head", "[", "$cnb", "]"}], "===", "NotebookObject"}], ",", 
      "\n", "\t\t", 
      RowBox[{
       RowBox[{"NotebookWrite", "[", 
        RowBox[{"$cnb", ",", 
         RowBox[{"Cell", "[", 
          RowBox[{
           RowBox[{"StringJoin", "@@", 
            RowBox[{"{", "a", "}"}]}], ",", "\"\<SmallText\>\""}], "]"}]}], 
        "]"}], ";", "\n", "\t", 
       RowBox[{"SelectionMove", "[", 
        RowBox[{"$cnb", ",", "After", ",", "Cell"}], "]"}]}]}], "]"}], "/;", 
    RowBox[{"$Notebooks", "===", "True"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "TarcerRecurse", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Factor", "\[Rule]", "Factor"}], ",", 
     RowBox[{"TimeConstraint", "->", "Infinity"}], ",", 
     RowBox[{"Table", ":>", "$TTable"}], ",", 
     RowBox[{"Together", "->", "Together"}], ",", 
     RowBox[{"Replace", "->", 
      RowBox[{"{", "}"}]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TarcerRecurse", "[", 
    RowBox[{"z_", ",", "opts___"}], "]"}], ":=", 
   RowBox[{"Catch", "[", 
    RowBox[{
     StyleBox["Block",
      FontSize->16,
      FontWeight->"Bold",
      FontColor->RGBColor[1, 0.2, 0.2]], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "basisdone", ",", "factorfun", ",", "fertig", ",", "dummm1", ",", 
        "dummm2", ",", "getvars", ",", "te", ",", "time", ",", "cutoff", ",", 
        "tog", ",", "ttable", ",", "facfun", ",", "nexp", ",", "oldexpr", ",",
         "rec", ",", "special", ",", "sti", ",", "tl", ",", "tcheck", ",", 
        "tjrd", ",", "tvrd", ",", "together", ",", "vars", ",", 
        RowBox[{"$cc", "=", "0"}], ",", "$cv"}], "}"}], ",", "\n", "\t\t\t", 
      RowBox[{
       RowBox[{"time", " ", "=", " ", 
        RowBox[{"AbsoluteTime", "[", "]"}]}], ";", "\n", "\t\t\t", 
       RowBox[{"ttable", "=", 
        RowBox[{
         RowBox[{"Table", "/.", 
          RowBox[{"{", "opts", "}"}]}], "/.", 
         RowBox[{"Options", "[", "TarcerRecurse", "]"}]}]}], ";", "\n", 
       "\t\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"MatchQ", "[", 
           RowBox[{"ttable", ",", 
            RowBox[{"{", "__RuleDelayed", "}"}]}], "]"}]}], ",", 
         RowBox[{"ttable", "=", 
          RowBox[{"{", "}"}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"special", "=", 
        RowBox[{
         RowBox[{"Replace", "/.", 
          RowBox[{"{", "opts", "}"}]}], "/.", 
         RowBox[{"Options", "[", "TarcerRecurse", "]"}]}]}], ";", "\n", 
       "\t\t\t", 
       RowBox[{"cutoff", "=", 
        RowBox[{
         RowBox[{"TimeConstraint", "/.", 
          RowBox[{"{", "opts", "}"}]}], "/.", 
         RowBox[{"Options", "[", "TarcerRecurse", "]"}]}]}], ";", "\n", 
       "\t\t\t", 
       RowBox[{"together", "=", 
        RowBox[{
         RowBox[{"Together", "/.", 
          RowBox[{"{", "opts", "}"}]}], "/.", 
         RowBox[{"Options", "[", "TarcerRecurse", "]"}]}]}], ";", 
       RowBox[{"factorfun", "=", 
        RowBox[{
         RowBox[{"Factor", "/.", 
          RowBox[{"{", "opts", "}"}]}], "/.", 
         RowBox[{"Options", "[", "TarcerRecurse", "]"}]}]}], ";", 
       RowBox[{"$commentnb", "=", "False"}], ";", 
       RowBox[{"tog", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"#1", ">", "1001"}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{"$Comment", ",", 
                  RowBox[{"FEPrint", "[", 
                   RowBox[{
                    RowBox[{"\"\<coefficient # \>\"", "<>", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ValueQ", "[", "$cv", "]"}], ",", 
                    RowBox[{"ToString", "[", "$cc", "]"}], ",", "\"\<\>\""}], 
                    "]"}], "<>", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ValueQ", "[", "$cv", "]"}], ",", 
                    RowBox[{"\"\< (\>\"", "<>", 
                    RowBox[{"ToString", "[", "$cv", "]"}], "<>", 
                    "\"\<)\>\""}], ",", "\"\<\>\""}], "]"}], "<>", 
                    "\"\< simplified, \>\""}], ",", 
                    RowBox[{"ToString", "[", "#1", "]"}]}], "]"}]}], "]"}]}], 
               "]"}], ";", "#2"}], ")"}], "&"}], ")"}], "[", 
          RowBox[{
           RowBox[{"LeafCount", "[", "#1", "]"}], ",", 
           RowBox[{
            RowBox[{"$cc", "++"}], ";", 
            RowBox[{"together", "[", "#1", "]"}]}]}], "]"}], "&"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"\[InvisibleSpace]", 
          RowBox[{"!", 
           RowBox[{"(", 
            RowBox[{"ValueQ", "[", "$TarcerRecursed", "]"}], ")"}]}]}], ",", 
         RowBox[{"$TarcerRecursed", "=", 
          RowBox[{"{", "}"}]}]}], "]"}], ";", 
       RowBox[{"$TarcerRecursed", "=", 
        RowBox[{"{", "}"}]}], ";", 
       RowBox[{"If", "[", "\[InvisibleSpace]", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"(", 
           RowBox[{"MemberQ", "[", 
            RowBox[{
            "$ContextPath", ",", "\"\<HighEnergyPhysics`fcloops`ToTFi`\>\""}],
             "]"}], ")"}]}], ",", 
         RowBox[{"t0", "=", "z"}], ",", 
         RowBox[{"t0", "=", 
          RowBox[{
           RowBox[{"HighEnergyPhysics`fcloops`ToTFi`ToTFi", "[", "z", "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"HighEnergyPhysics`fcloops`TFi`TFi", "\[RuleDelayed]", 
              StyleBox["TFI",
               FontColor->RGBColor[1, 0.6, 0]]}], ",", 
             RowBox[{
             "HighEnergyPhysics`fcloops`ToTFi`ToTFi", "\[RuleDelayed]", 
              "Identity"}]}], "}"}]}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"ttable", "=!=", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"t0", "=", 
          RowBox[{"t0", "/.", "ttable"}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"getvars", "=", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Variables", "[", "#1", "]"}], ",", 
           RowBox[{
            RowBox[{"MatchQ", "[", 
             RowBox[{"#1", ",", 
              RowBox[{
               RowBox[{
                StyleBox["TFI",
                 FontColor->RGBColor[1, 0.6, 0]], "[", "__", "]"}], "|", 
               RowBox[{
                StyleBox["TVI",
                 FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "__", "]"}], "|", 
               RowBox[{"TJI", "[", "__", "]"}], "|", 
               RowBox[{"TBI", "[", "__", "]"}], "|", 
               RowBox[{"TAI", "[", "__", "]"}]}]}], "]"}], "&"}]}], "]"}], 
         "&"}]}], ";", "\n", "\t\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"FreeQ", "[", 
           RowBox[{"t0", ",", "TFI"}], "]"}]}], ",", 
         RowBox[{"t0", "=", 
          RowBox[{"Collect", "[", 
           RowBox[{
            RowBox[{"t0", "=", 
             RowBox[{
              RowBox[{"TFIRecurse", "[", "t0", "]"}], "/.", "ttable"}]}], ",", 
            RowBox[{"getvars", "[", "t0", "]"}], ",", "tog"}], "]"}]}]}], 
        "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"FreeQ", "[", 
           RowBox[{"t0", ",", 
            RowBox[{"TVI", "[", 
             RowBox[{"_Plus", ",", "__"}], "]"}]}], "]"}]}], ",", "\n", 
         "\t\t\t", 
         RowBox[{
          RowBox[{"tvrd", "=", 
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"DownValues", "[", "TVR", "]"}], ",", 
              RowBox[{
               RowBox[{"!", 
                RowBox[{"FreeQ", "[", 
                 RowBox[{"#", ",", 
                  RowBox[{"TVI", "[", 
                   RowBox[{
                    RowBox[{"_", "-", "2"}], ",", "__"}], "]"}]}], "]"}]}], 
               "&"}]}], "]"}], "/.", 
            RowBox[{"TVR", "->", "TVI"}]}]}], ";", "\n", "\t\t\t\t", 
          RowBox[{"t0", "=", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"t0", "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"t0", "/.", "tvrd"}], "/.", "tvrd"}], "/.", "tvrd"}],
                "/.", "tvrd"}]}], ",", 
             RowBox[{"getvars", "[", "t0", "]"}], ",", "tog"}], "]"}]}], ";", 
          "\n", "\t\t\t\t", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"FreeQ", "[", 
              RowBox[{"t0", ",", 
               RowBox[{"TVI", "[", 
                RowBox[{"_Plus", ",", "__"}], "]"}]}], "]"}]}], ",", "\t", 
            RowBox[{"t0", "=", 
             RowBox[{"Collect", "[", 
              RowBox[{
               RowBox[{"t0", "=", 
                RowBox[{"t0", "//.", "tvrd"}]}], ",", 
               RowBox[{"getvars", "[", "t0", "]"}], ",", "tog"}], "]"}]}]}], 
           "]"}]}]}], "]"}], ";", "\n", "\t\t\t\t", "\n", "\t\t\t", 
       RowBox[{"tjrd", "=", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"DownValues", "[", "TJR", "]"}], ",", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"FreeQ", "[", 
              RowBox[{"#", ",", 
               RowBox[{"TJI", "[", 
                RowBox[{
                 RowBox[{"_", "-", "2"}], ",", "__"}], "]"}]}], "]"}]}], 
            "&"}]}], "]"}], "/.", 
         RowBox[{"TJR", "->", "TJI"}]}]}], ";", "\n", "\t\t\t", "\n", 
       "\t\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"FreeQ", "[", 
           RowBox[{"t0", ",", 
            RowBox[{"TJI", "[", 
             RowBox[{"_Plus", ",", "__"}], "]"}]}], "]"}]}], ",", "\n", 
         "\t\t\t", 
         RowBox[{
          RowBox[{"tjrd", "=", 
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"DownValues", "[", "TJR", "]"}], ",", 
              RowBox[{
               RowBox[{"!", 
                RowBox[{"FreeQ", "[", 
                 RowBox[{"#", ",", 
                  RowBox[{"TJI", "[", 
                   RowBox[{
                    RowBox[{"_", "-", "2"}], ",", "__"}], "]"}]}], "]"}]}], 
               "&"}]}], "]"}], "/.", 
            RowBox[{"TJR", "->", "TJI"}]}]}], ";", "\n", "\t\t\t\t", 
          RowBox[{"t0", "=", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"t0", "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"t0", "/.", "tjrd"}], "/.", "tjrd"}], "/.", "tjrd"}],
                "/.", "tjrd"}]}], ",", 
             RowBox[{"getvars", "[", "t0", "]"}], ",", "tog"}], "]"}]}], ";", 
          "\n", "\t\t\t\t", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"FreeQ", "[", 
              RowBox[{"t0", ",", 
               RowBox[{"TJI", "[", 
                RowBox[{"_Plus", ",", "__"}], "]"}]}], "]"}]}], ",", "\t", 
            RowBox[{"t0", "=", 
             RowBox[{"Collect", "[", 
              RowBox[{
               RowBox[{"t0", "=", 
                RowBox[{"t0", "//.", "tjrd"}]}], ",", 
               RowBox[{"getvars", "[", "t0", "]"}], ",", "tog"}], "]"}]}]}], 
           "]"}]}]}], "]"}], ";", "\n", "\t\t\t", "\n", "\t\t\t", 
       RowBox[{
        RowBox[{"rec", "[", 
         RowBox[{"expr_", ",", 
          RowBox[{"{", 
           RowBox[{"ti_", ",", "tr_"}], "}"}]}], "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sti", "=", 
           RowBox[{"ToString", "[", "ti", "]"}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"FreeQ", "[", 
             RowBox[{"expr", ",", "ti"}], "]"}], ",", "expr", ",", 
            RowBox[{
             RowBox[{"nexp", "=", "expr"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{"$Comment", ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"#1", "===", "1"}], ",", 
                    RowBox[{"FEPrint", "[", 
                    RowBox[{
                    "sti", "<>", "\"\< level, there is 1 \>\"", "<>", "sti"}],
                     "]"}], ",", 
                    RowBox[{"FEPrint", "[", 
                    RowBox[{
                    RowBox[{"sti", "<>", "\"\< level, there are \>\""}], ",", 
                    
                    RowBox[{"ToString", "[", "#1", "]"}], ",", 
                    RowBox[{"\"\< \>\"", "<>", "sti", "<>", "\"\<'s \>\""}]}],
                     "]"}]}], "]"}], "&"}], ")"}], "[", 
                RowBox[{"Count", "[", 
                 RowBox[{"nexp", ",", 
                  RowBox[{"ti", "[", "__", "]"}], ",", 
                  RowBox[{"-", "1"}]}], "]"}], "]"}]}], "]"}], ";", "\n", 
             "\t\t\t\t", "\n", "\t\t\t\t\t\t", 
             RowBox[{"nexp", "=", 
              RowBox[{
               RowBox[{"nexp", "/.", 
                RowBox[{"ti", "\[Rule]", "tr"}]}], "/.", 
               RowBox[{"tr", "\[Rule]", "ti"}]}]}], ";", "\n", 
             "\t\t\t\t\t\t\t", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"!", 
                RowBox[{"FreeQ", "[", 
                 RowBox[{"nexp", ",", 
                  RowBox[{"TJI", "[", 
                   RowBox[{"_Plus", ",", "__"}], "]"}]}], "]"}]}], ",", 
               RowBox[{"nexp", "=", 
                RowBox[{"nexp", "//.", "tjrd"}]}]}], "]"}], ";", "\n", 
             "\t\t\t\t\t\t", "\n", "\t\t\t\t\t\t", 
             RowBox[{"tvars", "=", 
              RowBox[{"getvars", "[", "nexp", "]"}]}], ";", 
             RowBox[{"$cc", "=", "0"}], ";", 
             RowBox[{"$cv", "=", 
              RowBox[{"Length", "[", "tvars", "]"}]}], ";", 
             RowBox[{"nexp", "=", 
              RowBox[{"Collect", "[", 
               RowBox[{"nexp", ",", "tvars", ",", "tog"}], "]"}]}], ";", 
             "\[IndentingNewLine]", "\n", "\t\t\t\t\t\t", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"cutoff", "=!=", "Infinity"}], ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"AbsoluteTime", "[", "]"}], "-", "time"}], ">", 
                  "cutoff"}], ",", 
                 RowBox[{"Throw", "[", "$Failed", "]"}]}], "]"}]}], "]"}], 
             ";", "\n", "\t\t\t\t\t\t", "nexp"}]}], "]"}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"basisdone", "=", "0"}], ";", 
       RowBox[{"tl", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            StyleBox["TFI",
             FontColor->RGBColor[1, 0.6, 0]], ",", 
            StyleBox["TFR",
             FontColor->RGBColor[0, 0.6, 0]]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            StyleBox["TVI",
             FontColor->RGBColor[0.2, 0.4, 0.8]], ",", 
            StyleBox["TVR",
             FontColor->RGBColor[0.2, 0.8, 1]]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"TJI", ",", "TJR"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"TBI", ",", "TBR"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"TAI", ",", "TAR"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"t0", "=", " ", 
           RowBox[{"FixedPoint", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"rec", "[", 
               RowBox[{"#", ",", 
                RowBox[{"tl", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "&"}], ",", "t0", 
             ",", "100"}], "]"}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Head", "[", "t0", "]"}], "===", "Plus"}], ",", 
            RowBox[{
             RowBox[{"fertig", "=", 
              RowBox[{"Select", "[", 
               RowBox[{"t0", ",", 
                RowBox[{"\[InvisibleSpace]", 
                 RowBox[{"!", 
                  RowBox[{"(", 
                   RowBox[{"FreeQ", "[", 
                    RowBox[{"#1", ",", 
                    RowBox[{"tl", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    "]"}], ")"}]}]}]}], "]"}]}], ";", 
             RowBox[{"basisdone", "=", 
              RowBox[{"basisdone", "+", "fertig"}]}], ";", 
             RowBox[{"t0", "=", 
              RowBox[{"t0", "-", "fertig"}]}]}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "tl", "]"}]}], "}"}]}], "]"}], ";", 
       RowBox[{"t0", "=", 
        RowBox[{"t0", "+", "basisdone"}]}], ";", 
       RowBox[{"$cv", "=", "."}], ";", 
       RowBox[{"t0", "=", 
        RowBox[{"Collect", "[", 
         RowBox[{"t0", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"TAI", "[", "__", "]"}], ",", 
            RowBox[{
             RowBox[{"TAI", "[", "a1__", "]"}], " ", 
             RowBox[{"TAI", "[", "a2__", "]"}]}], ",", 
            RowBox[{"TAI", "[", "__", "]"}], ",", 
            RowBox[{"TBI", "[", "__", "]"}], ",", 
            RowBox[{"TJI", "[", "__", "]"}], ",", 
            RowBox[{"TVI", "[", "__", "]"}], ",", 
            RowBox[{"TFI", "[", "__", "]"}]}], "}"}], ",", "factorfun"}], 
         "]"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{"$Comment", ",", 
         RowBox[{"FEPrint", "[", 
          RowBox[{"\"\<the result has \>\"", ",", 
           RowBox[{"ToString", "[", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"t0", "+", "dummm1", "+", "dummm2"}], "]"}], "-", "2"}],
             "]"}], ",", "\"\< terms\>\""}], "]"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{"$Notebooks", ",", 
         RowBox[{"SetSelectedNotebook", "[", 
          RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], "]"}], ";", 
       "t0"}]}], "]"}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarcerExpand", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.8.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "TarcerExpand", "]"}], "=", 
   RowBox[{"{", "\n", "\t\t", 
    RowBox[{
     RowBox[{"TarcerReduce", ":>", "$BasisIntegrals"}], ",", "\n", "\t", 
     RowBox[{"TarcerRecurse", "->", "False"}], ",", 
     RowBox[{"Zeta", "->", "True"}], ",", 
     RowBox[{"Replace", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Prefactor1", "\[Rule]", "Identity"}], ",", 
        RowBox[{"EulerGamma", " ", "\[Rule]", "0"}]}], "}"}]}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TarcerExpand", "[", 
    RowBox[{"expr_", ",", 
     RowBox[{"d_Symbol", "->", 
      RowBox[{"fe_", "/;", 
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"Variables", "[", "fe", "]"}], "]"}], "===", "1"}]}]}], ",", 
     "ru___Rule"}], "]"}], ":=", 
   RowBox[{"TarcerExpand", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"d", " ", "->", "fe"}], ",", "0", ",", "ru"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TarcerExpand", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"d_Symbol", "\[Rule]", "fe_"}], ",", 
    RowBox[{"order_Integer", "?", "NonNegative"}], ",", "opts___Rule"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{
    StyleBox["Block",
     FontSize->16,
     FontWeight->"Bold",
     FontColor->RGBColor[1, 0.2, 0.2]], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "t4", ",", "numfa", ",", "z2rule", ",",
        "restfa", ",", "ta0", ",", "tarcNumericalFactor", ",", "tarcFactor1", 
       ",", "eeps"}], 
      RowBox[{"(*", 
       RowBox[{",", "extracoll"}], "*)"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{"eeps", "=", 
       RowBox[{
        RowBox[{"Variables", "[", "fe", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tarcNumericalFactor", "[", "x_", "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"NumberQ", "[", "x", "]"}], ",", "x", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "x", "]"}], "===", "Times"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"NumberQ", "[", 
              RowBox[{"First", "[", "x", "]"}], "]"}], ",", 
             RowBox[{"First", "[", "x", "]"}], ",", "1"}], "]"}], ",", "1"}], 
          "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{
       RowBox[{"tarcFactor1", "[", "x_", "]"}], ":=", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "factor1t1", ",", "factor1t2", ",", "factor1t3", ",", "mt", ",", 
           "mi", ",", "m1", ",", "mp1", ",", 
           RowBox[{"nx", "=", "x"}], ",", "iIii"}], "}"}], ",", 
         RowBox[{
          RowBox[{"mt", "=", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"#1", "/.", "\[InvisibleSpace]", 
                 RowBox[{"Plus", "\[Rule]", "mi"}]}], "/.", 
                "\[InvisibleSpace]", 
                RowBox[{"mi", "\[Rule]", "Plus"}]}], "/.", 
               "\[InvisibleSpace]", 
               RowBox[{"m1", "\[Rule]", 
                RowBox[{"-", "1"}]}]}], "/.", "\[InvisibleSpace]", 
              RowBox[{"mp1", "\[Rule]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"+", "##1"}], ")"}]}], "&"}], ")"}]}]}], "/.", 
             "\[InvisibleSpace]", 
             RowBox[{"iIii", "\[Rule]", "\[ImaginaryI]"}]}], "&"}]}], ";", 
          RowBox[{
           RowBox[{"mi", "[", 
            RowBox[{"y_", ",", "z__"}], "]"}], ":=", 
           RowBox[{
            RowBox[{"m1", " ", 
             RowBox[{"mp1", "[", 
              RowBox[{"y", ",", "z"}], "]"}]}], "/;", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Head", "[", "#1", "]"}], "===", "Complex"}], ",", 
                 "False", ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"#1", "<", "0"}], ",", "True", ",", "False"}], 
                  "]"}]}], "]"}], "&"}], ")"}], "[", 
             RowBox[{"tarcNumericalFactor", "[", "y", "]"}], "]"}]}]}], ";", 
          RowBox[{"nx", "=", 
           RowBox[{"x", "/.", "\[InvisibleSpace]", 
            RowBox[{
             RowBox[{"Complex", "[", 
              RowBox[{"0", ",", "b_"}], "]"}], "\[Rule]", 
             RowBox[{"b", " ", "iIii"}]}]}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Head", "[", "nx", "]"}], "=!=", "Plus"}], ",", 
            RowBox[{"mt", "[", 
             RowBox[{"nx", "/.", "\[InvisibleSpace]", 
              RowBox[{"Plus", "\[Rule]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Factor1", "[", 
                  RowBox[{"+", "##1"}], "]"}], "&"}], ")"}]}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"factor1t1", "=", 
              RowBox[{"List", "@@", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"#1", "/.", "\[InvisibleSpace]", 
                   RowBox[{"Plus", "\[Rule]", "factor1t3"}]}], "&"}], ")"}], "/@",
                 "nx"}]}]}], ";", 
             RowBox[{"factor1t2", "=", 
              RowBox[{
               RowBox[{"PolynomialGCD", "@@", "factor1t1"}], "/.", 
               "\[InvisibleSpace]", 
               RowBox[{"factor1t3", "\[Rule]", "Plus"}]}]}], ";", 
             RowBox[{"mt", "[", 
              RowBox[{"factor1t2", " ", 
               RowBox[{"Plus", "@@", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox[
                    RowBox[{"#1", "/.", "\[InvisibleSpace]", 
                    RowBox[{"factor1t3", "\[Rule]", "Plus"}]}], "factor1t2"], 
                   "&"}], ")"}], "/@", "factor1t1"}]}]}], "]"}]}]}], 
           "]"}]}]}], "]"}]}], ";", 
      RowBox[{"Catch", "[", 
       RowBox[{
        RowBox[{"e", "=", "eeps"}], ";", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ints", ",", "recurse", ",", "zeta2replace"}], "}"}], "=", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"TarcerReduce", ",", "TarcerRecurse", ",", "Zeta"}], "}"}],
           "/.", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"opts", ",", 
             RowBox[{"Options", "[", "TarcerExpand", "]"}]}], "}"}], 
           "]"}]}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"zeta2replace", "=!=", "True"}], "&&", 
           RowBox[{"MemberQ", "[", 
            RowBox[{
            "$ContextPath", ",", "\"\<HighEnergyPhysics`general`Zeta2`\>\""}],
             "]"}]}], ",", 
          RowBox[{"z2rule", "=", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{"z2rule", "=", 
           RowBox[{
            SuperscriptBox["\[Pi]", "2"], "\[RuleDelayed]", 
            RowBox[{"6", " ", 
             RowBox[{
             "ToExpression", "[", 
              "\"\<HighEnergyPhysics`general`Zeta2`Zeta2\>\"", "]"}]}]}]}]}], 
         "]"}], ";", 
        RowBox[{"ints", "=", 
         RowBox[{"Flatten", "[", "ints", "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"recurse", "=!=", "True"}], ",", 
          RowBox[{"ta0", "=", "expr"}], ",", 
          RowBox[{"ta0", "=", 
           RowBox[{"TarcerRecurse", "[", "expr", "]"}]}]}], "]"}], ";", 
        RowBox[{"t1", "=", 
         RowBox[{
          RowBox[{"ta0", "/.", "ints"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"SEpsilon", "[", "de_", "]"}], "\[RuleDelayed]", 
             RowBox[{"SEpsilon", "[", 
              RowBox[{"ToString", "[", "d", "]"}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Prefactor1", "[", "de_", "]"}], "\[RuleDelayed]", 
             RowBox[{"Prefactor1", "[", " ", 
              RowBox[{"ToString", "[", 
               RowBox[{"de", ",", "InputForm"}], "]"}], "]"}]}]}], 
           "\[IndentingNewLine]", "}"}]}]}], ";", 
        RowBox[{"vars", "=", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{"Variables", "[", "t1", "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "#1", "]"}], ">", "0"}], "&"}]}], "]"}]}],
         ";", 
        RowBox[{"If", "[", "\[InvisibleSpace]", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"(", 
            RowBox[{"FreeQ", "[", 
             RowBox[{"vars", ",", 
              RowBox[{
               StyleBox["TFI",
                FontColor->RGBColor[1, 0.6, 0]], "|", 
               StyleBox["TVI",
                FontColor->RGBColor[0.2, 0.4, 0.8]], "|", "TJI", "|", "TKI", 
               "|", "TBI", "|", "TAI"}]}], "]"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{
           "Print", "[", "\"\<Returning the list of remaining integrals.\>\"",
             "]"}], ";", 
           RowBox[{"Throw", "[", 
            RowBox[{"Select", "[", 
             RowBox[{"vars", ",", "\[InvisibleSpace]", 
              RowBox[{
               RowBox[{"!", 
                RowBox[{"(", 
                 RowBox[{"FreeQ", "[", 
                  RowBox[{"#1", ",", 
                   RowBox[{
                    StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "|", 
                    StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "|", "TJI", "|", 
                    "TKI", "|", "TBI", "|", "TAI"}]}], "]"}], ")"}]}], 
               "&"}]}], "]"}], "]"}]}]}], "]"}], ";", 
        RowBox[{"t1", "=", 
         RowBox[{"t1", "/.", 
          RowBox[{"d", "\[Rule]", "fe"}]}]}], ";", 
        RowBox[{
         RowBox[{"polygafu", "[", 
          RowBox[{"2", ",", "1"}], "]"}], "=", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"Zeta", "[", "3", "]"}]}]}], ";", 
        RowBox[{
         RowBox[{"polygafu", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "=", 
         RowBox[{"2", "-", 
          RowBox[{"2", " ", 
           RowBox[{"Zeta", "[", "3", "]"}]}]}]}], ";", 
        RowBox[{
         RowBox[{"polygafu", "[", 
          RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
         RowBox[{
          RowBox[{"polygafu", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "=", 
          RowBox[{"FunctionExpand", "[", 
           RowBox[{"PolyGamma", "[", 
            RowBox[{"x", ",", "y"}], "]"}], "]"}]}]}], ";", 
        RowBox[{"t2", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Normal", "[", 
            RowBox[{"t1", "+", 
             SuperscriptBox[
              RowBox[{"O", "[", "e", "]"}], 
              RowBox[{"order", "+", "1"}]]}], "]"}], "/.", 
           RowBox[{"PolyGamma", "\[Rule]", "polygafu"}]}], "/.", 
          "\[IndentingNewLine]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Replace", "/.", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "TarcerExpand", "]"}]}], ")"}]}]}], ";", 
        RowBox[{"t3", "=", 
         RowBox[{"Collect", "[", 
          RowBox[{"t2", ",", "e", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Expand", "[", "#1", "]"}], "/.", "z2rule"}], ")"}], 
            "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"t3", "=", 
         RowBox[{"t2", "/.", 
          RowBox[{
           RowBox[{"ToString", "[", "d", "]"}], "\[RuleDelayed]", 
           RowBox[{"(", "fe", ")"}]}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Global`T3", "=", "t3"}], ";"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"t4", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"tarcFactor1", "[", 
               RowBox[{"Expand", "[", "t3", "]"}], "]"}], "//.", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"pre", ":", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"Prefactor1", "|", "SEpsilon"}], ")"}], "[", "a_",
                    "]"}], " ", 
                  RowBox[{"Prefactor1", "[", "b_", "]"}]}]}], ")"}], 
               "\[RuleDelayed]", 
               RowBox[{"Prefactor1", "[", 
                RowBox[{"a", " ", "b"}], "]"}]}]}], "/.", 
             RowBox[{
              RowBox[{"Prefactor1", "[", "1", "]"}], "\[RuleDelayed]", 
              "1"}]}], "/.", 
            RowBox[{
             RowBox[{"Prefactor1", "[", "xy_", "]"}], "\[RuleDelayed]", 
             RowBox[{"Prefactor1", "[", 
              RowBox[{"xy", "/.", 
               RowBox[{"st_String", "\[RuleDelayed]", 
                RowBox[{"ToExpression", "[", "st", "]"}]}]}], "]"}]}]}], "/.", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Prefactor1", "[", 
               RowBox[{
                RowBox[{"m_", "^", "e"}], " ", "xx_"}], "]"}], 
              RowBox[{"m_", "^", "any_"}]}], " ", ")"}], "\[RuleDelayed]", 
            RowBox[{"Prefactor1", "[", 
             RowBox[{
              RowBox[{"m", "^", 
               RowBox[{"(", 
                RowBox[{"e", "+", "any"}], ")"}]}], "xx"}], "]"}]}]}], "/.", 
          "z2rule"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Global`t4", "=", "t4"}], ";"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Head", "[", "t4", "]"}], "===", "Times"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"numfa", "=", 
               RowBox[{"tarcNumericalFactor", "[", "t4", "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"restfa", " ", "=", " ", 
               RowBox[{"Select", "[", 
                RowBox[{"t4", ",", 
                 RowBox[{
                  RowBox[{"FreeQ", "[", 
                   RowBox[{"#", ",", 
                    RowBox[{"eeps", "|", "Log", "|", "Zeta"}]}], "]"}], 
                  "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"Global`RR", "=", "restfa"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Global`NN", "=", "numfa"}], ";"}], "*)"}], 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"extracoll", "[", 
                RowBox[{"z_", ",", "e"}], "]"}], ":=", 
               RowBox[{"Block", "[", 
                RowBox[{
                 RowBox[{"{", "}"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Head", "[", "z", "]"}], "===", "Plus"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"extracoll", "[", 
                    RowBox[{"#", ",", "e"}], "]"}], "&"}], "/@", "z"}], ",", 
                   RowBox[{"z", "/.", 
                    RowBox[{"xy_Plus", "\[RuleDelayed]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", 
                    RowBox[{"Variables", "[", "xy", "]"}], "]"}], "===", 
                    "0"}], ",", "xy", ",", 
                    RowBox[{"Collect", "[", 
                    RowBox[{"xy", ",", 
                    RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"Variables", "[", "xy", "]"}], ",", 
                    RowBox[{"{", "e", "}"}]}], "]"}]}], "]"}]}], "]"}]}]}]}], 
                  "]"}]}], " ", "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"t4", ",", 
                   RowBox[{
                    RowBox[{"!", 
                    RowBox[{"FreeQ", "[", 
                    RowBox[{"#", ",", "Prefactor1"}], "]"}]}], "&"}]}], "]"}], 
                 RowBox[{"(", 
                  FractionBox["restfa", "numfa"], ")"}]}], ")"}], ".", 
               RowBox[{"extracoll", "[", " ", 
                RowBox[{
                 RowBox[{"Collect", "[", 
                  RowBox[{
                   RowBox[{"Expand", "[", 
                    FractionBox[
                    RowBox[{"numfa", "  ", 
                    RowBox[{"Select", "[", " ", 
                    RowBox[{"t4", ",", 
                    RowBox[{
                    RowBox[{"FreeQ", "[", 
                    RowBox[{"#", ",", "Prefactor1"}], "]"}], "&"}]}], "]"}]}], 
                    RowBox[{"restfa", " "}]], "]"}], ",", "e"}], "]"}], ",", 
                 "e"}], "]"}]}]}], ",", "t4"}], "]"}], "/.", 
           RowBox[{"s_String", "\[RuleDelayed]", 
            RowBox[{"ToExpression", "[", "s", "]"}]}]}], "/.", 
          RowBox[{"d", "\[Rule]", "fe"}]}], "/.", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Replace", "/.", 
            RowBox[{"{", "opts", "}"}]}], "/.", 
           RowBox[{"Options", "[", "TarcerExpand", "]"}]}], ")"}]}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Variables", "[", "fe", "]"}], "]"}], "===", "1"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct T's", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.9.1"],

Cell[CellGroupData[{

Cell["remember", "Subsection",
 CellTags->"T1.9.1.1"],

Cell["The function remember is not used by default.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tfch", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"TFR", ":>", 
      RowBox[{"Hold", "[", "TFR", "]"}]}], ",", 
     RowBox[{"TVR", ":>", 
      RowBox[{"Hold", "[", "TVR", "]"}]}], ",", 
     RowBox[{"TJR", ":>", 
      RowBox[{"Hold", "[", "TJR", "]"}]}], ",", 
     RowBox[{"TBR", ":>", 
      RowBox[{"Hold", "[", "TBR", "]"}]}], ",", 
     RowBox[{"TAR", ":>", 
      RowBox[{"Hold", "[", "TAR", "]"}]}], ",", 
     RowBox[{"TComment", ":>", 
      RowBox[{"Hold", "[", "TComment", "]"}]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rtfch", "=", 
   RowBox[{"Map", "[", 
    RowBox[{"Reverse", ",", "tfch"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"condrest", ",", "HoldRest"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "remember", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"remember", "[", "zi_HoldForm", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z", "=", 
       RowBox[{"zi", "/.", "tfch"}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"\[InvisibleSpace]", 
        RowBox[{"!", 
         RowBox[{"(", 
          RowBox[{"FreeQ", "[", 
           RowBox[{"z", ",", "Condition"}], "]"}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Hold", "[", "HoldForm", "]"}], "[", 
            RowBox[{
             RowBox[{"Hold", "[", "SetDelayed", "]"}], "[", 
             RowBox[{
              RowBox[{"z", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"ReplacePart", "[", 
               RowBox[{
                RowBox[{"z", "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"Prepend", "[", 
                 RowBox[{
                  RowBox[{"Extract", "[", 
                   RowBox[{"z", ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", "Hold"}], 
                   "]"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"z", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
                    
                    RowBox[{"PatternTest", "\[Rule]", "pt"}]}], "/.", 
                    RowBox[{
                    RowBox[{"pt", "[", 
                    RowBox[{"a_", ",", "b_"}], "]"}], "\[RuleDelayed]", 
                    "a"}]}], "/.", 
                    RowBox[{"Pattern", "\[Rule]", "pat"}]}], "/.", 
                   RowBox[{
                    RowBox[{"pat", "[", 
                    RowBox[{"a_", ",", "b_"}], "]"}], "\[RuleDelayed]", 
                    "a"}]}]}], "]"}], ",", "1"}], "]"}]}], "]"}], "]"}], "/.", 
           RowBox[{
            RowBox[{"Hold", "[", "HoldForm", "]"}], "\[Rule]", "HoldForm"}]}],
           "/.", "rtfch"}], "/.", 
         RowBox[{
          RowBox[{"Hold", "[", "SetDelayed", "]"}], "\[Rule]", 
          "SetDelayed"}]}], "/.", 
        RowBox[{"Hold", "\[Rule]", "Set"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Hold", "[", "HoldForm", "]"}], "[", 
            RowBox[{
             RowBox[{"Hold", "[", "SetDelayed", "]"}], "[", 
             RowBox[{
              RowBox[{"z", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"Prepend", "[", 
               RowBox[{
                RowBox[{"Extract", "[", 
                 RowBox[{"z", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}], ",", "Hold"}], "]"}], ",", 
                
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"z", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
                    
                    RowBox[{"PatternTest", "\[Rule]", "pt"}]}], "/.", 
                   RowBox[{
                    RowBox[{"pt", "[", 
                    RowBox[{"a_", ",", "b_"}], "]"}], "\[RuleDelayed]", 
                    "a"}]}], "/.", 
                  RowBox[{"Pattern", "\[Rule]", "pat"}]}], "/.", 
                 RowBox[{
                  RowBox[{"pat", "[", 
                   RowBox[{"a_", ",", "b_"}], "]"}], "\[RuleDelayed]", 
                  "a"}]}]}], "]"}]}], "]"}], "]"}], "/.", 
           RowBox[{
            RowBox[{"Hold", "[", "HoldForm", "]"}], "\[Rule]", "HoldForm"}]}],
           "/.", "rtfch"}], "/.", 
         RowBox[{
          RowBox[{"Hold", "[", "SetDelayed", "]"}], "\[Rule]", 
          "SetDelayed"}]}], "/.", 
        RowBox[{"Hold", "\[Rule]", "Set"}]}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData["$TarasovTdeltaplimit"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aa2", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "#"], "&"}], ",", " ", 
     RowBox[{"10000", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"$TarasovTdeltaplimit", "+", "1"}], ")"}], " ", "1000"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bb12", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"aa2", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Head", "[", "#", "]"}], "=!=", "Subscript"}], "&"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "aa2", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{"\"\<there are \>\"", ",", 
   RowBox[{"Length", "[", "bb12", "]"}], ",", 
   "\"\< recursion equations for $RankLimit = \>\"", ",", "$RankLimit"}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"there are \"\>", "\[InvisibleSpace]", "201", 
   "\[InvisibleSpace]", "\<\" recursion equations for $RankLimit = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5"}], "}"}]}],
  SequenceForm[
  "there are ", 201, " recursion equations for $RankLimit = ", {2, 5}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5008846342473907`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Global`$Remember", " ", "===", " ", "True"}], ",", 
    RowBox[{
     RowBox[{"Global`RCHECK", "=", "True"}], ";", " ", 
     RowBox[{"nb", " ", "=", 
      RowBox[{"Map", "[", 
       RowBox[{"remember", ",", "bb12"}], "]"}]}]}], ",", 
    RowBox[{"nb", "=", "bb12"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "bb12", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Unset", "[", "$Post", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ReleaseHold", "[", "nb", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Comment", "=", "False"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EndPackage", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"!", 
     RowBox[{
     "ValueQ", "[", "HighEnergyPhysics`FeynCalc`$FeynCalcDirectory", "]"}]}], 
    ",", 
    RowBox[{
    "BeginPackage", "[", "\"\<HighEnergyPhysics`general`Zeta2`\>\"", "]"}]}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Zeta2", "::", "usage"}], "=", "\n", 
   "\"\<Zeta2 denotes Zeta[2].\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Zeta2", " ", "/:", " ", 
   RowBox[{"N", "[", "Zeta2", "]"}], " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"Zeta", "[", "2", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Zeta2", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"Zeta2", ",", "fmt_"}], "]"}], ":=", 
   RowBox[{"InterpretationBox", "@@", 
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Zeta]\>\"", ",", "\"\<(\>\"", ",", "2", ",", "\"\<)\>\""}], 
        "}"}], "]"}], ",", "Zeta2", ",", 
      RowBox[{"Editable", "->", "False"}]}], "}"}]}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"EndPackage", "[", "]"}], ";"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["$BasisIntegrals", "Section",
 CellDingbat->"\[EmptySmallCircle]",
 CellTags->"T1.10.1"],

Cell["\<\
This is a (incomplete) set of basis integrals. You can add your favorite \
integrals here.\
\>", "Text"],

Cell["eta=Gamma[d/2-1]/Gamma[d-3]Gamma[3-d/2];", "Text"],

Cell[CellGroupData[{

Cell["\<\
$BasisIntegrals =
  {TAI[d_, 0, {{1, M_}}] -> 
    -I*E^(1/2*(4 - d)*EulerGamma)*M^2*
     Gamma[-1 + (4 - d)/2]*
     Prefactor1[(M^2)^(1/2*(-4 + d))*
       SEpsilon[d]], 
       
       TBI[d_, pp_, {{1, 0},{1, 0}}] -> 
   (I*E^(((4 - d)*EulerGamma)/2)*Gamma[2 - d/2]*
      Gamma[-1 + d/2]^2*
      Prefactor1[ (-pp)^((-4 + d)/2)*
        SEpsilon[d]])/Gamma[-2 + d],
        
        TJI[d_, pp_, {{1,0},{1,0},{1,0}}] ->-((pp*Gamma[3 - d]*Gamma[-1 + \
d/2]^3*
    E^((4 - d)*EulerGamma)*  Prefactor1[ 
        (-pp)^(-4 + d)*SEpsilon[d]^2])/
    (Gamma[-3 + (3*d)/2] )
),
    
          TJI[d_, M_^2, {{1,M_},{1,0},{1,0}}] ->(M^2*Gamma[3 - d]*Gamma[2 - \
d/2]*
    Gamma[-1 + d/2]^2*Gamma[-5 + 2*d]*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  (Gamma[-2 + d]*Gamma[-3 + (3*d)/2]),
  
  TJI[d_Symbol, (M_)^2, 
  {{1, M_}, {1, M_}, {1, M_}}]->M^2*Prefactor1[
    (M^2)^(-4 + d)*SEpsilon[d]^2]*
  (-6/(-4 + d)^2 + 17/(2*(-4 + d)) + 
    (-59 - 2*Pi^2)/8 + 
    (-4 + d)^3*TJI111e + 
    ((-4 + d)^2*(16755 - 4750*Pi^2 - 
         14*Pi^4 + 3840*Pi^2*Log[2] - 
         12080*Zeta[3]))/1920 + 
    ((-4 + d)*(195 + 98*Pi^2 - 
         48*Zeta[3]))/96),
         
         TJI[d_, 0, {{1, M_}, {1, M_}, {1, 0}}]->(M^2*Gamma[3 - d]*Gamma[2 - \
d/2]^2*
    Gamma[-1 + d/2]*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  (Gamma[4 - d]*Gamma[d/2]),
  
  TJI[d_, 0, {{1,M_},{1,0},{1,0}}] ->(M^2*Gamma[3 - d]*Gamma[2 - d/2]*
    Gamma[-1 + d/2]^2*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  Gamma[d/2]
        }\
\>", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["A",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      FormBox[
       RowBox[{"{", 
        RowBox[{"1", ",", "M_"}], "}"}],
       TraditionalForm], 
      RowBox[{"(", 
       FormBox["d_",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TAI[
      Pattern[$CellContext`d, 
       Blank[]], 0, {{1, 
        Pattern[$CellContext`M, 
         Blank[]]}}],
     Editable->True], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", "d"}], ")"}], " ", "EulerGamma"}]], " ", 
     SuperscriptBox["M", "2"], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       FractionBox[
        RowBox[{"4", "-", "d"}], "2"]}], "]"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["M", "2"], ")"}], 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", "d"}], ")"}]}]], " ", 
        InterpretationBox[
         StyleBox[
          SubscriptBox["S", "Global`d"],
          FontWeight->"Bold"],
         HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
         Editable->False]}],
       HighEnergyPhysics`Tarcer`Prefactor1[($CellContext`M^2)^(
          Rational[1, 2] (-4 + $CellContext`d)) 
        HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]],
       Editable->False], ")"}]}]}], ",", 
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["B",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d_",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TBI[
      Pattern[$CellContext`d, 
       Blank[]], 
      Pattern[$CellContext`pp, 
       Blank[]], {{1, 0}, {1, 0}}],
     Editable->True], "\[Rule]", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", "d"}], ")"}], " ", "EulerGamma"}]], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "-", 
        FractionBox["d", "2"]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["d", "2"]}], "]"}], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "pp"}], ")"}], 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "d"}], ")"}]}]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["S", "Global`d"],
           FontWeight->"Bold"],
          HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
          Editable->False]}],
        HighEnergyPhysics`Tarcer`Prefactor1[(-$CellContext`pp)^(
           Rational[1, 2] (-4 + $CellContext`d)) 
         HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]],
        Editable->False], ")"}]}], 
     RowBox[{"Gamma", "[", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "d"}], "]"}]]}], ",", 
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d_",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TJI[
      Pattern[$CellContext`d, 
       Blank[]], 
      Pattern[$CellContext`pp, 
       Blank[]], {{1, 0}, {1, 0}, {1, 0}}],
     Editable->True], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "-", "d"}], ")"}], " ", "EulerGamma"}]], " ", "pp", 
       " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"3", "-", "d"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Gamma", "[", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          FractionBox["d", "2"]}], "]"}], "3"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "pp"}], ")"}], 
           RowBox[{
            RowBox[{"-", "4"}], "+", "d"}]], " ", 
          InterpretationBox[
           StyleBox[
            SubsuperscriptBox["S", "Global`d", "2"],
            FontWeight->"Bold"],
           HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
           Editable->False]}],
         HighEnergyPhysics`Tarcer`Prefactor1[(-$CellContext`pp)^(-4 + \
$CellContext`d) HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]^2],
         Editable->False], ")"}]}], 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        FractionBox[
         RowBox[{"3", " ", "d"}], "2"]}], "]"}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d_",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TJI[
      Pattern[$CellContext`d, 
       Blank[]], Pattern[$CellContext`M, 
        Blank[]]^2, {{1, 
        Pattern[$CellContext`M, 
         Blank[]]}, {1, 0}, {1, 0}}],
     Editable->True], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "-", "d"}], ")"}], " ", "EulerGamma"}]], " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"3", "-", "d"}], "]"}], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "-", 
        FractionBox["d", "2"]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["d", "2"]}], "]"}], "2"], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", "d"}]}], "]"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["M", "2"], ")"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "d"}]], " ", 
         InterpretationBox[
          StyleBox[
           SubsuperscriptBox["S", "Global`d", "2"],
           FontWeight->"Bold"],
          HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
          Editable->False]}],
        HighEnergyPhysics`Tarcer`Prefactor1[($CellContext`M^2)^(-4 + \
$CellContext`d) HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]^2],
        Editable->False], ")"}]}], 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "d"}], "]"}], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        FractionBox[
         RowBox[{"3", " ", "d"}], "2"]}], "]"}]}]]}], ",", 
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["J",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d_Symbol",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TJI[
      Pattern[$CellContext`d, 
       Blank[Symbol]], Pattern[$CellContext`M, 
        Blank[]]^2, {{1, 
        Pattern[$CellContext`M, 
         Blank[]]}, {1, 
        Pattern[$CellContext`M, 
         Blank[]]}, {1, 
        Pattern[$CellContext`M, 
         Blank[]]}}],
     Editable->True], "\[Rule]", 
    RowBox[{
     SuperscriptBox["M", "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["M", "2"], ")"}], 
         RowBox[{
          RowBox[{"-", "4"}], "+", "d"}]], " ", 
        InterpretationBox[
         StyleBox[
          SubsuperscriptBox["S", "Global`d", "2"],
          FontWeight->"Bold"],
         HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
         Editable->False]}],
       HighEnergyPhysics`Tarcer`Prefactor1[($CellContext`M^2)^(-4 + \
$CellContext`d) HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]^2],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["6", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", "d"}], ")"}], "2"]]}], "+", 
       FractionBox["17", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "d"}], ")"}]}]], "+", 
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "59"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Pi]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "d"}], ")"}], "3"], " ", "TJI111e"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", "d"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"16755", "-", 
           RowBox[{"4750", " ", 
            SuperscriptBox["\[Pi]", "2"]}], "-", 
           RowBox[{"14", " ", 
            SuperscriptBox["\[Pi]", "4"]}], "+", 
           RowBox[{"3840", " ", 
            SuperscriptBox["\[Pi]", "2"], " ", 
            RowBox[{"Log", "[", "2", "]"}]}], "-", 
           RowBox[{"12080", " ", 
            RowBox[{"Zeta", "[", "3", "]"}]}]}], ")"}]}], "1920"], "+", 
       RowBox[{
        FractionBox["1", "96"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", "d"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"195", "+", 
          RowBox[{"98", " ", 
           SuperscriptBox["\[Pi]", "2"]}], "-", 
          RowBox[{"48", " ", 
           RowBox[{"Zeta", "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["K",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d_",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TJI[
      Pattern[$CellContext`d, 
       Blank[]], 0, {{1, 
        Pattern[$CellContext`M, 
         Blank[]]}, {1, 
        Pattern[$CellContext`M, 
         Blank[]]}, {1, 0}}],
     Editable->True], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "-", "d"}], ")"}], " ", "EulerGamma"}]], " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"3", "-", "d"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{"2", "-", 
         FractionBox["d", "2"]}], "]"}], "2"], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        FractionBox["d", "2"]}], "]"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["M", "2"], ")"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "d"}]], " ", 
         InterpretationBox[
          StyleBox[
           SubsuperscriptBox["S", "Global`d", "2"],
           FontWeight->"Bold"],
          HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
          Editable->False]}],
        HighEnergyPhysics`Tarcer`Prefactor1[($CellContext`M^2)^(-4 + \
$CellContext`d) HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]^2],
        Editable->False], ")"}]}], 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"4", "-", "d"}], "]"}], " ", 
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}]}]]}], ",", 
   RowBox[{
    InterpretationBox[
     SubsuperscriptBox[
      StyleBox["K",
       SingleLetterItalics->False,
       FontWeight->"Bold"], 
      RowBox[{
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}],
        TraditionalForm]}], 
      RowBox[{"(", 
       FormBox["d_",
        TraditionalForm], ")"}]],
     HighEnergyPhysics`Tarcer`TJI[
      Pattern[$CellContext`d, 
       Blank[]], 0, {{1, 
        Pattern[$CellContext`M, 
         Blank[]]}, {1, 0}, {1, 0}}],
     Editable->True], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "-", "d"}], ")"}], " ", "EulerGamma"}]], " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"3", "-", "d"}], "]"}], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "-", 
        FractionBox["d", "2"]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["d", "2"]}], "]"}], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["M", "2"], ")"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "d"}]], " ", 
         InterpretationBox[
          StyleBox[
           SubsuperscriptBox["S", "Global`d", "2"],
           FontWeight->"Bold"],
          HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d],
          Editable->False]}],
        HighEnergyPhysics`Tarcer`Prefactor1[($CellContext`M^2)^(-4 + \
$CellContext`d) HighEnergyPhysics`Tarcer`SEpsilon[$CellContext`d]^2],
        Editable->False], ")"}]}], 
     RowBox[{"Gamma", "[", 
      FractionBox["d", "2"], "]"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.500884638817445*^9}]
}, Open  ]],

Cell["\<\
$BasisIntegrals = 
  {TAI[d_, 0, {{1, M_}}] :> 
    -I*E^(1/2*(4 - d)*EulerGamma)*M^2*
     Gamma[-1 + (4 - d)/2]*
     Prefactor1[(M^2)^(1/2*(-4 + d))*
       SEpsilon[d]], 
       
       TBI[d_, pp_, {{1, 0},{1, 0}}] :> 
   (I*E^(((4 - d)*EulerGamma)/2 - 
         I/2*(-4 + d)*Pi)*Gamma[2 - d/2]*
      Gamma[-1 + d/2]^2*
      Prefactor1[(pp)^((-4 + d)/2)*
        SEpsilon[d]])/Gamma[-2 + d],
        
        TJI[d_, pp_, {{1,0},{1,0},{1,0}}] :>-((pp*Gamma[3 - d]*Gamma[-1 + \
d/2]^3*
    E^((4 - d)*EulerGamma)*  Prefactor1[
        (pp)^(-4 + d)*SEpsilon[d]^2])/
    (E^(I*(-4 + d)*Pi)*Gamma[-3 + (3*d)/2])
),
    
          TJI[d_, M_^2, {{1,M_},{1,0},{1,0}}] :>(M^2*Gamma[3 - d]*Gamma[2 - \
d/2]*
    Gamma[-1 + d/2]^2*Gamma[-5 + 2*d]*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  (Gamma[-2 + d]*Gamma[-3 + (3*d)/2]),
  
  TJI[d_Symbol, (M_)^2, 
  {{1, M_}, {1, M_}, {1, M_}}]:>M^2*Prefactor1[
    (M^2)^(-4 + d)*SEpsilon[d]^2]*
  (-6/(-4 + d)^2 + 17/(2*(-4 + d)) + 
    (-59 - 2*Pi^2)/8 + 
    (-4 + d)^3*TJI111e + 
    ((-4 + d)^2*(16755 - 4750*Pi^2 - 
         14*Pi^4 + 3840*Pi^2*Log[2] - 
         12080*Zeta[3]))/1920 + 
    ((-4 + d)*(195 + 98*Pi^2 - 
         48*Zeta[3]))/96),
         
         TJI[d_, 0, {{1, M_}, {1, M_}, {1, 0}}]:>(M^2*Gamma[3 - d]*Gamma[2 - \
d/2]^2*
    Gamma[-1 + d/2]*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  (Gamma[4 - d]*Gamma[d/2]),
  
  TJI[d_, 0, {{1,M_},{1,0},{1,0}}] :>(M^2*Gamma[3 - d]*Gamma[2 - d/2]*
    Gamma[-1 + d/2]^2*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  Gamma[d/2]
        }\
\>", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["A",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       FormBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "M_"}], "}"}],
        TraditionalForm], 
       RowBox[{"(", 
        FormBox["d_",
         TraditionalForm], ")"}]],
      TAI[
       Pattern[d, 
        Blank[]], 0, {{1, 
         Pattern[M, 
          Blank[]]}}],
      Editable->True], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", "d"}], ")"}], " ", 
        TagBox["\[DoubledGamma]",
         Function[{}, EulerGamma]]}]], " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"\[CapitalGamma]", "(", 
       RowBox[{
        FractionBox[
         RowBox[{"4", "-", "d"}], "2"], "-", "1"}], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["M", "2"], ")"}], 
          FractionBox[
           RowBox[{"d", "-", "4"}], "2"]], " ", 
         InterpretationBox[
          StyleBox[
           SubscriptBox["S", "d"],
           FontWeight->"Bold"],
          SEpsilon[d],
          Editable->False]}],
        Prefactor1[(M^2)^(Rational[1, 2] (-4 + d)) SEpsilon[d]],
        Editable->False], ")"}]}]}], ",", 
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["B",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d_",
         TraditionalForm], ")"}]],
      TBI[
       Pattern[d, 
        Blank[]], 
       Pattern[pp, 
        Blank[]], {{1, 0}, {1, 0}}],
      Editable->True], "\[RuleDelayed]", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"4", "-", "d"}], ")"}], " ", 
          TagBox["\[DoubledGamma]",
           Function[{}, EulerGamma]]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "4"}], ")"}], " ", "\[Pi]"}]}]], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"2", "-", 
         FractionBox["d", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"\[CapitalGamma]", "(", 
         RowBox[{
          FractionBox["d", "2"], "-", "1"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{
          SuperscriptBox["pp", 
           FractionBox[
            RowBox[{"d", "-", "4"}], "2"]], " ", 
          InterpretationBox[
           StyleBox[
            SubscriptBox["S", "d"],
            FontWeight->"Bold"],
           SEpsilon[d],
           Editable->False]}],
         Prefactor1[pp^(Rational[1, 2] (-4 + d)) SEpsilon[d]],
         Editable->False], ")"}]}], 
      RowBox[{"\[CapitalGamma]", "(", 
       RowBox[{"d", "-", "2"}], ")"}]]}], ",", 
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d_",
         TraditionalForm], ")"}]],
      TJI[
       Pattern[d, 
        Blank[]], 
       Pattern[pp, 
        Blank[]], {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True], "\[RuleDelayed]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"pp", " ", 
        RowBox[{"\[CapitalGamma]", "(", 
         RowBox[{"3", "-", "d"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{
           FractionBox["d", "2"], "-", "1"}], ")"}], "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", "-", "d"}], ")"}], " ", 
          TagBox["\[DoubledGamma]",
           Function[{}, EulerGamma]]}]], " ", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           SuperscriptBox["pp", 
            RowBox[{"d", "-", "4"}]], " ", 
           InterpretationBox[
            StyleBox[
             SubsuperscriptBox["S", "d", "2"],
             FontWeight->"Bold"],
            SEpsilon[d],
            Editable->False]}],
          Prefactor1[pp^(-4 + d) SEpsilon[d]^2],
          Editable->False], ")"}]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "4"}], ")"}], " ", "\[Pi]"}]], " ", 
        RowBox[{"\[CapitalGamma]", "(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "d"}], "2"], "-", "3"}], ")"}]}]]}]}], ",", 
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d_",
         TraditionalForm], ")"}]],
      TJI[
       Pattern[d, 
        Blank[]], Pattern[M, 
         Blank[]]^2, {{1, 
         Pattern[M, 
          Blank[]]}, {1, 0}, {1, 0}}],
      Editable->True], "\[RuleDelayed]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["M", "2"], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"3", "-", "d"}], ")"}], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"2", "-", 
         FractionBox["d", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"\[CapitalGamma]", "(", 
         RowBox[{
          FractionBox["d", "2"], "-", "1"}], ")"}], "2"], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{
         RowBox[{"2", " ", "d"}], "-", "5"}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "-", "d"}], ")"}], " ", 
         TagBox["\[DoubledGamma]",
          Function[{}, EulerGamma]]}]], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["M", "2"], ")"}], 
           RowBox[{"d", "-", "4"}]], " ", 
          InterpretationBox[
           StyleBox[
            SubsuperscriptBox["S", "d", "2"],
            FontWeight->"Bold"],
           SEpsilon[d],
           Editable->False]}],
         Prefactor1[(M^2)^(-4 + d) SEpsilon[d]^2],
         Editable->False], ")"}]}], 
      RowBox[{
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"d", "-", "2"}], ")"}], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "d"}], "2"], "-", "3"}], ")"}]}]]}], ",", 
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d_Symbol",
         TraditionalForm], ")"}]],
      TJI[
       Pattern[d, 
        Blank[Symbol]], Pattern[M, 
         Blank[]]^2, {{1, 
         Pattern[M, 
          Blank[]]}, {1, 
         Pattern[M, 
          Blank[]]}, {1, 
         Pattern[M, 
          Blank[]]}}],
      Editable->True], "\[RuleDelayed]", 
     RowBox[{
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["M", "2"], ")"}], 
          RowBox[{"d", "-", "4"}]], " ", 
         InterpretationBox[
          StyleBox[
           SubsuperscriptBox["S", "d", "2"],
           FontWeight->"Bold"],
          SEpsilon[d],
          Editable->False]}],
        Prefactor1[(M^2)^(-4 + d) SEpsilon[d]^2],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"TJI111e", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "4"}], ")"}], "3"]}], "+", 
        RowBox[{
         FractionBox["1", "8"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "59"}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Pi]", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "96"], " ", 
         RowBox[{"(", 
          RowBox[{"d", "-", "4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "48"}], " ", 
            TagBox[
             RowBox[{"\[Zeta]", "(", 
              TagBox["3",
               Zeta,
               Editable->True], ")"}],
             InterpretTemplate[
              Function[BoxForm`e$, 
               Zeta[BoxForm`e$]]]]}], "+", 
           RowBox[{"98", " ", 
            SuperscriptBox["\[Pi]", "2"]}], "+", "195"}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "4"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3840", " ", 
             SuperscriptBox["\[Pi]", "2"], " ", 
             RowBox[{"log", "(", "2", ")"}]}], "-", 
            RowBox[{"14", " ", 
             SuperscriptBox["\[Pi]", "4"]}], "-", 
            RowBox[{"4750", " ", 
             SuperscriptBox["\[Pi]", "2"]}], "-", 
            RowBox[{"12080", " ", 
             TagBox[
              RowBox[{"\[Zeta]", "(", 
               TagBox["3",
                Zeta,
                Editable->True], ")"}],
              InterpretTemplate[
               Function[BoxForm`e$, 
                Zeta[BoxForm`e$]]]]}], "+", "16755"}], ")"}]}], "1920"], "+", 
        
        FractionBox["17", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "4"}], ")"}]}]], "-", 
        FractionBox["6", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "4"}], ")"}], "2"]]}], ")"}]}]}], ",", 
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d_",
         TraditionalForm], ")"}]],
      TJI[
       Pattern[d, 
        Blank[]], 0, {{1, 
         Pattern[M, 
          Blank[]]}, {1, 
         Pattern[M, 
          Blank[]]}, {1, 0}}],
      Editable->True], "\[RuleDelayed]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["M", "2"], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"3", "-", "d"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"\[CapitalGamma]", "(", 
         RowBox[{"2", "-", 
          FractionBox["d", "2"]}], ")"}], "2"], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{
         FractionBox["d", "2"], "-", "1"}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "-", "d"}], ")"}], " ", 
         TagBox["\[DoubledGamma]",
          Function[{}, EulerGamma]]}]], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["M", "2"], ")"}], 
           RowBox[{"d", "-", "4"}]], " ", 
          InterpretationBox[
           StyleBox[
            SubsuperscriptBox["S", "d", "2"],
            FontWeight->"Bold"],
           SEpsilon[d],
           Editable->False]}],
         Prefactor1[(M^2)^(-4 + d) SEpsilon[d]^2],
         Editable->False], ")"}]}], 
      RowBox[{
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"4", "-", "d"}], ")"}], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        FractionBox["d", "2"], ")"}]}]]}], ",", 
    RowBox[{
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["K",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "M_"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["d_",
         TraditionalForm], ")"}]],
      TJI[
       Pattern[d, 
        Blank[]], 0, {{1, 
         Pattern[M, 
          Blank[]]}, {1, 0}, {1, 0}}],
      Editable->True], "\[RuleDelayed]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["M", "2"], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"3", "-", "d"}], ")"}], " ", 
       RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{"2", "-", 
         FractionBox["d", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"\[CapitalGamma]", "(", 
         RowBox[{
          FractionBox["d", "2"], "-", "1"}], ")"}], "2"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "-", "d"}], ")"}], " ", 
         TagBox["\[DoubledGamma]",
          Function[{}, EulerGamma]]}]], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["M", "2"], ")"}], 
           RowBox[{"d", "-", "4"}]], " ", 
          InterpretationBox[
           StyleBox[
            SubsuperscriptBox["S", "d", "2"],
            FontWeight->"Bold"],
           SEpsilon[d],
           Editable->False]}],
         Prefactor1[(M^2)^(-4 + d) SEpsilon[d]^2],
         Editable->False], ")"}]}], 
      RowBox[{"\[CapitalGamma]", "(", 
       FractionBox["d", "2"], ")"}]]}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save tarcer*.mx file", "Section",
 CellDingbat->"\[FilledSmallCircle]",
 CellTags->"T1.11.1"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Share", "[", "]"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.5008842719239197`*^9, 3.5008842740848093`*^9}}],

Cell["\<\
DumpSave[StringJoin[\"tarcer\", StringJoin @@ 
     ToString /@ $RankLimit, \".mx\"], 
   {$ContextPath, HighEnergyPhysics`Tarcer`Cayley, 
    HighEnergyPhysics`Tarcer`CayleyD, 
    HighEnergyPhysics`Tarcer`Cayleyu, 
    HighEnergyPhysics`Tarcer`Prefactor1, 
    HighEnergyPhysics`Tarcer`TarcerRecurse, 
    HighEnergyPhysics`Tarcer`TFIRecurse, 
    HighEnergyPhysics`Tarcer`TFISimplify, 
    HighEnergyPhysics`Tarcer`SEpsilon, 
    HighEnergyPhysics`Tarcer`TarcerExpand, 
    HighEnergyPhysics`Tarcer`TarcerReduce, 
    HighEnergyPhysics`Tarcer`TAI, 
    HighEnergyPhysics`Tarcer`TAR, 
    HighEnergyPhysics`Tarcer`TBI, 
    HighEnergyPhysics`Tarcer`TBR, 
    HighEnergyPhysics`Tarcer`TFI, 
    HighEnergyPhysics`Tarcer`TFR, 
    HighEnergyPhysics`Tarcer`TJI, 
    HighEnergyPhysics`Tarcer`TJR, 
    HighEnergyPhysics`Tarcer`TKI, 
    HighEnergyPhysics`Tarcer`TVI, 
    HighEnergyPhysics`Tarcer`TVR, 
    HighEnergyPhysics`Tarcer`$BasisIntegrals, 
    HighEnergyPhysics`Tarcer`$Comment, 
    HighEnergyPhysics`Tarcer`$CommentNotebook, 
    HighEnergyPhysics`Tarcer`$RankLimit, 
    HighEnergyPhysics`Tarcer`$RecursionStop, 
    HighEnergyPhysics`Tarcer`$TTable, 
    HighEnergyPhysics`Tarcer`Private`applytlrules, 
    HighEnergyPhysics`Tarcer`Private`applytlrules2,
    HighEnergyPhysics`Tarcer`Private`ExpandMaybe, 
    HighEnergyPhysics`Tarcer`Private`FactorC, 
    HighEnergyPhysics`Tarcer`Private`FEPrint, 
    HighEnergyPhysics`Tarcer`Private`fN, 
    HighEnergyPhysics`Tarcer`Private`mbt, 
    HighEnergyPhysics`Tarcer`Private`PNQ, 
    HighEnergyPhysics`Tarcer`Private`PQ, 
    HighEnergyPhysics`Tarcer`Private`ta, 
    HighEnergyPhysics`Tarcer`Private`TA, 
    HighEnergyPhysics`Tarcer`Private`TAIC, 
    HighEnergyPhysics`Tarcer`Private`TBIC, 
    HighEnergyPhysics`Tarcer`Private`TComment, 
    HighEnergyPhysics`Tarcer`Private`TLRComment, 
    HighEnergyPhysics`Tarcer`Private`TFIC, 
    HighEnergyPhysics`Tarcer`Private`TJIC, 
    HighEnergyPhysics`Tarcer`Private`TLR, 
    HighEnergyPhysics`Tarcer`Private`tlrule, 
    HighEnergyPhysics`Tarcer`Private`redblue, 
    HighEnergyPhysics`Tarcer`Private`TLRules, 
    HighEnergyPhysics`Tarcer`Private`TLRules2, 
    HighEnergyPhysics`Tarcer`Private`TVIC, 
    HighEnergyPhysics`Tarcer`Private`$TLRComment, 
    HighEnergyPhysics`general`Zeta2`Zeta2}]; \
\>", "Input",
 Editable->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"$HistoryLength", "=", "\[Infinity]"}], ";"}]], "Input"],

Cell["\<\
This gives the absolute time (in minutes) to run this notebook.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Round", "[", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "-", 
     "HighEnergyPhysics`Tarcer`Private`atime"}], "]"}], "/", "60."}], " ", 
  "min"}]], "Input"],

Cell[BoxData[
 RowBox[{"2.`", " ", "min"}]], "Output",
 CellChangeTimes->{3.500884640464253*^9}]
}, Open  ]],

Cell["Display the size of the generated file:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"filename", " ", "=", " ", 
  RowBox[{"\"\<tarcer\>\"", "<>", 
   RowBox[{"(", 
    RowBox[{"Apply", "[", 
     RowBox[{"StringJoin", ",", 
      RowBox[{"ToString", "/@", "$RankLimit"}]}], "]"}], ")"}], "<>", 
   "\"\<.mx\>\""}]}]], "Input"],

Cell[BoxData["\<\"tarcer25.mx\"\>"], "Output",
 CellChangeTimes->{3.500884640563472*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FileByteCount", "[", "filename", "]"}], " ", "Byte"}]], "Input"],

Cell[BoxData[
 RowBox[{"5170492", " ", "Byte"}]], "Output",
 CellChangeTimes->{3.5008846406305313`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input"],

Cell[BoxData["\<\"/home/rolfm/HighEnergyPhysics/Tarcer\"\>"], "Output",
 CellChangeTimes->{3.500884640657874*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MaxMemoryUsed", "[", "]"}]], "Input"],

Cell[BoxData["129757176"], "Output",
 CellChangeTimes->{3.500884640684606*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MemoryInUse", "[", "]"}]], "Input"],

Cell[BoxData["69417960"], "Output",
 CellChangeTimes->{3.500884640710617*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimeUsed", "[", "]"}]], "Input"],

Cell[BoxData["91.75`"], "Output",
 CellChangeTimes->{3.500884640889763*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1158, 906},
WindowMargins->{{87, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "specialTVR"->{
  Cell[709419, 23528, 69, 1, 37, "Subsection",
   CellTags->"specialTVR"]},
 "TLRdef"->{
  Cell[737047, 24302, 215, 7, 101, "Text",
   CellTags->"TLRdef"]},
 "tlrule17"->{
  Cell[770174, 25267, 77, 1, 29, "Text",
   CellTags->"tlrule17"]},
 "Tsymmetry"->{
  Cell[709181, 23515, 54, 1, 37, "Subsection",
   CellTags->"Tsymmetry"]},
 "$TTable"->{
  Cell[834702, 27330, 51, 1, 37, "Subsection",
   CellTags->"$TTable"]},
 "T1.1"->{
  Cell[579, 22, 72, 2, 83, "Title",
   CellTags->"T1.1"]},
 "T1.1.1"->{
  Cell[29712, 1125, 91, 2, 72, "Section",
   CellTags->"T1.1.1"]},
 "T1.10.1"->{
  Cell[880719, 28586, 93, 2, 72, "Section",
   CellTags->"T1.10.1"]},
 "T1.11.1"->{
  Cell[915130, 29710, 99, 2, 72, "Section",
   CellTags->"T1.11.1"]},
 "T1.2"->{
  Cell[828, 34, 409, 14, 101, "Text",
   CellTags->"T1.2"]},
 "T1.2.1"->{
  Cell[37112, 1383, 84, 2, 72, "Section",
   CellTags->"T1.2.1"]},
 "T1.2.1.1"->{
  Cell[36480, 1363, 77, 1, 28, "Subsubsection",
   CellTags->"T1.2.1.1"]},
 "T1.3.1"->{
  Cell[44988, 1627, 110, 2, 61, "Section",
   CellTags->"T1.3.1"]},
 "T1.3.1.1"->{
  Cell[47598, 1732, 62, 1, 37, "Subsection",
   CellTags->"T1.3.1.1"]},
 "T1.3.2.1"->{
  Cell[110671, 3605, 57, 1, 37, "Subsection",
   CellTags->"T1.3.2.1"]},
 "T1.3.3.1"->{
  Cell[125087, 3948, 58, 1, 37, "Subsection",
   CellTags->"T1.3.3.1"]},
 "T1.3.4.1"->{
  Cell[140288, 4381, 59, 1, 37, "Subsection",
   CellTags->"T1.3.4.1"]},
 "T1.3.5.1"->{
  Cell[142653, 4457, 53, 1, 37, "Subsection",
   CellTags->"T1.3.5.1"]},
 "T1.3.6.1"->{
  Cell[158706, 4904, 58, 1, 37, "Subsection",
   CellTags->"T1.3.6.1"]},
 "T1.3.7.1"->{
  Cell[160503, 4960, 49, 1, 37, "Subsection",
   CellTags->"T1.3.7.1"]},
 "T1.3.7.1.1"->{
  Cell[160782, 4972, 56, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.1.1"]},
 "T1.3.7.2.1"->{
  Cell[165487, 5140, 52, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.2.1"]},
 "T1.3.7.3.1"->{
  Cell[165732, 5153, 53, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.3.1"]},
 "T1.3.7.4.1"->{
  Cell[166083, 5171, 57, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.4.1"]},
 "T1.3.7.5.1"->{
  Cell[166357, 5184, 53, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.5.1"]},
 "T1.3.7.6.1"->{
  Cell[169976, 5271, 53, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.6.1"]},
 "T1.3.7.7.1"->{
  Cell[172315, 5354, 53, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.7.1"]},
 "T1.3.7.8.1"->{
  Cell[174045, 5418, 53, 1, 28, "Subsubsection",
   CellTags->"T1.3.7.8.1"]},
 "T1.4.1"->{
  Cell[174445, 5438, 102, 2, 72, "Section",
   CellTags->"T1.4.1"]},
 "T1.4.1.1"->{
  Cell[179085, 5589, 108, 3, 38, "Subsection",
   CellTags->"T1.4.1.1"]},
 "T1.4.2.1"->{
  Cell[179588, 5611, 106, 3, 38, "Subsection",
   CellTags->"T1.4.2.1"]},
 "T1.4.3.1"->{
  Cell[181721, 5693, 196, 6, 38, "Subsection",
   CellTags->"T1.4.3.1"]},
 "T1.4.4.1"->{
  Cell[187956, 5896, 233, 7, 59, "Subsection",
   CellTags->"T1.4.4.1"]},
 "T1.5.1"->{
  Cell[200104, 6303, 95, 2, 72, "Section",
   CellTags->"T1.5.1"]},
 "T1.5.1.1"->{
  Cell[200224, 6309, 64, 1, 37, "Subsection",
   CellTags->"T1.5.1.1"]},
 "T1.5.1.1.1"->{
  Cell[274031, 8254, 61, 1, 28, "Subsubsection",
   CellTags->"T1.5.1.1.1"]},
 "T1.5.2.1"->{
  Cell[280564, 8468, 58, 1, 37, "Subsection",
   CellTags->"T1.5.2.1"]},
 "T1.5.2.1.1"->{
  Cell[284941, 8602, 52, 1, 28, "Subsubsection",
   CellTags->"T1.5.2.1.1"]},
 "T1.5.3.1"->{
  Cell[300351, 9087, 59, 1, 37, "Subsection",
   CellTags->"T1.5.3.1"]},
 "T1.5.3.1.1"->{
  Cell[300754, 9102, 67, 1, 28, "Subsubsection",
   CellTags->"T1.5.3.1.1"]},
 "T1.5.3.2.1"->{
  Cell[311033, 9393, 67, 1, 28, "Subsubsection",
   CellTags->"T1.5.3.2.1"]},
 "T1.6.1"->{
  Cell[319324, 9628, 138, 2, 72, "Section",
   CellTags->"T1.6.1"]},
 "T1.6.1.1"->{
  Cell[320584, 9673, 55, 1, 37, "Subsection",
   CellTags->"T1.6.1.1"]},
 "T1.6.10.1"->{
  Cell[351873, 10829, 58, 1, 37, "Subsection",
   CellTags->"T1.6.10.1"]},
 "T1.6.100.1"->{
  Cell[660608, 21944, 61, 1, 37, "Subsection",
   CellTags->"T1.6.100.1"]},
 "T1.6.101.1"->{
  Cell[661637, 21986, 61, 1, 37, "Subsection",
   CellTags->"T1.6.101.1"]},
 "T1.6.102.1"->{
  Cell[662719, 22029, 61, 1, 37, "Subsection",
   CellTags->"T1.6.102.1"]},
 "T1.6.103.1"->{
  Cell[663750, 22071, 61, 1, 37, "Subsection",
   CellTags->"T1.6.103.1"]},
 "T1.6.104.1"->{
  Cell[664781, 22113, 61, 1, 37, "Subsection",
   CellTags->"T1.6.104.1"]},
 "T1.6.105.1"->{
  Cell[665861, 22156, 58, 1, 45, "Subsection",
   CellTags->"T1.6.105.1"]},
 "T1.6.106.1"->{
  Cell[668895, 22258, 60, 1, 37, "Subsection",
   CellTags->"T1.6.106.1"]},
 "T1.6.107.1"->{
  Cell[669264, 22276, 58, 1, 45, "Subsection",
   CellTags->"T1.6.107.1"]},
 "T1.6.108.1"->{
  Cell[672604, 22386, 60, 1, 37, "Subsection",
   CellTags->"T1.6.108.1"]},
 "T1.6.109.1"->{
  Cell[673165, 22410, 58, 1, 45, "Subsection",
   CellTags->"T1.6.109.1"]},
 "T1.6.11.1"->{
  Cell[353265, 10884, 56, 1, 37, "Subsection",
   CellTags->"T1.6.11.1"]},
 "T1.6.110.1"->{
  Cell[675984, 22506, 60, 1, 37, "Subsection",
   CellTags->"T1.6.110.1"]},
 "T1.6.111.1"->{
  Cell[676353, 22524, 58, 1, 45, "Subsection",
   CellTags->"T1.6.111.1"]},
 "T1.6.112.1"->{
  Cell[678129, 22586, 60, 1, 37, "Subsection",
   CellTags->"T1.6.112.1"]},
 "T1.6.113.1"->{
  Cell[678498, 22604, 58, 1, 37, "Subsection",
   CellTags->"T1.6.113.1"]},
 "T1.6.114.1"->{
  Cell[686170, 22861, 60, 1, 37, "Subsection",
   CellTags->"T1.6.114.1"]},
 "T1.6.115.1"->{
  Cell[687127, 22899, 60, 1, 37, "Subsection",
   CellTags->"T1.6.115.1"]},
 "T1.6.116.1"->{
  Cell[687918, 22936, 60, 1, 37, "Subsection",
   CellTags->"T1.6.116.1"]},
 "T1.6.117.1"->{
  Cell[688713, 22973, 61, 1, 37, "Subsection",
   CellTags->"T1.6.117.1"]},
 "T1.6.118.1"->{
  Cell[692199, 23072, 61, 1, 37, "Subsection",
   CellTags->"T1.6.118.1"]},
 "T1.6.119.1"->{
  Cell[695655, 23171, 61, 1, 37, "Subsection",
   CellTags->"T1.6.119.1"]},
 "T1.6.12.1"->{
  Cell[357437, 11046, 56, 1, 37, "Subsection",
   CellTags->"T1.6.12.1"]},
 "T1.6.120.1"->{
  Cell[699105, 23270, 60, 1, 37, "Subsection",
   CellTags->"T1.6.120.1"]},
 "T1.6.121.1"->{
  Cell[720207, 23716, 59, 1, 37, "Subsection",
   CellTags->"T1.6.121.1"]},
 "T1.6.122.1"->{
  Cell[726599, 23925, 60, 1, 37, "Subsection",
   CellTags->"T1.6.122.1"]},
 "T1.6.123.1"->{
  Cell[729585, 24025, 59, 1, 37, "Subsection",
   CellTags->"T1.6.123.1"]},
 "T1.6.124.1"->{
  Cell[732068, 24112, 57, 1, 37, "Subsection",
   CellTags->"T1.6.124.1"]},
 "T1.6.13.1"->{
  Cell[361609, 11208, 56, 1, 37, "Subsection",
   CellTags->"T1.6.13.1"]},
 "T1.6.14.1"->{
  Cell[368291, 11437, 67, 1, 37, "Subsection",
   CellTags->"T1.6.14.1"]},
 "T1.6.15.1"->{
  Cell[369389, 11478, 58, 1, 37, "Subsection",
   CellTags->"T1.6.15.1"]},
 "T1.6.16.1"->{
  Cell[392141, 12022, 56, 1, 37, "Subsection",
   CellTags->"T1.6.16.1"]},
 "T1.6.17.1"->{
  Cell[396208, 12174, 58, 1, 37, "Subsection",
   CellTags->"T1.6.17.1"]},
 "T1.6.18.1"->{
  Cell[397321, 12222, 56, 1, 37, "Subsection",
   CellTags->"T1.6.18.1"]},
 "T1.6.19.1"->{
  Cell[402895, 12425, 58, 1, 37, "Subsection",
   CellTags->"T1.6.19.1"]},
 "T1.6.2.1"->{
  Cell[327485, 9910, 57, 1, 37, "Subsection",
   CellTags->"T1.6.2.1"]},
 "T1.6.2.1.1"->{
  Cell[327825, 9926, 167, 7, 28, "Subsubsection",
   CellTags->"T1.6.2.1.1"]},
 "T1.6.2.2.1"->{
  Cell[329095, 9977, 167, 7, 28, "Subsubsection",
   CellTags->"T1.6.2.2.1"]},
 "T1.6.2.3.1"->{
  Cell[330534, 10033, 167, 7, 28, "Subsubsection",
   CellTags->"T1.6.2.3.1"]},
 "T1.6.2.4.1"->{
  Cell[331973, 10089, 167, 7, 28, "Subsubsection",
   CellTags->"T1.6.2.4.1"]},
 "T1.6.20.1"->{
  Cell[403998, 12471, 58, 1, 37, "Subsection",
   CellTags->"T1.6.20.1"]},
 "T1.6.21.1"->{
  Cell[405165, 12519, 56, 1, 45, "Subsection",
   CellTags->"T1.6.21.1"]},
 "T1.6.22.1"->{
  Cell[408457, 12646, 58, 1, 37, "Subsection",
   CellTags->"T1.6.22.1"]},
 "T1.6.23.1"->{
  Cell[409443, 12688, 56, 1, 45, "Subsection",
   CellTags->"T1.6.23.1"]},
 "T1.6.24.1"->{
  Cell[413474, 12840, 58, 1, 37, "Subsection",
   CellTags->"T1.6.24.1"]},
 "T1.6.25.1"->{
  Cell[414534, 12884, 56, 1, 45, "Subsection",
   CellTags->"T1.6.25.1"]},
 "T1.6.26.1"->{
  Cell[418322, 13027, 58, 1, 37, "Subsection",
   CellTags->"T1.6.26.1"]},
 "T1.6.27.1"->{
  Cell[419384, 13071, 56, 1, 37, "Subsection",
   CellTags->"T1.6.27.1"]},
 "T1.6.28.1"->{
  Cell[425582, 13290, 58, 1, 37, "Subsection",
   CellTags->"T1.6.28.1"]},
 "T1.6.29.1"->{
  Cell[427698, 13354, 57, 1, 37, "Subsection",
   CellTags->"T1.6.29.1"]},
 "T1.6.3.1"->{
  Cell[333424, 10146, 57, 1, 37, "Subsection",
   CellTags->"T1.6.3.1"]},
 "T1.6.30.1"->{
  Cell[430991, 13481, 58, 1, 37, "Subsection",
   CellTags->"T1.6.30.1"]},
 "T1.6.31.1"->{
  Cell[431996, 13523, 57, 1, 37, "Subsection",
   CellTags->"T1.6.31.1"]},
 "T1.6.32.1"->{
  Cell[436927, 13719, 58, 1, 37, "Subsection",
   CellTags->"T1.6.32.1"]},
 "T1.6.33.1"->{
  Cell[439010, 13807, 60, 1, 37, "Subsection",
   CellTags->"T1.6.33.1"]},
 "T1.6.34.1"->{
  Cell[441214, 13898, 57, 1, 37, "Subsection",
   CellTags->"T1.6.34.1"]},
 "T1.6.35.1"->{
  Cell[446955, 14108, 58, 1, 37, "Subsection",
   CellTags->"T1.6.35.1"]},
 "T1.6.36.1"->{
  Cell[448519, 14168, 57, 1, 37, "Subsection",
   CellTags->"T1.6.36.1"]},
 "T1.6.37.1"->{
  Cell[455216, 14396, 58, 1, 37, "Subsection",
   CellTags->"T1.6.37.1"]},
 "T1.6.38.1"->{
  Cell[457688, 14494, 60, 1, 37, "Subsection",
   CellTags->"T1.6.38.1"]},
 "T1.6.39.1"->{
  Cell[460779, 14610, 60, 1, 37, "Subsection",
   CellTags->"T1.6.39.1"]},
 "T1.6.4.1"->{
  Cell[337304, 10293, 246, 9, 40, "Subsection",
   CellTags->"T1.6.4.1"]},
 "T1.6.40.1"->{
  Cell[463081, 14694, 60, 1, 37, "Subsection",
   CellTags->"T1.6.40.1"]},
 "T1.6.41.1"->{
  Cell[464742, 14758, 57, 1, 37, "Subsection",
   CellTags->"T1.6.41.1"]},
 "T1.6.42.1"->{
  Cell[469995, 14950, 58, 1, 37, "Subsection",
   CellTags->"T1.6.42.1"]},
 "T1.6.43.1"->{
  Cell[471622, 15013, 67, 1, 37, "Subsection",
   CellTags->"T1.6.43.1"]},
 "T1.6.44.1"->{
  Cell[477735, 15238, 56, 1, 37, "Subsection",
   CellTags->"T1.6.44.1"]},
 "T1.6.45.1"->{
  Cell[491708, 15745, 58, 1, 37, "Subsection",
   CellTags->"T1.6.45.1"]},
 "T1.6.46.1"->{
  Cell[493143, 15802, 60, 1, 37, "Subsection",
   CellTags->"T1.6.46.1"]},
 "T1.6.47.1"->{
  Cell[494698, 15862, 56, 1, 37, "Subsection",
   CellTags->"T1.6.47.1"]},
 "T1.6.48.1"->{
  Cell[501089, 16085, 58, 1, 37, "Subsection",
   CellTags->"T1.6.48.1"]},
 "T1.6.49.1"->{
  Cell[502565, 16143, 60, 1, 37, "Subsection",
   CellTags->"T1.6.49.1"]},
 "T1.6.5.1"->{
  Cell[338231, 10331, 57, 1, 37, "Subsection",
   CellTags->"T1.6.5.1"]},
 "T1.6.50.1"->{
  Cell[504180, 16205, 56, 1, 37, "Subsection",
   CellTags->"T1.6.50.1"]},
 "T1.6.51.1"->{
  Cell[516354, 16625, 58, 1, 37, "Subsection",
   CellTags->"T1.6.51.1"]},
 "T1.6.52.1"->{
  Cell[517248, 16662, 56, 1, 37, "Subsection",
   CellTags->"T1.6.52.1"]},
 "T1.6.53.1"->{
  Cell[523007, 16871, 58, 1, 37, "Subsection",
   CellTags->"T1.6.53.1"]},
 "T1.6.54.1"->{
  Cell[524188, 16920, 60, 1, 37, "Subsection",
   CellTags->"T1.6.54.1"]},
 "T1.6.55.1"->{
  Cell[525449, 16971, 60, 1, 37, "Subsection",
   CellTags->"T1.6.55.1"]},
 "T1.6.56.1"->{
  Cell[526710, 17022, 56, 1, 37, "Subsection",
   CellTags->"T1.6.56.1"]},
 "T1.6.57.1"->{
  Cell[533173, 17252, 58, 1, 37, "Subsection",
   CellTags->"T1.6.57.1"]},
 "T1.6.58.1"->{
  Cell[534208, 17296, 56, 1, 37, "Subsection",
   CellTags->"T1.6.58.1"]},
 "T1.6.59.1"->{
  Cell[539745, 17487, 58, 1, 37, "Subsection",
   CellTags->"T1.6.59.1"]},
 "T1.6.6.1"->{
  Cell[342111, 10478, 246, 9, 40, "Subsection",
   CellTags->"T1.6.6.1"]},
 "T1.6.60.1"->{
  Cell[540773, 17529, 56, 1, 45, "Subsection",
   CellTags->"T1.6.60.1"]},
 "T1.6.61.1"->{
  Cell[546572, 17737, 58, 1, 37, "Subsection",
   CellTags->"T1.6.61.1"]},
 "T1.6.62.1"->{
  Cell[547928, 17791, 60, 1, 37, "Subsection",
   CellTags->"T1.6.62.1"]},
 "T1.6.63.1"->{
  Cell[549367, 17847, 60, 1, 37, "Subsection",
   CellTags->"T1.6.63.1"]},
 "T1.6.64.1"->{
  Cell[550823, 17903, 56, 1, 45, "Subsection",
   CellTags->"T1.6.64.1"]},
 "T1.6.65.1"->{
  Cell[564339, 18356, 58, 1, 37, "Subsection",
   CellTags->"T1.6.65.1"]},
 "T1.6.66.1"->{
  Cell[565545, 18405, 60, 1, 37, "Subsection",
   CellTags->"T1.6.66.1"]},
 "T1.6.67.1"->{
  Cell[566832, 18456, 60, 1, 37, "Subsection",
   CellTags->"T1.6.67.1"]},
 "T1.6.68.1"->{
  Cell[568119, 18507, 56, 1, 45, "Subsection",
   CellTags->"T1.6.68.1"]},
 "T1.6.69.1"->{
  Cell[576247, 18783, 58, 1, 37, "Subsection",
   CellTags->"T1.6.69.1"]},
 "T1.6.7.1"->{
  Cell[343038, 10516, 246, 9, 40, "Subsection",
   CellTags->"T1.6.7.1"]},
 "T1.6.70.1"->{
  Cell[577425, 18830, 56, 1, 45, "Subsection",
   CellTags->"T1.6.70.1"]},
 "T1.6.70.1.1"->{
  Cell[577506, 18835, 55, 1, 28, "Subsubsection",
   CellTags->"T1.6.70.1.1"]},
 "T1.6.70.2.1"->{
  Cell[582020, 18996, 55, 1, 28, "Subsubsection",
   CellTags->"T1.6.70.2.1"]},
 "T1.6.71.1"->{
  Cell[590786, 19318, 58, 1, 37, "Subsection",
   CellTags->"T1.6.71.1"]},
 "T1.6.72.1"->{
  Cell[591477, 19347, 56, 1, 37, "Subsection",
   CellTags->"T1.6.72.1"]},
 "T1.6.73.1"->{
  Cell[603480, 19737, 58, 1, 37, "Subsection",
   CellTags->"T1.6.73.1"]},
 "T1.6.74.1"->{
  Cell[604161, 19766, 56, 1, 37, "Subsection",
   CellTags->"T1.6.74.1"]},
 "T1.6.75.1"->{
  Cell[615580, 20196, 59, 1, 37, "Subsection",
   CellTags->"T1.6.75.1"]},
 "T1.6.76.1"->{
  Cell[616408, 20230, 59, 1, 37, "Subsection",
   CellTags->"T1.6.76.1"]},
 "T1.6.77.1"->{
  Cell[617442, 20271, 59, 1, 37, "Subsection",
   CellTags->"T1.6.77.1"]},
 "T1.6.78.1"->{
  Cell[618243, 20302, 59, 1, 37, "Subsection",
   CellTags->"T1.6.78.1"]},
 "T1.6.79.1"->{
  Cell[619158, 20337, 56, 1, 45, "Subsection",
   CellTags->"T1.6.79.1"]},
 "T1.6.8.1"->{
  Cell[344259, 10563, 246, 9, 40, "Subsection",
   CellTags->"T1.6.8.1"]},
 "T1.6.80.1"->{
  Cell[625064, 20544, 56, 1, 45, "Subsection",
   CellTags->"T1.6.80.1"]},
 "T1.6.81.1"->{
  Cell[628447, 20672, 58, 1, 37, "Subsection",
   CellTags->"T1.6.81.1"]},
 "T1.6.82.1"->{
  Cell[629296, 20707, 56, 1, 37, "Subsection",
   CellTags->"T1.6.82.1"]},
 "T1.6.83.1"->{
  Cell[632427, 20825, 58, 1, 37, "Subsection",
   CellTags->"T1.6.83.1"]},
 "T1.6.84.1"->{
  Cell[633157, 20855, 60, 1, 37, "Subsection",
   CellTags->"T1.6.84.1"]},
 "T1.6.85.1"->{
  Cell[634419, 20904, 60, 1, 37, "Subsection",
   CellTags->"T1.6.85.1"]},
 "T1.6.86.1"->{
  Cell[635802, 20956, 56, 1, 37, "Subsection",
   CellTags->"T1.6.86.1"]},
 "T1.6.87.1"->{
  Cell[637993, 21047, 58, 1, 37, "Subsection",
   CellTags->"T1.6.87.1"]},
 "T1.6.88.1"->{
  Cell[638772, 21079, 56, 1, 45, "Subsection",
   CellTags->"T1.6.88.1"]},
 "T1.6.89.1"->{
  Cell[641129, 21173, 58, 1, 37, "Subsection",
   CellTags->"T1.6.89.1"]},
 "T1.6.9.1"->{
  Cell[345480, 10610, 55, 1, 37, "Subsection",
   CellTags->"T1.6.9.1"]},
 "T1.6.90.1"->{
  Cell[641720, 21197, 56, 1, 45, "Subsection",
   CellTags->"T1.6.90.1"]},
 "T1.6.91.1"->{
  Cell[643251, 21263, 58, 1, 37, "Subsection",
   CellTags->"T1.6.91.1"]},
 "T1.6.92.1"->{
  Cell[643953, 21292, 56, 1, 45, "Subsection",
   CellTags->"T1.6.92.1"]},
 "T1.6.93.1"->{
  Cell[645358, 21353, 58, 1, 37, "Subsection",
   CellTags->"T1.6.93.1"]},
 "T1.6.94.1"->{
  Cell[645911, 21377, 56, 1, 37, "Subsection",
   CellTags->"T1.6.94.1"]},
 "T1.6.95.1"->{
  Cell[650938, 21568, 58, 1, 37, "Subsection",
   CellTags->"T1.6.95.1"]},
 "T1.6.96.1"->{
  Cell[651737, 21601, 60, 1, 37, "Subsection",
   CellTags->"T1.6.96.1"]},
 "T1.6.97.1"->{
  Cell[652661, 21637, 60, 1, 37, "Subsection",
   CellTags->"T1.6.97.1"]},
 "T1.6.98.1"->{
  Cell[653585, 21673, 57, 1, 37, "Subsection",
   CellTags->"T1.6.98.1"]},
 "T1.6.99.1"->{
  Cell[659686, 21904, 59, 1, 37, "Subsection",
   CellTags->"T1.6.99.1"]},
 "T1.7.1"->{
  Cell[734297, 24197, 106, 2, 72, "Section",
   CellTags->"T1.7.1"]},
 "T1.7.1.1"->{
  Cell[734428, 24203, 69, 1, 37, "Subsection",
   CellTags->"T1.7.1.1"]},
 "T1.7.2.1"->{
  Cell[813233, 26649, 49, 1, 37, "Subsection",
   CellTags->"T1.7.2.1"]},
 "T1.7.3.1"->{
  Cell[830801, 27224, 53, 1, 37, "Subsection",
   CellTags->"T1.7.3.1"]},
 "T1.7.4.1"->{
  Cell[834885, 27341, 58, 1, 37, "Subsection",
   CellTags->"T1.7.4.1"]},
 "T1.8.1"->{
  Cell[853794, 27830, 90, 2, 72, "Section",
   CellTags->"T1.8.1"]},
 "T1.9.1"->{
  Cell[871778, 28295, 91, 2, 72, "Section",
   CellTags->"T1.9.1"]},
 "T1.9.1.1"->{
  Cell[871894, 28301, 53, 1, 37, "Subsection",
   CellTags->"T1.9.1.1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"specialTVR", 920109, 29881},
 {"TLRdef", 920198, 29884},
 {"tlrule17", 920281, 29887},
 {"Tsymmetry", 920365, 29890},
 {"$TTable", 920454, 29893},
 {"T1.1", 920538, 29896},
 {"T1.1.1", 920610, 29899},
 {"T1.10.1", 920691, 29902},
 {"T1.11.1", 920775, 29905},
 {"T1.2", 920856, 29908},
 {"T1.2.1", 920930, 29911},
 {"T1.2.1.1", 921012, 29914},
 {"T1.3.1", 921100, 29917},
 {"T1.3.1.1", 921183, 29920},
 {"T1.3.2.1", 921270, 29923},
 {"T1.3.3.1", 921358, 29926},
 {"T1.3.4.1", 921446, 29929},
 {"T1.3.5.1", 921534, 29932},
 {"T1.3.6.1", 921622, 29935},
 {"T1.3.7.1", 921710, 29938},
 {"T1.3.7.1.1", 921800, 29941},
 {"T1.3.7.2.1", 921895, 29944},
 {"T1.3.7.3.1", 921990, 29947},
 {"T1.3.7.4.1", 922085, 29950},
 {"T1.3.7.5.1", 922180, 29953},
 {"T1.3.7.6.1", 922275, 29956},
 {"T1.3.7.7.1", 922370, 29959},
 {"T1.3.7.8.1", 922465, 29962},
 {"T1.4.1", 922556, 29965},
 {"T1.4.1.1", 922640, 29968},
 {"T1.4.2.1", 922729, 29971},
 {"T1.4.3.1", 922818, 29974},
 {"T1.4.4.1", 922907, 29977},
 {"T1.5.1", 922994, 29980},
 {"T1.5.1.1", 923077, 29983},
 {"T1.5.1.1.1", 923167, 29986},
 {"T1.5.2.1", 923260, 29989},
 {"T1.5.2.1.1", 923350, 29992},
 {"T1.5.3.1", 923443, 29995},
 {"T1.5.3.1.1", 923533, 29998},
 {"T1.5.3.2.1", 923628, 30001},
 {"T1.6.1", 923719, 30004},
 {"T1.6.1.1", 923803, 30007},
 {"T1.6.10.1", 923892, 30010},
 {"T1.6.100.1", 923984, 30013},
 {"T1.6.101.1", 924077, 30016},
 {"T1.6.102.1", 924170, 30019},
 {"T1.6.103.1", 924263, 30022},
 {"T1.6.104.1", 924356, 30025},
 {"T1.6.105.1", 924449, 30028},
 {"T1.6.106.1", 924542, 30031},
 {"T1.6.107.1", 924635, 30034},
 {"T1.6.108.1", 924728, 30037},
 {"T1.6.109.1", 924821, 30040},
 {"T1.6.11.1", 924913, 30043},
 {"T1.6.110.1", 925005, 30046},
 {"T1.6.111.1", 925098, 30049},
 {"T1.6.112.1", 925191, 30052},
 {"T1.6.113.1", 925284, 30055},
 {"T1.6.114.1", 925377, 30058},
 {"T1.6.115.1", 925470, 30061},
 {"T1.6.116.1", 925563, 30064},
 {"T1.6.117.1", 925656, 30067},
 {"T1.6.118.1", 925749, 30070},
 {"T1.6.119.1", 925842, 30073},
 {"T1.6.12.1", 925934, 30076},
 {"T1.6.120.1", 926026, 30079},
 {"T1.6.121.1", 926119, 30082},
 {"T1.6.122.1", 926212, 30085},
 {"T1.6.123.1", 926305, 30088},
 {"T1.6.124.1", 926398, 30091},
 {"T1.6.13.1", 926490, 30094},
 {"T1.6.14.1", 926581, 30097},
 {"T1.6.15.1", 926672, 30100},
 {"T1.6.16.1", 926763, 30103},
 {"T1.6.17.1", 926854, 30106},
 {"T1.6.18.1", 926945, 30109},
 {"T1.6.19.1", 927036, 30112},
 {"T1.6.2.1", 927126, 30115},
 {"T1.6.2.1.1", 927216, 30118},
 {"T1.6.2.2.1", 927312, 30121},
 {"T1.6.2.3.1", 927408, 30124},
 {"T1.6.2.4.1", 927505, 30127},
 {"T1.6.20.1", 927601, 30130},
 {"T1.6.21.1", 927692, 30133},
 {"T1.6.22.1", 927783, 30136},
 {"T1.6.23.1", 927874, 30139},
 {"T1.6.24.1", 927965, 30142},
 {"T1.6.25.1", 928056, 30145},
 {"T1.6.26.1", 928147, 30148},
 {"T1.6.27.1", 928238, 30151},
 {"T1.6.28.1", 928329, 30154},
 {"T1.6.29.1", 928420, 30157},
 {"T1.6.3.1", 928510, 30160},
 {"T1.6.30.1", 928600, 30163},
 {"T1.6.31.1", 928691, 30166},
 {"T1.6.32.1", 928782, 30169},
 {"T1.6.33.1", 928873, 30172},
 {"T1.6.34.1", 928964, 30175},
 {"T1.6.35.1", 929055, 30178},
 {"T1.6.36.1", 929146, 30181},
 {"T1.6.37.1", 929237, 30184},
 {"T1.6.38.1", 929328, 30187},
 {"T1.6.39.1", 929419, 30190},
 {"T1.6.4.1", 929509, 30193},
 {"T1.6.40.1", 929600, 30196},
 {"T1.6.41.1", 929691, 30199},
 {"T1.6.42.1", 929782, 30202},
 {"T1.6.43.1", 929873, 30205},
 {"T1.6.44.1", 929964, 30208},
 {"T1.6.45.1", 930055, 30211},
 {"T1.6.46.1", 930146, 30214},
 {"T1.6.47.1", 930237, 30217},
 {"T1.6.48.1", 930328, 30220},
 {"T1.6.49.1", 930419, 30223},
 {"T1.6.5.1", 930509, 30226},
 {"T1.6.50.1", 930599, 30229},
 {"T1.6.51.1", 930690, 30232},
 {"T1.6.52.1", 930781, 30235},
 {"T1.6.53.1", 930872, 30238},
 {"T1.6.54.1", 930963, 30241},
 {"T1.6.55.1", 931054, 30244},
 {"T1.6.56.1", 931145, 30247},
 {"T1.6.57.1", 931236, 30250},
 {"T1.6.58.1", 931327, 30253},
 {"T1.6.59.1", 931418, 30256},
 {"T1.6.6.1", 931508, 30259},
 {"T1.6.60.1", 931599, 30262},
 {"T1.6.61.1", 931690, 30265},
 {"T1.6.62.1", 931781, 30268},
 {"T1.6.63.1", 931872, 30271},
 {"T1.6.64.1", 931963, 30274},
 {"T1.6.65.1", 932054, 30277},
 {"T1.6.66.1", 932145, 30280},
 {"T1.6.67.1", 932236, 30283},
 {"T1.6.68.1", 932327, 30286},
 {"T1.6.69.1", 932418, 30289},
 {"T1.6.7.1", 932508, 30292},
 {"T1.6.70.1", 932599, 30295},
 {"T1.6.70.1.1", 932692, 30298},
 {"T1.6.70.2.1", 932790, 30301},
 {"T1.6.71.1", 932886, 30304},
 {"T1.6.72.1", 932977, 30307},
 {"T1.6.73.1", 933068, 30310},
 {"T1.6.74.1", 933159, 30313},
 {"T1.6.75.1", 933250, 30316},
 {"T1.6.76.1", 933341, 30319},
 {"T1.6.77.1", 933432, 30322},
 {"T1.6.78.1", 933523, 30325},
 {"T1.6.79.1", 933614, 30328},
 {"T1.6.8.1", 933704, 30331},
 {"T1.6.80.1", 933795, 30334},
 {"T1.6.81.1", 933886, 30337},
 {"T1.6.82.1", 933977, 30340},
 {"T1.6.83.1", 934068, 30343},
 {"T1.6.84.1", 934159, 30346},
 {"T1.6.85.1", 934250, 30349},
 {"T1.6.86.1", 934341, 30352},
 {"T1.6.87.1", 934432, 30355},
 {"T1.6.88.1", 934523, 30358},
 {"T1.6.89.1", 934614, 30361},
 {"T1.6.9.1", 934704, 30364},
 {"T1.6.90.1", 934794, 30367},
 {"T1.6.91.1", 934885, 30370},
 {"T1.6.92.1", 934976, 30373},
 {"T1.6.93.1", 935067, 30376},
 {"T1.6.94.1", 935158, 30379},
 {"T1.6.95.1", 935249, 30382},
 {"T1.6.96.1", 935340, 30385},
 {"T1.6.97.1", 935431, 30388},
 {"T1.6.98.1", 935522, 30391},
 {"T1.6.99.1", 935613, 30394},
 {"T1.7.1", 935701, 30397},
 {"T1.7.1.1", 935786, 30400},
 {"T1.7.2.1", 935875, 30403},
 {"T1.7.3.1", 935964, 30406},
 {"T1.7.4.1", 936053, 30409},
 {"T1.8.1", 936140, 30412},
 {"T1.9.1", 936222, 30415},
 {"T1.9.1.1", 936306, 30418}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 72, 2, 83, "Title",
 CellTags->"T1.1"],
Cell[654, 26, 171, 6, 29, "Text"],
Cell[828, 34, 409, 14, 101, "Text",
 CellTags->"T1.2"],
Cell[1240, 50, 56, 1, 29, "Text"],
Cell[1299, 53, 225, 6, 29, "Text"],
Cell[1527, 61, 140, 3, 29, "Text"],
Cell[1670, 66, 185, 4, 47, "Text"],
Cell[1858, 72, 154, 4, 47, "Text"],
Cell[2015, 78, 95, 2, 29, "Text"],
Cell[2113, 82, 384, 8, 83, "Text"],
Cell[2500, 92, 155, 3, 29, "Text"],
Cell[2658, 97, 131, 3, 29, "Text"],
Cell[2792, 102, 137, 3, 29, "Text"],
Cell[2932, 107, 177, 6, 29, "Text"],
Cell[3112, 115, 149, 6, 29, "Text"],
Cell[3264, 123, 162, 6, 29, "Text"],
Cell[3429, 131, 153, 6, 29, "Text"],
Cell[3585, 139, 153, 6, 29, "Text"],
Cell[3741, 147, 153, 6, 29, "Text"],
Cell[3897, 155, 158, 6, 29, "Text"],
Cell[4058, 163, 156, 3, 29, "Text"],
Cell[4217, 168, 1081, 21, 245, "Text"],
Cell[5301, 191, 147, 3, 29, "Text"],
Cell[5451, 196, 497, 9, 101, "Text"],
Cell[5951, 207, 92, 2, 29, "Text"],
Cell[6046, 211, 174, 3, 29, "Text"],
Cell[6223, 216, 219, 6, 47, "Text"],
Cell[6445, 224, 78, 2, 30, "Input"],
Cell[6526, 228, 180, 4, 29, "Text"],
Cell[6709, 234, 212, 4, 47, "Text"],
Cell[6924, 240, 249, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[7198, 252, 74, 1, 72, "Section"],
Cell[7275, 255, 98, 2, 29, "Text"],
Cell[7376, 259, 91, 2, 29, "Text"],
Cell[7470, 263, 116, 2, 29, "Text"],
Cell[7589, 267, 117, 2, 29, "Text"],
Cell[7709, 271, 104, 2, 29, "Text"],
Cell[7816, 275, 99, 2, 29, "Text"],
Cell[7918, 279, 100, 2, 29, "Text"],
Cell[8021, 283, 101, 2, 29, "Text"],
Cell[8125, 287, 95, 2, 29, "Text"],
Cell[8223, 291, 100, 2, 29, "Text"],
Cell[8326, 295, 91, 2, 29, "Text"],
Cell[8420, 299, 100, 2, 24, "SmallText"],
Cell[8523, 303, 96, 2, 24, "SmallText"],
Cell[8622, 307, 97, 2, 24, "SmallText"],
Cell[8722, 311, 101, 2, 24, "SmallText"],
Cell[8826, 315, 97, 2, 24, "SmallText"],
Cell[8926, 319, 97, 2, 24, "SmallText"],
Cell[9026, 323, 97, 2, 24, "SmallText"],
Cell[9126, 327, 97, 2, 24, "SmallText"],
Cell[9226, 331, 109, 2, 29, "Text"],
Cell[9338, 335, 138, 3, 29, "Text"],
Cell[9479, 340, 136, 3, 29, "Text"],
Cell[9618, 345, 457, 15, 42, "Text"],
Cell[10078, 362, 499, 16, 42, "Text"],
Cell[10580, 380, 102, 2, 29, "Text"],
Cell[10685, 384, 106, 2, 29, "Text"],
Cell[10794, 388, 105, 2, 24, "SmallText"],
Cell[10902, 392, 175, 7, 29, "Text"],
Cell[11080, 401, 96, 2, 24, "SmallText"],
Cell[11179, 405, 101, 2, 29, "Text"],
Cell[11283, 409, 111, 2, 24, "SmallText"],
Cell[11397, 413, 111, 2, 24, "SmallText"],
Cell[11511, 417, 147, 3, 29, "Text"],
Cell[11661, 422, 97, 2, 29, "Text"],
Cell[11761, 426, 99, 2, 29, "Text"],
Cell[11863, 430, 520, 19, 40, "SmallText"],
Cell[12386, 451, 520, 19, 40, "SmallText"],
Cell[12909, 472, 520, 19, 40, "SmallText"],
Cell[13432, 493, 520, 19, 40, "SmallText"],
Cell[13955, 514, 99, 2, 29, "Text"],
Cell[14057, 518, 606, 21, 45, "Text"],
Cell[14666, 541, 99, 2, 29, "Text"],
Cell[14768, 545, 606, 21, 45, "Text"],
Cell[15377, 568, 606, 21, 45, "Text"],
Cell[15986, 591, 606, 21, 45, "Text"],
Cell[16595, 614, 97, 2, 29, "Text"],
Cell[16695, 618, 100, 2, 29, "Text"],
Cell[16798, 622, 98, 2, 32, "Text"],
Cell[16899, 626, 98, 2, 32, "Text"],
Cell[17000, 630, 98, 2, 32, "Text"],
Cell[17101, 634, 109, 2, 32, "Text"],
Cell[17213, 638, 100, 2, 29, "Text"],
Cell[17316, 642, 98, 2, 29, "Text"],
Cell[17417, 646, 100, 2, 29, "Text"],
Cell[17520, 650, 98, 2, 29, "Text"],
Cell[17621, 654, 100, 2, 29, "Text"],
Cell[17724, 658, 100, 2, 29, "Text"],
Cell[17827, 662, 98, 2, 29, "Text"],
Cell[17928, 666, 100, 2, 29, "Text"],
Cell[18031, 670, 98, 2, 29, "Text"],
Cell[18132, 674, 100, 2, 29, "Text"],
Cell[18235, 678, 98, 2, 29, "Text"],
Cell[18336, 682, 100, 2, 29, "Text"],
Cell[18439, 686, 98, 2, 29, "Text"],
Cell[18540, 690, 100, 2, 29, "Text"],
Cell[18643, 694, 98, 2, 29, "Text"],
Cell[18744, 698, 100, 2, 29, "Text"],
Cell[18847, 702, 98, 2, 29, "Text"],
Cell[18948, 706, 100, 2, 29, "Text"],
Cell[19051, 710, 102, 2, 29, "Text"],
Cell[19156, 714, 98, 2, 29, "Text"],
Cell[19257, 718, 100, 2, 29, "Text"],
Cell[19360, 722, 98, 2, 29, "Text"],
Cell[19461, 726, 100, 2, 29, "Text"],
Cell[19564, 730, 102, 2, 29, "Text"],
Cell[19669, 734, 102, 2, 29, "Text"],
Cell[19774, 738, 102, 2, 29, "Text"],
Cell[19879, 742, 98, 2, 29, "Text"],
Cell[19980, 746, 100, 2, 29, "Text"],
Cell[20083, 750, 109, 2, 29, "Text"],
Cell[20195, 754, 98, 2, 29, "Text"],
Cell[20296, 758, 100, 2, 32, "Text"],
Cell[20399, 762, 102, 2, 32, "Text"],
Cell[20504, 766, 98, 2, 32, "Text"],
Cell[20605, 770, 100, 2, 32, "Text"],
Cell[20708, 774, 102, 2, 32, "Text"],
Cell[20813, 778, 98, 2, 32, "Text"],
Cell[20914, 782, 100, 2, 32, "Text"],
Cell[21017, 786, 98, 2, 32, "Text"],
Cell[21118, 790, 100, 2, 32, "Text"],
Cell[21221, 794, 102, 2, 32, "Text"],
Cell[21326, 798, 102, 2, 32, "Text"],
Cell[21431, 802, 98, 2, 32, "Text"],
Cell[21532, 806, 100, 2, 32, "Text"],
Cell[21635, 810, 98, 2, 32, "Text"],
Cell[21736, 814, 100, 2, 29, "Text"],
Cell[21839, 818, 98, 2, 29, "Text"],
Cell[21940, 822, 100, 2, 29, "Text"],
Cell[22043, 826, 102, 2, 29, "Text"],
Cell[22148, 830, 102, 2, 29, "Text"],
Cell[22253, 834, 98, 2, 29, "Text"],
Cell[22354, 838, 100, 2, 29, "Text"],
Cell[22457, 842, 102, 2, 29, "Text"],
Cell[22562, 846, 102, 2, 29, "Text"],
Cell[22667, 850, 98, 2, 29, "Text"],
Cell[22768, 854, 100, 2, 29, "Text"],
Cell[22871, 858, 98, 2, 29, "Text"],
Cell[22972, 862, 99, 2, 24, "SmallText"],
Cell[23074, 866, 99, 2, 24, "SmallText"],
Cell[23176, 870, 100, 2, 29, "Text"],
Cell[23279, 874, 98, 2, 29, "Text"],
Cell[23380, 878, 100, 2, 29, "Text"],
Cell[23483, 882, 98, 2, 29, "Text"],
Cell[23584, 886, 101, 2, 29, "Text"],
Cell[23688, 890, 101, 2, 29, "Text"],
Cell[23792, 894, 101, 2, 29, "Text"],
Cell[23896, 898, 101, 2, 29, "Text"],
Cell[24000, 902, 98, 2, 29, "Text"],
Cell[24101, 906, 98, 2, 29, "Text"],
Cell[24202, 910, 100, 2, 29, "Text"],
Cell[24305, 914, 98, 2, 29, "Text"],
Cell[24406, 918, 100, 2, 29, "Text"],
Cell[24509, 922, 102, 2, 29, "Text"],
Cell[24614, 926, 102, 2, 29, "Text"],
Cell[24719, 930, 98, 2, 29, "Text"],
Cell[24820, 934, 100, 2, 29, "Text"],
Cell[24923, 938, 98, 2, 29, "Text"],
Cell[25024, 942, 100, 2, 29, "Text"],
Cell[25127, 946, 98, 2, 29, "Text"],
Cell[25228, 950, 100, 2, 29, "Text"],
Cell[25331, 954, 98, 2, 29, "Text"],
Cell[25432, 958, 100, 2, 29, "Text"],
Cell[25535, 962, 98, 2, 29, "Text"],
Cell[25636, 966, 100, 2, 29, "Text"],
Cell[25739, 970, 102, 2, 29, "Text"],
Cell[25844, 974, 102, 2, 29, "Text"],
Cell[25949, 978, 99, 2, 29, "Text"],
Cell[26051, 982, 101, 2, 29, "Text"],
Cell[26155, 986, 103, 2, 29, "Text"],
Cell[26261, 990, 103, 2, 29, "Text"],
Cell[26367, 994, 103, 2, 29, "Text"],
Cell[26473, 998, 103, 2, 29, "Text"],
Cell[26579, 1002, 103, 2, 29, "Text"],
Cell[26685, 1006, 100, 2, 29, "Text"],
Cell[26788, 1010, 102, 2, 29, "Text"],
Cell[26893, 1014, 100, 2, 29, "Text"],
Cell[26996, 1018, 102, 2, 29, "Text"],
Cell[27101, 1022, 100, 2, 29, "Text"],
Cell[27204, 1026, 102, 2, 29, "Text"],
Cell[27309, 1030, 100, 2, 29, "Text"],
Cell[27412, 1034, 102, 2, 29, "Text"],
Cell[27517, 1038, 100, 2, 29, "Text"],
Cell[27620, 1042, 102, 2, 29, "Text"],
Cell[27725, 1046, 102, 2, 29, "Text"],
Cell[27830, 1050, 102, 2, 29, "Text"],
Cell[27935, 1054, 102, 2, 29, "Text"],
Cell[28040, 1058, 102, 2, 29, "Text"],
Cell[28145, 1062, 102, 2, 29, "Text"],
Cell[28250, 1066, 102, 2, 29, "Text"],
Cell[28355, 1070, 101, 2, 29, "Text"],
Cell[28459, 1074, 102, 2, 29, "Text"],
Cell[28564, 1078, 101, 2, 29, "Text"],
Cell[28668, 1082, 99, 2, 29, "Text"],
Cell[28770, 1086, 113, 2, 29, "Text"],
Cell[28886, 1090, 97, 2, 29, "Text"],
Cell[28986, 1094, 91, 2, 29, "Text"],
Cell[29080, 1098, 95, 2, 29, "Text"],
Cell[29178, 1102, 100, 2, 29, "Text"],
Cell[29281, 1106, 97, 2, 29, "Text"],
Cell[29381, 1110, 98, 2, 29, "Text"],
Cell[29482, 1114, 101, 2, 29, "Text"],
Cell[29586, 1118, 89, 2, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29712, 1125, 91, 2, 72, "Section",
 CellTags->"T1.1.1"],
Cell[29806, 1129, 332, 10, 51, "SmallText"],
Cell[30141, 1141, 118, 3, 29, "Text"],
Cell[30262, 1146, 3986, 130, 95, "Text"],
Cell[34251, 1278, 222, 5, 83, "Text"],
Cell[34476, 1285, 80, 2, 30, "Input"],
Cell[34559, 1289, 146, 5, 30, "Input"],
Cell[34708, 1296, 246, 8, 30, "Input"],
Cell[34957, 1306, 80, 2, 30, "Input"],
Cell[35040, 1310, 107, 3, 29, "Text"],
Cell[35150, 1315, 339, 9, 30, "Input"],
Cell[35492, 1326, 215, 6, 24, "SmallText"],
Cell[35710, 1334, 520, 15, 50, "Input"],
Cell[36233, 1351, 109, 3, 30, "Input"],
Cell[36345, 1356, 110, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[36480, 1363, 77, 1, 28, "Subsubsection",
 CellTags->"T1.2.1.1"],
Cell[36560, 1366, 503, 11, 101, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37112, 1383, 84, 2, 72, "Section",
 CellTags->"T1.2.1"],
Cell[37199, 1387, 26, 0, 30, "Input"],
Cell[37228, 1389, 118, 3, 30, "Input"],
Cell[37349, 1394, 307, 6, 69, "Input"],
Cell[37659, 1402, 681, 11, 145, "Input"],
Cell[38343, 1415, 209, 5, 30, "Input"],
Cell[38555, 1422, 173, 5, 30, "Input"],
Cell[38731, 1429, 187, 5, 30, "Input"],
Cell[38921, 1436, 187, 5, 30, "Input"],
Cell[39111, 1443, 199, 5, 30, "Input"],
Cell[39313, 1450, 176, 5, 30, "Input"],
Cell[39492, 1457, 580, 15, 222, "Input"],
Cell[40075, 1474, 263, 6, 69, "Input"],
Cell[40341, 1482, 279, 6, 69, "Input"],
Cell[40623, 1490, 226, 5, 50, "Input"],
Cell[40852, 1497, 222, 5, 50, "Input"],
Cell[41077, 1504, 247, 6, 69, "Input"],
Cell[41327, 1512, 227, 5, 50, "Input"],
Cell[41557, 1519, 218, 5, 30, "Input"],
Cell[41778, 1526, 201, 5, 30, "Input"],
Cell[41982, 1533, 201, 5, 30, "Input"],
Cell[42186, 1540, 201, 5, 30, "Input"],
Cell[42390, 1547, 201, 5, 30, "Input"],
Cell[42594, 1554, 201, 5, 30, "Input"],
Cell[42798, 1561, 501, 9, 107, "Input"],
Cell[43302, 1572, 242, 5, 50, "Input"],
Cell[43547, 1579, 232, 5, 50, "Input"],
Cell[43782, 1586, 196, 5, 30, "Input"],
Cell[43981, 1593, 300, 6, 69, "Input"],
Cell[44284, 1601, 257, 6, 69, "Input"],
Cell[44544, 1609, 229, 5, 50, "Input"],
Cell[44776, 1616, 92, 2, 30, "Input"],
Cell[44871, 1620, 80, 2, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44988, 1627, 110, 2, 61, "Section",
 CellTags->"T1.3.1"],
Cell[45101, 1631, 999, 36, 34, "Text"],
Cell[46103, 1669, 125, 4, 30, "Input"],
Cell[46231, 1675, 253, 8, 50, "Input"],
Cell[46487, 1685, 73, 0, 29, "Text"],
Cell[46563, 1687, 85, 2, 30, "Input"],
Cell[46651, 1691, 115, 3, 29, "Text"],
Cell[46769, 1696, 82, 2, 30, "Input"],
Cell[46854, 1700, 719, 28, 32, "Text"],
Cell[CellGroupData[{
Cell[47598, 1732, 62, 1, 37, "Subsection",
 CellTags->"T1.3.1.1"],
Cell[47663, 1735, 106, 3, 30, "Input"],
Cell[47772, 1740, 632, 16, 50, "Input"],
Cell[48407, 1758, 660, 18, 69, "Input"],
Cell[49070, 1778, 418, 11, 30, "Input"],
Cell[49491, 1791, 115, 3, 29, "Text"],
Cell[49609, 1796, 551, 15, 50, "Input"],
Cell[50163, 1813, 425, 12, 30, "Input"],
Cell[50591, 1827, 514, 15, 30, "Input"],
Cell[51108, 1844, 570, 16, 50, "Input"],
Cell[51681, 1862, 330, 10, 30, "Input"],
Cell[52014, 1874, 412, 12, 30, "Input"],
Cell[52429, 1888, 466, 13, 30, "Input"],
Cell[52898, 1903, 454, 13, 30, "Input"],
Cell[53355, 1918, 513, 13, 126, "Input"],
Cell[53871, 1933, 271, 8, 30, "Input"],
Cell[54145, 1943, 271, 8, 30, "Input"],
Cell[54419, 1953, 271, 8, 30, "Input"],
Cell[54693, 1963, 271, 8, 30, "Input"],
Cell[54967, 1973, 271, 8, 30, "Input"],
Cell[55241, 1983, 174, 5, 30, "Input"],
Cell[55418, 1990, 227, 7, 30, "Input"],
Cell[55648, 1999, 340, 10, 30, "Input"],
Cell[55991, 2011, 630, 17, 30, "Input"],
Cell[56624, 2030, 420, 12, 30, "Input"],
Cell[57047, 2044, 513, 15, 30, "Input"],
Cell[57563, 2061, 340, 10, 30, "Input"],
Cell[57906, 2073, 420, 12, 30, "Input"],
Cell[58329, 2087, 630, 17, 30, "Input"],
Cell[58962, 2106, 1573, 42, 107, "Input"],
Cell[60538, 2150, 1836, 47, 107, "Input"],
Cell[62377, 2199, 1695, 48, 107, "Input"],
Cell[64075, 2249, 1940, 53, 107, "Input"],
Cell[66018, 2304, 629, 19, 30, "Input"],
Cell[66650, 2325, 1876, 50, 107, "Input"],
Cell[68529, 2377, 1709, 47, 88, "Input"],
Cell[70241, 2426, 1130, 32, 88, "Input"],
Cell[71374, 2460, 1709, 47, 88, "Input"],
Cell[73086, 2509, 573, 19, 30, "Input"],
Cell[73662, 2530, 1130, 32, 88, "Input"],
Cell[74795, 2564, 1454, 39, 107, "Input"],
Cell[76252, 2605, 511, 18, 30, "Input"],
Cell[76766, 2625, 1443, 39, 107, "Input"],
Cell[78212, 2666, 403, 13, 30, "Input"],
Cell[78618, 2681, 107, 3, 47, "Text"],
Cell[78728, 2686, 1723, 45, 107, "Input"],
Cell[80454, 2733, 1723, 45, 107, "Input"],
Cell[82180, 2780, 1698, 48, 107, "Input"],
Cell[83881, 2830, 1945, 53, 107, "Input"],
Cell[85829, 2885, 1881, 50, 107, "Input"],
Cell[87713, 2937, 1714, 47, 88, "Input"],
Cell[89430, 2986, 1132, 32, 88, "Input"],
Cell[90565, 3020, 1457, 39, 107, "Input"],
Cell[92025, 3061, 1446, 39, 107, "Input"],
Cell[93474, 3102, 1720, 45, 107, "Input"],
Cell[95197, 3149, 1720, 45, 107, "Input"],
Cell[96920, 3196, 1695, 48, 107, "Input"],
Cell[98618, 3246, 1940, 53, 107, "Input"],
Cell[100561, 3301, 1876, 50, 107, "Input"],
Cell[102440, 3353, 1709, 47, 88, "Input"],
Cell[104152, 3402, 1130, 32, 88, "Input"],
Cell[105285, 3436, 1454, 39, 107, "Input"],
Cell[106742, 3477, 1443, 39, 107, "Input"],
Cell[108188, 3518, 234, 6, 30, "Input"],
Cell[108425, 3526, 234, 6, 30, "Input"],
Cell[108662, 3534, 234, 6, 30, "Input"],
Cell[108899, 3542, 234, 6, 30, "Input"],
Cell[109136, 3550, 234, 6, 30, "Input"],
Cell[109373, 3558, 314, 10, 37, "Input"],
Cell[109690, 3570, 266, 8, 30, "Input"],
Cell[109959, 3580, 415, 11, 30, "Input"],
Cell[110377, 3593, 257, 7, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110671, 3605, 57, 1, 37, "Subsection",
 CellTags->"T1.3.2.1"],
Cell[110731, 3608, 14319, 335, 1249, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125087, 3948, 58, 1, 37, "Subsection",
 CellTags->"T1.3.3.1"],
Cell[125148, 3951, 2155, 59, 165, "Input"],
Cell[127306, 4012, 2155, 59, 165, "Input"],
Cell[129464, 4073, 2155, 59, 165, "Input"],
Cell[131622, 4134, 2155, 59, 165, "Input"],
Cell[133780, 4195, 2155, 59, 165, "Input"],
Cell[135938, 4256, 2155, 59, 165, "Input"],
Cell[138096, 4317, 2155, 59, 165, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140288, 4381, 59, 1, 37, "Subsection",
 CellTags->"T1.3.4.1"],
Cell[140350, 4384, 2266, 68, 107, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142653, 4457, 53, 1, 37, "Subsection",
 CellTags->"T1.3.5.1"],
Cell[142709, 4460, 129, 3, 46, "Input"],
Cell[142841, 4465, 7271, 191, 430, "Input"],
Cell[150115, 4658, 512, 14, 50, "Input"],
Cell[150630, 4674, 662, 25, 34, "Text"],
Cell[151295, 4701, 7374, 198, 373, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158706, 4904, 58, 1, 37, "Subsection",
 CellTags->"T1.3.6.1"],
Cell[158767, 4907, 1699, 48, 126, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160503, 4960, 49, 1, 37, "Subsection",
 CellTags->"T1.3.7.1"],
Cell[160555, 4963, 202, 5, 30, "Input"],
Cell[CellGroupData[{
Cell[160782, 4972, 56, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.1.1"],
Cell[160841, 4975, 738, 28, 34, "Text"],
Cell[161582, 5005, 454, 12, 30, "Input"],
Cell[162039, 5019, 342, 10, 30, "Input"],
Cell[162384, 5031, 344, 10, 30, "Input"],
Cell[162731, 5043, 348, 10, 30, "Input"],
Cell[163082, 5055, 338, 10, 30, "Input"],
Cell[163423, 5067, 346, 10, 30, "Input"],
Cell[163772, 5079, 336, 10, 30, "Input"],
Cell[164111, 5091, 336, 10, 30, "Input"],
Cell[164450, 5103, 344, 10, 30, "Input"],
Cell[164797, 5115, 340, 10, 30, "Input"],
Cell[165140, 5127, 310, 8, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165487, 5140, 52, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.2.1"],
Cell[165542, 5143, 153, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165732, 5153, 53, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.3.1"],
Cell[165788, 5156, 101, 3, 30, "Input"],
Cell[165892, 5161, 154, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166083, 5171, 57, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.4.1"],
Cell[166143, 5174, 177, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166357, 5184, 53, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.5.1"],
Cell[166413, 5187, 3526, 79, 1262, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169976, 5271, 53, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.6.1"],
Cell[170032, 5274, 1588, 50, 69, "Input"],
Cell[171623, 5326, 311, 10, 30, "Input"],
Cell[171937, 5338, 341, 11, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172315, 5354, 53, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.7.1"],
Cell[172371, 5357, 1358, 45, 50, "Input"],
Cell[173732, 5404, 276, 9, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174045, 5418, 53, 1, 28, "Subsubsection",
 CellTags->"T1.3.7.8.1"],
Cell[174101, 5421, 283, 10, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[174445, 5438, 102, 2, 72, "Section",
 CellTags->"T1.4.1"],
Cell[174550, 5442, 810, 25, 92, "Input"],
Cell[175363, 5469, 2976, 89, 237, "Input"],
Cell[178342, 5560, 182, 6, 32, "Text"],
Cell[178527, 5568, 435, 13, 36, "Input"],
Cell[178965, 5583, 95, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[179085, 5589, 108, 3, 38, "Subsection",
 CellTags->"T1.4.1.1"],
Cell[179196, 5594, 224, 7, 30, "Input"],
Cell[179423, 5603, 128, 3, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179588, 5611, 106, 3, 38, "Subsection",
 CellTags->"T1.4.2.1"],
Cell[179697, 5616, 147, 7, 40, "Text"],
Cell[179847, 5625, 1837, 63, 54, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181721, 5693, 196, 6, 38, "Subsection",
 CellTags->"T1.4.3.1"],
Cell[181920, 5701, 2244, 71, 103, "Input"],
Cell[184167, 5774, 179, 5, 30, "Input"],
Cell[184349, 5781, 2260, 68, 77, "Input"],
Cell[186612, 5851, 1307, 40, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187956, 5896, 233, 7, 59, "Subsection",
 CellTags->"T1.4.4.1"],
Cell[188192, 5905, 2949, 92, 132, "Input"],
Cell[191144, 5999, 2791, 91, 106, "Input"],
Cell[193938, 6092, 2791, 91, 106, "Input"],
Cell[196732, 6185, 2791, 91, 106, "Input"],
Cell[199526, 6278, 179, 5, 30, "Input"],
Cell[199708, 6285, 179, 5, 30, "Input"],
Cell[199890, 6292, 165, 5, 30, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[200104, 6303, 95, 2, 72, "Section",
 CellTags->"T1.5.1"],
Cell[CellGroupData[{
Cell[200224, 6309, 64, 1, 37, "Subsection",
 CellTags->"T1.5.1.1"],
Cell[200291, 6312, 131, 3, 47, "Text"],
Cell[200425, 6317, 67, 0, 29, "Text"],
Cell[200495, 6319, 226, 8, 34, "Text"],
Cell[200724, 6329, 3464, 90, 149, "Input"],
Cell[204191, 6421, 3420, 86, 120, "Input"],
Cell[207614, 6509, 275, 8, 30, "Input"],
Cell[207892, 6519, 249, 7, 30, "Input"],
Cell[208144, 6528, 310, 9, 30, "Input"],
Cell[208457, 6539, 283, 8, 30, "Input"],
Cell[208743, 6549, 249, 7, 30, "Input"],
Cell[208995, 6558, 325, 9, 30, "Input"],
Cell[209323, 6569, 182, 6, 41, "Input"],
Cell[209508, 6577, 59, 0, 30, "Input"],
Cell[209570, 6579, 233, 7, 30, "Input"],
Cell[209806, 6588, 233, 7, 30, "Input"],
Cell[210042, 6597, 234, 7, 30, "Input"],
Cell[210279, 6606, 261, 7, 30, "Input"],
Cell[210543, 6615, 235, 7, 30, "Input"],
Cell[210781, 6624, 235, 7, 30, "Input"],
Cell[211019, 6633, 2167, 65, 88, "Input"],
Cell[213189, 6700, 81, 2, 30, "Input"],
Cell[213273, 6704, 610, 18, 30, "Input"],
Cell[213886, 6724, 186, 5, 30, "Input"],
Cell[214075, 6731, 76, 0, 29, "Text"],
Cell[214154, 6733, 173, 6, 30, "Input"],
Cell[214330, 6741, 134, 4, 30, "Input"],
Cell[214467, 6747, 9844, 243, 391, "Input"],
Cell[224314, 6992, 9528, 235, 371, "Input"],
Cell[233845, 7229, 12850, 315, 434, "Input"],
Cell[246698, 7546, 11337, 282, 392, "Input"],
Cell[258038, 7830, 12420, 304, 450, "Input"],
Cell[270461, 8136, 119, 3, 30, "Input"],
Cell[270583, 8141, 1389, 43, 69, "Input"],
Cell[271975, 8186, 1014, 31, 69, "Input"],
Cell[272992, 8219, 1014, 31, 69, "Input"],
Cell[CellGroupData[{
Cell[274031, 8254, 61, 1, 28, "Subsubsection",
 CellTags->"T1.5.1.1.1"],
Cell[274095, 8257, 4767, 148, 177, "Input"],
Cell[278865, 8407, 370, 11, 30, "Input"],
Cell[279238, 8420, 355, 11, 30, "Input"],
Cell[279596, 8433, 420, 14, 30, "Input"],
Cell[280019, 8449, 496, 13, 30, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[280564, 8468, 58, 1, 37, "Subsection",
 CellTags->"T1.5.2.1"],
Cell[280625, 8471, 4291, 127, 290, "Input"],
Cell[CellGroupData[{
Cell[284941, 8602, 52, 1, 28, "Subsubsection",
 CellTags->"T1.5.2.1.1"],
Cell[284996, 8605, 367, 11, 30, "Input"],
Cell[285366, 8618, 393, 12, 30, "Input"],
Cell[285762, 8632, 330, 11, 30, "Input"],
Cell[286095, 8645, 239, 10, 40, "Text"],
Cell[286337, 8657, 20, 0, 29, "Text"],
Cell[286360, 8659, 3284, 95, 100, "Input"],
Cell[289647, 8756, 20, 0, 29, "Text"],
Cell[289670, 8758, 2974, 87, 100, "Input"],
Cell[292647, 8847, 20, 0, 29, "Text"],
Cell[292670, 8849, 1741, 53, 78, "Input"],
Cell[294414, 8904, 20, 0, 29, "Text"],
Cell[294437, 8906, 1475, 44, 118, "Input"],
Cell[295915, 8952, 20, 0, 29, "Text"],
Cell[295938, 8954, 2177, 62, 121, "Input"],
Cell[298118, 9018, 20, 0, 29, "Text"],
Cell[298141, 9020, 2161, 61, 100, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[300351, 9087, 59, 1, 37, "Subsection",
 CellTags->"T1.5.3.1"],
Cell[300413, 9090, 174, 3, 29, "Text"],
Cell[300590, 9095, 139, 3, 47, "Text"],
Cell[CellGroupData[{
Cell[300754, 9102, 67, 1, 28, "Subsubsection",
 CellTags->"T1.5.3.1.1"],
Cell[300824, 9105, 1210, 40, 81, "Input"],
Cell[302037, 9147, 2525, 76, 194, "Input"],
Cell[304565, 9225, 6431, 163, 405, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311033, 9393, 67, 1, 28, "Subsubsection",
 CellTags->"T1.5.3.2.1"],
Cell[311103, 9396, 1018, 34, 81, "Input"],
Cell[312124, 9432, 854, 26, 50, "Input"],
Cell[312981, 9460, 92, 2, 30, "Input"],
Cell[313076, 9464, 6187, 157, 443, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[319324, 9628, 138, 2, 72, "Section",
 CellTags->"T1.6.1"],
Cell[319465, 9632, 793, 26, 30, "Input"],
Cell[320261, 9660, 298, 9, 47, "Text"],
Cell[CellGroupData[{
Cell[320584, 9673, 55, 1, 37, "Subsection",
 CellTags->"T1.6.1.1"],
Cell[320642, 9676, 92, 4, 29, "Text"],
Cell[320737, 9682, 6571, 217, 86, "Input"],
Cell[327311, 9901, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327485, 9910, 57, 1, 37, "Subsection",
 CellTags->"T1.6.2.1"],
Cell[327545, 9913, 255, 9, 30, "Input"],
Cell[CellGroupData[{
Cell[327825, 9926, 167, 7, 28, "Subsubsection",
 CellTags->"T1.6.2.1.1"],
Cell[327995, 9935, 1063, 37, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[329095, 9977, 167, 7, 28, "Subsubsection",
 CellTags->"T1.6.2.2.1"],
Cell[329265, 9986, 1232, 42, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[330534, 10033, 167, 7, 28, "Subsubsection",
 CellTags->"T1.6.2.3.1"],
Cell[330704, 10042, 1232, 42, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331973, 10089, 167, 7, 28, "Subsubsection",
 CellTags->"T1.6.2.4.1"],
Cell[332143, 10098, 1232, 42, 47, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[333424, 10146, 57, 1, 37, "Subsection",
 CellTags->"T1.6.3.1"],
Cell[333484, 10149, 162, 4, 30, "Input"],
Cell[333649, 10155, 377, 12, 33, "Text"],
Cell[334029, 10169, 3094, 113, 39, "Input"],
Cell[337126, 10284, 141, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337304, 10293, 246, 9, 40, "Subsection",
 CellTags->"T1.6.4.1"],
Cell[337553, 10304, 99, 3, 30, "Input"],
Cell[337655, 10309, 539, 17, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[338231, 10331, 57, 1, 37, "Subsection",
 CellTags->"T1.6.5.1"],
Cell[338291, 10334, 162, 4, 30, "Input"],
Cell[338456, 10340, 377, 12, 33, "Text"],
Cell[338836, 10354, 3094, 113, 39, "Input"],
Cell[341933, 10469, 141, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342111, 10478, 246, 9, 40, "Subsection",
 CellTags->"T1.6.6.1"],
Cell[342360, 10489, 99, 3, 30, "Input"],
Cell[342462, 10494, 539, 17, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343038, 10516, 246, 9, 40, "Subsection",
 CellTags->"T1.6.7.1"],
Cell[343287, 10527, 130, 3, 30, "Input"],
Cell[343420, 10532, 260, 7, 30, "Input"],
Cell[343683, 10541, 539, 17, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344259, 10563, 246, 9, 40, "Subsection",
 CellTags->"T1.6.8.1"],
Cell[344508, 10574, 130, 3, 30, "Input"],
Cell[344641, 10579, 260, 7, 30, "Input"],
Cell[344904, 10588, 539, 17, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345480, 10610, 55, 1, 37, "Subsection",
 CellTags->"T1.6.9.1"],
Cell[345538, 10613, 92, 4, 29, "Text"],
Cell[345633, 10619, 6063, 199, 105, "Input"],
Cell[351699, 10820, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351873, 10829, 58, 1, 37, "Subsection",
 CellTags->"T1.6.10.1"],
Cell[351934, 10832, 232, 8, 30, "Input"],
Cell[352169, 10842, 1059, 37, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353265, 10884, 56, 1, 37, "Subsection",
 CellTags->"T1.6.11.1"],
Cell[353324, 10887, 624, 26, 33, "Text"],
Cell[353951, 10915, 3309, 120, 39, "Input"],
Cell[357263, 11037, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357437, 11046, 56, 1, 37, "Subsection",
 CellTags->"T1.6.12.1"],
Cell[357496, 11049, 624, 26, 33, "Text"],
Cell[358123, 11077, 3309, 120, 39, "Input"],
Cell[361435, 11199, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361609, 11208, 56, 1, 37, "Subsection",
 CellTags->"T1.6.13.1"],
Cell[361668, 11211, 6446, 215, 110, "Input"],
Cell[368117, 11428, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368291, 11437, 67, 1, 37, "Subsection",
 CellTags->"T1.6.14.1"],
Cell[368361, 11440, 662, 21, 30, "Input"],
Cell[369026, 11463, 326, 10, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369389, 11478, 58, 1, 37, "Subsection",
 CellTags->"T1.6.15.1"],
Cell[369450, 11481, 22654, 536, 8558, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[392141, 12022, 56, 1, 37, "Subsection",
 CellTags->"T1.6.16.1"],
Cell[392200, 12025, 92, 4, 29, "Text"],
Cell[392295, 12031, 3736, 132, 40, "Input"],
Cell[396034, 12165, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[396208, 12174, 58, 1, 37, "Subsection",
 CellTags->"T1.6.17.1"],
Cell[396269, 12177, 49, 1, 30, "Input"],
Cell[396321, 12180, 232, 8, 30, "Input"],
Cell[396556, 12190, 514, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[397095, 12211, 93, 2, 30, "Input"],
Cell[397191, 12215, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[397321, 12222, 56, 1, 37, "Subsection",
 CellTags->"T1.6.18.1"],
Cell[397380, 12225, 92, 4, 29, "Text"],
Cell[397475, 12231, 5243, 183, 89, "Input"],
Cell[402721, 12416, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402895, 12425, 58, 1, 37, "Subsection",
 CellTags->"T1.6.19.1"],
Cell[402956, 12428, 274, 9, 30, "Input"],
Cell[403233, 12439, 514, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[403772, 12460, 93, 2, 30, "Input"],
Cell[403868, 12464, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[403998, 12471, 58, 1, 37, "Subsection",
 CellTags->"T1.6.20.1"],
Cell[404059, 12474, 340, 11, 30, "Input"],
Cell[404402, 12487, 514, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[404941, 12508, 93, 2, 30, "Input"],
Cell[405037, 12512, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[405165, 12519, 56, 1, 45, "Subsection",
 CellTags->"T1.6.21.1"],
Cell[405224, 12522, 92, 4, 29, "Text"],
Cell[405319, 12528, 2961, 107, 67, "Input"],
Cell[408283, 12637, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408457, 12646, 58, 1, 37, "Subsection",
 CellTags->"T1.6.22.1"],
Cell[408518, 12649, 232, 8, 30, "Input"],
Cell[408753, 12659, 441, 14, 30, "Input"],
Cell[CellGroupData[{
Cell[409219, 12677, 93, 2, 30, "Input"],
Cell[409315, 12681, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[409443, 12688, 56, 1, 45, "Subsection",
 CellTags->"T1.6.23.1"],
Cell[409502, 12691, 92, 4, 29, "Text"],
Cell[409597, 12697, 3700, 132, 67, "Input"],
Cell[413300, 12831, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413474, 12840, 58, 1, 37, "Subsection",
 CellTags->"T1.6.24.1"],
Cell[413535, 12843, 232, 8, 30, "Input"],
Cell[413770, 12853, 515, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[414310, 12873, 93, 2, 30, "Input"],
Cell[414406, 12877, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[414534, 12884, 56, 1, 45, "Subsection",
 CellTags->"T1.6.25.1"],
Cell[414593, 12887, 92, 4, 29, "Text"],
Cell[414688, 12893, 3457, 123, 69, "Input"],
Cell[418148, 13018, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418322, 13027, 58, 1, 37, "Subsection",
 CellTags->"T1.6.26.1"],
Cell[418383, 13030, 232, 8, 30, "Input"],
Cell[418618, 13040, 517, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[419160, 13060, 93, 2, 30, "Input"],
Cell[419256, 13064, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[419384, 13071, 56, 1, 37, "Subsection",
 CellTags->"T1.6.27.1"],
Cell[419443, 13074, 230, 9, 32, "Text"],
Cell[419676, 13085, 5729, 194, 116, "Input"],
Cell[425408, 13281, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[425582, 13290, 58, 1, 37, "Subsection",
 CellTags->"T1.6.28.1"],
Cell[425643, 13293, 95, 3, 30, "Input"],
Cell[425741, 13298, 1867, 49, 100, "Input"],
Cell[427611, 13349, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[427698, 13354, 57, 1, 37, "Subsection",
 CellTags->"T1.6.29.1"],
Cell[427758, 13357, 92, 4, 29, "Text"],
Cell[427853, 13363, 2961, 107, 67, "Input"],
Cell[430817, 13472, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[430991, 13481, 58, 1, 37, "Subsection",
 CellTags->"T1.6.30.1"],
Cell[431052, 13484, 232, 8, 30, "Input"],
Cell[431287, 13494, 448, 14, 30, "Input"],
Cell[CellGroupData[{
Cell[431760, 13512, 105, 2, 30, "Input"],
Cell[431868, 13516, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[431996, 13523, 57, 1, 37, "Subsection",
 CellTags->"T1.6.31.1"],
Cell[432056, 13526, 382, 16, 32, "Text"],
Cell[432441, 13544, 2278, 86, 39, "Input"],
Cell[434722, 13632, 137, 4, 30, "Input"],
Cell[434862, 13638, 2028, 76, 58, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436927, 13719, 58, 1, 37, "Subsection",
 CellTags->"T1.6.32.1"],
Cell[436988, 13722, 381, 16, 32, "Text"],
Cell[437372, 13740, 95, 3, 30, "Input"],
Cell[437470, 13745, 117, 3, 24, "SmallText"],
Cell[437590, 13750, 725, 26, 24, "SmallText"],
Cell[438318, 13778, 602, 22, 30, "Input"],
Cell[438923, 13802, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439010, 13807, 60, 1, 37, "Subsection",
 CellTags->"T1.6.33.1"],
Cell[439073, 13810, 381, 16, 32, "Text"],
Cell[439457, 13828, 202, 6, 30, "Input"],
Cell[439662, 13836, 117, 3, 24, "SmallText"],
Cell[439782, 13841, 731, 26, 24, "SmallText"],
Cell[440516, 13869, 608, 22, 30, "Input"],
Cell[441127, 13893, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[441214, 13898, 57, 1, 37, "Subsection",
 CellTags->"T1.6.34.1"],
Cell[441274, 13901, 512, 21, 50, "Text"],
Cell[441789, 13924, 4989, 173, 116, "Input"],
Cell[446781, 14099, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446955, 14108, 58, 1, 37, "Subsection",
 CellTags->"T1.6.35.1"],
Cell[447016, 14111, 274, 9, 30, "Input"],
Cell[447293, 14122, 1136, 39, 34, "Input"],
Cell[448432, 14163, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448519, 14168, 57, 1, 37, "Subsection",
 CellTags->"T1.6.36.1"],
Cell[448579, 14171, 277, 10, 50, "Text"],
Cell[448859, 14183, 6180, 202, 93, "Input"],
Cell[455042, 14387, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455216, 14396, 58, 1, 37, "Subsection",
 CellTags->"T1.6.37.1"],
Cell[455277, 14399, 246, 10, 32, "Text"],
Cell[455526, 14411, 136, 4, 30, "Input"],
Cell[455665, 14417, 782, 25, 30, "Input"],
Cell[CellGroupData[{
Cell[456472, 14446, 93, 2, 30, "Input"],
Cell[456568, 14450, 79, 1, 23, "Print"]
}, Open  ]],
Cell[456662, 14454, 880, 28, 30, "Input"],
Cell[457545, 14484, 106, 5, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[457688, 14494, 60, 1, 37, "Subsection",
 CellTags->"T1.6.38.1"],
Cell[457751, 14497, 263, 8, 30, "Input"],
Cell[458017, 14507, 596, 21, 30, "Input"],
Cell[458616, 14530, 80, 2, 30, "Input"],
Cell[458699, 14534, 172, 5, 30, "Input"],
Cell[458874, 14541, 126, 4, 30, "Input"],
Cell[459003, 14547, 479, 17, 30, "Input"],
Cell[459485, 14566, 1204, 37, 34, "Input"],
Cell[460692, 14605, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460779, 14610, 60, 1, 37, "Subsection",
 CellTags->"T1.6.39.1"],
Cell[460842, 14613, 263, 8, 30, "Input"],
Cell[461108, 14623, 141, 4, 30, "Input"],
Cell[461252, 14629, 126, 4, 30, "Input"],
Cell[461381, 14635, 479, 17, 30, "Input"],
Cell[461863, 14654, 1128, 33, 34, "Input"],
Cell[462994, 14689, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[463081, 14694, 60, 1, 37, "Subsection",
 CellTags->"T1.6.40.1"],
Cell[463144, 14697, 447, 15, 30, "Input"],
Cell[463594, 14714, 479, 17, 30, "Input"],
Cell[464076, 14733, 576, 18, 30, "Input"],
Cell[464655, 14753, 50, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464742, 14758, 57, 1, 37, "Subsection",
 CellTags->"T1.6.41.1"],
Cell[464802, 14761, 92, 4, 29, "Text"],
Cell[464897, 14767, 4921, 172, 68, "Input"],
Cell[469821, 14941, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[469995, 14950, 58, 1, 37, "Subsection",
 CellTags->"T1.6.42.1"],
Cell[470056, 14953, 588, 20, 30, "Input"],
Cell[470647, 14975, 728, 23, 30, "Input"],
Cell[CellGroupData[{
Cell[471400, 15002, 93, 2, 30, "Input"],
Cell[471496, 15006, 77, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[471622, 15013, 67, 1, 37, "Subsection",
 CellTags->"T1.6.43.1"],
Cell[471692, 15016, 111, 3, 29, "Text"],
Cell[471806, 15021, 92, 4, 29, "Text"],
Cell[471901, 15027, 5657, 200, 91, "Input"],
Cell[477561, 15229, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477735, 15238, 56, 1, 37, "Subsection",
 CellTags->"T1.6.44.1"],
Cell[477794, 15241, 92, 4, 29, "Text"],
Cell[477889, 15247, 5038, 179, 89, "Input"],
Cell[482930, 15428, 8601, 306, 64, "Text"],
Cell[491534, 15736, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[491708, 15745, 58, 1, 37, "Subsection",
 CellTags->"T1.6.45.1"],
Cell[491769, 15748, 463, 16, 30, "Input"],
Cell[492235, 15766, 659, 21, 30, "Input"],
Cell[CellGroupData[{
Cell[492919, 15791, 93, 2, 30, "Input"],
Cell[493015, 15795, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[493143, 15802, 60, 1, 37, "Subsection",
 CellTags->"T1.6.46.1"],
Cell[493206, 15805, 573, 19, 30, "Input"],
Cell[493782, 15826, 665, 21, 30, "Input"],
Cell[CellGroupData[{
Cell[494472, 15851, 95, 2, 30, "Input"],
Cell[494570, 15855, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[494698, 15862, 56, 1, 37, "Subsection",
 CellTags->"T1.6.47.1"],
Cell[494757, 15865, 92, 4, 29, "Text"],
Cell[494852, 15871, 6060, 203, 91, "Input"],
Cell[500915, 16076, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[501089, 16085, 58, 1, 37, "Subsection",
 CellTags->"T1.6.48.1"],
Cell[501150, 16088, 463, 16, 30, "Input"],
Cell[501616, 16106, 700, 22, 30, "Input"],
Cell[CellGroupData[{
Cell[502341, 16132, 93, 2, 30, "Input"],
Cell[502437, 16136, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[502565, 16143, 60, 1, 37, "Subsection",
 CellTags->"T1.6.49.1"],
Cell[502628, 16146, 573, 19, 30, "Input"],
Cell[503204, 16167, 725, 23, 30, "Input"],
Cell[CellGroupData[{
Cell[503954, 16194, 95, 2, 30, "Input"],
Cell[504052, 16198, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[504180, 16205, 56, 1, 37, "Subsection",
 CellTags->"T1.6.50.1"],
Cell[504239, 16208, 92, 4, 29, "Text"],
Cell[504334, 16214, 11843, 400, 205, "Input"],
Cell[516180, 16616, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516354, 16625, 58, 1, 37, "Subsection",
 CellTags->"T1.6.51.1"],
Cell[516415, 16628, 95, 3, 30, "Input"],
Cell[516513, 16633, 591, 19, 30, "Input"],
Cell[517107, 16654, 104, 3, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517248, 16662, 56, 1, 37, "Subsection",
 CellTags->"T1.6.52.1"],
Cell[517307, 16665, 258, 11, 29, "Text"],
Cell[517568, 16678, 5262, 182, 123, "Input"],
Cell[522833, 16862, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[523007, 16871, 58, 1, 37, "Subsection",
 CellTags->"T1.6.53.1"],
Cell[523068, 16874, 407, 14, 30, "Input"],
Cell[523478, 16890, 461, 15, 30, "Input"],
Cell[CellGroupData[{
Cell[523964, 16909, 93, 2, 30, "Input"],
Cell[524060, 16913, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[524188, 16920, 60, 1, 37, "Subsection",
 CellTags->"T1.6.54.1"],
Cell[524251, 16923, 477, 16, 30, "Input"],
Cell[524731, 16941, 467, 15, 30, "Input"],
Cell[CellGroupData[{
Cell[525223, 16960, 95, 2, 30, "Input"],
Cell[525321, 16964, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[525449, 16971, 60, 1, 37, "Subsection",
 CellTags->"T1.6.55.1"],
Cell[525512, 16974, 477, 16, 30, "Input"],
Cell[525992, 16992, 467, 15, 30, "Input"],
Cell[CellGroupData[{
Cell[526484, 17011, 95, 2, 30, "Input"],
Cell[526582, 17015, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[526710, 17022, 56, 1, 37, "Subsection",
 CellTags->"T1.6.56.1"],
Cell[526769, 17025, 204, 9, 29, "Text"],
Cell[526976, 17036, 6020, 205, 91, "Input"],
Cell[532999, 17243, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533173, 17252, 58, 1, 37, "Subsection",
 CellTags->"T1.6.57.1"],
Cell[533234, 17255, 269, 9, 30, "Input"],
Cell[533506, 17266, 453, 15, 30, "Input"],
Cell[CellGroupData[{
Cell[533984, 17285, 93, 2, 30, "Input"],
Cell[534080, 17289, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[534208, 17296, 56, 1, 37, "Subsection",
 CellTags->"T1.6.58.1"],
Cell[534267, 17299, 216, 9, 29, "Text"],
Cell[534486, 17310, 5082, 166, 116, "Input"],
Cell[539571, 17478, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539745, 17487, 58, 1, 37, "Subsection",
 CellTags->"T1.6.59.1"],
Cell[539806, 17490, 274, 9, 30, "Input"],
Cell[540083, 17501, 439, 13, 30, "Input"],
Cell[CellGroupData[{
Cell[540547, 17518, 93, 2, 30, "Input"],
Cell[540643, 17522, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[540773, 17529, 56, 1, 45, "Subsection",
 CellTags->"T1.6.60.1"],
Cell[540832, 17532, 257, 11, 29, "Text"],
Cell[541092, 17545, 5303, 181, 91, "Input"],
Cell[546398, 17728, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[546572, 17737, 58, 1, 37, "Subsection",
 CellTags->"T1.6.61.1"],
Cell[546633, 17740, 493, 17, 30, "Input"],
Cell[547129, 17759, 551, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[547705, 17780, 93, 2, 30, "Input"],
Cell[547801, 17784, 78, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[547928, 17791, 60, 1, 37, "Subsection",
 CellTags->"T1.6.62.1"],
Cell[547991, 17794, 565, 19, 30, "Input"],
Cell[548559, 17815, 557, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[549141, 17836, 95, 2, 30, "Input"],
Cell[549239, 17840, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[549367, 17847, 60, 1, 37, "Subsection",
 CellTags->"T1.6.63.1"],
Cell[549430, 17850, 580, 19, 30, "Input"],
Cell[550013, 17871, 557, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[550595, 17892, 95, 2, 30, "Input"],
Cell[550693, 17896, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[550823, 17903, 56, 1, 45, "Subsection",
 CellTags->"T1.6.64.1"],
Cell[550882, 17906, 203, 9, 29, "Text"],
Cell[551088, 17917, 12433, 402, 190, "Input"],
Cell[563524, 18321, 137, 4, 30, "Input"],
Cell[563664, 18327, 124, 4, 30, "Input"],
Cell[563791, 18333, 511, 18, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[564339, 18356, 58, 1, 37, "Subsection",
 CellTags->"T1.6.65.1"],
Cell[564400, 18359, 350, 12, 30, "Input"],
Cell[564753, 18373, 544, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[565322, 18394, 93, 2, 30, "Input"],
Cell[565418, 18398, 78, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[565545, 18405, 60, 1, 37, "Subsection",
 CellTags->"T1.6.66.1"],
Cell[565608, 18408, 420, 14, 30, "Input"],
Cell[566031, 18424, 548, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[566604, 18445, 95, 2, 30, "Input"],
Cell[566702, 18449, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[566832, 18456, 60, 1, 37, "Subsection",
 CellTags->"T1.6.67.1"],
Cell[566895, 18459, 420, 14, 30, "Input"],
Cell[567318, 18475, 550, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[567893, 18496, 95, 2, 30, "Input"],
Cell[567991, 18500, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[568119, 18507, 56, 1, 45, "Subsection",
 CellTags->"T1.6.68.1"],
Cell[568178, 18510, 216, 9, 29, "Text"],
Cell[568397, 18521, 7673, 251, 117, "Input"],
Cell[576073, 18774, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576247, 18783, 58, 1, 37, "Subsection",
 CellTags->"T1.6.69.1"],
Cell[576308, 18786, 350, 12, 30, "Input"],
Cell[576661, 18800, 515, 15, 30, "Input"],
Cell[CellGroupData[{
Cell[577201, 18819, 93, 2, 30, "Input"],
Cell[577297, 18823, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[577425, 18830, 56, 1, 45, "Subsection",
 CellTags->"T1.6.70.1"],
Cell[CellGroupData[{
Cell[577506, 18835, 55, 1, 28, "Subsubsection",
 CellTags->"T1.6.70.1.1"],
Cell[577564, 18838, 226, 7, 30, "Input"],
Cell[577793, 18847, 688, 22, 34, "Input"],
Cell[578484, 18871, 957, 29, 34, "Input"],
Cell[579444, 18902, 1648, 56, 78, "Input"],
Cell[581095, 18960, 294, 9, 34, "Input"],
Cell[581392, 18971, 294, 9, 34, "Input"],
Cell[581689, 18982, 294, 9, 34, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[582020, 18996, 55, 1, 28, "Subsubsection",
 CellTags->"T1.6.70.2.1"],
Cell[582078, 18999, 1446, 50, 74, "Input"],
Cell[583527, 19051, 294, 9, 34, "Input"],
Cell[583824, 19062, 294, 9, 34, "Input"],
Cell[584121, 19073, 294, 9, 34, "Input"],
Cell[584418, 19084, 81, 2, 30, "Input"],
Cell[584502, 19088, 99, 5, 29, "Text"],
Cell[584604, 19095, 5993, 211, 159, "Input"],
Cell[590600, 19308, 137, 4, 30, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[590786, 19318, 58, 1, 37, "Subsection",
 CellTags->"T1.6.71.1"],
Cell[590847, 19321, 95, 3, 30, "Input"],
Cell[590945, 19326, 443, 14, 30, "Input"],
Cell[591391, 19342, 49, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591477, 19347, 56, 1, 37, "Subsection",
 CellTags->"T1.6.72.1"],
Cell[591536, 19350, 99, 5, 29, "Text"],
Cell[591638, 19357, 11665, 369, 300, "Input"],
Cell[603306, 19728, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603480, 19737, 58, 1, 37, "Subsection",
 CellTags->"T1.6.73.1"],
Cell[603541, 19740, 115, 4, 30, "Input"],
Cell[603659, 19746, 413, 13, 30, "Input"],
Cell[604075, 19761, 49, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[604161, 19766, 56, 1, 37, "Subsection",
 CellTags->"T1.6.74.1"],
Cell[604220, 19769, 92, 4, 29, "Text"],
Cell[604315, 19775, 2266, 85, 39, "Input"],
Cell[606584, 19862, 141, 4, 30, "Input"],
Cell[606728, 19868, 2281, 85, 40, "Input"],
Cell[609012, 19955, 141, 4, 30, "Input"],
Cell[609156, 19961, 2582, 92, 39, "Input"],
Cell[611741, 20055, 141, 4, 30, "Input"],
Cell[611885, 20061, 3514, 124, 40, "Input"],
Cell[615402, 20187, 141, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[615580, 20196, 59, 1, 37, "Subsection",
 CellTags->"T1.6.75.1"],
Cell[615642, 20199, 230, 8, 30, "Input"],
Cell[615875, 20209, 444, 14, 30, "Input"],
Cell[616322, 20225, 49, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[616408, 20230, 59, 1, 37, "Subsection",
 CellTags->"T1.6.76.1"],
Cell[616470, 20233, 367, 13, 30, "Input"],
Cell[616840, 20248, 513, 16, 30, "Input"],
Cell[617356, 20266, 49, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617442, 20271, 59, 1, 37, "Subsection",
 CellTags->"T1.6.77.1"],
Cell[617504, 20274, 98, 3, 30, "Input"],
Cell[617605, 20279, 549, 16, 30, "Input"],
Cell[618157, 20297, 49, 0, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618243, 20302, 59, 1, 37, "Subsection",
 CellTags->"T1.6.78.1"],
Cell[618305, 20305, 230, 8, 30, "Input"],
Cell[618538, 20315, 531, 15, 30, "Input"],
Cell[619072, 20332, 49, 0, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[619158, 20337, 56, 1, 45, "Subsection",
 CellTags->"T1.6.79.1"],
Cell[619217, 20340, 181, 6, 32, "Text"],
Cell[619401, 20348, 181, 5, 30, "Input"],
Cell[619585, 20355, 501, 16, 34, "Text"],
Cell[620089, 20373, 4798, 160, 67, "Input"],
Cell[624890, 20535, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[625064, 20544, 56, 1, 45, "Subsection",
 CellTags->"T1.6.80.1"],
Cell[625123, 20547, 551, 20, 32, "Text"],
Cell[625677, 20569, 2593, 92, 39, "Input"],
Cell[628273, 20663, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[628447, 20672, 58, 1, 37, "Subsection",
 CellTags->"T1.6.81.1"],
Cell[628508, 20675, 227, 8, 30, "Input"],
Cell[628738, 20685, 469, 15, 30, "Input"],
Cell[629210, 20702, 49, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[629296, 20707, 56, 1, 37, "Subsection",
 CellTags->"T1.6.82.1"],
Cell[629355, 20710, 92, 4, 29, "Text"],
Cell[629450, 20716, 2800, 98, 40, "Input"],
Cell[632253, 20816, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[632427, 20825, 58, 1, 37, "Subsection",
 CellTags->"T1.6.83.1"],
Cell[632488, 20828, 227, 8, 30, "Input"],
Cell[632718, 20838, 402, 12, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[633157, 20855, 60, 1, 37, "Subsection",
 CellTags->"T1.6.84.1"],
Cell[633220, 20858, 335, 11, 30, "Input"],
Cell[633558, 20871, 335, 12, 30, "Input"],
Cell[633896, 20885, 486, 14, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[634419, 20904, 60, 1, 37, "Subsection",
 CellTags->"T1.6.85.1"],
Cell[634482, 20907, 456, 14, 30, "Input"],
Cell[634941, 20923, 335, 12, 30, "Input"],
Cell[635279, 20937, 486, 14, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[635802, 20956, 56, 1, 37, "Subsection",
 CellTags->"T1.6.86.1"],
Cell[635861, 20959, 92, 4, 29, "Text"],
Cell[635956, 20965, 1860, 71, 39, "Input"],
Cell[637819, 21038, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637993, 21047, 58, 1, 37, "Subsection",
 CellTags->"T1.6.87.1"],
Cell[638054, 21050, 227, 8, 30, "Input"],
Cell[638284, 21060, 451, 14, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[638772, 21079, 56, 1, 45, "Subsection",
 CellTags->"T1.6.88.1"],
Cell[638831, 21082, 92, 4, 29, "Text"],
Cell[638926, 21088, 2026, 74, 39, "Input"],
Cell[640955, 21164, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[641129, 21173, 58, 1, 37, "Subsection",
 CellTags->"T1.6.89.1"],
Cell[641190, 21176, 95, 3, 30, "Input"],
Cell[641288, 21181, 395, 11, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[641720, 21197, 56, 1, 45, "Subsection",
 CellTags->"T1.6.90.1"],
Cell[641779, 21200, 92, 4, 29, "Text"],
Cell[641874, 21206, 1200, 46, 39, "Input"],
Cell[643077, 21254, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[643251, 21263, 58, 1, 37, "Subsection",
 CellTags->"T1.6.91.1"],
Cell[643312, 21266, 227, 8, 30, "Input"],
Cell[643542, 21276, 374, 11, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[643953, 21292, 56, 1, 45, "Subsection",
 CellTags->"T1.6.92.1"],
Cell[644012, 21295, 92, 4, 29, "Text"],
Cell[644107, 21301, 1074, 41, 39, "Input"],
Cell[645184, 21344, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[645358, 21353, 58, 1, 37, "Subsection",
 CellTags->"T1.6.93.1"],
Cell[645419, 21356, 95, 3, 30, "Input"],
Cell[645517, 21361, 357, 11, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[645911, 21377, 56, 1, 37, "Subsection",
 CellTags->"T1.6.94.1"],
Cell[645970, 21380, 330, 11, 33, "Text"],
Cell[646303, 21393, 2031, 72, 37, "Text"],
Cell[648337, 21467, 2424, 90, 39, "Input"],
Cell[650764, 21559, 137, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[650938, 21568, 58, 1, 37, "Subsection",
 CellTags->"T1.6.95.1"],
Cell[650999, 21571, 227, 8, 30, "Input"],
Cell[651229, 21581, 471, 15, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[651737, 21601, 60, 1, 37, "Subsection",
 CellTags->"T1.6.96.1"],
Cell[651800, 21604, 344, 11, 30, "Input"],
Cell[652147, 21617, 477, 15, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[652661, 21637, 60, 1, 37, "Subsection",
 CellTags->"T1.6.97.1"],
Cell[652724, 21640, 344, 11, 30, "Input"],
Cell[653071, 21653, 477, 15, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[653585, 21673, 57, 1, 37, "Subsection",
 CellTags->"T1.6.98.1"],
Cell[653645, 21676, 39, 0, 29, "Text"],
Cell[653687, 21678, 2717, 96, 37, "Text"],
Cell[656407, 21776, 116, 3, 29, "Text"],
Cell[656526, 21781, 2981, 112, 39, "Input"],
Cell[659510, 21895, 139, 4, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[659686, 21904, 59, 1, 37, "Subsection",
 CellTags->"T1.6.99.1"],
Cell[659748, 21907, 97, 3, 30, "Input"],
Cell[659848, 21912, 510, 17, 30, "Input"],
Cell[CellGroupData[{
Cell[660383, 21933, 94, 2, 30, "Input"],
Cell[660480, 21937, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[660608, 21944, 61, 1, 37, "Subsection",
 CellTags->"T1.6.100.1"],
Cell[660672, 21947, 203, 6, 30, "Input"],
Cell[660878, 21955, 508, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[661411, 21975, 95, 2, 30, "Input"],
Cell[661509, 21979, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[661637, 21986, 61, 1, 37, "Subsection",
 CellTags->"T1.6.101.1"],
Cell[661701, 21989, 254, 7, 30, "Input"],
Cell[661958, 21998, 508, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[662491, 22018, 95, 2, 30, "Input"],
Cell[662589, 22022, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[662719, 22029, 61, 1, 37, "Subsection",
 CellTags->"T1.6.102.1"],
Cell[662783, 22032, 203, 6, 30, "Input"],
Cell[662989, 22040, 508, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[663522, 22060, 95, 2, 30, "Input"],
Cell[663620, 22064, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[663750, 22071, 61, 1, 37, "Subsection",
 CellTags->"T1.6.103.1"],
Cell[663814, 22074, 203, 6, 30, "Input"],
Cell[664020, 22082, 508, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[664553, 22102, 95, 2, 30, "Input"],
Cell[664651, 22106, 81, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[664781, 22113, 61, 1, 37, "Subsection",
 CellTags->"T1.6.104.1"],
Cell[664845, 22116, 254, 7, 30, "Input"],
Cell[665102, 22125, 508, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[665635, 22145, 95, 2, 30, "Input"],
Cell[665733, 22149, 79, 1, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[665861, 22156, 58, 1, 45, "Subsection",
 CellTags->"T1.6.105.1"],
Cell[665922, 22159, 116, 4, 30, "Text"],
Cell[666041, 22165, 525, 16, 34, "Text"],
Cell[666569, 22183, 2289, 70, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[668895, 22258, 60, 1, 37, "Subsection",
 CellTags->"T1.6.106.1"],
Cell[668958, 22261, 97, 3, 30, "Input"],
Cell[669058, 22266, 169, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[669264, 22276, 58, 1, 45, "Subsection",
 CellTags->"T1.6.107.1"],
Cell[669325, 22279, 116, 4, 30, "Text"],
Cell[669444, 22285, 525, 16, 34, "Text"],
Cell[669972, 22303, 2595, 78, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[672604, 22386, 60, 1, 37, "Subsection",
 CellTags->"T1.6.108.1"],
Cell[672667, 22389, 97, 3, 30, "Input"],
Cell[672767, 22394, 361, 11, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[673165, 22410, 58, 1, 45, "Subsection",
 CellTags->"T1.6.109.1"],
Cell[673226, 22413, 116, 4, 30, "Text"],
Cell[673345, 22419, 525, 16, 34, "Text"],
Cell[673873, 22437, 2074, 64, 69, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[675984, 22506, 60, 1, 37, "Subsection",
 CellTags->"T1.6.110.1"],
Cell[676047, 22509, 97, 3, 30, "Input"],
Cell[676147, 22514, 169, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676353, 22524, 58, 1, 45, "Subsection",
 CellTags->"T1.6.111.1"],
Cell[676414, 22527, 116, 4, 29, "Text"],
Cell[676533, 22533, 1559, 48, 69, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[678129, 22586, 60, 1, 37, "Subsection",
 CellTags->"T1.6.112.1"],
Cell[678192, 22589, 97, 3, 30, "Input"],
Cell[678292, 22594, 169, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[678498, 22604, 58, 1, 37, "Subsection",
 CellTags->"T1.6.113.1"],
Cell[678559, 22607, 43, 0, 29, "Text"],
Cell[678605, 22609, 305, 10, 33, "Text"],
Cell[678913, 22621, 6831, 224, 96, "Input"],
Cell[685747, 22847, 386, 9, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[686170, 22861, 60, 1, 37, "Subsection",
 CellTags->"T1.6.114.1"],
Cell[686233, 22864, 229, 8, 30, "Input"],
Cell[686465, 22874, 625, 20, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687127, 22899, 60, 1, 37, "Subsection",
 CellTags->"T1.6.115.1"],
Cell[687190, 22902, 691, 29, 446, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687918, 22936, 60, 1, 37, "Subsection",
 CellTags->"T1.6.116.1"],
Cell[687981, 22939, 695, 29, 446, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[688713, 22973, 61, 1, 37, "Subsection",
 CellTags->"T1.6.117.1"],
Cell[688777, 22976, 3385, 91, 297, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[692199, 23072, 61, 1, 37, "Subsection",
 CellTags->"T1.6.118.1"],
Cell[692263, 23075, 3355, 91, 278, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[695655, 23171, 61, 1, 37, "Subsection",
 CellTags->"T1.6.119.1"],
Cell[695719, 23174, 3349, 91, 278, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[699105, 23270, 60, 1, 37, "Subsection",
 CellTags->"T1.6.120.1"],
Cell[699168, 23273, 240, 6, 94, "Input"],
Cell[CellGroupData[{
Cell[699433, 23283, 4436, 118, 192, "Input"],
Cell[703872, 23403, 1607, 22, 23, "Print"]
}, Open  ]],
Cell[705494, 23428, 23, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[705542, 23432, 1926, 50, 123, "Input"],
Cell[707471, 23484, 1605, 22, 23, "Print"]
}, Open  ]],
Cell[709091, 23509, 53, 1, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[709181, 23515, 54, 1, 37, "Subsection",
 CellTags->"Tsymmetry"],
Cell[709238, 23518, 34, 0, 29, "Text"],
Cell[709275, 23520, 107, 3, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[709419, 23528, 69, 1, 37, "Subsection",
 CellTags->"specialTVR"],
Cell[709491, 23531, 579, 11, 174, "Input"],
Cell[710073, 23544, 1683, 27, 414, "Input"],
Cell[711759, 23573, 1597, 26, 398, "Input"],
Cell[713359, 23601, 3547, 56, 894, "Input"],
Cell[716909, 23659, 3261, 52, 830, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[720207, 23716, 59, 1, 37, "Subsection",
 CellTags->"T1.6.121.1"],
Cell[720269, 23719, 230, 5, 83, "Text"],
Cell[720502, 23726, 1143, 33, 88, "Input"],
Cell[721648, 23761, 237, 5, 83, "Text"],
Cell[721888, 23768, 1251, 37, 88, "Input"],
Cell[723142, 23807, 239, 5, 83, "Text"],
Cell[723384, 23814, 1257, 37, 88, "Input"],
Cell[724644, 23853, 238, 5, 83, "Text"],
Cell[724885, 23860, 1252, 37, 88, "Input"],
Cell[726140, 23899, 219, 14, 245, "Text"],
Cell[726362, 23915, 200, 5, 78, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[726599, 23925, 60, 1, 37, "Subsection",
 CellTags->"T1.6.122.1"],
Cell[726662, 23928, 949, 29, 69, "Input"],
Cell[727614, 23959, 949, 29, 69, "Input"],
Cell[728566, 23990, 133, 3, 46, "Input"],
Cell[728702, 23995, 846, 25, 69, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[729585, 24025, 59, 1, 37, "Subsection",
 CellTags->"T1.6.123.1"],
Cell[729647, 24028, 793, 25, 50, "Input"],
Cell[730443, 24055, 793, 25, 50, "Input"],
Cell[731239, 24082, 792, 25, 50, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[732068, 24112, 57, 1, 37, "Subsection",
 CellTags->"T1.6.124.1"],
Cell[732128, 24115, 535, 17, 50, "Input"],
Cell[732666, 24134, 533, 17, 50, "Input"],
Cell[733202, 24153, 362, 12, 30, "Input"],
Cell[733567, 24167, 334, 11, 30, "Input"],
Cell[733904, 24180, 344, 11, 30, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[734297, 24197, 106, 2, 72, "Section",
 CellTags->"T1.7.1"],
Cell[CellGroupData[{
Cell[734428, 24203, 69, 1, 37, "Subsection",
 CellTags->"T1.7.1.1"],
Cell[734500, 24206, 45, 0, 29, "Text"],
Cell[734548, 24208, 81, 2, 30, "Input"],
Cell[734632, 24212, 275, 7, 30, "Input"],
Cell[734910, 24221, 451, 15, 30, "Input"],
Cell[735364, 24238, 354, 11, 30, "Input"],
Cell[735721, 24251, 453, 15, 30, "Input"],
Cell[736177, 24268, 356, 11, 30, "Input"],
Cell[736536, 24281, 82, 2, 29, "Text"],
Cell[736621, 24285, 84, 2, 30, "Input"],
Cell[736708, 24289, 336, 11, 30, "Input"],
Cell[737047, 24302, 215, 7, 101, "Text",
 CellTags->"TLRdef"],
Cell[737265, 24311, 388, 13, 30, "Input"],
Cell[737656, 24326, 755, 23, 30, "Input"],
Cell[738414, 24351, 26, 0, 29, "Text"],
Cell[738443, 24353, 3735, 100, 232, "Input"],
Cell[742181, 24455, 102, 2, 33, "Text"],
Cell[742286, 24459, 3693, 97, 232, "Input"],
Cell[745982, 24558, 127, 3, 31, "Text"],
Cell[746112, 24563, 2718, 74, 202, "Input"],
Cell[748833, 24639, 127, 3, 31, "Text"],
Cell[748963, 24644, 2980, 82, 202, "Input"],
Cell[751946, 24728, 150, 4, 31, "Text"],
Cell[752099, 24734, 3363, 91, 246, "Input"],
Cell[755465, 24827, 37, 0, 29, "Text"],
Cell[755505, 24829, 2534, 69, 120, "Input"],
Cell[758042, 24900, 37, 0, 29, "Text"],
Cell[758082, 24902, 2524, 69, 120, "Input"],
Cell[760609, 24973, 35, 0, 29, "Text"],
Cell[760647, 24975, 2979, 76, 297, "Input"],
Cell[763629, 25053, 31, 0, 29, "Text"],
Cell[763663, 25055, 224, 6, 101, "Text"],
Cell[763890, 25063, 31, 0, 29, "Text"],
Cell[763924, 25065, 204, 5, 62, "Input"],
Cell[764131, 25072, 146, 3, 47, "Text"],
Cell[764280, 25077, 443, 15, 222, "Input"],
Cell[764726, 25094, 443, 15, 222, "Input"],
Cell[765172, 25111, 49, 0, 29, "Text"],
Cell[765224, 25113, 1495, 43, 82, "Input"],
Cell[766722, 25158, 49, 0, 29, "Text"],
Cell[766774, 25160, 1498, 43, 81, "Input"],
Cell[768275, 25205, 25, 0, 29, "Text"],
Cell[768303, 25207, 876, 27, 50, "Input"],
Cell[769182, 25236, 989, 29, 50, "Input"],
Cell[770174, 25267, 77, 1, 29, "Text",
 CellTags->"tlrule17"],
Cell[770254, 25270, 2195, 64, 189, "Input"],
Cell[772452, 25336, 3938, 106, 233, "Input"],
Cell[776393, 25444, 3938, 106, 233, "Input"],
Cell[780334, 25552, 37, 0, 29, "Text"],
Cell[780374, 25554, 1908, 54, 189, "Input"],
Cell[782285, 25610, 1071, 31, 50, "Input"],
Cell[783359, 25643, 1289, 35, 76, "Input"],
Cell[784651, 25680, 5310, 191, 164, "Text"],
Cell[789964, 25873, 3323, 91, 224, "Input"],
Cell[793290, 25966, 9990, 351, 113, "Text"],
Cell[803283, 26319, 3684, 103, 235, "Input"],
Cell[806970, 26424, 65, 0, 29, "Text"],
Cell[807038, 26426, 1351, 36, 69, "Input"],
Cell[808392, 26464, 137, 4, 30, "Input"],
Cell[808532, 26470, 190, 6, 30, "Input"],
Cell[808725, 26478, 496, 17, 30, "Input"],
Cell[809224, 26497, 496, 17, 30, "Input"],
Cell[809723, 26516, 496, 17, 30, "Input"],
Cell[810222, 26535, 496, 17, 30, "Input"],
Cell[810721, 26554, 496, 17, 30, "Input"],
Cell[811220, 26573, 496, 17, 30, "Input"],
Cell[811719, 26592, 125, 3, 30, "Input"],
Cell[811847, 26597, 263, 8, 30, "Input"],
Cell[812113, 26607, 466, 15, 30, "Input"],
Cell[812582, 26624, 505, 15, 30, "Input"],
Cell[813090, 26641, 106, 3, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[813233, 26649, 49, 1, 37, "Subsection",
 CellTags->"T1.7.2.1"],
Cell[813285, 26652, 86, 3, 47, "Text"],
Cell[813374, 26657, 1913, 57, 126, "Input"],
Cell[815290, 26716, 788, 25, 50, "Input"],
Cell[816081, 26743, 788, 25, 50, "Input"],
Cell[816872, 26770, 1878, 56, 105, "Input"],
Cell[818753, 26828, 682, 21, 30, "Input"],
Cell[819438, 26851, 682, 21, 30, "Input"],
Cell[820123, 26874, 1459, 43, 81, "Input"],
Cell[821585, 26919, 683, 21, 30, "Input"],
Cell[822271, 26942, 683, 21, 30, "Input"],
Cell[822957, 26965, 1536, 47, 105, "Input"],
Cell[824496, 27014, 1690, 49, 126, "Input"],
Cell[826189, 27065, 22, 0, 29, "Text"],
Cell[826214, 27067, 435, 15, 30, "Input"],
Cell[826652, 27084, 321, 11, 30, "Input"],
Cell[826976, 27097, 1611, 50, 104, "Input"],
Cell[828590, 27149, 2174, 70, 152, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[830801, 27224, 53, 1, 37, "Subsection",
 CellTags->"T1.7.3.1"],
Cell[830857, 27227, 85, 2, 30, "Input"],
Cell[830945, 27231, 3720, 94, 164, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834702, 27330, 51, 1, 37, "Subsection",
 CellTags->"$TTable"],
Cell[834756, 27333, 92, 3, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834885, 27341, 58, 1, 37, "Subsection",
 CellTags->"T1.7.4.1"],
Cell[834946, 27344, 220, 6, 30, "Input"],
Cell[835169, 27352, 713, 20, 69, "Input"],
Cell[835885, 27374, 415, 11, 30, "Input"],
Cell[836303, 27387, 17442, 437, 1028, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[853794, 27830, 90, 2, 72, "Section",
 CellTags->"T1.8.1"],
Cell[853887, 27834, 532, 14, 69, "Input"],
Cell[854422, 27850, 463, 14, 30, "Input"],
Cell[854888, 27866, 16853, 424, 859, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[871778, 28295, 91, 2, 72, "Section",
 CellTags->"T1.9.1"],
Cell[CellGroupData[{
Cell[871894, 28301, 53, 1, 37, "Subsection",
 CellTags->"T1.9.1.1"],
Cell[871950, 28304, 61, 0, 29, "Text"],
Cell[872014, 28306, 565, 16, 30, "Input"],
Cell[872582, 28324, 136, 4, 30, "Input"],
Cell[872721, 28330, 122, 3, 30, "Input"],
Cell[872846, 28335, 83, 2, 30, "Input"],
Cell[872932, 28339, 4183, 104, 183, "Input"],
Cell[877118, 28445, 46, 0, 30, "Input"],
Cell[877167, 28447, 330, 11, 30, "Input"],
Cell[877500, 28460, 230, 8, 30, "Input"],
Cell[877733, 28470, 78, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[877836, 28476, 216, 5, 30, "Input"],
Cell[878055, 28483, 411, 10, 23, "Print"]
}, Open  ]],
Cell[878481, 28496, 366, 10, 30, "Input"],
Cell[878850, 28508, 79, 2, 30, "Input"],
Cell[878932, 28512, 62, 1, 30, "Input"],
Cell[878997, 28515, 83, 2, 30, "Input"],
Cell[879083, 28519, 78, 2, 30, "Input"],
Cell[879164, 28523, 69, 2, 30, "Input"],
Cell[879236, 28527, 76, 2, 30, "Input"],
Cell[879315, 28531, 297, 10, 30, "Input"],
Cell[879615, 28543, 139, 4, 50, "Input"],
Cell[879757, 28549, 92, 2, 30, "Input"],
Cell[879852, 28553, 648, 18, 50, "Input"],
Cell[880503, 28573, 69, 2, 30, "Input"],
Cell[880575, 28577, 95, 3, 30, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[880719, 28586, 93, 2, 72, "Section",
 CellTags->"T1.10.1"],
Cell[880815, 28590, 114, 3, 29, "Text"],
Cell[880932, 28595, 56, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[881013, 28599, 1634, 53, 798, "Input"],
Cell[882650, 28654, 15571, 498, 450, "Output"]
}, Open  ]],
Cell[898236, 29155, 1675, 54, 911, "Text"],
Cell[899914, 29211, 15179, 494, 315, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[915130, 29710, 99, 2, 72, "Section",
 CellTags->"T1.11.1"],
Cell[915232, 29714, 167, 4, 30, "Input"],
Cell[915402, 29720, 2354, 56, 878, "Input"],
Cell[917759, 29778, 90, 2, 30, "Input"],
Cell[917852, 29782, 87, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[917964, 29788, 217, 7, 30, "Input"],
Cell[918184, 29797, 96, 2, 30, "Output"]
}, Open  ]],
Cell[918295, 29802, 55, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[918375, 29806, 265, 7, 30, "Input"],
Cell[918643, 29815, 88, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[918768, 29821, 99, 2, 30, "Input"],
Cell[918870, 29825, 103, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[919010, 29832, 57, 1, 30, "Input"],
Cell[919070, 29835, 113, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[919220, 29841, 61, 1, 30, "Input"],
Cell[919284, 29844, 78, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[919399, 29850, 59, 1, 30, "Input"],
Cell[919461, 29853, 77, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[919575, 29859, 56, 1, 30, "Input"],
Cell[919634, 29862, 75, 1, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
