(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    150234,       3821]
NotebookOptionsPosition[    145721,       3671]
NotebookOutlinePosition[    146438,       3699]
CellTagsIndexPosition[    146308,       3693]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The 2-loop ghost selfenergy ", "Subsection"],

Cell[BoxData[
 RowBox[{"<<", "HighEnergyPhysics`FeynCalc`"}]], "Input"],

Cell["Loading FeynCalc from /home/rolf/fccvs/fc7/HighEnergyPhysics", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.472902144270391*^9}],

Cell["\<\
Loading TARCER /home/rolf/fccvs/fc7/HighEnergyPhysics/Tarcer/tarcer25.mx\
\>", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.472902144291067*^9}],

Cell[TextData[{
 StyleBox["FeynCalc",
  FontWeight->"Bold"],
 " ",
 "7.0.0",
 " For help, type ?FeynCalc, use the built-in ",
 ButtonBox["help system",
  BaseStyle->"AddOnsLink",
  ButtonFunction:>(FrontEndExecute[
    FrontEnd`HelpBrowserLookup["AddOns", #]]& ),
  ButtonData:>{"Short Overview", "intro"},
  ButtonNote->"Open the help browser"],
 " or visit ",
 ButtonBox["www.feyncalc.org",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feyncalc.org/"], None},
  ButtonNote->"http://www.feyncalc.org/"]
}], "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.472902144813043*^9}],

Cell["Loading PHI ", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.472902144874477*^9}],

Cell[TextData[{
 "Loading FeynArts, see ",
 ButtonBox["www.feynarts.de",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feynarts.de/"], None},
  ButtonNote->"http://www.feynarts.de/"],
 " for documentation"
}], "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.472902145592544*^9}],

Cell["FeynArts 3.5 patched for use with FeynCalc", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.472902145692881*^9}],

Cell[CellGroupData[{

Cell["The graphs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Paint", "[", 
   RowBox[{
    RowBox[{"inserts", "=", 
     RowBox[{"InsertFields", "[", 
      RowBox[{
       RowBox[{"Rest", "@", 
        RowBox[{"CreateTopologies", "[", 
         RowBox[{"2", ",", 
          RowBox[{"1", "\[Rule]", "1"}], ",", 
          RowBox[{"ExcludeTopologies", "\[Rule]", 
           RowBox[{"{", "Tadpoles", "}"}]}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"U", "[", "5", "]"}], "}"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"U", "[", "5", "]"}], "}"}]}], ",", 
       RowBox[{"InsertionLevel", "\[Rule]", "Classes"}], ",", 
       RowBox[{"GenericModel", "\[Rule]", "\"\<FCQCDLorentz\>\""}], ",", 
       RowBox[{"Model", "\[Rule]", "\"\<FCQCD\>\""}]}], "]"}]}], ",", 
    RowBox[{"ColumnsXRows", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}]}], ",", 
    RowBox[{"SheetHeader", "\[Rule]", "False"}], ",", 
    RowBox[{"PaintLevel", "\[Rule]", 
     RowBox[{"{", "Generic", "}"}]}], ",", 
    RowBox[{"Numbering", "\[Rule]", "None"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 10.9452}, {0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.864573208290214, 9.864573207387709}, 
         3.8669453704948786`, {3.1065638443429586`, 4.747417796295682}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.81579111096687, 6.815791085716318}, \
{1, 1}], LineBox[CompressedData["
1:eJwdVXlUzAsbHsmHGJdIM83SzGSW3+83UkI1hUfW0qK6lpAW5GpfFNFyJblI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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.316594227670251`, 6.68340579846254}, \
{-1, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{9.99999997334453, 14.000000000000902`}, {10.00000002665547, 
         6.000000000000003}}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {10.6952, 10.0000000086634}, {-1, 0}], 
       LineBox[CompressedData["
1:eJwlkAs0lYkexSWiEKWcw3fenHO+7zsKUZJoJzXKTZRHIUUJKc9SN6I0RCTX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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.657315156232203, 13.342684817461137`}, \
{1, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.989559209705002, 9.989559209635424}, 4.010454381060245, {
         0.002603396315374207, 1.5681929371436802`}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.13981750122236, 13.139817526177083`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{9.99999997334337, 13.99999999999999}], 
        PointBox[{10.00000002665663, 6.}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {0, 22}, {0, 0}, {22, 22}], InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 10.9452}, {0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.864573208290214, 9.864573207387709}, 
         3.8669453704948786`, {3.1065638443429586`, 4.747417796295682}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.81579111096687, 6.815791085716318}, \
{1, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.989559228732924, 10.010440771197487`}, 
         4.0104543619824895`, {4.714992378597311, 6.280581915631125}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.13981753178458, 6.860182493170143}, \
{-1, 1}], LineBox[CompressedData["
1:eJwd1nk8VWkfAPBTyC2qq/R2MYRzjoRJO1r0aCQhKdst3hDG0ggpXTVTlkZI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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {11.645199999999999`, 10.00000001499435}, \
{-1, 0}], LineBox[CompressedData["
1:eJwlkAs0lYkexSWiEKWcw3fenHO+7zsKUZJoJzXKTZRHIUUJKc9SN6I0RCTX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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.657315156232203, 13.342684817461137`}, \
{1, -1}], LineBox[CompressedData["
1:eJwtlQlQk9cahiNFCxWpSFkUpFCSf42CUi0icj8qXkS4rMUqglqVRZagtFqJ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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.316594195929966`, 13.316594222062754`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{9.99999997334337, 13.99999999999999}], 
        PointBox[{10.00000002665663, 6.}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {22, 22}, {0, 0}, {22, 22}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 10.}, 3.9999999999999947`, {
         3.141592653589793, 6.283185307179586}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.3048000000000055`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVHk01QkYtVWkhkhv+b33LL33W+hgFDPJ6IoslUTZKqY0kozTorQvHoNC
NVnqCJFKVDK2LFOTcHAeRczTPIeQLBPSvnhpfjPNd8537rl/fN/57r3nfMZB
O7yC1VRUVHzY/he/Fheq/6EYWQOrRCXxHIwWRtoY2IlRN849PGLJgT8+dfXG
inG34/ETDxUOTCtLLYe7xMhulAbvnJwHoSCs0c5agjR1t5GXJhx4bIk+vyxR
gkN9r8v2RnBQ1mtgnqmQoDXAqdNokJ3va+/RJUhcMwx0K9jFRVXR7Uh6BYmJ
kQdnL2nzcMsuKi9qK4mUyNGgS/k8pCx0e1G1k8Txmdlx4mV8pMdsvKsfRsJE
EU29b+ajrXiWdbcfiaMqO275OBLwf1ST1f0DiRtLp2q7LhK4oxNjVy8kEXhQ
oBPSQ6D54sQi2aQEljmlDRIlAbu/DNKOsfdpyJNLi98TWOj/5FV7tQQf/HMV
Tm0ErLeV6a/JkaDSKThTfpLAaFvg4QBWX9qelRo2NIHFyXm2p45K4Pzy4/pP
hXyszQjTqjsggWd2+JItJB/T/nCtER+XYG5ByIb553h4Y/FhqzxZgiq1jpM6
rN7T3kRWYrkElJeFY3YiF/R3Xfu/DEvwc6kLuYjk4gHTmRBuSmJbBdrm9HFg
Vf1OsHo/icGAM8lOdRxUb1X0eD4gUeqY3pLUzgEnSu56j6SgTFdcLfmGCzIk
SIs+RKEcRvGhrN8j3DaJQz0Fp97oU0OvuWhptOp7+IWC/mSbgV4iD6p+zyd9
KBq3M+8bDZnzIZYm5EXa0lC6X1fI2/iwjBncPLaYhtmBGKvfwwjc71ju7ELT
OP728rDnWwIJifknfbVoLPXzI8xDBdD4kfTI6KNwREp77aoVwPujlMkvoxA5
smpgi6oQf8drJ948QcFiKE+0yFiINy69V8WbKUxG8P1fsHxSttGzzJ6C7ZD3
6hJ1IdpbJxogpkBp1d6bahDgxrSKNwb6FOpqwlu+7BJggbPmB+tZFLK9ffxq
pwugr/d8/IwuhZjwqWDrJAI5v+0rMjGmoBmiXDs2m0C/Tlr8E3a/3x7Gtv4s
H/GW7xbs2E6BE5EVYcvmd82pOq4ul8LM3AGr1Ec8NDuHvi8cocDj/Jnbnc1D
nK459wTrRysRVVHB5ju4ceIZeZqG1k7P0cAqHtaYHO7mPKORstdRPj6Dj+1k
z6Ml1gzu6cY6+B7i43iH06kzBxi8M9NY/kabgFa1Ybr2TQax9nLfpkLWzzOV
xaubGSSkRj7V8xOgyXzTLl05g7NzxtxblQJcsXeQMjIGac6zbcaThRjfORbh
UciAO5p4vmueCBVN+zPORTOQfvCoj4kSwbx5nNfvwSAkQ3lB0SaCziv3Za5c
BrvVmPXkDEP472j6JbuPRnIvb324sSHcFIc3GxfR8B+1VuOw3PWa9zsqjkbR
T3dTR6YbQjNt4P38UBoBZNGwV4cI98de6uX50mh4XiBSJIgw3TGp//RaGp/X
bn+R9K0I0hypiUMAjcLA63dcZELUXLZJaN1DYzhUfiN/kxAZE6WhvHQa54sP
zm35JEBB54XFec00ymSqupdyBdDtqb56UJtB3KcgmWawAJYyNV71Ola/6Iik
3EWAxodenbuvMNg0lblB3Yv1x/2S3r6PDB65r/heESvAsWPGRqkrTbHOIgjK
AQFSQisva6eZorzf2aB3qxATxTZS+3aWfzapXa4ugmpmqu+xKVMkV8u+2Vso
wukSH2XVXDNE//o4c2iDIawGdcmnLP/6T43+RzP8A4COQGc=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.706292966747745, 12.23006116185843}, \
{1, -1}], 
       CircleBox[{9.999999999999995, 13.05}, 2.0499999999999945`, {
        0.2213144423477913, 2.9202782112420023`}], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["F",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 15.795199999999994`}, \
{0, -1}], 
       CircleBox[{9.999999999999995, 13.95}, 2.0499999999999945`, {
        3.3629070959375844`, 6.061870864831795}], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["F",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 11.204800000000002`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVAtQzXkUTu9RSXoQPaj7f/z+/9u23V7c6vZlVFqU7HoUYtGmGGF70YuK
q0mm28bdbct65JXqovIoTAo9WHUTFTaUXqIhKutRe5k9M2fOnDPf+b45M2e+
Wesil4Sqq6mpLVPl1/px/GvwUPsWAoi2rVmj6ybEi8y0BfnuAiwNtjd0/kUI
g1l5TZelArT6aZZWJQoR2F+v/uCJAPuiHubFJguRqz1UpetCQfNeWYnJJiHI
9lslNfspuCyWSBbPFeJu9Jvllx9RqMuw6czVFUJrsvDplek0Jtr7bJVX8whN
cr8V4kdjysGToh3RPC6sMalbEEpjQsb7/C00D70H92/MiqSxZ+REsfMjDu2d
YZrW4TQkUXnnunI4RLbs+ShbRmPYti2lNYhDd/HOPIkbjUEmaewGz6HS7KCy
RaVH3/xSoNDn8LbXyevABwpndRZ5a48RZGsdWKLWSsFvvm1xlBoHakzxzPYy
hW6rzqzHxhyUXSO++/IpBJfRRmJXDq97Hr7O20eh8a/W5BMbOVz0e+A4spNC
alh3ov8JDldF0pW/xlCon7L5kqyfQ5as46wokULMq/UwduDhMSfzB38ZheaZ
tzz6Ynhs7v+SsKmMQj/tK24t5xFY06Hu1EsB71xXXerjUeQW+e8jloae0YLG
wYlCxOkbxitjaLyQkgx1cyEqVodcrbtL47nVHaMZRkIwnwZEhhSDgHTt0uB3
PN7mDdp57mDQti9Qv+8Gj+wU+aBlDQP2D7Hi2C4ekikLveO/MDi813eOzIkH
yenyfi5gket3SGzXxWHRwZHpQ64sPntpBVyRcTBc5egbruo7TS9Z3J7H4eWZ
1oS7FAtRfH7l6DhB06cay15tFf4n7Qrt2wQb9xSO2j9lcC1a7WHP7wTKc9MC
nEsZxNFFRSM7CDrSa10FUgbubfkXrCMIFvZcV8aFMEgtfZnVHk5QsmLF0D9u
DAo7Vk2fosJzmU0T3GYxWBt2Y1RLTnDnbFVbtyGDnUmjsdOrCdoUGjndugwO
lc2X3R4laJkbXGtnoNp3nSz4zYlD+WxzSYUlA5PznjbOURzSLNnCeBW/R/Fj
verzHCYeXZ5rHMYg1yO4aLxX9T/HO2y3HGHwpFjwstGIR3votbClPQwSunS4
co5HwdvstTYuLExcBC7r7Hkc83Q0L8pgEbIyq8vdiged3R+d/pzFYesUz9JR
Dj1LzWYXOBCIn5gRn+scGiKZBo0YAq/3uzXdYzhMO6LBFpwheP5OvFSb4pDq
eXYxW09wYN5Hp4QmgvV2M5Lm3ieIt7K2mJZEYNxcEFtdRxBw0cd9g4jgvu2f
yUuKCE4uO6dQvGGxOblW+nk3QeYabXfDShbijCYNuT8B1v6tL89msd1z289O
Uwkk4eZ6JbEsnIkNTj1jMVCb2R4UweJcmk0ApWAxmJPSEKHqvUytjhvsZaHD
pMgTVfigD+k+LWEsUn+MsG3LYtFW9cjAaBkL//MWXqJyFU/dmOJMIIubrwo8
dnWymCcx6tJZycLVaiC/2ZRgKNbczne7at45u2b5AoJO4/ftPnIWq+9FXE9T
3WcRbngqp56FxNlwfEMhwUy+Wy7SJRg7cTNXv4HApPqp0i+QoMr74lZB+9e7
4zT7jhKwlX2Ju1oIZnjIJvUNE1zjW/VPVxAcGd5QYjWfw9EOqZXDfoKppiYD
ymwO4o0JBs0qfdu8xviIJg6+CUFB5mMsJinLns75zCHU5/s7ytMshlNzpbQx
D95M+p3DEhaOduPPTE14fPrmp8z/fsrjPwQ/Oso=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.283684782537893`, 12.224334161450233`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {44, 22}, {0, 0}, {22, 22}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 10.}, 3.9999999999999947`, {
         3.141592653589793, 6.283185307179586}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.3048000000000055`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVHk01QkYtVWkhkhv+b33LL33W+hgFDPJ6IoslUTZKqY0kozTorQvHoNC
NVnqCJFKVDK2LFOTcHAeRczTPIeQLBPSvnhpfjPNd8537rl/fN/57r3nfMZB
O7yC1VRUVHzY/he/Fheq/6EYWQOrRCXxHIwWRtoY2IlRN849PGLJgT8+dfXG
inG34/ETDxUOTCtLLYe7xMhulAbvnJwHoSCs0c5agjR1t5GXJhx4bIk+vyxR
gkN9r8v2RnBQ1mtgnqmQoDXAqdNokJ3va+/RJUhcMwx0K9jFRVXR7Uh6BYmJ
kQdnL2nzcMsuKi9qK4mUyNGgS/k8pCx0e1G1k8Txmdlx4mV8pMdsvKsfRsJE
EU29b+ajrXiWdbcfiaMqO275OBLwf1ST1f0DiRtLp2q7LhK4oxNjVy8kEXhQ
oBPSQ6D54sQi2aQEljmlDRIlAbu/DNKOsfdpyJNLi98TWOj/5FV7tQQf/HMV
Tm0ErLeV6a/JkaDSKThTfpLAaFvg4QBWX9qelRo2NIHFyXm2p45K4Pzy4/pP
hXyszQjTqjsggWd2+JItJB/T/nCtER+XYG5ByIb553h4Y/FhqzxZgiq1jpM6
rN7T3kRWYrkElJeFY3YiF/R3Xfu/DEvwc6kLuYjk4gHTmRBuSmJbBdrm9HFg
Vf1OsHo/icGAM8lOdRxUb1X0eD4gUeqY3pLUzgEnSu56j6SgTFdcLfmGCzIk
SIs+RKEcRvGhrN8j3DaJQz0Fp97oU0OvuWhptOp7+IWC/mSbgV4iD6p+zyd9
KBq3M+8bDZnzIZYm5EXa0lC6X1fI2/iwjBncPLaYhtmBGKvfwwjc71ju7ELT
OP728rDnWwIJifknfbVoLPXzI8xDBdD4kfTI6KNwREp77aoVwPujlMkvoxA5
smpgi6oQf8drJ948QcFiKE+0yFiINy69V8WbKUxG8P1fsHxSttGzzJ6C7ZD3
6hJ1IdpbJxogpkBp1d6bahDgxrSKNwb6FOpqwlu+7BJggbPmB+tZFLK9ffxq
pwugr/d8/IwuhZjwqWDrJAI5v+0rMjGmoBmiXDs2m0C/Tlr8E3a/3x7Gtv4s
H/GW7xbs2E6BE5EVYcvmd82pOq4ul8LM3AGr1Ec8NDuHvi8cocDj/Jnbnc1D
nK459wTrRysRVVHB5ju4ceIZeZqG1k7P0cAqHtaYHO7mPKORstdRPj6Dj+1k
z6Ml1gzu6cY6+B7i43iH06kzBxi8M9NY/kabgFa1Ybr2TQax9nLfpkLWzzOV
xaubGSSkRj7V8xOgyXzTLl05g7NzxtxblQJcsXeQMjIGac6zbcaThRjfORbh
UciAO5p4vmueCBVN+zPORTOQfvCoj4kSwbx5nNfvwSAkQ3lB0SaCziv3Za5c
BrvVmPXkDEP472j6JbuPRnIvb324sSHcFIc3GxfR8B+1VuOw3PWa9zsqjkbR
T3dTR6YbQjNt4P38UBoBZNGwV4cI98de6uX50mh4XiBSJIgw3TGp//RaGp/X
bn+R9K0I0hypiUMAjcLA63dcZELUXLZJaN1DYzhUfiN/kxAZE6WhvHQa54sP
zm35JEBB54XFec00ymSqupdyBdDtqb56UJtB3KcgmWawAJYyNV71Ola/6Iik
3EWAxodenbuvMNg0lblB3Yv1x/2S3r6PDB65r/heESvAsWPGRqkrTbHOIgjK
AQFSQisva6eZorzf2aB3qxATxTZS+3aWfzapXa4ugmpmqu+xKVMkV8u+2Vso
wukSH2XVXDNE//o4c2iDIawGdcmnLP/6T43+RzP8A4COQGc=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.706292966747745, 12.23006116185843}, \
{1, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 13.05}, 2.0499999999999945`, {
         0.2213144423477913, 2.9202782112420023`}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 15.795199999999994`}, \
{0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 13.95}, 2.0499999999999945`, {
         3.3629070959375844`, 6.061870864831795}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 11.204800000000002`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVAtQzXkUTu9RSXoQPaj7f/z+/9u23V7c6vZlVFqU7HoUYtGmGGF70YuK
q0mm28bdbct65JXqovIoTAo9WHUTFTaUXqIhKutRe5k9M2fOnDPf+b45M2e+
Wesil4Sqq6mpLVPl1/px/GvwUPsWAoi2rVmj6ybEi8y0BfnuAiwNtjd0/kUI
g1l5TZelArT6aZZWJQoR2F+v/uCJAPuiHubFJguRqz1UpetCQfNeWYnJJiHI
9lslNfspuCyWSBbPFeJu9Jvllx9RqMuw6czVFUJrsvDplek0Jtr7bJVX8whN
cr8V4kdjysGToh3RPC6sMalbEEpjQsb7/C00D70H92/MiqSxZ+REsfMjDu2d
YZrW4TQkUXnnunI4RLbs+ShbRmPYti2lNYhDd/HOPIkbjUEmaewGz6HS7KCy
RaVH3/xSoNDn8LbXyevABwpndRZ5a48RZGsdWKLWSsFvvm1xlBoHakzxzPYy
hW6rzqzHxhyUXSO++/IpBJfRRmJXDq97Hr7O20eh8a/W5BMbOVz0e+A4spNC
alh3ov8JDldF0pW/xlCon7L5kqyfQ5as46wokULMq/UwduDhMSfzB38ZheaZ
tzz6Ynhs7v+SsKmMQj/tK24t5xFY06Hu1EsB71xXXerjUeQW+e8jloae0YLG
wYlCxOkbxitjaLyQkgx1cyEqVodcrbtL47nVHaMZRkIwnwZEhhSDgHTt0uB3
PN7mDdp57mDQti9Qv+8Gj+wU+aBlDQP2D7Hi2C4ekikLveO/MDi813eOzIkH
yenyfi5gket3SGzXxWHRwZHpQ64sPntpBVyRcTBc5egbruo7TS9Z3J7H4eWZ
1oS7FAtRfH7l6DhB06cay15tFf4n7Qrt2wQb9xSO2j9lcC1a7WHP7wTKc9MC
nEsZxNFFRSM7CDrSa10FUgbubfkXrCMIFvZcV8aFMEgtfZnVHk5QsmLF0D9u
DAo7Vk2fosJzmU0T3GYxWBt2Y1RLTnDnbFVbtyGDnUmjsdOrCdoUGjndugwO
lc2X3R4laJkbXGtnoNp3nSz4zYlD+WxzSYUlA5PznjbOURzSLNnCeBW/R/Fj
verzHCYeXZ5rHMYg1yO4aLxX9T/HO2y3HGHwpFjwstGIR3votbClPQwSunS4
co5HwdvstTYuLExcBC7r7Hkc83Q0L8pgEbIyq8vdiged3R+d/pzFYesUz9JR
Dj1LzWYXOBCIn5gRn+scGiKZBo0YAq/3uzXdYzhMO6LBFpwheP5OvFSb4pDq
eXYxW09wYN5Hp4QmgvV2M5Lm3ieIt7K2mJZEYNxcEFtdRxBw0cd9g4jgvu2f
yUuKCE4uO6dQvGGxOblW+nk3QeYabXfDShbijCYNuT8B1v6tL89msd1z289O
Uwkk4eZ6JbEsnIkNTj1jMVCb2R4UweJcmk0ApWAxmJPSEKHqvUytjhvsZaHD
pMgTVfigD+k+LWEsUn+MsG3LYtFW9cjAaBkL//MWXqJyFU/dmOJMIIubrwo8
dnWymCcx6tJZycLVaiC/2ZRgKNbczne7at45u2b5AoJO4/ftPnIWq+9FXE9T
3WcRbngqp56FxNlwfEMhwUy+Wy7SJRg7cTNXv4HApPqp0i+QoMr74lZB+9e7
4zT7jhKwlX2Ju1oIZnjIJvUNE1zjW/VPVxAcGd5QYjWfw9EOqZXDfoKppiYD
ymwO4o0JBs0qfdu8xviIJg6+CUFB5mMsJinLns75zCHU5/s7ytMshlNzpbQx
D95M+p3DEhaOduPPTE14fPrmp8z/fsrjPwQ/Oso=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.283684782537893`, 12.224334161450233`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {66, 22}, {0, 0}, {22, 22}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       LineBox[CompressedData["
1:eJw9lwk4VfkfxiW5yJIWdzv3uqu7UVEppXpNKZG/0kaJSDKUrSJJiESLrFMh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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.0548000000000055`}, \
{0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.493974050732, 10.324871971010285`}, 
         3.5090449505152663`, {2.0105863474436756`, 3.2343067312428637`}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          
          8.247272727272728]& ], {5.923353752278861, 12.10602642726922}, \
{1, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 13.05}, 2.0499999999999945`, {
         0.2213144423477913, 2.9202782112420023`}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 15.795199999999994`}, \
{0, -1}], LineBox[CompressedData["
1:eJw9lXlUjXkYx+tKUrJURIN777u/lzJjiZR8MWWpK1lv65m5KqWmZWQZSYvC
CO2ihJAlWyqNZcgyGhGubCUdZTuWq4WajLa5xnve3znv+f3xO7/3+T3P8/1+
Hrk6bL6/RE9PL0z3fd2/LRm+7aPwT2vGbItSKY7eVlY/Pa3ABOe3qYbZUsQo
vYLrVAqsUh7VhJ6WosUxzFrZyeN+F/uosUOKaRGj7WsP8qhv821R28mwccag
pv5ePDYvv/7gU4IMXqp9EaU0jwYrGI+ukeFWhuGtK0Y8tnSlZm6ykWOLBxtY
ZcBD1VVmUrZejsDqS/viLXls1J46F39dDoW/pZmNA4/FnvaKFD0Ca2822GlD
eGjrlAGOYwjsnnNh5roDPP4t7GdwzZ3AYe9hvfWf8LBIismNCiSgyTvYuNFE
gQ8nP/qvWUFg392hUarxCpib3ev0/5WANulQk3S+Avu1QeUaPwKT5toO1CxV
wHlw+c49cwjcnn6r2D1IgcacQ7nbKV28Q9tMDXXne1W3lu1olcOsLsJ4hrsC
PgNk+/tckmNm88YNX8YpYF+oVxKdKEdiYPyUM8YKlKUjP3ueHI+5SZrmB7r8
bJsjM2k5kswHxVam8eC+cwvJMJZjSHSdhcaJh5Nt7OAqAzlCLhiM3dDC4Ykq
J2C/pRyO2e4Xt+ZwuG/b5Z08Q46srKpNNi4c2o9WLKzVxbOI/6xljDh0D/PP
PlEth92Q8EVTa1gs0P5+rXMcAftZztbtV1lMs/BtNkgmUPLb5rTSchbdL4eY
NTQQ2FqDFZefs1jTci23iiHRONyr/p4Zh6SMjzGvPUkYjK0olLtzIAIe9nkR
TWJpSspddRYHm+K8Q/tTSaxoN41LfMahwJh0ku4iEX3HliIpHi0Tlamrs0gE
Z/Lvj/zEYxnrcmxUMomqiXRBQCqPc4sWFJ2LIyEdOledW8wjeKJ+7ZEwEo86
PY6nXueR8W6Oc5tK957qAr+0ch65u3+YcGYKidvHens1lPLQ0494cWUkiUku
Vy5HZfEwSy1s/75bl1/f59GPg3jMfGyeuO4Zgcf3L3aeHcNjbb3JcuXfBGzS
CwynvudwUPlq3IfzBB5VW/hwezk89fZsDSsj4JQpsRrvxmEI9JNPVxMY+07W
pNbjcL00vXi+EYn0yBEtT86ySKxVlrS6klhCX/adHcNi++auqC95JDzldI/G
g0VXz9dFQlOpW64sQlZLEnr7UuJ5JFXkYlJMiffHzw5xPdFOIU34/6uy7vC5
LC3GH3Eg3yQFNH4U3re4yKrSzInGQ+H9sdLWzKJJNKyF/Eo47doNMlrM/22o
m9FdfVqsT0f39uGODZRYP5+ld27OuUqJ9Q0YfOac8WFKrH/KjW5qSQol9md6
wXGl83oKMqF/adUlCx+EU2J/+94oCt0cSIn9n9f29Hx9ACXqo9LV18MnlMJK
QT81uxSfh8dT8BP09UuwaeywfAq9Bf3F9XdQW9dQoj6/WL39MHIkLer3/Pu8
AR3htKjvfPNVDr0qaVH/Ha+y/eezjOgPyWLbY9RaBmaCf5gKyYHwPxlkCv6S
Hfbb5fOGEf1XWhHzzrqDQbDgz6qXhenBbQwsBP+urBiQtPwJgy2Cvx1Cyjz9
TzF4JPj/sluPS7wuXoLAhz3Nz3w+T2NEfngfHr8zyIQR+WLq56GOqKVF/pS8
s1v28xla5JPKfIfdmBxa5NebDza9srfRIt9M3U2zN22lRf69joxVJ2TRqBL4
qO/2qcPhJI2jAj9NiaJdVzQ0cgW+Hsj/62FYD40ogb+R5vOcoyczIp/zJGhF
HIMggd+hktDla+4xSBL4bvmqrO0+w4r8j8icPKpfFCvOh2HGef1zdX1KEObH
QH1thpGEE+eLo8exrFkshyZh/tR7m/zROZbDemE+xSZOqG2jOBwR5lfH/35j
xfn2HxDt6BI=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 10.954800000000002`}, \
{0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{10.449854645994966`, 10.292774083425702`}, 
         3.562197172882098, {-0.08228199986392748, 1.120574228356973}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.06662399700678, 12.100299426861024`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {0, 0}, {0, 0}, {22, 22}], InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 10.}, 3.9999999999999947`, {
         3.141592653589793, 6.283185307179586}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.3048000000000055`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVHk01QkYtVWkhkhv+b33LL33W+hgFDPJ6IoslUTZKqY0kozTorQvHoNC
NVnqCJFKVDK2LFOTcHAeRczTPIeQLBPSvnhpfjPNd8537rl/fN/57r3nfMZB
O7yC1VRUVHzY/he/Fheq/6EYWQOrRCXxHIwWRtoY2IlRN849PGLJgT8+dfXG
inG34/ETDxUOTCtLLYe7xMhulAbvnJwHoSCs0c5agjR1t5GXJhx4bIk+vyxR
gkN9r8v2RnBQ1mtgnqmQoDXAqdNokJ3va+/RJUhcMwx0K9jFRVXR7Uh6BYmJ
kQdnL2nzcMsuKi9qK4mUyNGgS/k8pCx0e1G1k8Txmdlx4mV8pMdsvKsfRsJE
EU29b+ajrXiWdbcfiaMqO275OBLwf1ST1f0DiRtLp2q7LhK4oxNjVy8kEXhQ
oBPSQ6D54sQi2aQEljmlDRIlAbu/DNKOsfdpyJNLi98TWOj/5FV7tQQf/HMV
Tm0ErLeV6a/JkaDSKThTfpLAaFvg4QBWX9qelRo2NIHFyXm2p45K4Pzy4/pP
hXyszQjTqjsggWd2+JItJB/T/nCtER+XYG5ByIb553h4Y/FhqzxZgiq1jpM6
rN7T3kRWYrkElJeFY3YiF/R3Xfu/DEvwc6kLuYjk4gHTmRBuSmJbBdrm9HFg
Vf1OsHo/icGAM8lOdRxUb1X0eD4gUeqY3pLUzgEnSu56j6SgTFdcLfmGCzIk
SIs+RKEcRvGhrN8j3DaJQz0Fp97oU0OvuWhptOp7+IWC/mSbgV4iD6p+zyd9
KBq3M+8bDZnzIZYm5EXa0lC6X1fI2/iwjBncPLaYhtmBGKvfwwjc71ju7ELT
OP728rDnWwIJifknfbVoLPXzI8xDBdD4kfTI6KNwREp77aoVwPujlMkvoxA5
smpgi6oQf8drJ948QcFiKE+0yFiINy69V8WbKUxG8P1fsHxSttGzzJ6C7ZD3
6hJ1IdpbJxogpkBp1d6bahDgxrSKNwb6FOpqwlu+7BJggbPmB+tZFLK9ffxq
pwugr/d8/IwuhZjwqWDrJAI5v+0rMjGmoBmiXDs2m0C/Tlr8E3a/3x7Gtv4s
H/GW7xbs2E6BE5EVYcvmd82pOq4ul8LM3AGr1Ec8NDuHvi8cocDj/Jnbnc1D
nK459wTrRysRVVHB5ju4ceIZeZqG1k7P0cAqHtaYHO7mPKORstdRPj6Dj+1k
z6Ml1gzu6cY6+B7i43iH06kzBxi8M9NY/kabgFa1Ybr2TQax9nLfpkLWzzOV
xaubGSSkRj7V8xOgyXzTLl05g7NzxtxblQJcsXeQMjIGac6zbcaThRjfORbh
UciAO5p4vmueCBVN+zPORTOQfvCoj4kSwbx5nNfvwSAkQ3lB0SaCziv3Za5c
BrvVmPXkDEP472j6JbuPRnIvb324sSHcFIc3GxfR8B+1VuOw3PWa9zsqjkbR
T3dTR6YbQjNt4P38UBoBZNGwV4cI98de6uX50mh4XiBSJIgw3TGp//RaGp/X
bn+R9K0I0hypiUMAjcLA63dcZELUXLZJaN1DYzhUfiN/kxAZE6WhvHQa54sP
zm35JEBB54XFec00ymSqupdyBdDtqb56UJtB3KcgmWawAJYyNV71Ola/6Iik
3EWAxodenbuvMNg0lblB3Yv1x/2S3r6PDB65r/heESvAsWPGRqkrTbHOIgjK
AQFSQisva6eZorzf2aB3qxATxTZS+3aWfzapXa4ugmpmqu+xKVMkV8u+2Vso
wukSH2XVXDNE//o4c2iDIawGdcmnLP/6T43+RzP8A4COQGc=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.706292966747745, 12.23006116185843}, \
{1, -1}], LineBox[CompressedData["
1:eJw9lXlYTXkcxlsYTWmZinkYqnu2m+65t0iZMPUyZKJkV1RMuqTlFkJSWi0z
aHkqKS5TWgYjdSsm0ygiNfaytBjVEOHWkBLdytzhPOf3POc5f/yec77b+36+
At+QJVItDQ2NEPXz//vzscDHT8cK73rTXEzPmWPlFIWQXCiCnfOLlC+yzBGr
yE0jCkTY5nbyjqzYHIaXkusV2izqh4QPulXmuJjYcIVazaK1z+eNr4MFIiq6
jd7kstgXcPXe2wQL5BWsSXRpZtE+HrpskwXsAj9Mdexn8fNQSvpeiQBb8xsz
xCoWHkOVepW7BDgsnLUmqpPFHuXZ8rirAjzI6uy6W81ixaoZVskaBPbYmdWY
pLJQ/u223tGagF/ZnN/jvVh8KBo9onoxAc8TzwaGaRam+6PlO/0J2Pis/mpH
rwhdhT3S8C0E1to8Tyi4LoKJ8d1B6WYCpmGeRm1nRMhRbqy540egtrjuX+uj
IjiPqTl8bD4B2z+nuhYeEqH7SL48kVLH89zc80F9f9zj+oZDvQJ0EYl9FYUi
eBta5Iy6KEC54Y7IkTdEmFGkURq1W4CdGVGX5/eJUJmKvKxFAkx6eM3aUKSu
z/51WDqtrl/ZHW0bzMLyG/egNF0BXsYRr6wvsJhjHzOmfoQAaXNUNyMNxGjy
OLI+52sBLkkLZ2/xE6PBfsgr6XsBNvqLw++WitF/sm5ZizqeMmqUSVO/GMPj
pFlnGgW49iLpVBUjwVLlT9WDtgSuni+v1/lOApj6vB6RRMB1z/ZgFwcJhp+O
NW5vJxDGVB5wmihB+JtqeT1DwvhJrrmkS4wDaT3Rz1aRGLxp7/64UAzB+vuj
nkSRkIeE2Mj9xZCUZOfnpJA4qNOzK8JCjFO65FzzTBIJk+taHrWweDPNLWV7
Bon0gAemK4+z2CBccFqUREJS27w8U8aifPlSRXksifbnxXJfVxYB0zRbfg0h
YaWdv1Q2nUX6y/nOfR4kTITLjwQ7sJAfnWxX9h0J22UDuWYuLDQ0Nz25ZEai
ttTRKcGfhXFKUb/NsLq+dxPjLA+xmPfQZHdkK4FJ7GzteXdYRLTpBbhdI1Af
tPxDlakYuW4dtl0XCFgJX+U8XCvGI69VvSGVBP4IGOq4XiTGWGgmFTcSuDWm
1Uj+UYwr51JLluiQCN7/jwE9T4I9LW6lva4kTjY7ZZ+LkeDgvqGdA9kk8h83
a1jnSzD0yWckbGzVp0SCoO1aCSN9KP4+jFIs0Cuh+O/tXIJcz/RTkHH/f1o5
HLpQSOM2F9/sRJ5eMmhUcPmtUIy/YTyXhojLP8a8N13xLY0Grr4SS2VEvAUN
K67+Tpm7zm1Nmu+PajhxgmM7xffPe92tv+Zfpvj+SseUlesWUDDm+p9cO0yt
TKb4+cw69Zub8y4Kbdz8UhtLl90Lpfj5flmrkO3zp/j5L+p7dKFtPYV4Th83
XH08vWUU9nP6acy0ej8hjsJRTl/Bgfox4/IoqDj9xRrM9BU3Ubw+B8a/6DIz
o3n9lr/KNlSF0ry+80y2zdS+QfP6V3VkSZcIGdRy/tBcYX+aimDQzfmHqdM6
EVrBIJDzl0WBX6Z3J4PLnP/K6qJfilUM0jl/1j8tSg3sY6Dk/Lu1znB/QDOD
bZy/ZwRVrpKeZWDF+b/K/eOCOHW8SI4Px163er+fxfD88CqYenijnjofji/6
fp6+m1ponj+lLx02/FhG83zyMDnkYH2E5vnV2SXRzjpI83zTX6yftfcAzfPv
WViMb0IGDWuOjxrub1UzC2l4cPzUJxSZl+7QWMfx9UTelfshH2ns5vi7xWSR
c9R0hufzL1roRSzD81umJQsIv8vwfB/bUdnXwAhhz/E/NH26aPROIb8fxulm
G8hrhIjk9oeRpjJNR8sSVdx+cfI8nfGD0BJG3P5p89I7PzjFEvHcforZbdfS
R1nCg9tfA5/8JsTnPSfCf3ygAUo=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 16.045199999999994`}, \
{0, -1}], LineBox[CompressedData["
1:eJw9lXlUjXkYx+tKUrJURIN777u/lzJjiZR8MWWpK1lv65m5KqWmZWQZSYvC
CO2ihJAlWyqNZcgyGhGubCUdZTuWq4WajLa5xnve3znv+f3xO7/3+T3P8/1+
Hrk6bL6/RE9PL0z3fd2/LRm+7aPwT2vGbItSKY7eVlY/Pa3ABOe3qYbZUsQo
vYLrVAqsUh7VhJ6WosUxzFrZyeN+F/uosUOKaRGj7WsP8qhv821R28mwccag
pv5ePDYvv/7gU4IMXqp9EaU0jwYrGI+ukeFWhuGtK0Y8tnSlZm6ykWOLBxtY
ZcBD1VVmUrZejsDqS/viLXls1J46F39dDoW/pZmNA4/FnvaKFD0Ca2822GlD
eGjrlAGOYwjsnnNh5roDPP4t7GdwzZ3AYe9hvfWf8LBIismNCiSgyTvYuNFE
gQ8nP/qvWUFg392hUarxCpib3ev0/5WANulQk3S+Avu1QeUaPwKT5toO1CxV
wHlw+c49cwjcnn6r2D1IgcacQ7nbKV28Q9tMDXXne1W3lu1olcOsLsJ4hrsC
PgNk+/tckmNm88YNX8YpYF+oVxKdKEdiYPyUM8YKlKUjP3ueHI+5SZrmB7r8
bJsjM2k5kswHxVam8eC+cwvJMJZjSHSdhcaJh5Nt7OAqAzlCLhiM3dDC4Ykq
J2C/pRyO2e4Xt+ZwuG/b5Z08Q46srKpNNi4c2o9WLKzVxbOI/6xljDh0D/PP
PlEth92Q8EVTa1gs0P5+rXMcAftZztbtV1lMs/BtNkgmUPLb5rTSchbdL4eY
NTQQ2FqDFZefs1jTci23iiHRONyr/p4Zh6SMjzGvPUkYjK0olLtzIAIe9nkR
TWJpSspddRYHm+K8Q/tTSaxoN41LfMahwJh0ku4iEX3HliIpHi0Tlamrs0gE
Z/Lvj/zEYxnrcmxUMomqiXRBQCqPc4sWFJ2LIyEdOledW8wjeKJ+7ZEwEo86
PY6nXueR8W6Oc5tK957qAr+0ch65u3+YcGYKidvHens1lPLQ0494cWUkiUku
Vy5HZfEwSy1s/75bl1/f59GPg3jMfGyeuO4Zgcf3L3aeHcNjbb3JcuXfBGzS
CwynvudwUPlq3IfzBB5VW/hwezk89fZsDSsj4JQpsRrvxmEI9JNPVxMY+07W
pNbjcL00vXi+EYn0yBEtT86ySKxVlrS6klhCX/adHcNi++auqC95JDzldI/G
g0VXz9dFQlOpW64sQlZLEnr7UuJ5JFXkYlJMiffHzw5xPdFOIU34/6uy7vC5
LC3GH3Eg3yQFNH4U3re4yKrSzInGQ+H9sdLWzKJJNKyF/Eo47doNMlrM/22o
m9FdfVqsT0f39uGODZRYP5+ld27OuUqJ9Q0YfOac8WFKrH/KjW5qSQol9md6
wXGl83oKMqF/adUlCx+EU2J/+94oCt0cSIn9n9f29Hx9ACXqo9LV18MnlMJK
QT81uxSfh8dT8BP09UuwaeywfAq9Bf3F9XdQW9dQoj6/WL39MHIkLer3/Pu8
AR3htKjvfPNVDr0qaVH/Ha+y/eezjOgPyWLbY9RaBmaCf5gKyYHwPxlkCv6S
Hfbb5fOGEf1XWhHzzrqDQbDgz6qXhenBbQwsBP+urBiQtPwJgy2Cvx1Cyjz9
TzF4JPj/sluPS7wuXoLAhz3Nz3w+T2NEfngfHr8zyIQR+WLq56GOqKVF/pS8
s1v28xla5JPKfIfdmBxa5NebDza9srfRIt9M3U2zN22lRf69joxVJ2TRqBL4
qO/2qcPhJI2jAj9NiaJdVzQ0cgW+Hsj/62FYD40ogb+R5vOcoyczIp/zJGhF
HIMggd+hktDla+4xSBL4bvmqrO0+w4r8j8icPKpfFCvOh2HGef1zdX1KEObH
QH1thpGEE+eLo8exrFkshyZh/tR7m/zROZbDemE+xSZOqG2jOBwR5lfH/35j
xfn2HxDt6BI=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 10.954800000000002`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVAtQzXkUTu9RSXoQPaj7f/z+/9u23V7c6vZlVFqU7HoUYtGmGGF70YuK
q0mm28bdbct65JXqovIoTAo9WHUTFTaUXqIhKutRe5k9M2fOnDPf+b45M2e+
Wesil4Sqq6mpLVPl1/px/GvwUPsWAoi2rVmj6ybEi8y0BfnuAiwNtjd0/kUI
g1l5TZelArT6aZZWJQoR2F+v/uCJAPuiHubFJguRqz1UpetCQfNeWYnJJiHI
9lslNfspuCyWSBbPFeJu9Jvllx9RqMuw6czVFUJrsvDplek0Jtr7bJVX8whN
cr8V4kdjysGToh3RPC6sMalbEEpjQsb7/C00D70H92/MiqSxZ+REsfMjDu2d
YZrW4TQkUXnnunI4RLbs+ShbRmPYti2lNYhDd/HOPIkbjUEmaewGz6HS7KCy
RaVH3/xSoNDn8LbXyevABwpndRZ5a48RZGsdWKLWSsFvvm1xlBoHakzxzPYy
hW6rzqzHxhyUXSO++/IpBJfRRmJXDq97Hr7O20eh8a/W5BMbOVz0e+A4spNC
alh3ov8JDldF0pW/xlCon7L5kqyfQ5as46wokULMq/UwduDhMSfzB38ZheaZ
tzz6Ynhs7v+SsKmMQj/tK24t5xFY06Hu1EsB71xXXerjUeQW+e8jloae0YLG
wYlCxOkbxitjaLyQkgx1cyEqVodcrbtL47nVHaMZRkIwnwZEhhSDgHTt0uB3
PN7mDdp57mDQti9Qv+8Gj+wU+aBlDQP2D7Hi2C4ekikLveO/MDi813eOzIkH
yenyfi5gket3SGzXxWHRwZHpQ64sPntpBVyRcTBc5egbruo7TS9Z3J7H4eWZ
1oS7FAtRfH7l6DhB06cay15tFf4n7Qrt2wQb9xSO2j9lcC1a7WHP7wTKc9MC
nEsZxNFFRSM7CDrSa10FUgbubfkXrCMIFvZcV8aFMEgtfZnVHk5QsmLF0D9u
DAo7Vk2fosJzmU0T3GYxWBt2Y1RLTnDnbFVbtyGDnUmjsdOrCdoUGjndugwO
lc2X3R4laJkbXGtnoNp3nSz4zYlD+WxzSYUlA5PznjbOURzSLNnCeBW/R/Fj
verzHCYeXZ5rHMYg1yO4aLxX9T/HO2y3HGHwpFjwstGIR3votbClPQwSunS4
co5HwdvstTYuLExcBC7r7Hkc83Q0L8pgEbIyq8vdiged3R+d/pzFYesUz9JR
Dj1LzWYXOBCIn5gRn+scGiKZBo0YAq/3uzXdYzhMO6LBFpwheP5OvFSb4pDq
eXYxW09wYN5Hp4QmgvV2M5Lm3ieIt7K2mJZEYNxcEFtdRxBw0cd9g4jgvu2f
yUuKCE4uO6dQvGGxOblW+nk3QeYabXfDShbijCYNuT8B1v6tL89msd1z289O
Uwkk4eZ6JbEsnIkNTj1jMVCb2R4UweJcmk0ApWAxmJPSEKHqvUytjhvsZaHD
pMgTVfigD+k+LWEsUn+MsG3LYtFW9cjAaBkL//MWXqJyFU/dmOJMIIubrwo8
dnWymCcx6tJZycLVaiC/2ZRgKNbczne7at45u2b5AoJO4/ftPnIWq+9FXE9T
3WcRbngqp56FxNlwfEMhwUy+Wy7SJRg7cTNXv4HApPqp0i+QoMr74lZB+9e7
4zT7jhKwlX2Ju1oIZnjIJvUNE1zjW/VPVxAcGd5QYjWfw9EOqZXDfoKppiYD
ymwO4o0JBs0qfdu8xviIJg6+CUFB5mMsJinLns75zCHU5/s7ytMshlNzpbQx
D95M+p3DEhaOduPPTE14fPrmp8z/fsrjPwQ/Oso=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.283684782537893`, 12.224334161450233`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {22, 0}, {0, 0}, {22, 22}], InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{1.525446435834965*^-12, 10.}, {3.000000000006441, 10.}}]}, 
       PolygonBox[{{2.1, 10.}, {0.9, 9.6}, {0.9, 10.4}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {1.5, 10.9452}, {0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{19.999999999998018`, 10.}, {16.99999999999754, 10.}}]}, 
       PolygonBox[{{19.1, 10.}, {17.9, 10.4}, {17.9, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {18.5, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{12.000000000001542`, 10.}, {8.00000000000287, 10.}}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999986, 9.3048}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{14.499999999999986`, 10.}, 2.500000000000015, {
         5.773159728050814*^-15, 3.141592653589787}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.499999999999986`, 13.1952}, {0, -1}], 
       LineBox[CompressedData["
1:eJw9Vgs0Veke76XS0FDT43qdfY7inH0eezPVlVc/RaVEQomERKkJiYRBRKEb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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.499999999999986`, 6.5548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{5.5, 10.}, 2.5, {-3.141592653589793, 0.}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["U",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.499999999999999, 6.8048}, {0, 1}], 
       LineBox[CompressedData["
1:eJw9Vgs0lGkfFxFjaGaYYa6Ny1yU6stiJfKLUka5lJD4iBRdttqicg1T6Ev3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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox[
           FormBox["V",
            TraditionalForm],
           TraditionalForm,
           Editable->True],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.5, 13.4452}, {0, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999997, 10.}], 
        PointBox[{8., 10.}], PointBox[{3., 10.}], PointBox[{17., 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {44, 0}, {0, 0}, {22, 22}]},
   AspectRatio->NCache[
     Rational[1, 2], 0.5],
   PlotRange->{{0, 88}, {0, 44}}], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902146249308*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculating the bare 2-loop off-shell ghost selfenergy diagrams\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuarkMass", "=", "0"}], ";"}]], "Input"],

Cell["We need to put the AmplitudeLevel setting to Classes here.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amps", "=", 
    RowBox[{"CalcColorFactor", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"CreateFeynAmp", "[", 
          RowBox[{"inserts", ",", 
           RowBox[{"Truncated", "\[Rule]", "True"}], ",", 
           RowBox[{"PreFactor", "\[Rule]", "I"}], ",", 
           RowBox[{"AmplitudeLevel", "\[Rule]", 
            RowBox[{"{", "Classes", "}"}]}]}], "]"}], "/.", 
         RowBox[{"p1", "\[RuleDelayed]", "p"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"li1", "\[RuleDelayed]", "\[Mu]"}], ",", 
          RowBox[{"li2", "\[RuleDelayed]", "\[Nu]"}]}], "}"}]}], "/.", 
       RowBox[{
        RowBox[{"FeynAmpList", "[", "__", "]"}], "\[RuleDelayed]", "List"}]}],
       " ", "/.", " ", 
      RowBox[{
       RowBox[{"FeynAmp", "[", 
        RowBox[{"_", ",", "_", ",", "x_"}], "]"}], "\[RuleDelayed]", "x"}]}], 
     "]"}]}], ";"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.4700000000000024`", ",", "Null"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148174882*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amps", "//", "TableForm"}]], "Input"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          SubscriptBox[
           TagBox[
            StyleBox["\<\"q\"\>",
             FontSlant->"Italic"],
            StyleForm[#, FontSlant -> "Italic"]& ], "2"],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li6"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li5", "li6"}]], "(", 
         FormBox[
          RowBox[{"p", "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"\[Mu]", "li3", "li5"}]], "(", 
         RowBox[{
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", 
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"p", "-", 
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
           TraditionalForm]}], ")"}]}]},
      {
       RowBox[{"\[ImaginaryI]", " ", "Tf", " ", 
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["N", "f"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"p", "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{"tr", "(", 
         FormBox[
          RowBox[{
           RowBox[{
            SubscriptBox["\[CapitalPi]", "q"], "(", 
            FormBox[
             RowBox[{
              SubscriptBox[
               TagBox[
                StyleBox["\<\"q\"\>",
                 FontSlant->"Italic"],
                StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
             TraditionalForm], ")"}], ".", 
           SuperscriptBox["Q", "\[Mu]"], ".", 
           RowBox[{
            SubscriptBox["\[CapitalPi]", "q"], "(", 
            FormBox[
             RowBox[{
              SubscriptBox[
               TagBox[
                StyleBox["\<\"q\"\>",
                 FontSlant->"Italic"],
                StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
              SubscriptBox[
               TagBox[
                StyleBox["\<\"q\"\>",
                 FontSlant->"Italic"],
                StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
             TraditionalForm], ")"}], ".", 
           SuperscriptBox["Q", "li3"]}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"p", "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SubscriptBox["\[CapitalPi]", "u"], "(", 
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
           TraditionalForm], ")"}], "2"], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          SubscriptBox[
           TagBox[
            StyleBox["\<\"q\"\>",
             FontSlant->"Italic"],
            StyleForm[#, FontSlant -> "Italic"]& ], "1"],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li8"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li5", "li6"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li7", "li8"}]], "(", 
         FormBox[
          RowBox[{"p", "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"li3", "li5", "li7"}]], "(", 
         RowBox[{
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", 
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"p", "-", 
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", "p"}],
           TraditionalForm]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"\[Mu]", "li4", "li6"}]], "(", 
         RowBox[{
          FormBox[
           RowBox[{"p", "-", 
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "1"], "-", 
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{
            SubscriptBox[
             TagBox[
              StyleBox["\<\"q\"\>",
               FontSlant->"Italic"],
              StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
           TraditionalForm]}], ")"}]}]},
      {
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{"-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "2"], "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{"p", "-", 
           SubscriptBox[
            TagBox[
             StyleBox["\<\"q\"\>",
              FontSlant->"Italic"],
             StyleForm[#, FontSlant -> "Italic"]& ], "1"]}],
          TraditionalForm], ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148239208*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to do self energy diagrams", "Subsection"],

Cell["This is a substitution rule for a tensor integral of rank 1.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsub1", "=", 
  RowBox[{
   RowBox[{"FCI", "[", 
    RowBox[{
     RowBox[{"FVD", "[", 
      RowBox[{
       RowBox[{"qu1", ":", 
        RowBox[{"(", 
         RowBox[{"q1", "|", "q2"}], ")"}]}], ",", "mu"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{
       RowBox[{"qu2", ":", 
        RowBox[{"(", 
         RowBox[{"q1", "|", "q2"}], ")"}]}], ",", "nu"}], "]"}]}], "]"}], ":>", 
   RowBox[{"TIDL", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"qu1", ",", "mu"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qu2", ",", "nu"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     SuperscriptBox[
      FormBox[
       RowBox[{"qu1", ":", 
        RowBox[{
         SubscriptBox[
          TagBox[
           StyleBox["\<\"q\"\>",
            FontSlant->"Italic"],
           StyleForm[#, FontSlant -> "Italic"]& ], "1"], "|", 
         SubscriptBox[
          TagBox[
           StyleBox["\<\"q\"\>",
            FontSlant->"Italic"],
           StyleForm[#, FontSlant -> "Italic"]& ], "2"]}]}],
       TraditionalForm], 
      FormBox[
       FormBox["mu",
        TraditionalForm],
       TraditionalForm]], ")"}], " ", 
    RowBox[{"(", 
     SuperscriptBox[
      FormBox[
       RowBox[{"qu2", ":", 
        RowBox[{
         SubscriptBox[
          TagBox[
           StyleBox["\<\"q\"\>",
            FontSlant->"Italic"],
           StyleForm[#, FontSlant -> "Italic"]& ], "1"], "|", 
         SubscriptBox[
          TagBox[
           StyleBox["\<\"q\"\>",
            FontSlant->"Italic"],
           StyleForm[#, FontSlant -> "Italic"]& ], "2"]}]}],
       TraditionalForm], 
      FormBox[
       FormBox["nu",
        TraditionalForm],
       TraditionalForm]], ")"}]}], "\[RuleDelayed]", 
   RowBox[{"TIDL", "(", 
    RowBox[{
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"qu1", "mu"},
        {"qu2", "nu"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
     RowBox[{"{", "p", "}"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148481415*^9}]
}, Open  ]],

Cell["This is a substitution rule for a tensor integral of rank 2.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsub2", "=", 
  RowBox[{
   RowBox[{"FCI", "[", 
    RowBox[{"FVD", "[", 
     RowBox[{
      RowBox[{"qu", ":", 
       RowBox[{"(", 
        RowBox[{"q1", "|", "q2"}], ")"}]}], ",", "al_"}], "]"}], "]"}], ":>", 
   
   RowBox[{"TIDL", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"qu", ",", "al"}], "}"}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox[
     RowBox[{"qu", ":", 
      RowBox[{
       SubscriptBox[
        TagBox[
         StyleBox["\<\"q\"\>",
          FontSlant->"Italic"],
         StyleForm[#, FontSlant -> "Italic"]& ], "1"], "|", 
       SubscriptBox[
        TagBox[
         StyleBox["\<\"q\"\>",
          FontSlant->"Italic"],
         StyleForm[#, FontSlant -> "Italic"]& ], "2"]}]}],
     TraditionalForm], 
    FormBox[
     FormBox["al_",
      TraditionalForm],
     TraditionalForm]], "\[RuleDelayed]", 
   RowBox[{"TIDL", "(", 
    RowBox[{
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"qu", "al"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
     RowBox[{"{", "p", "}"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148822219*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ScalarProduct", "[", 
    RowBox[{"p", ",", "p"}], "]"}], "=", "pp"}], ";", 
  RowBox[{
   RowBox[{"FAD", "[", "p", "]"}], "=", 
   RowBox[{"1", "/", "pp"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"do2self1", "[", "z_", "]"}], ":=", 
  RowBox[{"FCE", "[", 
   RowBox[{"ToFI", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ch1", "[", "z", "]"}], "=", 
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"SUNSimplify", "[", 
              RowBox[{
               RowBox[{"Explicit", "[", 
                RowBox[{"z", ",", 
                 RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
                 RowBox[{"Gauge", "\[Rule]", 
                  RowBox[{"1", "-", "\[Xi]"}]}]}], "]"}], ",", 
               RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "/.", 
             "\[InvisibleSpace]", 
             RowBox[{"DiracTrace", "\[Rule]", "TR"}]}], "]"}], ",", 
           RowBox[{"q1", "|", "q2"}]}], "]"}]}], ")"}], "/.", 
       "\[InvisibleSpace]", "tsub1"}], "/.", "\[InvisibleSpace]", "tsub2"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "q2"}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"do2self2", "[", "z_", "]"}], ":=", 
  RowBox[{
   RowBox[{"TarcerRecurse", "[", 
    RowBox[{
     RowBox[{"Collect3", "[", 
      RowBox[{
       RowBox[{"z", "/.", "inttable"}], ",", 
       RowBox[{"{", 
        RowBox[{"TAI", ",", "TBI", ",", "TVI", ",", "TFI"}], "}"}], ",", 
       RowBox[{"Factoring", "\[Rule]", "Factor2"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{"comment", ",", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<starting recursion on \>\"", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"ch2", "[", "z", "]"}], "]"}], ",", "\"\< integrals\>\""}], 
        "]"}]}], "]"}], ";", 
     RowBox[{"ch2", "[", "z", "]"}]}], "]"}], "/.", "\[InvisibleSpace]", 
   RowBox[{"x_Plus", "\[RuleDelayed]", 
    RowBox[{
     RowBox[{"Collect2", "[", 
      RowBox[{"x", ",", "\[Xi]"}], "]"}], "/;", 
     RowBox[{
      RowBox[{"Variables", "[", "x", "]"}], "\[Equal]", 
      RowBox[{"{", 
       RowBox[{"D", ",", "\[Xi]"}], "}"}]}]}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculate the graphs one by one", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"comment", "=", "True"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SPD", "[", 
    RowBox[{"p", ",", "p"}], "]"}], "=", "pp"}], ";"}]], "Input"],

Cell["Do all the algebra but no integrals yet.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"res1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<calculating \>\"", ",", "i", ",", " ", "\"\<  time = \>\"", ",", 
         
         RowBox[{
          RowBox[{"Timing", "[", 
           RowBox[{
            RowBox[{"re", "[", "i", "]"}], "=", 
            RowBox[{"do2self1", "[", 
             RowBox[{"(", 
              RowBox[{"amps", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ")"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         "\"\<, number of integrals to calculate = \>\"", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"re", "[", "i", "]"}], "]"}]}], "]"}], ";", 
       RowBox[{"re", "[", "i", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", 
        RowBox[{"Length", "[", "amps", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "1", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.4499999999999993`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "36"}],
   SequenceForm[
   "calculating ", 1, "  time = ", 0.4499999999999993, 
    ", number of integrals to calculate = ", 36],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "2", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "1.370000000000001`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "108"}],
   SequenceForm[
   "calculating ", 2, "  time = ", 1.370000000000001, 
    ", number of integrals to calculate = ", 108],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.4729021507209673`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "3", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "1.1999999999999993`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "75"}],
   SequenceForm[
   "calculating ", 3, "  time = ", 1.1999999999999993`, 
    ", number of integrals to calculate = ", 75],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902151921319*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "4", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.379999999999999`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "54"}],
   SequenceForm[
   "calculating ", 4, "  time = ", 0.379999999999999, 
    ", number of integrals to calculate = ", 54],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902152304139*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "5", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.6799999999999997`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "56"}],
   SequenceForm[
   "calculating ", 5, "  time = ", 0.6799999999999997, 
    ", number of integrals to calculate = ", 56],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.4729021529892063`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "6", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "7.629999999999999`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "514"}],
   SequenceForm[
   "calculating ", 6, "  time = ", 7.629999999999999, 
    ", number of integrals to calculate = ", 514],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902160627427*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "7", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.30000000000000426`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "25"}],
   SequenceForm[
   "calculating ", 7, "  time = ", 0.30000000000000426`, 
    ", number of integrals to calculate = ", 25],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902160924849*^9}]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"12.020000000000003`", ",", "Null"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.47290216095982*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"allints", " ", "=", " ", 
   RowBox[{"Cases2", "[", 
    RowBox[{"res1", ",", "TFI"}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allints", "//", "Length"}]], "Input"],

Cell[BoxData[
 FormBox["651", TraditionalForm]], "Output",
 CellChangeTimes->{3.472902161324441*^9}]
}, Open  ]],

Cell["\<\
There are 651 integrals to be done for the ghost self energy. There are \
several possibilities how to proceed. One possibility is to calculate the \
integrals one by one and save them to a file. This can be conveniently done \
using the CheckDB function. If the file \"tfioffshellmassless.s\" does not \
exist the first argument of CheckDB is evaluated, otherwise the list is \
loaded and assigned to inttable:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"inttable", "=", 
    RowBox[{"CheckDB", "[", 
     RowBox[{
      RowBox[{"Dispatch", "[", 
       RowBox[{"Thread", "[", 
        RowBox[{"allints", "\[Rule]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"WriteString", "[", 
             RowBox[{"\"\<stdout\>\"", ",", "\"\<.\>\""}], "]"}], ";", 
            RowBox[{"TarcerRecurse", "[", 
             RowBox[{
             "allints", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "allints", "]"}]}], "}"}]}], "]"}]}], 
        "]"}], "]"}], ",", "\"\<tfioffshellmassless.s\>\""}], "]"}]}], ";"}], 
  "]"}]], "Input"],

Cell["\<\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
...........................\
\>", "Print",
 CellChangeTimes->{3.4729021613834677`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"100.27999999999999`", ",", "Null"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.4729022641856117`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"result", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Collect2", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"TAI", ",", "TBI", ",", "TJI"}], "}"}], ",", 
        RowBox[{"Factoring", "\[Rule]", "Factor2"}]}], "]"}], "&"}], "/@", 
     RowBox[{"(", 
      RowBox[{"res1", "/.", "inttable"}], ")"}]}]}], ";"}], "]"}]], "Input",
 CellChangeTimes->{3.472902291302947*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.6299999999999955`", ",", "Null"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.472902265353889*^9, 3.4729022932360287`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"pp", " ", "\[Xi]", " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["D", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"-", "\[Xi]"}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["D", "2"]}], "-", 
       RowBox[{"17", " ", "D", " ", "\[Xi]"}], "+", 
       RowBox[{"6", " ", "D"}], "+", 
       RowBox[{"8", " ", "\[Xi]"}]}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        SubsuperscriptBox[
         StyleBox["B",
          SingleLetterItalics->False,
          FontWeight->"Bold"], 
         RowBox[{
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm], 
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm]}], 
         RowBox[{"(", 
          FormBox["D",
           TraditionalForm], ")"}]],
        HighEnergyPhysics`Tarcer`TBI[D, $CellContext`pp, {{1, 0}, {1, 0}}],
        Editable->True], ")"}], "2"]}], 
    RowBox[{"64", " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", "D"}], ")"}]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", "-", "D"}], ")"}], "2"]}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", "-", "D"}], ")"}], " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", 
         SuperscriptBox["D", "3"], " ", 
         SuperscriptBox["\[Xi]", "2"]}]}], "+", 
       RowBox[{"21", " ", 
        SuperscriptBox["D", "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "-", 
       RowBox[{"68", " ", "D", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"60", " ", "D", " ", "\[Xi]"}], "-", 
       RowBox[{"8", " ", "D"}], "+", 
       RowBox[{"72", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"96", " ", "\[Xi]"}], "+", "32"}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["D",
         TraditionalForm], ")"}]],
      HighEnergyPhysics`Tarcer`TJI[
      D, $CellContext`pp, {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True]}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.47290226571873*^9, 3.472902297794883*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Variables", "[", "result", "]"}], "//", "InputForm"}]], "Input"],

Cell["\<\
{CA, D, Gstrong, Nf, pp, Tf, \[Xi], SD[ci1, ci2], 
 TBI[D, pp, {{1, 0}, {1, 0}}], 
 TJI[D, pp, {{1, 0}, {1, 0}, {1, 0}}]}\
\>", "Output",
 CellChangeTimes->{3.472902266029595*^9, 3.472902301242632*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "TBI", "]"}]], "Input"],

Cell[BoxData[
 FormBox["\<\"HighEnergyPhysics`Tarcer`\"\>", TraditionalForm]], "Output",
 CellChangeTimes->{3.472902266139612*^9, 3.472902303599511*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Do the expansion of the master integrals in \[CurlyEpsilon] and compare with \
the literature\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "Tf"}]], "Input",
 CellChangeTimes->{{3.472902385691998*^9, 3.472902386092847*^9}, 
   3.47290247120977*^9}],

Cell["HighEnergyPhysics`qcd`Tf`Tf", "Print", "PrintUsage",
 CellChangeTimes->{3.472902471654913*^9},
 CellTags->"Info3472906071-3368256"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Nf"}]], "Input",
 CellChangeTimes->{{3.472902394185211*^9, 3.472902394672224*^9}}],

Cell[BoxData[
 StyleBox["\<\"Nf denotes the number of flavors.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.4729023951089*^9},
 CellTags->"Info3472905995-6725410"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghselftf", " ", "=", 
  RowBox[{"result", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "D"}], ")"}], "2"], " ", "Tf", " ", 
     SubscriptBox["C", "A"], " ", 
     SubscriptBox["N", "f"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["D",
         TraditionalForm], ")"}]],
      HighEnergyPhysics`Tarcer`TJI[
      D, $CellContext`pp, {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", "-", "D"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"6", "-", "D"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902266274378*^9, 3.472902309827043*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eta", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{
        FractionBox["D", "2"], "-", "1"}], "]"}], "2"], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"3", "-", 
       FractionBox["D", "2"]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"D", "-", "3"}], "]"}]]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TarcerExpand", "[", 
  RowBox[{
   FractionBox["ghselftf", 
    SuperscriptBox["eta", "2"]], ",", 
   RowBox[{"D", "\[Rule]", 
    RowBox[{"4", "-", 
     RowBox[{"2", " ", "Epsilon"}]}]}], ",", "0"}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pp", " ", "Tf", " ", 
     SubscriptBox["C", "A"], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["S", "HighEnergyPhysics`FeynCalc`Epsilon`Epsilon"],
        FontWeight->"Bold"],
       HighEnergyPhysics`Tarcer`SEpsilon[
       4 - 2 HighEnergyPhysics`FeynCalc`Epsilon`Epsilon],
       Editable->False], "2"], " ", 
     SubscriptBox["N", "f"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "pp"}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["7", 
       RowBox[{"4", " ", 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]}]]}], "-", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        TagBox["\[CurlyEpsilon]",
         TraditionalForm], "2"]}]], "-", 
     FractionBox["53", "8"]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.4729022694319267`*^9, 3.472902312744775*^9}]
}, Open  ]],

Cell[TextData[{
 "The above is exactly what is given in eq. (6.13) of \"A.I. Davydychev, \
P.Osland, O.V. Tarasov, Phy. Rev. D ",
 StyleBox["58",
  FontWeight->"Bold"],
 ", 036007 (1998)\"."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghselfca", " ", "=", 
  RowBox[{"Collect2", "[", 
   RowBox[{
    RowBox[{"Plus", "@@", 
     RowBox[{"Drop", "[", 
      RowBox[{"result", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"TBI", ",", "TJI"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"pp", " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["D", "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "-", 
       RowBox[{"15", " ", "D", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"58", " ", "D", " ", "\[Xi]"}], "-", 
       RowBox[{"16", " ", "D"}], "+", 
       RowBox[{"26", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"104", " ", "\[Xi]"}], "+", "56"}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        SubsuperscriptBox[
         StyleBox["B",
          SingleLetterItalics->False,
          FontWeight->"Bold"], 
         RowBox[{
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm], 
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm]}], 
         RowBox[{"(", 
          FormBox["D",
           TraditionalForm], ")"}]],
        HighEnergyPhysics`Tarcer`TBI[D, $CellContext`pp, {{1, 0}, {1, 0}}],
        Editable->True], ")"}], "2"]}], 
    RowBox[{"32", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "4"}], ")"}]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"D", "-", "6"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"D", "-", "4"}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["D", "5"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"115", " ", 
        SuperscriptBox["D", "4"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["D", "4"], " ", "\[Xi]"}], "+", 
       RowBox[{"867", " ", 
        SuperscriptBox["D", "3"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"130", " ", 
        SuperscriptBox["D", "3"], " ", "\[Xi]"}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["D", "3"]}], "-", 
       RowBox[{"3216", " ", 
        SuperscriptBox["D", "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"1188", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["D", "2"]}], "+", 
       RowBox[{"5884", " ", "D", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"3840", " ", "D", " ", "\[Xi]"}], "+", 
       RowBox[{"432", " ", "D"}], "-", 
       RowBox[{"4256", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"4160", " ", "\[Xi]"}], "-", "1024"}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["D",
         TraditionalForm], ")"}]],
      HighEnergyPhysics`Tarcer`TJI[
      D, $CellContext`pp, {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True]}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902269837351*^9, 3.4729023225678062`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TarcerExpand", "[", 
  RowBox[{
   FractionBox["ghselfca", 
    SuperscriptBox["eta", "2"]], ",", 
   RowBox[{"D", "\[Rule]", 
    RowBox[{"4", "-", 
     RowBox[{"2", " ", "Epsilon"}]}]}], ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pp", " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["S", "HighEnergyPhysics`FeynCalc`Epsilon`Epsilon"],
        FontWeight->"Bold"],
       HighEnergyPhysics`Tarcer`SEpsilon[
       4 - 2 HighEnergyPhysics`FeynCalc`Epsilon`Epsilon],
       Editable->False], "2"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "pp"}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", 
              TemplateBox[{"3"},
               "Zeta"]}], "4"]}], "+", 
           FractionBox["17", "8"], "-", 
           FractionBox[
            SuperscriptBox["\[Pi]", "4"], "320"]}], ")"}], " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", 
              TemplateBox[{"3"},
               "Zeta"]}], "2"]}], "-", 
           FractionBox["383", "128"]}], ")"}], " ", "\[Xi]"}], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          TemplateBox[{"3"},
           "Zeta"]}], "2"], "-", 
        FractionBox[
         SuperscriptBox["\[Pi]", "4"], "80"], "+", 
        FractionBox["3881", "64"]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       TemplateBox[{"3"},
        "Zeta"], " ", 
       SuperscriptBox["\[Xi]", "2"]}], "16"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       TemplateBox[{"3"},
        "Zeta"]}], "4"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Xi]", "2"], "32"]}], "+", 
       FractionBox[
        RowBox[{"7", " ", "\[Xi]"}], "16"], "+", 
       FractionBox["5", "4"]}], 
      SuperscriptBox[
       TagBox["\[CurlyEpsilon]",
        TraditionalForm], "2"]], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"7", " ", "\[Xi]"}], "32"], "+", 
       FractionBox["83", "16"]}], 
      TagBox["\[CurlyEpsilon]",
       TraditionalForm]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["\[Xi]", "2"]}], "8"], "-", 
     FractionBox[
      RowBox[{"9", " ", "\[Xi]"}], "64"], "+", 
     FractionBox["599", "32"]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902269911478*^9, 3.4729023374245157`*^9}]
}, Open  ]],

Cell[TextData[{
 "This verifies eq. (6.12) of \"A.I. Davydychev, P.Osland, O.V. Tarasov, Phy. \
Rev. D ",
 StyleBox["58",
  FontWeight->"Bold"],
 ", 036007 (1998)\"."
}], "Text"]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1036, 602},
WindowMargins->{{Automatic, 14}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3472906071-3368256"->{
  Cell[134141, 3279, 137, 2, 63, "Print",
   CellTags->"Info3472906071-3368256"]},
 "Info3472905995-6725410"->{
  Cell[134429, 3290, 179, 4, 62, "Print",
   CellTags->"Info3472905995-6725410"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3472906071-3368256", 146090, 3684},
 {"Info3472905995-6725410", 146202, 3687}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 50, 0, 56, "Subsection"],
Cell[620, 24, 71, 1, 46, "Input"],
Cell[694, 27, 214, 4, 24, "Text"],
Cell[911, 33, 234, 6, 24, "Text"],
Cell[1148, 41, 670, 22, 26, "Text"],
Cell[1821, 65, 166, 4, 24, "Text"],
Cell[1990, 71, 371, 12, 24, "Text"],
Cell[2364, 85, 196, 4, 24, "Text"],
Cell[CellGroupData[{
Cell[2585, 93, 35, 0, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[2645, 97, 1092, 27, 227, "Input"],
Cell[3740, 126, 81746, 1627, 282, 66770, 1380, "CachedBoxData", "BoxData", \
"Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85535, 1759, 96, 2, 42, "Subsubsection"],
Cell[85634, 1763, 75, 2, 46, "Input"],
Cell[85712, 1767, 74, 0, 44, "Text"],
Cell[CellGroupData[{
Cell[85811, 1771, 981, 26, 137, "Input"],
Cell[86795, 1799, 169, 5, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87001, 1809, 61, 1, 46, "Input"],
Cell[87065, 1812, 27286, 830, 309, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[114412, 2649, 59, 0, 56, "Subsection"],
Cell[114474, 2651, 76, 0, 44, "Text"],
Cell[CellGroupData[{
Cell[114575, 2655, 688, 23, 46, "Input"],
Cell[115266, 2680, 1896, 61, 71, "Output"]
}, Open  ]],
Cell[117177, 2744, 76, 0, 44, "Text"],
Cell[CellGroupData[{
Cell[117278, 2748, 425, 15, 46, "Input"],
Cell[117706, 2765, 1229, 38, 49, "Output"]
}, Open  ]],
Cell[118950, 2806, 223, 7, 46, "Input"],
Cell[119176, 2815, 1119, 30, 197, "Input"],
Cell[120298, 2847, 1027, 27, 137, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121362, 2879, 53, 0, 56, "Subsection"],
Cell[121418, 2881, 76, 2, 46, "Input"],
Cell[121497, 2885, 124, 4, 46, "Input"],
Cell[121624, 2891, 56, 0, 44, "Text"],
Cell[CellGroupData[{
Cell[121705, 2895, 962, 27, 107, "Input"],
Cell[CellGroupData[{
Cell[122692, 2926, 524, 12, 35, "Print"],
Cell[123219, 2940, 526, 12, 35, "Print"],
Cell[123748, 2954, 525, 12, 35, "Print"],
Cell[124276, 2968, 522, 12, 35, "Print"],
Cell[124801, 2982, 526, 12, 35, "Print"],
Cell[125330, 2996, 524, 12, 35, "Print"],
Cell[125857, 3010, 527, 12, 35, "Print"]
}, Open  ]],
Cell[126399, 3025, 168, 5, 45, "Output"]
}, Open  ]],
Cell[126582, 3033, 147, 4, 46, "Input"],
Cell[CellGroupData[{
Cell[126754, 3041, 61, 1, 46, "Input"],
Cell[126818, 3044, 100, 2, 45, "Output"]
}, Open  ]],
Cell[126933, 3049, 435, 7, 127, "Text"],
Cell[CellGroupData[{
Cell[127393, 3060, 811, 22, 227, "Input"],
Cell[128207, 3084, 736, 11, 35, "Print"],
Cell[128946, 3097, 171, 5, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129154, 3107, 460, 13, 107, "Input"],
Cell[129617, 3122, 195, 5, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129849, 3132, 82, 2, 46, "Input"],
Cell[129934, 3136, 3266, 101, 134, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133237, 3242, 99, 2, 46, "Input"],
Cell[133339, 3246, 211, 5, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133587, 3256, 62, 1, 46, "Input"],
Cell[133652, 3259, 152, 2, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133853, 3267, 123, 3, 84, "Subsection"],
Cell[CellGroupData[{
Cell[134001, 3274, 137, 3, 46, "Input"],
Cell[134141, 3279, 137, 2, 63, "Print",
 CellTags->"Info3472906071-3368256"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134315, 3286, 111, 2, 46, "Input"],
Cell[134429, 3290, 179, 4, 62, "Print",
 CellTags->"Info3472905995-6725410"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134645, 3299, 118, 3, 46, "Input"],
Cell[134766, 3304, 1271, 42, 87, "Output"]
}, Open  ]],
Cell[136052, 3349, 382, 13, 96, "Input"],
Cell[CellGroupData[{
Cell[136459, 3366, 242, 7, 79, "Input"],
Cell[136704, 3375, 1226, 38, 79, "Output"]
}, Open  ]],
Cell[137945, 3416, 202, 6, 73, "Text"],
Cell[CellGroupData[{
Cell[138172, 3426, 327, 10, 46, "Input"],
Cell[138502, 3438, 3867, 115, 202, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142406, 3558, 242, 7, 79, "Input"],
Cell[142651, 3567, 2861, 92, 267, "Output"]
}, Open  ]],
Cell[145527, 3662, 178, 6, 45, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
